@@ -46,7 +46,7 @@ shell.history_manager = Rex::Ui::Text::Shell::HistoryManager.new
 
 shell.run { |line|
   line.gsub!(/(\r|\n)/, '')
-  line.gsub!(/\\n/, "\n")
+  line.gsub!("\\n", "\n")
 
   break if (line =~ /^(exit|quit)/i)
 
