@@ -597,6 +597,10 @@ NAVIGATION_CONFIG = [
                   },
                 ]
               },
+              {
+                path: 'Post-Mixins.md',
+                title: 'PostMixins'
+              },
               {
                 path: 'How-to-log-in-Metasploit.md',
                 title: 'Logging'
@@ -856,6 +860,9 @@ NAVIGATION_CONFIG = [
           {
             path: 'Loading-Test-Modules.md'
           },
+          {
+            path: 'Payload-Testing.md'
+          },
           {
             path: 'Measuring-Metasploit-Performance.md'
           }
