@@ -40,7 +40,7 @@ module Exploit::FileDropper
   #   exploiting).
   # @return [void]
   def register_files_for_cleanup(*files)
-    @dropped_files += files
+    @dropped_files += files.map(&:dup)
   end
 
   def allow_no_cleanup
@@ -56,7 +56,7 @@ module Exploit::FileDropper
   #   exploiting).
   # @return [void]
   def register_dirs_for_cleanup(*dirs)
-    @dropped_dirs += dirs
+    @dropped_dirs += dirs.map(&:dup)
   end
 
   # Singular versions
@@ -173,10 +173,7 @@ module Exploit::FileDropper
       stat.file? || stat.directory?
     else
       if session.platform == 'windows'
-        f = shell_command_token("cmd.exe /C IF exist \"#{normalized}\" ( echo true )")
-        if f =~ /true/
-          f = shell_command_token("cmd.exe /C IF exist \"#{normalized}\\\\\" ( echo false ) ELSE ( echo true )")
-        end
+        f = session.shell_command_token("cmd.exe /C IF exist \"#{normalized}\" ( echo true )")
       else
         f = session.shell_command_token("test -f \"#{normalized}\" -o -d \"#{normalized}\" && echo true")
       end
