@@ -40,11 +40,35 @@ module Exploit::Remote::AutoCheck
 
     warning_msg = 'ForceExploit is enabled, proceeding with exploitation.'
     error_msg = '"set ForceExploit true" to override check result.'
-
     check_code = check
+
     case check_code
     when Exploit::CheckCode::Vulnerable, Exploit::CheckCode::Appears
       print_good(check_code.message)
+
+      if respond_to?(:report_vuln)
+        report_vuln_opts = {
+          name: fullname,
+          username: respond_to?(:owner) ? owner : nil,
+          refs: references,
+          info: description.strip
+        }
+
+        if respond_to?(:session) && session.respond_to?(:session_host)
+          report_vuln(
+            **report_vuln_opts,
+            host: session.session_host
+          )
+        elsif respond_to?(:rhost)
+          report_vuln(
+            **report_vuln_opts,
+            host: rhost,
+            port: respond_to?(:rport) ? rport : nil,
+            proto: Msf::DBManager::DEFAULT_SERVICE_PROTO
+          )
+        end
+      end
+
       return yield
     when Exploit::CheckCode::Detected
       print_warning(check_code.message)
