@@ -176,7 +176,7 @@ module Msf::Exploit::Remote::HTTP::NagiosXi::Login
     # Make sure we only use the cookies we need, otherwise we may encounter a session timeout
     auth_cookies = clean_cookies(pre_auth_cookies, auth_cookies)
 
-    # Try to visit the dasboard
+    # Try to visit the dashboard
     visit_nagios_dashboard(auth_cookies, finish_install)
   end
 
@@ -235,7 +235,7 @@ module Msf::Exploit::Remote::HTTP::NagiosXi::Login
     unless res_index.code == 200 && res_index.body.include?('>Home Dashboard<')
       # Check if we need to sign the license agreement
       unless res_index.code == 302 && res_index.headers['Location'].end_with?('login.php?showlicense')
-        return [2, ['Received unexpected reply while trying to acess the NagiosXI home dashboard after authenticating.']]
+        return [2, ['Received unexpected reply while trying to access the NagiosXI home dashboard after authenticating.']]
       end
 
       print_warning('The Nagios XI license agreement has not yet been signed on the target.')
@@ -251,7 +251,7 @@ module Msf::Exploit::Remote::HTTP::NagiosXi::Login
       return [5, [auth_cookies, nsp]]
     end
 
-    # Return the HTTP resonse body and the authentication cookies.
+    # Return the HTTP response body and the authentication cookies.
     # The response body can be used to obtain the version number.
     # The cookies can be used by exploit modules to send authenticated requests.
     [0, [res_index.body, auth_cookies]]
