@@ -14,8 +14,9 @@ module Msf
             # @option opts [Rex::Proto::Kerberos::Model::EncryptedData] :enc_auth_data
             # @option opts [Rex::Proto::Kerberos::Model::EncryptionKey] :subkey
             # @option opts [Rex::Proto::Kerberos::Model::Checksum] :checksum
-            # @option opts [Rex::Proto::Kerberos::Model::Authenticator] :auhtenticator
+            # @option opts [Rex::Proto::Kerberos::Model::Authenticator] :authenticator
             # @option opts [Array<Rex::Proto::Kerberos::Model::PreAuthDataEntry>] :pa_data
+            # @option opts [String] :impersonate_type
             # @return [Rex::Proto::Kerberos::Model::KdcRequest]
             # @raise [RuntimeError] if ticket isn't available
             # @see Rex::Proto::Kerberos::Model::AuthorizationData
@@ -70,6 +71,35 @@ module Msf
 
               pa_data = []
               pa_data.push(pa_ap_req)
+              if opts.key?(:impersonate_type) && opts.fetch(:impersonate_type) == 'dmsa'
+                x509_user = Rex::Proto::Kerberos::Model::PreAuthS4uX509User.new(opts[:session_key], opts[:impersonate], opts[:impersonate_type], realm, opts[:nonce])
+
+                pa_data_x509_user = Rex::Proto::Kerberos::Model::PreAuthDataEntry.new(
+                  type: Rex::Proto::Kerberos::Model::PreAuthType::PA_S4U_X509_USER,
+                  value: x509_user.encode
+                )
+
+                pa_data << pa_data_x509_user
+
+                pa_pac_options_flags = Rex::Proto::Kerberos::Model::PreAuthPacOptionsFlags.from_flags(
+                  [
+                    Rex::Proto::Kerberos::Model::PreAuthPacOptionsFlags::BRANCH_AWARE
+                  ]
+                )
+
+                pa_pac_options = Rex::Proto::Kerberos::Model::PreAuthPacOptions.new(
+                  flags: pa_pac_options_flags
+                )
+
+                pa_pac = Rex::Proto::Kerberos::Model::PreAuthDataEntry.new(
+                  type: Rex::Proto::Kerberos::Model::PreAuthType::PA_PAC_OPTIONS,
+                  value: pa_pac_options.encode
+                )
+
+                pa_data << pa_pac
+              end
+
+
               if opts[:pa_data]
                 opts[:pa_data].each { |pa| pa_data.push(pa) }
               end
@@ -330,7 +360,6 @@ module Msf
                 value: pa_for_user.encode
               )
             end
-
           end
         end
       end
