@@ -476,8 +476,8 @@ module Exploit::Remote::RDP
     vprint_status("Sending client control request control PDU")
     rdp_send(rdp_build_pkt(pdu_client_control_request))
 
-    vprint_status("Sending client input sychronize PDU")
-    rdp_send(rdp_build_pkt(pdu_client_input_event_sychronize))
+    vprint_status("Sending client input synchronize PDU")
+    rdp_send(rdp_build_pkt(pdu_client_input_event_synchronize))
 
     vprint_status("Sending client font list PDU")
     rdp_send(rdp_build_pkt(pdu_client_font_list))
@@ -1145,7 +1145,7 @@ module Exploit::Remote::RDP
 
   # https://docs.microsoft.com/en-us/openspecs/windows_protocols/ms-rdpbcgr/ff7f06f8-0dcf-4c8d-be1f-596ae60c4396
   # Client Input Event Data - TS_INPUT_PDU_DATA - 2.2.8.1.1.3.1
-  def pdu_client_input_event_sychronize
+  def pdu_client_input_event_synchronize
     pdu =
       "\x01\x00" +         # numEvents: 1
       "\x00\x00" +         # pad2Octets
