@@ -40,9 +40,9 @@ class Exploit
   #
   # Launches an exploitation single attempt.
   #
-  def exploit_single(mod, opts)
+  def exploit_single(mod, opts, &block)
     begin
-      session = mod.exploit_simple(opts)
+      session = mod.exploit_simple(opts, &block)
     rescue ::Interrupt
       raise $!
     rescue ::Msf::OptionValidateError => e
@@ -124,6 +124,7 @@ class Exploit
       mod.options.include?('rhosts')
 
     opts = {
+      'Action'      => args[:action],
       'Encoder'     => args[:encoder] || mod_with_opts.datastore['ENCODER'],
       'Payload'     => args[:payload] || mod_with_opts.datastore['PAYLOAD'],
       'Target'      => args[:target] || mod_with_opts.datastore['TARGET'],
@@ -136,21 +137,16 @@ class Exploit
       'Quiet'       => args[:quiet] || false
     }
 
-    begin
-      mod_with_opts.validate
-    rescue ::Msf::OptionValidateError => e
-      ::Msf::Ui::Formatter::OptionValidateError.print_error(mod_with_opts, e)
-      return false
-    end
-
     driver.run_single('reload_lib -a') if args[:reload_libs]
 
-    if rhosts && has_rhosts_option
+    if rhosts && has_rhosts_option && !mod.class.included_modules.include?(Msf::Auxiliary::MultipleTargetHosts)
       rhosts_walker = Msf::RhostsWalker.new(rhosts, mod_with_opts.datastore)
       rhosts_walker_count = rhosts_walker.count
       rhosts_walker = rhosts_walker.to_enum
     end
 
+    run_mod = nil
+
     # For multiple targets exploit attempts.
     if rhosts_walker && rhosts_walker_count > 1
       opts[:multi] = true
@@ -163,7 +159,7 @@ class Exploit
         # Catch the interrupt exception to stop the whole module during exploit
         begin
           print_status("Exploiting target #{datastore['RHOSTS']}")
-          session = exploit_single(nmod, opts)
+          session = exploit_single(nmod, opts) { |mod| run_mod = mod }
         rescue ::Interrupt
           print_status("Stopping exploiting current target #{datastore['RHOSTS']}...")
           print_status("Control-C again to force quit exploiting all targets.")
@@ -185,7 +181,7 @@ class Exploit
       if rhosts_walker && rhosts_walker_count == 1
         nmod.datastore.merge!(rhosts_walker.next)
       end
-      session = exploit_single(nmod, opts)
+      session = exploit_single(nmod, opts) { |mod| run_mod = mod }
       # If we were given a session, let's see what we can do with it
       if session
         any_session = true
@@ -211,7 +207,7 @@ class Exploit
     end
 
     # If we didn't get any session and exploit ended launch.
-    unless any_session
+    unless any_session || run_mod&.error.is_a?(Msf::OptionValidateError)
     # If we didn't run a payload handler for this exploit it doesn't
     # make sense to complain to the user that we didn't get a session
       unless mod_with_opts.datastore["DisablePayloadHandler"]
