@@ -7,28 +7,36 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::Exploit::Remote::HttpClient
   include Msf::Auxiliary::Scanner
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'            => 'HTTP Strict Transport Security (HSTS) Detection',
-      'Description'     => %q{
-        Display HTTP Strict Transport Security (HSTS) information about each system.
-      },
-      'Author'          => 'Matt "hostess" Andreko <mandreko[at]accuvant.com>',
-      'License'         => MSF_LICENSE,
-      'DefaultOptions'  => { 'SSL' => true }
-    ))
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => 'HTTP Strict Transport Security (HSTS) Detection',
+        'Description' => %q{
+          Display HTTP Strict Transport Security (HSTS) information about each system.
+        },
+        'Author' => 'Matt "hostess" Andreko <mandreko[at]accuvant.com>',
+        'License' => MSF_LICENSE,
+        'DefaultOptions' => { 'SSL' => true },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options([
-        Opt::RPORT(443)
-      ])
+      Opt::RPORT(443)
+    ])
   end
 
   def run_host(ip)
     begin
       res = send_request_cgi({
-        'uri'    => '/',
+        'uri' => '/',
         'method' => 'GET',
-        }, 25)
+      }, 25)
 
       if res
         hsts = res.headers['Strict-Transport-Security']
@@ -47,7 +55,6 @@ class MetasploitModule < Msf::Auxiliary
       else
         print_error("#{ip}:#{rport} No headers were returned.")
       end
-
     rescue ::Timeout::Error, ::Errno::EPIPE
     end
   end
