@@ -12,8 +12,8 @@ class MetasploitModule < Msf::Encoder
 
   def initialize
     super(
-      'Name'             => 'The EICAR Encoder',
-      'Description'      => %q{
+      'Name' => 'The EICAR Encoder',
+      'Description' => %q{
         This encoder merely replaces the given payload with the EICAR test string.
         Note, this is sure to ruin your payload.
 
@@ -21,18 +21,17 @@ class MetasploitModule < Msf::Encoder
         standards should alert and do what it would normally do when malware is
         transmitted across the wire.
       },
-      'Author'           => 'todb',
-      'License'          => MSF_LICENSE,
-      'Arch'             => ARCH_ALL,
-      'EncoderType'      => Msf::Encoder::Type::Unspecified)
-
+      'Author' => 'todb',
+      'License' => MSF_LICENSE,
+      'Arch' => ARCH_ALL,
+      'EncoderType' => Msf::Encoder::Type::Unspecified)
   end
 
   # Avoid stating the string directly, don't want to get caught by local
   # antivirus!
   def eicar_test_string
-    obfus_eicar = ["x5o!p%@ap[4\\pzx54(p^)7cc)7}$eicar", "standard", "antivirus", "test", "file!$h+h*"]
-    obfus_eicar.join("-").upcase
+    obfus_eicar = ['x5o!p%@ap[4\\pzx54(p^)7cc)7}$eicar', 'standard', 'antivirus', 'test', 'file!$h+h*']
+    obfus_eicar.join('-').upcase
   end
 
   # TODO: add an option to merely prepend and not delete, using
@@ -40,7 +39,7 @@ class MetasploitModule < Msf::Encoder
   # and not part of a larger whole. Problem is, OptBool is
   # acting funny here as an encoder option.
   #
-  def encode_block(state, buf)
-    buf = eicar_test_string
+  def encode_block(_state, _buf)
+    eicar_test_string
   end
 end
