@@ -40,8 +40,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'https://github.com/mcw0/PoC/blob/master/CVE-2021-36260.py']
         ],
         'DisclosureDate' => '2021-09-18',
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_ARMLE],
         'Privileged' => false,
         'Targets' => [
           [
