@@ -39,8 +39,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://claroty.com/2021/09/21/blog-research-securing-network-management-systems-nagios-xi/']
         ],
         'DisclosureDate' => '2021-07-15',
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Privileged' => false,
         'Targets' => [
           [
@@ -53,7 +51,7 @@ class MetasploitModule < Msf::Exploit::Remote
                 'PAYLOAD' => 'cmd/unix/reverse_openssl'
               },
               'Payload' => {
-                'Append' => ' & disown'
+                'Append' => '& disown'
               }
             }
           ],
