@@ -44,8 +44,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2020-13851'], # RCE via the `events` feature
           ['URL', 'https://www.coresecurity.com/core-labs/advisories/pandora-fms-community-multiple-vulnerabilities']
         ],
-        'Platform' => ['linux', 'unix'],
-        'Arch' => [ARCH_X86, ARCH_X64, ARCH_CMD],
         'Targets' => [
           [
             'Linux (x86)', {
