@@ -33,8 +33,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://attackerkb.com/topics/kE3lzTZGV2/cve-2023-23333']
         ],
         'DisclosureDate' => '2023-05-15',
-        'Platform' => ['php', 'unix', 'linux'],
-        'Arch' => [ARCH_PHP, ARCH_CMD, ARCH_ARMLE, ARCH_X64],
         'Privileged' => false,
         'Targets' => [
           [
