@@ -34,8 +34,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2022-02-18', # Public disclosure
         'License' => MSF_LICENSE,
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Targets' => [
           [
             'Unix Command',
