@@ -35,9 +35,7 @@ class MetasploitModule < Msf::Exploit::Remote
           ['ATT&CK', Mitre::Attack::Technique::T1021_REMOTE_SERVICES]
         ],
         'License' => MSF_LICENSE,
-        'Platform' => ['unix', 'linux'],
         'Privileged' => false,
-        'Arch' => [ARCH_CMD],
         'Targets' => [
           [
             'Unix/Linux Command',
