@@ -47,8 +47,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2020-04-30', # F-Secure advisory
         'License' => MSF_LICENSE,
-        'Platform' => ['python', 'unix'],
-        'Arch' => [ARCH_PYTHON, ARCH_CMD],
         'Privileged' => true,
         'Targets' => [
           [
