@@ -78,8 +78,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://github.com/naihsin/IoT/blob/main/D-Link/DIR-600/cmd%20injection/README.md']
         ],
         'DisclosureDate' => '2013-02-01',
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_MIPSLE, ARCH_MIPSBE, ARCH_ARMLE],
         'Privileged' => true,
         'Targets' => [
           [
