@@ -44,8 +44,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://saelo.github.io/presentations/blackhat_us_18_attacking_client_side_jit_compilers.pdf'],
           ['URL', 'https://bugs.chromium.org/p/chromium/issues/detail?id=888923'],
         ],
-        'Arch' => [ ARCH_X64 ],
-        'Platform' => ['windows', 'osx', 'linux'],
         'DefaultTarget' => 0,
         'Notes' => {
           'Reliability' => [ REPEATABLE_SESSION ],
