@@ -38,9 +38,7 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'CVE', '2024-38856']
         ],
         'License' => MSF_LICENSE,
-        'Platform' => %w[linux win],
         'Privileged' => true, # You get a root session when exploiting a docker container though user level session on Windows.
-        'Arch' => [ ARCH_CMD ],
         'Targets' => [
           [
             'Linux Command',
