@@ -41,8 +41,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://github.com/Chocapikk/CVE-2024-36401']
         ],
         'DisclosureDate' => '2024-07-01',
-        'Platform' => ['unix', 'linux', 'windows'],
-        'Arch' => [ARCH_CMD],
         'Privileged' => true,
         'Targets' => [
           [
