@@ -49,8 +49,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2020-10-07',
         'License' => MSF_LICENSE,
-        'Platform' => %w[unix linux win],
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Privileged' => false,
         'Targets' => [
           [
