@@ -48,8 +48,6 @@ class MetasploitModule < Msf::Exploit::Remote
         'Payload' => {
           'BadChars' => "\x00\x0d\x0a"
         },
-        'Platform' => %w[linux win php],
-        'Arch' => [ ARCH_X86, ARCH_X64, ARCH_PHP],
         'Targets' => [
           [
             'PHP', {
