@@ -29,8 +29,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2016-4437'],
           ['URL', 'https://github.com/Medicean/VulApps/tree/master/s/shiro/1']
         ],
-        'Platform' => %w[win unix],
-        'Arch' => [ ARCH_CMD ],
         'Targets' => [
           [
             'Unix Command payload',
