@@ -37,7 +37,6 @@ class MetasploitModule < Msf::Exploit::Remote
                           'PayloadType' => 'cmd'
                         }
         },
-        'Platform' => %w{unix win},
         'Arch' => ARCH_CMD,
         'Targets' => [
           ['stunshell / Unix', { 'Platform' => 'unix' } ],
@@ -55,7 +54,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     register_options(
       [
-        OptString.new('TARGETURI', [true, "The path to the andalas_oku shell", "/IDC.php"]),
+        OptString.new('TARGETURI', [true, 'The path to the andalas_oku shell', '/IDC.php']),
       ]
     )
   end
@@ -89,7 +88,7 @@ class MetasploitModule < Msf::Exploit::Remote
         }
     }
     res = send_request_cgi(request_parameters)
-    if not (res and res.code == 200)
+    if !(res and res.code == 200)
       fail_with(Failure::Unknown, 'Failed to execute the command.')
     end
   end
