@@ -27,7 +27,6 @@ class MetasploitModule < Msf::Exploit::Remote
         'References' => [
           ['URL', 'https://www.tenable.com/plugins/nessus/94675']
         ],
-        'Platform' => %w[linux win],
         'Targets' => [
           ['Windows', { 'Platform' => 'win' }],
           ['Linux', { 'Platform' => 'linux' }]
@@ -180,9 +179,9 @@ class MetasploitModule < Msf::Exploit::Remote
     )
 
     if !res.nil? && res.code == 200
-      print_status("Successfully sent build configuration")
+      print_status('Successfully sent build configuration')
     else
-      print_status("Failed to send build configuration")
+      print_status('Failed to send build configuration')
     end
   end
 
