@@ -30,36 +30,41 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2016-3510']
         ],
         'Privileged' => false,
-        'Platform' => %w{unix win solaris},
         'Targets' => [
           [
             'Unix',
-            'Platform' => 'unix',
-            'Arch' => ARCH_CMD,
-            'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_python' },
-            'Payload' => {
-              'Compat' => { 'PayloadType' => 'cmd' }
+            {
+              'Platform' => 'unix',
+              'Arch' => ARCH_CMD,
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_python' },
+              'Payload' => {
+                'Compat' => { 'PayloadType' => 'cmd' }
+              }
             }
           ],
           [
             'Windows',
-            'Platform' => 'win',
-            'Payload' => {},
-            'DefaultOptions' => { 'PAYLOAD' => 'windows/meterpreter/reverse_tcp' }
+            {
+              'Platform' => 'win',
+              'Payload' => {},
+              'DefaultOptions' => { 'PAYLOAD' => 'windows/meterpreter/reverse_tcp' }
+            }
           ],
           [
             'Solaris',
-            'Platform' => 'solaris',
-            'Arch' => ARCH_CMD,
-            'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_perl' },
-            'Payload' => {
-              'Space' => 2048,
-              'DisableNops' => true,
-              'Compat' =>
+            {
+              'Platform' => 'solaris',
+              'Arch' => ARCH_CMD,
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_perl' },
+              'Payload' => {
+                'Space' => 2048,
+                'DisableNops' => true,
+                'Compat' =>
                 {
                   'PayloadType' => 'cmd',
-                  'RequiredCmd' => 'generic perl telnet',
+                  'RequiredCmd' => 'generic perl telnet'
                 }
+              }
             }
           ]
         ],
