@@ -29,8 +29,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://www.openmediavault.org/?p=2797']
         ],
         'License' => MSF_LICENSE,
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Payload' => { 'BadChars' => "\x00" },
         'DisclosureDate' => '2020-09-28',
         'Targets' => [
