@@ -31,8 +31,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://github.com/rapid7/metasploit-framework/pull/13353'] # First ref is this module
         ],
         'License' => MSF_LICENSE,
-        'Platform' => ['unix', 'linux'],
-        'Arch' => [ARCH_CMD, ARCH_X86, ARCH_X64],
         'Payload' => { 'BadChars' => "\x00" },
         'DisclosureDate' => '2020-04-28',
         'Targets' => [
