@@ -361,7 +361,7 @@ RSpec.describe Msf::Exploit::Remote::BrowserAutopwn2 do
     # Prepare framework.exploits
     exploits = double('exploits')
     allow(exploits).to receive(:create) { |arg| mock_exploit_create(arg) }
-    allow(exploits).to receive(:each_pair).and_yield(available_exploits[0].fullname, '__SYMBOLIC__').and_yield(available_exploits[1].fullname, '__SYMBOLIC__').and_yield(available_exploits[2].fullname, '__SYMBOLIC__')
+    allow(exploits).to receive(:module_refnames).and_return(available_exploits.map(&:fullname))
     allow(framework).to receive(:exploits).and_return(exploits)
 
     # Prepare jobs
@@ -401,7 +401,7 @@ RSpec.describe Msf::Exploit::Remote::BrowserAutopwn2 do
       payload_class_by_reference_name[reference_name] = klass
     end
 
-    allow(payloads).to receive(:keys) {
+    allow(payloads).to receive(:module_refnames) {
                          payload_class_by_reference_name.keys
                        }
 
