@@ -306,7 +306,8 @@ module Acceptance::Session
               "[-] [[TCP-Server] Propagates close events to the peer] Exception: Rex::Post::Meterpreter::RequestError: core_channel_open: Operation failed: 1",
               "[-] [[TCP-Server] Propagates close events from the peer] FAILED: [TCP-Server] Propagates close events from the peer",
               "[-] [[TCP-Server] Propagates close events from the peer] Exception: Rex::Post::Meterpreter::RequestError: core_channel_open: Operation failed: 1",
-              "[-] FAILED: [UDP] Has the correct peer information"
+              "[-] FAILED: [UDP] Has the correct peer information",
+              ["[-] FAILED: [UDP] Receives data from the peer", { flaky: true }],
             ]
           }
         }
